@@ -5,13 +5,17 @@ cd $top_srcdir
 
 h=`find . -name "*.h"`
 c=`find . -name "*.cc"`
+ic=`find . -name "*.icc"`
 a=`find . -name "*.am"`
 d=`find . -name "*.ac"`
 m=`find . -name "*.m4"`
 t=`find . -name "*.tex"`
+b=`find . -name "*.bib"`
 p=`find . -name "*.plot"`
 f=`find . -name "*.fig"`
-L="$h $c $a $d $m $t $p $f"
+s=`find . -name "*.sh"`
+M=`find . -name "Makefile*"`
+L="$h $c $ic $a $d $m $t $b $p $f $s $M"
 status=0
 for x in $L; do
  if test -h $x; then continue; fi ; # symb link
@@ -24,7 +28,8 @@ for x in $L; do
  if diff $x tmp.txt >/dev/null; then
   true
  else
-  echo "$x: non US-ASCII near line `cat tmp.txt | wc -l`:"
+  nl=`cat tmp.txt | wc -l`
+  echo "$x: non US-ASCII near line `expr $nl + 1`:"
   tail -1 tmp.txt; echo
   status=1
  fi
