@@ -1,22 +1,30 @@
 #include "rheolef.h"
 using namespace rheolef;
 using namespace std;
-#include "runge_kutta_ssp.icc"
+#include "harten.icc"
 #include "burgers.icc"
+#include "burgers_flux_godunov.icc"
+#include "runge_kutta_ssp.icc"
 int main(int argc, char**argv) {
   environment rheolef (argc, argv);
   geo omega (argv[1]);
   space Xh (omega, argv[2]);
-  Float tf = 0.5, cfl = 1;
-  size_t p    = (argc > 3) ? atoi(argv[3]) : pmax;
-  size_t nmax = (argc > 4) ? atoi(argv[4]) : floor(1+tf/(cfl*omega.hmin()));
+  Float cfl = 1;
+  limiter_option_type lopt;
+  size_t nmax = (argc > 3) ? atoi(argv[3]) : numeric_limits<size_t>::max();
+  Float  tf   = (argc > 4) ? atof(argv[4]) : 2.5;
+  size_t p    = (argc > 5) ? atoi(argv[5]) : pmax;
+  lopt.M      = (argc > 6) ? atoi(argv[6]) : u_init().M();
+  if (nmax == numeric_limits<size_t>::max()) {
+      nmax = floor(1+tf/(cfl*omega.hmin()));
+  }
   Float delta_t = tf/nmax;
   form_option_type fopt;
   fopt.invert = true;
   trial u (Xh); test v (Xh);
   form inv_m = integrate (u*v, fopt);
   vector<field> uh(p+1, field(Xh,0));
-  uh[0] = interpolate (Xh, u_init);
+  uh[0] = interpolate (Xh, u_init());
   branch even("t","u");
   dout << catchmark("delta_t") << delta_t << endl
        << even(0,uh[0]);
@@ -24,14 +32,15 @@ int main(int argc, char**argv) {
     for (size_t i = 1; i <= p; ++i) {
       uh[i] = 0;
       for (size_t j = 0; j < i; ++j) {
-        field lh
-         = integrate (dot(compose(f,uh[j]),grad_h(v)))
+        field lh = 
+         - integrate (dot(compose(f,uh[j]),grad_h(v)))
          + integrate ("internal_sides",
              compose (phi, normal(), inner(uh[j]), outer(uh[j]))*jump(v))
          + integrate ("boundary",
-             compose (phi, normal(), uh[j], g)*v);
+             compose (phi, normal(), uh[j], g(n*delta_t))*v);
         uh[i] += alpha[p][i][j]*uh[j] - delta_t*beta[p][i][j]*(inv_m*lh);
       }
+      uh[i] = limiter(uh[i], g(n*delta_t)(point(-1)), lopt);
     }
     uh[0] = uh[p];
     dout << even(n*delta_t,uh[0]);
