@@ -19,14 +19,28 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
-GEODIR=${TOP_SRCDIR}/nfem/ptst
-SBINDIR="../../nfem/sbin"
-BINDIR="../../nfem/pbin"
-NPROC_MAX=${NPROC_MAX-"2"}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/doc/pexample"}
+NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-echo "      not yet (skipped)"
-exit 0
+#echo "      not yet (skipped)"
+#exit 0
 
+err_linf_l1_P0="0.1"
+err_linf_l1_P1d="0.06"
+
+status=0
+
+run "mkgeo_grid -e 50 -a -1 -b 1 > tmp.geo"
+if test $? -ne 0; then status=1; fi
+
+loop_mpirun "./burgers_dg tmp P0d 500 2.5 2>/dev/null | ./harten_error $err_linf_l1_P0 >/dev/null 2>/dev/null"
+if test $? -ne 0; then status=1; fi
+
+loop_mpirun "./burgers_dg tmp P1d 500 2.5 2>/dev/null | ./harten_error $err_linf_l1_P1d >/dev/null 2>/dev/null"
+if test $? -ne 0; then status=1; fi
+
+run "rm -f tmp.geo"
+
+exit $status
