@@ -35,11 +35,7 @@ int main (int argc, char **argv) {
     Float alpha = Float(1.5) + delta_t*phi::sigma(d,nu,t);
     Float beta  = delta_t*nu;
     form c = integrate (alpha*varphi*psi + beta*dot(grad(varphi),grad(psi)), qopt);
-    field lh =  Float(2.0)*integrate (compose(phi_h,      X1)*psi, qopt)
-              - Float(0.5)*integrate (compose(phi_h_prec, X2)*psi, qopt);
-#ifdef TODO // boost::proto & g++-4.8
-    field lh = integrate ((Float(2)*compose(phi_h, X1) - Float(0.5)*compose(phi_h_prec, X2))*psi, qopt);
-#endif // TODO
+    field lh = integrate (omega, (2*compose(phi_h, X1) - 0.5*compose(phi_h_prec, X2))*psi, qopt);
     solver sc (c.uu());
     phi_h_prec = phi_h;
     phi_h.set_u() = sc.solve (lh.u() - c.ub()*phi_h.b());
