@@ -4,6 +4,7 @@ using namespace std;
 #include "rotating-hill.h"
 int main (int argc, char **argv) {
   environment rheolef (argc,argv);
+  Float tol = (argc > 1) ? atof(argv[1]) : 1e-10;
   Float nu;
   din >> catchmark("nu") >> nu;
   branch get ("t","phi");
@@ -16,7 +17,8 @@ int main (int argc, char **argv) {
     const space& Xh = phi_h.get_space();
     size_t d = Xh.get_geo().dimension();
     field pi_h_phi = interpolate (Xh, phi(d,nu,t));
-    form m (Xh, Xh, "mass");
+    trial phi (Xh); test psi (Xh);
+    form m = integrate (phi*psi);
     field eh = phi_h - pi_h_phi;
     Float err_l2 = sqrt(m(eh,eh));
     Float err_linf = eh.max_abs();
@@ -27,4 +29,5 @@ int main (int argc, char **argv) {
   }
   derr << "# error_l2_l2     = " << sqrt(err_l2_l2) << endl;
   derr << "# error_linf_linf = " << err_linf_linf << endl;
+  return (err_linf_linf <= tol) ? 0 : 1;
 }
