@@ -8,8 +8,9 @@ int main(int argc, char**argv) {
   size_t d = omega.dimension();
   space Xh (omega, argv[2]);
   Xh.block ("boundary");
-  form a (Xh, Xh, "grad_grad");
-  field lh = riesz (Xh, f(d));
+  trial u (Xh); test v (Xh);
+  form a = integrate (dot(grad(u),grad(v)));
+  field lh = integrate (f(d)*v);
   field uh (Xh);
   uh ["boundary"] = 0;
   solver sa (a.uu());
