@@ -15,7 +15,8 @@ int main (int argc, char **argv) {
   branch event ("t","u");
   dout << event (0, uh);
   for (size_t n = 1; n <= n_max; n++) {
-    field lh = integrate ((uh+delta_t)*v);
+    field rhs = uh + delta_t;
+    field lh = integrate (rhs*v);
     uh.set_u() = sa.solve (lh.u() - a.ub()*uh.b());
     dout << event (n*delta_t, uh);
   }
