@@ -5,20 +5,18 @@ using namespace rheolef;
 int main (int argc, char**argv) {
   environment rheolef(argc, argv);
   geo lambda (argv[1]);
+  size_t d = lambda.dimension();
   space Xh (lambda, "P1");
   field phi_h = interpolate(Xh, phi);
-  band gh (phi_h);
-  space Bh (gh.band(), "P1");
-  form m (Bh, Bh, "mass",      gh);
-  form a (Bh, Bh, "grad_grad", gh);
-  a = m+a;
-  size_t d = lambda.dimension();
-  field lh = riesz (Bh, f(d), gh);
+  band gamma_h (phi_h);
+  space Bh (gamma_h.band(), "P1");
+  trial u (Bh); test v (Bh);
+  form  a  = integrate (gamma_h, u*v + dot(grad_s(u),grad_s(v)));
+  field lh = integrate (gamma_h, f(d)*v);
   field uh (Bh,0);
   size_t max_iter = 10000;
   Float tol = 1e-10;
   pminres (a.uu(), uh.set_u(), lh.u(), eye(), max_iter, tol, &derr);
-  gh.band().save();
-  dout << catchmark("u")   << uh 
-       << catchmark("phi") << phi_h;
+  dout << catchmark("phi") << phi_h
+       << catchmark("u")   << uh;
 }
