@@ -11,8 +11,9 @@ int main(int argc, char**argv) {
   N = Xh.get_geo().dimension();
   field pi_h_u = interpolate(Xh, u_ex);
   field eh = pi_h_u - uh;
-  form m (Xh, Xh, "mass");
-  form a (Xh, Xh, "grad_grad");
+  trial u (Xh); test v (Xh);
+  form  m  = integrate (u*v);
+  form  a  = integrate (dot(grad(u),grad(v)));
   derr << "error_l2    "  << sqrt(m(eh,eh)) << endl
        << "error_h1    "  << sqrt(a(eh,eh)) << endl
        << "error_linf  "  << eh.max_abs() << endl;
