@@ -9,10 +9,11 @@ int main(int argc, char**argv) {
   geo omega (argv[1]);
   d = omega.dimension();
   space Xh (omega, argv[2]);
-  form m (Xh, Xh, "mass");
-  form a (Xh, Xh, "grad_grad");
-  field b = m*field(Xh,1);
-  field lh = riesz(Xh, f) + riesz(Xh, g, "boundary");
+  trial u (Xh); test v (Xh);
+  form  m  = integrate (u*v);
+  form  a  = integrate (dot(grad(u),grad(v)));
+  field b  = m*field(Xh,1);
+  field lh = integrate (f*v) + integrate ("boundary", g*v);
   csr<Float> A = {{  a.uu(),     b.u()}, 
                   {trans(b.u()),  0   }};
   vec<Float> B =  {  lh.u(),      0   };
