@@ -21,27 +21,35 @@
 # -------------------------------------------------------------------------
 SRCDIR=${SRCDIR-"."}
 TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+DATADIR="${TOP_SRCDIR}/nfem/ptst"
 NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
 
+eps="1e-7"
+# geo                   err_P1  err_P2  err_P3
 L="
-line-20-bdry
-square-10-bdry
-cube-5-bdry
+line-bdry-v2            9e-4	$eps	$eps
+carre-bamg-v2           2e-3	$eps	$eps
+carre-bamg-q-dom-v2     5e-4	$eps	$eps
+carre-tq-10-dom-v2      2e-3	$eps	$eps
+cube-dom-v2             2e-2	$eps	$eps
+cube-H-6-dom-v2         3e-3	$eps	$eps
+cube-P-5-dom-v2         7e-3	$eps	$eps
+my_cube_PH-5-v2         8e-3	$eps	$eps
+my_cube_TP-5-v2         8e-3	$eps	$eps
+my_cube_TPH-5-v2        7e-3	$eps	$eps
 "
-EXPECT="
-3e-4
-1e-3
-4e-3
-"
-
-for geo in $L; do
-  err=`echo $EXPECT | awk '{print $1}'`
-  EXPECT=`echo $EXPECT | awk '{for (i=2; i <= NF; i++) print $i}'`
-  loop_mpirun "./neumann-laplace $SRCDIR/$geo P1 2>/dev/null | ./neumann-laplace-check $err 2>/dev/null >/dev/null"
-  if test $? -ne 0; then status=1; fi
+while test "$L" != ""; do
+  geo=`echo $L | awk '{print $1}'`
+  L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
+  for Pk in P1 P2 P3; do
+    err=`echo $L | awk '{print $1}'`
+    L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
+    loop_mpirun "./neumann-laplace $DATADIR/$geo $Pk 2>/dev/null | RHEOPATH=$DATADIR ./neumann-laplace-check $err 2>/dev/null >/dev/null"
+    if test $? -ne 0; then status=1; fi
+  done
 done
 
 exit $status
