@@ -11,11 +11,11 @@ int main(int argc, char**argv) {
   Float beta = (k+1)*(k+d)/d;
   trial u (Xh); test v (Xh);
   form  a = integrate (u*v + dot(grad_h(u),grad_h(v)))
-          + integrate (omega.internal_sides(), 
+          + integrate ("internal_sides", 
                   beta*penalty()*jump(u)*jump(v)
 	 	- jump(u)*average(dot(grad_h(v),normal()))
 	 	- jump(v)*average(dot(grad_h(u),normal())));
-  field lh = integrate (f(d)*v) + integrate ("boundary", g(d)*inner(v));
+  field lh = integrate (f(d)*v) + integrate ("boundary", g(d)*v);
   solver sa (a.uu());
   field uh(Xh);
   uh.set_u() = sa.solve(lh.u());
