@@ -22,9 +22,9 @@
 SRCDIR=${SRCDIR-"."}
 TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 GEODIR="${TOP_SRCDIR}/nfem/ptst"
+SBINDIR="../../nfem/sbin"
+BINDIR="../../nfem/pbin"
 NPROC_MAX=${NPROC_MAX-"8"}
-SBINDIR="${TOP_SRCDIR}/nfem/sbin"
-BINDIR="${TOP_SRCDIR}/nfem/pbin"
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
