@@ -1,11 +1,11 @@
-struct u_poiseuille : field_functor<u_poiseuille,Float> {
+struct u_poiseuille {
   Float operator() (const point& x) const {
     return a*(c+x[1])*(c-x[1]); }
   u_poiseuille (const Float& c1, std::string sc) : c(c1)
    { a = (sc == "cartesian") ? 3/(2*pow(c,3)) : 4/pow(c,4); }
   protected: Float c, a;
 };
-struct psi_poiseuille : field_functor<psi_poiseuille,Float> {
+struct psi_poiseuille {
   Float operator() (const point& x) const {
     return xy ? a*sqr(c-x[1])*(2*c+x[1]) : a*sqr(c-x[1])*sqr(c+x[1]); }
   psi_poiseuille (const Float& c1, std::string sc)
