@@ -1,10 +1,10 @@
-struct u : field_functor<u,point> {
+struct u {
   point operator() (const point & x) const {
     return (d == 1) ? point(u0) : point(x[1], -x[0]); }
   u (size_t d1) : d(d1), u0 (0.5/acos(Float(-1))) {}
   protected: size_t d; Float u0;
 };
-struct phi : field_functor<phi,Float> {
+struct phi {
   static Float sigma(size_t d, Float nu1, Float t) {
     const Float t0 = 0.2;
     return 4*nu1/t0 - 2*d*nu1/(t0 + 4*nu1*t); }
