@@ -8,7 +8,7 @@ int main(int argc, char**argv) {
   field uh; din >> uh;
   space Xh = uh.get_space();
   size_t d = Xh.get_geo().dimension();
-  field pi_h_u = interpolate(Xh, u(d));
+  field pi_h_u = interpolate(Xh, u_exact(d));
   field eh = uh - pi_h_u;
   trial u (Xh); test v (Xh);
   form m = integrate (u*v);
