@@ -9,9 +9,10 @@ int main(int argc, char**argv) {
       >> catchmark("p")  >> ph;
   const space& Xh = uh.get_space();
   const space& Qh = ph.get_space();
-  form a  (Xh, Xh, "2D_D");
-  form b  (Xh, Qh, "div"); b = -b;
-  form mp (Qh, Qh, "mass");
+  trial u (Xh), p (Qh); test v (Xh), q (Qh);
+  form a  = integrate (2*ddot(D(u),D(v)));
+  form b  = integrate (-div(u)*q);
+  form mp = integrate (p*q);
   solver fact_mp (mp.uu());
   field m_ru = a*uh + b.trans_mult(ph);
   field m_rp = b*uh;
