@@ -6,7 +6,7 @@ int main(int argc, char**argv) {
   environment rheolef (argc, argv);
   geo  omega (argv[1]);
   string sys_coord = omega.coordinate_system_name();
-  Float c = omega.xmax()[1];
+  Float cr = omega.xmax()[1];
   space Xh (omega, "P2", "vector");
   Xh.block ("upstream");
   Xh.block ("wall");
@@ -14,13 +14,15 @@ int main(int argc, char**argv) {
   Xh[1].block ("downstream");
   space Qh  (omega, "P1");
   space Wh  (omega["upstream"], "P2");
+  trial u (Xh), p (Qh);
+  test  v (Xh), q (Qh);
+  form a  = integrate (2*ddot(D(u),D(v)));
+  form b  = integrate (-div(u)*q);
+  form mp = integrate (p*q);
+  solver_abtb stokes (a.uu(), b.uu(), mp.uu());
   field uh (Xh, 0);
   field ph (Qh, 0);
-  uh[0]["upstream"] = interpolate (Wh, u(c,sys_coord));
-  form a (Xh, Xh, "2D_D");
-  form b = - form(Xh, Qh, "div");
-  form mp (Qh, Qh, "mass");
-  solver_abtb stokes (a.uu(), b.uu(), mp.uu());
+  uh[0]["upstream"] = interpolate (Wh, u_poiseuille(cr,sys_coord));
   stokes.solve (-(a.ub()*uh.b()), -(b.ub()*uh.b()), uh.set_u(), ph.set_u());
   dout << catchmark("inv_lambda") << 0 << endl
        << catchmark("u")  << uh
