@@ -7,6 +7,7 @@ int main (int argc, char** argv) {
   field uh;
   din >> uh;
   const geo& omega = uh.get_geo();
+  size_t d = omega.dimension();
   string sys_coord = omega.coordinate_system_name();
   Float c = omega.xmax()[1];
   string approx = "P" + itos(uh.get_space().degree());
@@ -16,13 +17,17 @@ int main (int argc, char** argv) {
   Ph.block("axis");
   space Wh (omega["upstream"], approx);
   const space& Xh = uh.get_space();
-  form a (Ph, Ph, "s_grad_grad");
-  form b (Ph, Xh, "s_curl");
   field psi_h (Ph, 0);
-  psi_h["upstream"] = interpolate (Wh, psi(c,sys_coord));
+  psi_h["upstream"] = interpolate (Wh, psi_poiseuille(c,sys_coord));
   psi_h["wall"] = 0;
   psi_h["axis"] = -1;
-  field lh = b.trans_mult(uh);
+  form_option_type fopt;
+  fopt.ignore_sys_coord = true;
+  trial psi (Ph), u (Xh);
+  test   xi (Ph), v (Xh);
+  form a = (d == 3) ? integrate (ddot(grad(psi), grad(xi)))
+                    : integrate ( dot(grad(psi), grad(xi)), fopt);
+  field lh = integrate (dot(uh,bcurl(xi)));
   solver sa (a.uu());
   psi_h.set_u() = sa.solve (lh.u() - a.ub()*psi_h.b());
   dout << catchmark("psi") << psi_h;
