@@ -22,14 +22,16 @@
 SRCDIR=${SRCDIR-"."}
 TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 GEODIR="${TOP_SRCDIR}/nfem/ptst"
-BINDIR="${TOP_SRCDIR}/nfem/pbin"
-SBINDIR="${TOP_SRCDIR}/nfem/sbin"
+SBINDIR="../../nfem/sbin"
+BINDIR="../../nfem/pbin"
 ROUNDER="../../nfem/pbin/field - -field -round"
 NPROC_MAX=${NPROC_MAX-"8"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-#echo "    not yet (skiped)"
-#exit 0
+if test x"${QD_EXT}" != x""; then
+  echo "      not yet (skiped when QD lib is active)"
+  exit 0
+fi
 
 status=0
 # --------------------------------------------------------------------
