@@ -1,5 +1,4 @@
 #include "rheolef.h"
-#include "rheolef/catchmark.h"
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
@@ -9,11 +8,12 @@ int main(int argc, char**argv) {
   space Xh (omega, "P1");
   Xh.block ("left");
   Xh.block ("right");
-  space Qh (omega, "P0");
+  space Qh (omega, "P0", "vector");
+  test v (Xh);
   field eta (Qh);
   eta ["east"] = 1;
   eta ["west"] = epsilon;
-  field lh = riesz (Xh, field(Xh,1));
+  field lh = integrate (v);
   form b = -form(Xh, Qh, "grad"); 
   form inv_m (Qh, Qh, "inv_mass", 1/eta); 
   form a = trans(b)*inv_m*b;
