@@ -1,5 +1,4 @@
 #include "rheolef.h"
-#include "rheolef/catchmark.h"
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
@@ -11,11 +10,12 @@ int main(int argc, char**argv) {
   Xh.block ("right");
   string eta_approx = "P" + itos(Xh.degree()-1) + "d";
   space Qh (omega, eta_approx);
-  field eta (Qh);
-  eta ["east"] = 1;
-  eta ["west"] = epsilon;
-  form a (Xh, Xh, "grad_grad", eta);
-  field lh = riesz (Xh, 1);
+  field eta_h (Qh);
+  eta_h ["east"] = 1;
+  eta_h ["west"] = epsilon;
+  trial u (Xh); test v (Xh);
+  form  a  = integrate (eta_h*dot(grad(u),grad(v)));
+  field lh = integrate (v);
   field uh (Xh);
   uh["left"] = uh["right"] = 0;
   solver sa (a.uu());
