@@ -11,13 +11,11 @@ int main(int argc, char**argv) {
   space Th (omega, approx);
   trial phi(Th); test psi(Th);
   form ah = integrate (dot(u(w),grad_h(phi))*psi)
-          + integrate (omega.boundary(), 
-		max(0, -dot(u(w),normal()))*inner(phi)*inner(psi))
-          + integrate (omega.internal_sides(), 
+          + integrate ("boundary", max(0, -dot(u(w),normal()))*phi*psi)
+          + integrate ("internal_sides", 
 	 	- dot(u(w),normal())*jump(phi)*average(psi)
                 + 0.5*alpha*abs(dot(u(w),normal()))*jump(phi)*jump(psi));
-  field lh = integrate (omega.boundary(),
-		phi_exact(w)*max(0, -dot(u(w),normal()))*inner(psi));
+  field lh = integrate ("boundary", phi_exact(w)*max(0, -dot(u(w),normal()))*psi);
   solver sah (ah.uu());
   field phi_h(Th);
   phi_h.set_u() = sah.solve(lh.u());
