@@ -1,7 +1,7 @@
 #include "rheolef.h"
 using namespace rheolef;
 using namespace std;
-struct phi : field_functor<phi,Float> {
+struct phi {
  Float operator() (const point& x) const { return exp(-sigma*x[0]); }
  phi(Float sigma1) : sigma(sigma1) {}
  Float sigma;
