@@ -12,7 +12,7 @@ int main (int argc, char** argv) {
     psi_min = psi_h.dof(idof);
     idof_min = idof;
   }
-  const array<point>& xdof = psi_h.get_space().get_xdofs();
+  const disarray<point>& xdof = psi_h.get_space().get_xdofs();
   point xmin = xdof [idof_min];
   dout << "xc\t\tyc\t\tpsi" << std::endl
        << xmin[0] << "\t" << xmin[1] << "\t" << psi_min << std::endl;
