@@ -5,10 +5,10 @@ int main(int argc, char** argv) {
   environment rheolef (argc, argv);
   field uh;
   din >> uh;
-  string grad_approx = "P" + itos(uh.get_space().degree()-1) + "d";
+  const space& Xh = uh.get_space();
+  string grad_approx = "P" + itos(Xh.degree()-1) + "d";
   string valued = (uh.size() == 3) ? "vector" : "scalar";
   space Lh  (uh.get_geo(), grad_approx, valued);
-  form curl  (uh.get_space(), Lh, "curl");
-  form inv_m (Lh, Lh, "inv_mass");
-  dout << catchmark("w") << inv_m*(curl*uh);
+  field curl_uh = interpolate (Lh, curl(uh));
+  dout << catchmark("w") << curl_uh;
 }
