@@ -1,20 +1,22 @@
 #include "rheolef/rheolef.h"
 using namespace rheolef;
 using namespace std;
-
+size_t d;
 Float epsilon;
-
 Float u (const point& x) { 
-  if (x[0] < Float(0.5)) 
-    return x[0]*((1+3*epsilon)/(2*(1+epsilon)) - x[0])/(2*epsilon);
+  Float x0 = (d <= 2) ? x[0] : x[1];
+  if (x0 < Float(0.5))
+    return x0*((1+3*epsilon)/(2*(1+epsilon)) - x0)/(2*epsilon);
   else
-    return (1-x[0])*(x[0] + (1-epsilon)/(2*(1+epsilon)))/2;
+    return (1-x0)*(x0 + (1-epsilon)/(2*(1+epsilon)))/2;
 }
 int main(int argc, char**argv)
 {
+  Float error_linf_expected = (argc > 1) ? atof(argv[1]) : 1e+38;
   field uh;
   cin >> catchmark("epsilon") >> epsilon
       >> catchmark("u")       >> uh;
+  d = uh.get_geo().dimension();
   space Vh = uh.get_space();
   field pi_h_u = interpolate(Vh, u);
   field eh = pi_h_u - uh;
@@ -23,6 +25,5 @@ int main(int argc, char**argv)
   Float error_l2   = sqrt(m(eh,eh));
   cerr << "error_linf "  << error_linf << endl
        << "error_l2   "  << error_l2   << endl;
-  Float tol = 1e-5;
-  return (error_linf < tol) && (error_l2 < tol) ? 0 : 1;
+  return (error_linf < error_linf_expected) ? 0 : 1;
 }
