@@ -57,45 +57,83 @@ numbering_P2::idof (
 	const size_type*      mesh_n_geo,
 	const size_type*      mesh_n_element,
 	const geo_element&    K,
-	size_type             i_dof_local) const
+	size_type             loc_idof) const
 {
         // all vertices-based dof are numbered first
         // then all edge-based dof
         // and then all dof based on interior nodes (e.g. quadrangles)
 
 	// for mixed triangle-quadrangle mesh : assume triangle are numbered first
-        switch (K.type()) {
+        switch (K.variant()) {
 	  case reference_element::p: 
             return K.index();
 	  case reference_element::e: 
-            if (i_dof_local < 2) {
-              return K [i_dof_local];
+            if (loc_idof < 2) {
+              return K [loc_idof];
             } else {
               return mesh_n_geo[0] + K.index();
             }
-	  case reference_element::t: 
-            if (i_dof_local < 3) {
-              return K [i_dof_local];
-            } else {
-              return mesh_n_geo[0] + K.edge(i_dof_local - 3);
+	  case reference_element::t: {
+            if (loc_idof < 3) {
+              return K [loc_idof];
             }
-	  case reference_element::q: 
-            if (i_dof_local < 4) {
-              return K [i_dof_local];
-            } else if (i_dof_local < 8) {
-              return mesh_n_geo[0] + K.edge(i_dof_local - 4);
-            } else {
-              return mesh_n_geo[0] + mesh_n_geo[1]
-		  + K.index() - mesh_n_element[reference_element::t];
+            size_type nv = mesh_n_geo[0];
+	    size_type loc_iedg = loc_idof - 3;
+            size_type iedg = K.edge(loc_iedg);
+            return nv + iedg;
+          }
+	  case reference_element::q: {
+            if (loc_idof < 4) {
+              return K [loc_idof];
+            } 
+            if (loc_idof < 8) {
+              return mesh_n_geo[0] + K.edge(loc_idof - 4);
             }
+	    size_type iqua = K.index() - mesh_n_element[reference_element::t];
+            return mesh_n_geo[0] + mesh_n_geo[1] + iqua;
+          }
 	  case reference_element::T: 
-            if (i_dof_local < 4) {
-              return K [i_dof_local];
+            if (loc_idof < 4) {
+              return K [loc_idof];
             } else {
-              return mesh_n_geo[0] + K.edge(i_dof_local - 4);
+              return mesh_n_geo[0] + K.edge(loc_idof - 4);
             }
-	  case reference_element::P: 
-	  case reference_element::H:
+	  case reference_element::P: {
+            if (loc_idof < 6) { // 6 vertex dofs
+              return K [loc_idof];
+            }
+            size_type nv = mesh_n_geo[0];
+            if (loc_idof < 6+9) { // 9 edge face dofs
+              return nv + K.edge(loc_idof - 6);
+            } 
+            // 3 quad face dofs
+            size_type nedg = mesh_n_geo[1];
+            size_type ntri = mesh_n_element[reference_element::t];
+	    size_type iqua = K.face(loc_idof - 6 - 9) - ntri;
+            return nv + nedg + iqua;
+          }
+	  case reference_element::H: {
+            if (loc_idof < 8) { // 8 vertex dofs
+              return K [loc_idof];
+            } 
+            size_type nv = mesh_n_geo[0];
+            if (loc_idof < 8+12) { // 12 edge face dofs
+              return nv + K.edge(loc_idof - 8);
+            } 
+            size_type nedg = mesh_n_geo[1];
+            size_type ntri = mesh_n_element[reference_element::t];
+            if (loc_idof < 8+12+6) { // 6 face dofs
+	      size_type iqua = K.face(loc_idof - 8 - 12) - ntri;
+              return nv + nedg + iqua;
+            } 
+            // else: 1 volume dof
+	    assert_macro (loc_idof < 27, "invalid loc_idof="<<loc_idof);
+	    size_type nqua = mesh_n_element[reference_element::q];
+	    size_type ntet = mesh_n_element[reference_element::T];
+	    size_type npri = mesh_n_element[reference_element::P];
+	    size_type ihex = K.index() - ntet - npri;
+            return nv + nedg + nqua + ihex;
+          }
 	  default:
 	    error_macro ("unsupported P2 element on `" << K.name() << "'");
 	    return 0;
@@ -106,11 +144,11 @@ numbering_P2::idof (
 	const size_type*      mesh_n_geo,
 	const size_type*      mesh_n_element,
 	const geo_element&    K, 
-	vector<size_type>&    i_dof) const
+	vector<size_type>&    idof) const
 {
-  for (size_type i_dof_local = 0; i_dof_local < K.size(); i_dof_local++)
-    i_dof[i_dof_local] 
-     = numbering_P2::idof (mesh_n_geo, mesh_n_element, K, i_dof_local);
+  for (size_type loc_idof = 0; loc_idof < K.size(); loc_idof++)
+    idof[loc_idof] 
+     = numbering_P2::idof (mesh_n_geo, mesh_n_element, K, loc_idof);
 }
 numbering_P2::size_type
 numbering_P2::ndof (
@@ -129,11 +167,15 @@ numbering_P2::ndof (
 	return mesh_n_geo[0]
 	  + mesh_n_geo[1]
 	  + mesh_n_element[reference_element::q];
-      case 3:
+      case 3: {
+        // number of vertices + nb of edges in the mesh
+	// + number of quadrangle (extra interior node)
+	// + number of hexaedra   (extra interior node)
 	return mesh_n_geo[0]
 	  + mesh_n_geo[1]
-	  + mesh_n_element[reference_element::P]
+	  + mesh_n_element[reference_element::q]
 	  + mesh_n_element[reference_element::H];
+      }
       default:
 	fatal_macro ("unsupported P2 approximation in `" << mesh_map_dimension << "'");
 	return 0;
