@@ -61,13 +61,13 @@ EXAMPLE:
 
 INPUT FILE SPECIFICATION:
   @table @code
-  @itemx @var{filename}
+  @item @var{filename}
   	specifies the name of the file containing
       	the input mesh. The ".geo" extension is assumed.
 	
 @cindex RHEOPATH environment variable
 
-  @itemx -I@var{geodir} 
+  @item -I@var{geodir} 
       	add @var{geodir} to the mesh search path.
       	This mechanism initializes a search path given by the environment variable
       	@samp{RHEOPATH}. If the environment variable 
@@ -75,9 +75,9 @@ INPUT FILE SPECIFICATION:
       	default value is the current directory
 	(@pxref{geo class}).
 
-  @itemx -
+  @item -
   	read mesh on standard input instead on a file.
-  @itemx -name
+  @item -name
 	when mesh comes from standard input, the mesh name
 	is not known and is set to "output" by default.
 	This option allows to change this default.
@@ -87,17 +87,17 @@ INPUT FILE SPECIFICATION:
 
 INQUIRE OPTIONS:
   @table @code
-  @itemx -size 
+  @item -size 
      print the number of elements in the mesh and exit.
-  @itemx -n-node 
+  @item -n-node 
      print the number of nodes in the mesh and exit.
-  @itemx -hmin
+  @item -hmin
      print the smallest edge length in the mesh and exit.
-  @itemx -hmax
+  @item -hmax
      print the largest edge length in the mesh and exit.
-  @itemx -xmin
+  @item -xmin
      print the lower-left-bottom vertice in the mesh and exit.
-  @itemx -xmax
+  @item -xmax
      print the upper-right-top vertice in the mesh and exit.
   @end table
 
@@ -110,101 +110,101 @@ RENDER OPTIONS:
 @toindex @code{PlotM}
   The default render could also specified by using the RHEOLEF_RENDER environment variable.
   @table @code
-  @itemx -mayavi
+  @item -mayavi
     	use Mayavi.
 	This is the default.
-  @itemx -plotmtv
+  @item -plotmtv
   	use plotmtv tool.
-  @itemx -gnuplot
+  @item -gnuplot
   	use gnuplot tool.
-  @itemx -vtk
+  @item -vtk
     	use Visualization Toolkit.
-  @itemx -x3d
+  @item -x3d
     	use x3d visualization tool.
-  @itemx -atom
+  @item -atom
   	use PlotM atom representation (from lassp, Cornell).
   @end table
 GRAPHIC OPTIONS:
   @table @code
 @cindex @code{stereo 3D rendering}
-  @itemx -color
+  @item -color
 	use colors. This is the default.
-  @itemx -black-and-white
+  @item -black-and-white
 	Option only available with @code{mayavi}.
-  @itemx -stereo
+  @item -stereo
   	Rendering mode suitable for red-blue anaglyph 3D stereoscopic glasses.
 	Option only available with @code{mayavi}.
-  @itemx -grid
+  @item -grid
     	rendering mode. This is the default.
-  @itemx -fill
+  @item -fill
     	rendering mode. Fill mesh faces using light effects when available.
-  @itemx -shrink
+  @item -shrink
   	rendering mode. Shrink 3d elements (with vtk only).
-  @itemx -tube
+  @item -tube
   	rendering mode. All edges appears as tubes (with vtk only).
-  @itemx -ball
+  @item -ball
   	rendering mode. Vertices appears as balls (with vtk only).
-  @itemx -full
+  @item -full
   	rendering mode. All edges appears (with vtk only).
-  @itemx -cut
+  @item -cut
     	rendering mode. cut by plane and clip (with vtk only).
         Works with @samp{-full}, @samp{-tube} or @samp{-ball} modes.
         Does not clip mesh with @samp{-fill} and @samp{-grid} modes.
         Does not work yet with @samp{-shrink} mode.
         This option is still in development.
 
-  @itemx -origin @var{x} [@var{y} [@var{z}]]
+  @item -origin @var{x} [@var{y} [@var{z}]]
 	set the origin point of the cutting plane 
 	when using with the @samp{-cut} option.
 	Default is (0.5,0.5,0.5).
 
-  @itemx -normal @var{nx} [@var{ny} [@var{nz}]]
+  @item -normal @var{nx} [@var{ny} [@var{nz}]]
   	set the normal vector of the cutting plane.
 	when using with the @samp{-cut} option.
 	Default is (1,0,0).
-  @itemx -split
+  @item -split
 	split each edge by inserting a node.
 	The resulting mesh is P2-iso-P1.
   @end table
 OUTPUT FORMAT OPTIONS:
   @table @code
-  @itemx -geo
+  @item -geo
     	output mesh on standard output stream in geo text file format,
 	instead of plotting it.
 
 @toindex @code{bamg}
-  @itemx -bamg
+  @item -bamg
     	output mesh on standard output stream in bamg text file format,
 	instead of plotting it.
 
 @toindex @code{gmsh}
-  @itemx -gmsh
+  @item -gmsh
     	output mesh on standard output stream in gmsh ascii file format,
 	instead of plotting it.
 
 @toindex @code{tegen}
-  @itemx -tegen
+  @item -tegen
     	output mesh on stream in tegen text file format,
 	instead of plotting it (TODO).
 
 @toindex @code{mmg3d}
-  @itemx -mmg3d
+  @item -mmg3d
     	output mesh on standard output stream in mmg3d text file format,
 	instead of plotting it.
 
 @fiindex @file{.cemagref} cemagref topographic mesh
 @cindex  @code{cemagref} topographic mesh
 
-  @itemx -cemagref
+  @item -cemagref
     	output mesh on standard output stream in cemagref text file format,
 	instead of plotting it. Notices that the mesh does not contains 
         the topographic elevation. If you want to include the elevation,
         in the output, use the @code{field} command with the @code{-cemagref} option.
-  @itemx -upgrade
+  @item -upgrade
     	edges and faces are numbered. This numbering is required
 	for the quadratic approximation.
 
-  @itemx -ndigit @var{int}
+  @item -ndigit @var{int}
     	number of digits used to print floating point values 
 	when using the @samp{-geo} option.
 	Default depends upon the machine precision
@@ -220,13 +220,13 @@ INPUT FORMAT OPTIONS:
 @cindex mesh file format conversion
 
   @table @code
-  @itemx -input-geo
+  @item -input-geo
 	read the mesh in the @file{.geo} format.
 	This is the default.
 
 @fiindex @file{.bamg} bamg mesh
 @toindex @code{bamg}
-  @itemx -input-bamg
+  @item -input-bamg
 	read the mesh in the @file{.bamg} format.
         Since edges are not numbered in @file{.bamg} format,
 	this file format is not suitable for using P2 elements.
@@ -236,7 +236,7 @@ INPUT FORMAT OPTIONS:
 
 @fiindex @file{.msh} gmsh mesh
 @toindex @code{gmsh}
-  @itemx -input-gmsh
+  @item -input-gmsh
 	read the mesh in the @file{.msh} format.
         Since edges in 2D and faces in 3D are not numbered in @file{.msh}
         format, this file format is not suitable for using P2 elements.
@@ -248,7 +248,7 @@ INPUT FORMAT OPTIONS:
 @fiindex @file{.ele} tetgen mesh elements
 @fiindex @file{.face} tetgen mesh boundary faces
 @toindex @code{tetgen}
-  @itemx -input-tetgen
+  @item -input-tetgen
 	read the mesh as the concatenation of @file{.node}, @file{.ele} and @file{.face} tetgen format.
         Since in 3D are not all numbered in tetgen
         format, this file format is not suitable for using P2 elements.
@@ -258,7 +258,7 @@ INPUT FORMAT OPTIONS:
 
 @fiindex @file{.mmg3d} mmg3d mesh
 @toindex @code{mmg3d}
-  @itemx -input-mmg3d
+  @item -input-mmg3d
 	read the mesh in the @file{.mmg3d} format.
         Since edges and faces are not numbered in @file{.mmg3d} format,
 	this file format is not suitable for using P2 elements.
@@ -271,7 +271,7 @@ INPUT FORMAT OPTIONS:
 @toindex @code{tetra}, grummp mesh generator
 @fiindex @file{.template} grummp mesh file format specification
 @fiindex @file{.g} grummp mesh
-  @itemx -input-grummp
+  @item -input-grummp
     	read the mesh on standard input stream in grummp text file format.
 	The @code{.g} grummp file format is defined
         grummp @file{.template} specification file
@@ -304,7 +304,7 @@ INPUT FORMAT OPTIONS:
 
 @fiindex @file{.qmg} qmg mesh
 @toindex @code{qmg}
-  @itemx -input-qmg
+  @item -input-qmg
     	output mesh on standard output stream in qmg text file format.
 	instead of plotting it.
         Since edges are not numbered in @file{.qmg} format,
@@ -315,7 +315,7 @@ INPUT FORMAT OPTIONS:
 
 @fiindex @file{.dmn} domain names
 @cindex mesh file format conversion
-  @itemx -dmn @var{domain-names-file}
+  @item -dmn @var{domain-names-file}
 	An auxilliary @file{.dmn} file defining the boundary domain names
 	as used by @code{rheolef} could be used, since @code{bamg}, @code{mmg3d}, @code{tetgen}
 	and @code{grummp} use numeric
@@ -351,7 +351,7 @@ INPUT FORMAT OPTIONS:
 @fiindex @file{.cemagref} cemagref topographic mesh
 @cindex  @code{cemagref} topographic mesh
 
-  @itemx -input-cemagref
+  @item -input-cemagref
 	read the mesh in the @file{.cemagref} format.
 	Notices that the reader skip the topographic elevation informations.
 	If you want to load the elevation, use the @code{field} 
@@ -361,28 +361,28 @@ INPUT FORMAT OPTIONS:
 
 OTHERS OPTIONS:
   @table @code
-    @itemx -verbose
+    @item -verbose
     	print messages related to graphic files created and
        	command system calls (this is the default).
 
-    @itemx -noverbose
+    @item -noverbose
     	does not print previous messages.
 
-    @itemx -clean
+    @item -clean
     	clear temporary graphic files (this is the default).
     
-    @itemx -noclean
+    @item -noclean
     	does not clear temporary graphic files.
 
-    @itemx -execute
+    @item -execute
     	execute graphic command (this is the default).
     
-    @itemx -noexecute
+    @item -noexecute
    	does not execute graphic command. Generates only 
 	graphic files. This is usefull in conjuction with the
 	"-noclean" command.
 
-  @itemx -check
+  @item -check
   @itemx -dump
   	used for debug purpose.
   @end table
@@ -409,19 +409,19 @@ when dimension is two or three, the number of edges is also specified.
 Follows the vertex coordinates, the elements and the faces or edges.
 One element starts with a letter indicating the element type
 @table @samp
-       	@itemx p
+       	@item p
        		point 
-       	@itemx e
+       	@item e
        		edge 
-	@itemx t
+	@item t
 		triangle
-	@itemx q
+	@item q
 		quadrangle
-	@itemx T
+	@item T
 		tetrahedron
-        @itemx P
+        @item P
 		prism
-	@itemx H
+	@item H
 		hexaedron
 @end table
 @noindent
@@ -783,8 +783,8 @@ int main(int argc, char **argv)
         case get_n_node : cout << g.n_node() << endl; break;
         case get_hmin   : cout << g.hmin() << endl; break;
         case get_hmax   : cout << g.hmax() << endl; break;
-        case get_xmin   : cout << g.xmin().put(cout,g.dimension()) << endl; break;
-        case get_xmax   : cout << g.xmax().put(cout,g.dimension()) << endl; break;
+        case get_xmin   : cout << ptos (g.xmin(), g.dimension()) << endl; break;
+        case get_xmax   : cout << ptos (g.xmax(), g.dimension()) << endl; break;
 	default: break;
     }
     return 0;
