@@ -275,7 +275,7 @@ template <class ConstructBbox_2>
 class MyConstruct_bbox_2 : public ConstructBbox_2 {
 public:
   using ConstructBbox_2::operator();
-  CGAL::Bbox_2 operator()(const point_basic<double>& p) const {
+  CGAL::Bbox_2 operator()(const point_basic<Float>& p) const {
     return CGAL::Bbox_2(p.x(), p.y(), p.x(), p.y());
   }
 };
