@@ -40,7 +40,7 @@
 #include "rheolef/reference_element.h"
 #include "rheolef/geo_element_indirect.h"
 #include "rheolef/heap_allocator.h"
-#include "rheolef/array.h"
+#include "rheolef/disarray.h"
 #include "rheolef/reference_element_face_transformation.h"
 
 #include <boost/serialization/serialization.hpp>
@@ -258,12 +258,12 @@ public:
 // geometric predicate
 
     template <class T, class M>
-    bool contains (const array<point_basic<T>,M>& node, const point_basic<T>& x) const;
+    bool contains (const disarray<point_basic<T>,M>& node, const point_basic<T>& x) const;
 
 // i/o;
 
-  friend std::istream& operator>> (std::istream& is, geo_element& K);
-  friend std::ostream& operator<< (std::ostream& os, const geo_element& K);
+  void put (std::ostream& is) const;
+  void get (std::istream& os);
 
 // static: fix orientation & shift helpers, for 2d edges & 3d faces:
 
@@ -335,6 +335,29 @@ public:
   template<class A = std::allocator<std::vector<int>::size_type> > class geo_element_auto;
 #endif // TO_CLEAN
 };
+// specialization, from disarray.h (because of a g++ bug when T=float128)
+template<>
+struct _disarray_put_element_type<geo_element> {
+  std::ostream& operator() (std::ostream& os, const geo_element& K) const { K.put(os); return os; }
+};
+template<>
+struct _disarray_get_element_type<geo_element> {
+  std::istream& operator() (std::istream& is, geo_element& K) const { K.get(is); return is; }
+};
+inline
+std::istream&
+operator>> (std::istream& is, geo_element& K)
+{
+  K.get (is);
+  return is;
+}
+inline
+std::ostream&
+operator<< (std::ostream& os, const geo_element& K)
+{
+  K.put (os);
+  return os;
+}
 // --------------------------------------------------------------------
 // geo_element_auto: generic dynamically allocated class
 // --------------------------------------------------------------------
