@@ -24,13 +24,13 @@
 // massive hack vector for all T=geo_element of the same variant & order
 // => elements have exactly the same size 
 // Since the order is known only at at run time, geo_element size is unknown at
-// compile time and the the array<T> cannot be used.
+// compile time and the disarray<T> cannot be used.
 // 
 // Nevertheless, the situation is similar at run time:
 //  - elements can be stored contiguously in memory
 //  - mpi communications can be efficienly performed, as for known MPI_Datatype
 //
-#include "rheolef/array.h"
+#include "rheolef/disarray.h"
 
 namespace rheolef {
 
@@ -75,12 +75,12 @@ struct hack_array_iterator {
 // the sequential representation
 // -------------------------------------------------------------
 template <class T, class A>
-class hack_array_seq_rep : public array_rep<typename T::raw_type,sequential,A> {
+class hack_array_seq_rep : public disarray_rep<typename T::raw_type,sequential,A> {
 public:
 
 // typedefs:
 
-  typedef array_rep<typename T::raw_type, sequential, A> base;
+  typedef disarray_rep<typename T::raw_type, sequential, A> base;
   typedef T		  	              raw_value_type;
   typedef typename T::generic_type            value_type;
   typedef typename T::generic_type            generic_value_type;
@@ -240,18 +240,18 @@ public:
 
   template <class A2>
   void repartition (					      // old_numbering for *this
-        const array_rep<size_type,distributed,A2>& partition,	      // old_ownership
+        const disarray_rep<size_type,distributed,A2>& partition,	      // old_ownership
         hack_array_mpi_rep<T,A>&                new_array,	      // new_ownership (created)
-        array_rep<size_type,distributed,A2>&    old_numbering,     // new_ownership
-        array_rep<size_type,distributed,A2>&    new_numbering) const; // old_ownership
+        disarray_rep<size_type,distributed,A2>&    old_numbering,     // new_ownership
+        disarray_rep<size_type,distributed,A2>&    new_numbering) const; // old_ownership
 
 #ifdef TODO
     void permutation_apply (				      // old_numbering for *this
-        const array_rep<size_type,distributed,>& new_numbering,        // old_ownership
-        array_rep<T,distributed>&               new_array) const;     // new_ownership (already allocated)
+        const disarray_rep<size_type,distributed,>& new_numbering,        // old_ownership
+        disarray_rep<T,distributed>&               new_array) const;     // new_ownership (already allocated)
 
     void reverse_permutation (                                // old_ownership for *this=iold2dis_inew
-        array_rep<size_type,distributed>& inew2dis_iold) const;       // new_ownership
+        disarray_rep<size_type,distributed>& inew2dis_iold) const;       // new_ownership
 #endif // TODO
 
     // get all external pairs (dis_i, values):
@@ -300,7 +300,7 @@ NAME:  hack_array - container in distributed environment (@PACKAGE@-@VERSION@)
 SYNOPSYS:       
 @noindent
 STL-like vector container for a distributed memory machine model.
-Contrarily to array<T>, here T can have a size only known at compile time.
+Contrarily to disarray<T>, here T can have a size only known at compile time.
 This class is used when T is a geo_element raw class, i.e. T=geo_element_e_raw.
 The size of the geo_element depends upon the oder and is known only at run-time.
 For efficiency purpose, the hack_array allocate all geo_elements of the 
@@ -313,7 +313,7 @@ EXAMPLE:
     std::pair<size_t,size_t> param (reference_element::t, 3); // triangle, order=3
     hack_array<geo_element_raw> x (distributor(100), param);
 @end example
-The hack_array<T> interface is similar to those of the array<T> one.
+The hack_array<T> interface is similar to those of the disarray<T> one.
 
 OBJECT REQUIREMENT:
  There are many pre-requises for the template objet type T:
