@@ -136,15 +136,16 @@ class point_basic {
 	point_basic<T> operator- (const point_basic<T>& v) const
 		{ return point_basic<T> (_x[0]-v[0], _x[1]-v[1], _x[2]-v[2]); }
 
-	point_basic<T> operator* (const T& a) const
-		{ return point_basic<T> (a*_x[0], a*_x[1], a*_x[2]); }
-#ifdef TO_CLEAN
-	point_basic<T> operator* (int a) const
-		{ return operator* (T(a)); }
-#endif // TO_CLEAN
+	template <class U>
+        typename
+        std::enable_if<
+	  details::is_rheolef_arithmetic<U>::value
+         ,point_basic<T>
+        >::type
+        operator* (const U& a) const
+		{ return point_basic<T> (_x[0]*a, _x[1]*a, _x[2]*a); }
 	point_basic<T> operator/ (const T& a) const
 		{ return operator* (T(1)/T(a)); }
-
 	point_basic<T> operator/ (point_basic<T> v) const
 		{ return point_basic<T> (_x[0]/v[0], _x[1]/v[1], _x[2]/v[2]); }
 
@@ -157,30 +158,16 @@ class point_basic {
 typedef point_basic<Float> point;
 
 // algebra:
-#ifdef TO_CLEAN
-template<class T>
+template <class T, class U>
 inline
-point_basic<T>
-operator* (int a, const point_basic<T>& u)
+typename
+std::enable_if<
+  details::is_rheolef_arithmetic<U>::value
+ ,point_basic<T>
+>::type
+operator* (const U& a, const point_basic<T>& u)
 {
-  return u.operator* (T(a));
-}
-#endif // TO_CLEAN
-#if defined(_RHEOLEF_HAVE_QD) || defined(_RHEOLEF_HAVE_FLOAT128)
-template<class T>
-inline
-point_basic<T>
-operator* (double a, const point_basic<T>& u)
-{
-  return u.operator* (T(a));
-}
-#endif // FLOAT
-template<class T>
-inline
-point_basic<T>
-operator* (const T& a, const point_basic<T>& u)
-{
-  return u.operator* (a);
+  return point_basic<T> (a*u[0], a*u[1], a*u[2]);
 }
 template<class T>
 inline
