@@ -160,7 +160,7 @@ protected:
     void _initialize (reference_element hat_K) const;
 // data:
     quadrature_option_type        _options;
-    mutable boost::array<quadrature_on_geo<T>,reference_element::max_variant>
+    mutable std::array<quadrature_on_geo<T>,reference_element::max_variant>
 				  _quad;
     mutable std::vector<bool>     _initialized;
 private:
