@@ -27,10 +27,30 @@ template<class T>
 void
 quadrature_on_geo<T>::init_tetrahedron  (quadrature_option_type opt)
 {
+  quadrature_option_type::family_type f = opt.get_family();
+  // -------------------------------------------------------------------------
+  // special case : equispaced, for irregular (e.g. Heaviside) functions
+  // -------------------------------------------------------------------------
+  if (f == quadrature_option_type::equispaced) {
+    size_type r = opt.get_order();
+    if (r == 0) {
+      wx (x(1/T(3),1/T(3),1/(3)), T(1)/6);
+    } else {
+      size_type n = (r+1)*(r+2)*(r+3)/6;
+      T w = (1/T(6))/T(n);
+      for (size_type i = 0; i <= r; i++) {
+        for (size_type j = 0; i+j <= r; j++) {
+          for (size_type k = 0; i+j+k <= r; k++) {
+            wx (x(T(i)/r,T(j)/r,T(k)/r), w);
+          }
+        }
+      }
+    }
+    return;
+  }
   // -------------------------------------------------------------------------
   // special case : superconvergent patch recovery nodes & weights
   // -------------------------------------------------------------------------
-  quadrature_option_type::family_type f = opt.get_family();
   if (f == quadrature_option_type::superconvergent) {
     switch (opt.get_order()) {
       case 0:
@@ -67,7 +87,7 @@ quadrature_on_geo<T>::init_tetrahedron  (quadrature_option_type opt)
   // -------------------------------------------------------------------------
   // general case: Gauss
   // -------------------------------------------------------------------------
-  assert_macro (f == quadrature_option_type::gauss,
+  check_macro (f == quadrature_option_type::gauss,
         "unsupported quadrature family \"" << opt.get_family_name() << "\"");
  
   switch (opt.get_order()) {
