@@ -112,11 +112,29 @@ quadrature_on_geo<T>::init_triangle (quadrature_option_type opt)
 	    error_macro ("unsupported Gauss-Lobatto("<<opt.get_order()<<")");
     }
     return;
+  }  
+  // -------------------------------------------------------------------------
+  // special case : equispaced, for irregular (e.g. Heaviside) functions
+  // -------------------------------------------------------------------------
+  if (f == quadrature_option_type::equispaced) {
+    size_type r = opt.get_order();
+    if (r == 0) {
+      wx (x(1/T(3),1/T(3)), 0.5);
+    } else {
+      size_type n = (r+1)*(r+2)/2;
+      T w = 0.5/T(n);
+      for (size_type i = 0; i <= r; i++) {
+        for (size_type j = 0; i+j <= r; j++) {
+          wx (x(T(i)/r,T(j)/r), w);
+        }
+      }
+    }
+    return;
   }
   // -------------------------------------------------------------------------
   // default & general case : Gauss points
   // -------------------------------------------------------------------------
-  assert_macro (f == quadrature_option_type::gauss,
+  check_macro (f == quadrature_option_type::gauss,
         "unsupported quadrature family \"" << opt.get_family_name() << "\"");
 
   switch (opt.get_order()) {
