@@ -122,7 +122,7 @@ int main(int argc, char**argv) {
           for (size_t j = 0; j <= r-i; j++) {
             Float sq = integrate  (hat_K, monom2d(i,j), quad);
             Float se = exact_integrate_t (monom2d(i,j));
-	    warning_macro ("error = " << fabs(sq-se));
+	    trace_macro ("error = " << fabs(sq-se));
             if (fabs(sq-se) > tol) {
 	        cerr << "Iq(" << r << ";" << i << "," << j << ") = "
 	             << sq << " != " << se 
