@@ -215,8 +215,8 @@ reference_element::n_node (variant_type variant, size_type order)
 }
 void
 reference_element::init_local_nnode_by_variant (
-    size_type                                               order, 
-    boost::array<size_type,reference_element::max_variant>& sz)
+    size_type                                             order, 
+    std::array<size_type,reference_element::max_variant>& sz)
 {
   sz [reference_element::p] = 1;
   sz [reference_element::e] = order-1;
