@@ -110,10 +110,6 @@ exp2d (const tensor_basic<T>& chi) {
 #include <boost/numeric/ublas/matrix.hpp>
 #include <boost/numeric/ublas/lu.hpp>
 
-#ifndef TO_CLEAN
-#include <boost/numeric/ublas/io.hpp>
-#endif // TO_CLEAN
-
 namespace boost { namespace numeric { namespace ublas {
 
 namespace details {
@@ -207,21 +203,6 @@ expm_pad (const MATRIX &H, const size_t p = 6) {
   // implement matrix inversion
   permutation_matrix<size_type> pm(n); 
   int status = lu_factorize (Q, pm);
-  check_macro (status == 0, "exp(tensor): LU factorization failed");
-#ifdef TO_CLEAN
-  if (status != 0) {
-    std::cerr << std::setprecision(16);
-    warning_macro ("matrix to invert was Q="<<Q);
-    warning_macro ("input was H="<<H);
-    warning_macro ("norm="<<norm<<", s="<<s<<", scale="<<scale);
-    warning_macro ("H2="<<H2);
-    warning_macro ("U="<<U);
-    warning_macro ("P="<<P);
-    for (size_type i = 0; i < p+2; ++i) {
-      warning_macro ("c("<<i<<")="<<c(i));
-    }
-  }
-#endif // TO_CLEAN
   check_macro (status == 0, "exp(tensor): inversion failed");
   H2 = I;  // H2 is not needed anymore, so it is temporary used as identity matrix for substituting.
   lu_substitute(Q, pm, H2); 
