@@ -106,50 +106,58 @@ tensor_basic<T>::operator== (const tensor_basic<T>& b) const
   return true;
 }
 template<class T>
-tensor_basic<T> operator- (const tensor_basic<T>& a)
+tensor_basic<T> 
+tensor_basic<T>::operator- () const
 {
     tensor_basic<T> b;
     typedef typename tensor_basic<T>::size_type size_type;
-    for (size_type i = 0; i < 3; i++) for (size_type j = 0; j < 3; j++)
-        b._x[i][j] = - a._x[i][j];
+    for (size_type i = 0; i < 3; i++)
+    for (size_type j = 0; j < 3; j++)
+        b._x[i][j] = - _x[i][j];
     return b;
 }
 template<class T>
-tensor_basic<T> operator+ (const tensor_basic<T>& a, const tensor_basic<T>& b)
+tensor_basic<T> 
+tensor_basic<T>::operator+ (const tensor_basic<T>& b) const
 {
     tensor_basic<T> c;
     typedef typename tensor_basic<T>::size_type size_type;
-    for (size_type i = 0; i < 3; i++) for (size_type j = 0; j < 3; j++)
-        c._x[i][j] = a._x[i][j] + b._x[i][j];
+    for (size_type i = 0; i < 3; i++)
+    for (size_type j = 0; j < 3; j++)
+        c._x[i][j] = _x[i][j] + b._x[i][j];
     return c;
 }
 template<class T>
-tensor_basic<T> operator- (const tensor_basic<T>& a, const tensor_basic<T>& b)
+tensor_basic<T>
+tensor_basic<T>::operator- (const tensor_basic<T>& b) const
 {
     tensor_basic<T> c;
     typedef typename tensor_basic<T>::size_type size_type;
-    for (size_type i = 0; i < 3; i++) for (size_type j = 0; j < 3; j++)
-        c._x[i][j] = a._x[i][j] - b._x[i][j];
+    for (size_type i = 0; i < 3; i++)
+    for (size_type j = 0; j < 3; j++)
+        c._x[i][j] = _x[i][j] - b._x[i][j];
     return c;
 }
 template<class T>
-tensor_basic<T> operator* (const T& k, const tensor_basic<T>& a)
+tensor_basic<T>
+tensor_basic<T>::operator* (const T& k) const
 {
     tensor_basic<T> b;
     typedef typename tensor_basic<T>::size_type size_type;
-    for (size_type i = 0; i < 3; i++) for (size_type j = 0; j < 3; j++)
-        b._x[i][j] = k * a._x[i][j];
+    for (size_type i = 0; i < 3; i++)
+    for (size_type j = 0; j < 3; j++)
+        b._x[i][j] = _x[i][j] * k;
     return b;
 }
 template<class T>
 point_basic<T>
-operator* (const tensor_basic<T>& a, const point_basic<T>& x)
+tensor_basic<T>::operator* (const point_basic<T>& x) const
 {
     point_basic<T> y;
     typedef typename tensor_basic<T>::size_type size_type;
     for (size_type i = 0; i < 3; i++)
     for (size_type j = 0; j < 3; j++)
-        y [i] += a._x[i][j] * x[j];
+        y [i] += _x[i][j] * x[j];
     return y;
 }
 template<class T>
@@ -157,7 +165,8 @@ point_basic<T> operator* (const point_basic<T>& x, const tensor_basic<T>& a)
 {
     point_basic<T> y;
     typedef typename tensor_basic<T>::size_type size_type;
-    for (size_type i = 0; i < 3; i++) for (size_type j = 0; j < 3; j++)
+    for (size_type i = 0; i < 3; i++)
+    for (size_type j = 0; j < 3; j++)
         y [i] += a._x[j][i] * x[j];
     return y;
 }
@@ -166,7 +175,8 @@ tensor_basic<T> trans (const tensor_basic<T>& a, size_t d)
 {
     tensor_basic<T> b;
     typedef typename tensor_basic<T>::size_type size_type;
-    for (size_type i = 0; i < d; i++) for (size_type j = 0; j < d; j++)
+    for (size_type i = 0; i < d; i++)
+    for (size_type j = 0; j < d; j++)
         b._x[i][j] = a._x[j][i];
     return b;
 }
@@ -221,10 +231,11 @@ prod (const tensor_basic<T>& a, const tensor_basic<T>& b, tensor_basic<T>& resul
     }
 }
 template<class T>
-tensor_basic<T> operator* (const tensor_basic<T>& a, const tensor_basic<T>& b)
+tensor_basic<T>
+tensor_basic<T>::operator* (const tensor_basic<T>& b) const
 {
     tensor_basic<T> c;
-    prod (a,b,c,3,3,3);
+    prod (*this,b,c,3,3,3);
     return c;
 }
 template<class T>
@@ -232,7 +243,8 @@ T ddot (const tensor_basic<T>& a, const tensor_basic<T> & b)
 {
     T r = 0;
     typedef typename tensor_basic<T>::size_type size_type;
-    for (size_type i = 0; i < 3; i++) for (size_type j = 0; j < 3; j++)
+    for (size_type i = 0; i < 3; i++) 
+    for (size_type j = 0; j < 3; j++)
         r += a._x[i][j] * b._x[i][j];
     return r;
 }
@@ -348,13 +360,6 @@ static point_basic<T> eig2x2 (const tensor_basic<T>& a, tensor_basic<T>& q)
     T n1 = sqrt(1+sqr(c1));
     q(0,1) =  1/n1;
     q(1,1) = c1/n1;
-#ifdef TO_CLEAN
-    tensor_basic<T> I = tensor_basic<T>::eye(2);
-warning_macro ("q=" << q);
-warning_macro ("err0=" << norm(I-trans(q,2)*q));
-warning_macro ("err1=" << norm(I-q*trans(q,2)));
-warning_macro ("err2=" << norm(a-q*diag(d)*trans(q,2)));
-#endif // TO_CLEAN
     return d;
 }
 // ------------------------------------------
@@ -433,17 +438,11 @@ tensor_basic<T>::svd (tensor_basic<T>& u, tensor_basic<T>& v, size_t dim) const
 // ----------------------------------------------------------------------------
 #define _RHEOLEF_instanciation(T)                                             	\
 template class tensor_basic<T>;							\
-template tensor_basic<T> operator- (const tensor_basic<T>& a);			\
-template tensor_basic<T> operator+ (const tensor_basic<T>& a, const tensor_basic<T>& b);	\
-template tensor_basic<T> operator- (const tensor_basic<T>& a, const tensor_basic<T>& b);	\
-template tensor_basic<T> operator* (const T& k, const tensor_basic<T>& a);			\
-template point_basic<T>  operator* (const tensor_basic<T>& a, const point_basic<T>& x);		\
 template point_basic<T>  operator* (const point_basic<T>& x, const tensor_basic<T>& a);		\
 template tensor_basic<T> trans (const tensor_basic<T>&, size_t);			 	\
 template tensor_basic<T> inv (const tensor_basic<T>&, size_t);					\
 template void prod (const tensor_basic<T>& a, const tensor_basic<T>& b, tensor_basic<T>& result, \
 		    size_t di, size_t dj, size_t dk);						\
-template tensor_basic<T> operator* (const tensor_basic<T>& a, const tensor_basic<T>& b);	\
 template T ddot (const tensor_basic<T>& a, const tensor_basic<T> & b);			\
 template void cumul_otimes (tensor_basic<T>& t, const point_basic<T>& a, const point_basic<T>& b, size_t na, size_t nb); \
 template bool invert_3x3 (const tensor_basic<T>& A, tensor_basic<T>& result);			\
