@@ -63,8 +63,8 @@ class tensor_basic {
 
 // affectation:
 
-	tensor_basic<T>& operator = (const tensor_basic<T>& a);
-	tensor_basic<T>& operator = (const T& val);
+	tensor_basic<T>& operator= (const tensor_basic<T>& a);
+	tensor_basic<T>& operator= (const T& val);
 
 // modifiers:
 
@@ -91,12 +91,18 @@ class tensor_basic {
 
 	bool operator== (const tensor_basic<T>&) const;
 	bool operator!= (const tensor_basic<T>& b) const { return ! operator== (b); }
+	const tensor_basic<T>& operator+ () const { return *this; }
+	tensor_basic<T> operator- () const;
+        tensor_basic<T> operator+ (const tensor_basic<T>& b) const;
+        tensor_basic<T> operator- (const tensor_basic<T>& b) const;
+        tensor_basic<T> operator* (const tensor_basic<T>& b) const;
+	tensor_basic<T> operator* (const T& k) const;
+	tensor_basic<T> operator/ (const T& k) const; 
+	point_basic<T>  operator* (const point_basic<T>&) const;
         point_basic<T>  trans_mult (const point_basic<T>& x) const;
 
 // metric and geometric transformations:
 
-	template <class U>
-	friend U ddot (const tensor_basic<U>&, const tensor_basic<U>&);
 	T determinant (size_type d = 3) const;
 
 // spectral:
@@ -125,25 +131,9 @@ typedef tensor_basic<Float> tensor;
 
 // algebra (cont.)
 
-template <class U>
-tensor_basic<U> operator- (const tensor_basic<U>&);
-template <class U>
-tensor_basic<U> operator+ (const tensor_basic<U>&, const tensor_basic<U>&);
-template <class U>
-tensor_basic<U> operator- (const tensor_basic<U>&, const tensor_basic<U>&);
-template <class U>
-tensor_basic<U> operator* (const U& k, const tensor_basic<U>& a);
-template <class U>
-tensor_basic<U> operator* (const tensor_basic<U>& a, const U& k);
-template <class U>
-tensor_basic<U> operator/ (const tensor_basic<U>& a, const U& k);
-template <class U>
-point_basic<U>  operator* (const tensor_basic<U>&, const point_basic<U>&);
 template <class U>
 point_basic<U>  operator* (const point_basic<U>& yt, const tensor_basic<U>& a);
 template <class U>
-tensor_basic<U> operator* (const tensor_basic<U>& a, const tensor_basic<U>& b);
-template <class U>
 tensor_basic<U> trans (const tensor_basic<U>& a, size_t d = 3);
 template <class U>
 void prod (const tensor_basic<U>& a, const tensor_basic<U>& b, tensor_basic<U>& result,
@@ -151,6 +141,8 @@ void prod (const tensor_basic<U>& a, const tensor_basic<U>& b, tensor_basic<U>&
 // tr(a) = a00 + a11 + a22
 template <class U>
 U tr (const tensor_basic<U>& a, size_t d=3); 
+template <class U>
+U ddot (const tensor_basic<U>&, const tensor_basic<U>&);
 // a = u otimes v <==> aij = ui*vj
 template <class U>
 tensor_basic<U> otimes (const point_basic<U>& u, const point_basic<U>& v, size_t d=3);
@@ -299,43 +291,24 @@ tensor_basic<T>::operator()(size_type i, size_type j) const
 {
     return _x[i%3][j%3];
 }
-template<class T>
+template <class T, class U>
 inline
-tensor_basic<T>
-operator* (const tensor_basic<T>& a, const T& k)
+typename
+std::enable_if<
+  details::is_rheolef_arithmetic<U>::value
+ ,tensor_basic<T>
+>::type
+operator* (const U& k, const tensor_basic<T>& a) 
 {
-    return k*a;
+    return a*k;
 }
 template<class T>
 inline
 tensor_basic<T>
-operator/ (const tensor_basic<T>& a, const T& k)
+tensor_basic<T>::operator/ (const T& k) const
 {
-    return (1/k)*a;
+    return operator* (1./k);
 }
-#if defined(_RHEOLEF_HAVE_QD) || defined(_RHEOLEF_HAVE_FLOAT128)
-template<class T>
-inline
-tensor_basic<T>
-operator* (double k, const tensor_basic<T>& a)
-{
-    return T(k)*a;
-}
-template<class T>
-inline
-tensor_basic<T>
-operator* (const tensor_basic<T>& a, double k)
-{
-    return T(k)*a;
-}
-template<class T>
-inline
-tensor_basic<T>
-operator/ (const tensor_basic<T>& a, double k)
-{
-    return (1/k)*a;
-}
-#endif // FLOAT 
 template<class T>
 inline
 point_basic<T>
