@@ -99,6 +99,18 @@ tensor3_basic<T>::operator- (const tensor3_basic<T>& b) const
       c(i,j,k) = _x[i][j][k] - b(i,j,k);
     return c;
 }
+template<class T>
+T
+dddot (const tensor3_basic<T>& a, const tensor3_basic<T> & b)
+{
+    T r = 0;
+    typedef typename tensor_basic<T>::size_type size_type;
+    for (size_type i = 0; i < 3; i++) 
+    for (size_type j = 0; j < 3; j++)
+    for (size_type k = 0; k < 3; k++)
+        r += a(i,j,k) * b(i,j,k);
+    return r;
+}
 // ----------------------------------------------------------------------------
 // io
 // ----------------------------------------------------------------------------
@@ -139,6 +151,7 @@ tensor3_basic<T>::get (istream& in)
 // ----------------------------------------------------------------------------
 #define _RHEOLEF_instanciation(T)                                             	\
 template class tensor3_basic<T>;						\
+template T dddot (const tensor3_basic<T>&, const tensor3_basic<T>&);		\
 
 _RHEOLEF_instanciation(Float)
 
