@@ -63,6 +63,8 @@ public:
 // algebra
   tensor3_basic<T>& operator*= (const T& k);
   tensor3_basic<T>& operator/= (const T& k) { return operator*= (1./k); }
+  tensor3_basic<T>  operator*  (const T& k) const;
+  tensor3_basic<T>  operator/  (const T& k) const;
   tensor_basic<T>   operator*  (const point_basic<T>& v) const;
   tensor3_basic<T>  operator*  (const tensor_basic<T>& b) const;
   tensor3_basic<T>  operator+  (const tensor3_basic<T>& b) const;
@@ -115,26 +117,62 @@ tensor3_basic<T>::operator() (size_type i, size_type j, size_type k) const
 template <class T>
 inline
 tensor3_basic<T>
-operator* (const T& k, const tensor3_basic<T>& a)
+tensor3_basic<T>::operator* (const T& k) const
 {
-  tensor3_basic<T> b = a;
+  tensor3_basic<T> b = *this;
   b *= k;
   return b;
 }
-template <class T>
+template <class T, class U>
 inline
-tensor3_basic<T>
-operator* (const tensor3_basic<T>& a, const T& k)
+typename
+std::enable_if<
+  details::is_rheolef_arithmetic<U>::value
+ ,tensor3_basic<T>
+>::type
+operator* (const U& k, const tensor3_basic<T>& a)
 {
-  return k*a;
+  return a*k;
 }
 template <class T>
 inline
 tensor3_basic<T>
-operator/ (const tensor3_basic<T>& a, const T& k)
+tensor3_basic<T>::operator/ (const T& k) const
 {
-  return (1./k)/a;
+  return operator* (1./k);
 }
+template <class U>
+U dddot (const tensor3_basic<U>&, const tensor3_basic<U>&);
+
+template <class T>
+inline
+T
+norm2 (const tensor3_basic<T>& a)
+{
+  return dddot(a,a);
+}
+template <class T>
+inline
+T
+dist2 (const tensor3_basic<T>& a, const tensor3_basic<T>& b)
+{
+  return norm2(a-b);
+}
+template <class U>
+inline
+U
+norm  (const tensor3_basic<U>& a)
+{
+  return sqrt(norm2(a));
+}
+template <class U>
+inline
+U
+dist (const tensor3_basic<U>& a, const tensor3_basic<U>& b)
+{
+  return norm(a-b);
+}
+
 // inputs/outputs:
 template<class T>
 inline
