@@ -74,6 +74,8 @@ public:
 
   tensor4_basic<T>& operator*= (const T& k);
   tensor4_basic<T>& operator/= (const T& k) { return operator*= (1./k); }
+  tensor4_basic<T>  operator* (const T& k) const;
+  tensor4_basic<T>  operator/ (const T& k) const;
   tensor4_basic<T>  operator+ (const tensor4_basic<T>& b) const;
   tensor4_basic<T>  operator- (const tensor4_basic<T>& b) const;
 
@@ -156,25 +158,29 @@ tensor4_basic<T>::operator() (size_type i, size_type j, size_type k, size_type l
 template <class T>
 inline
 tensor4_basic<T>
-operator* (const T& k, const tensor4_basic<T>& a)
+tensor4_basic<T>::operator* (const T& k) const
 {
-  tensor4_basic<T> b = a;
+  tensor4_basic<T> b = *this;
   b *= k;
   return b;
 }
-template <class T>
+template <class T, class U>
 inline
-tensor4_basic<T>
-operator* (const tensor4_basic<T>& a, const T& k)
+typename
+std::enable_if<
+  details::is_rheolef_arithmetic<U>::value
+ ,tensor4_basic<T>
+>::type
+operator* (const U& k, const tensor4_basic<T>& a)
 {
-  return k*a;
+  return a*k;
 }
 template <class T>
 inline
 tensor4_basic<T>
-operator/ (const tensor4_basic<T>& a, const T& k)
+tensor4_basic<T>::operator/ (const T& k) const
 {
-  return (1./k)/a;
+  return operator* (1./k);
 }
 // inputs/outputs:
 #ifdef TODO
