@@ -25,9 +25,11 @@ DATA_DIR="${TOP_SRCDIR}/nfem/data"
 NPROC_MAX=${NPROC_MAX-"7"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
+if test "$QD_EXT" = ".float128"; then QD_EXT=""; fi
+
 status=0
 
-run "./tensor4_tst 2>/dev/null | diff $SRCDIR/tensor4_tst.valid - >/dev/null"
+run "./tensor4_tst 2>/dev/null | diff $SRCDIR/tensor4_tst${QD_EXT}.valid - >/dev/null"
 if test $? -ne 0; then status=1; fi
 
 exit $status
