@@ -20,12 +20,12 @@
 #
 # -------------------------------------------------------------------------
 TOP_SRCDIR=${TOP_SRCDIR-"../.."}
-SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}
+SRCDIR=${SRCDIR-"../../nfem/geo_element"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
 
-run "./tensor_tst < $SRCDIR/tensor_tst.in | diff $SRCDIR/tensor_tst.out.valid -"
+run "./tensor_tst < $SRCDIR/tensor_tst.in | diff $SRCDIR/tensor_tst.out.valid - >/dev/null"
 if test $? -ne 0; then status=1; fi
 
 exit $status
