@@ -123,8 +123,8 @@ field::extract_line_path (const vector<size_t>& mask, vector<point>& x, vector<F
 	a = V.x_dof(Ki, 0);
 	b = V.x_dof(Ki, 1);
 	x[3*i]   = a;
-	x[3*i+1] = (2*a+b)/3;
-	x[3*i+2] = (a+2*b)/3;
+	x[3*i+1] = (2.*a+b)/3.;
+	x[3*i+2] = (a+2.*b)/3.;
 	y[3*i]   = at(dof(0));
 	y[3*i+1] = evaluate(meshpoint(point(1/3.),pi));
 	y[3*i+2] = evaluate(meshpoint(point(2/3.),pi));
@@ -311,10 +311,10 @@ field::gnuplot2d_elevation (const string& basename, plot_options& opt) const
 	      for (geo::size_type i = 1; i <= K.size(); i++) {
 		  point x_n = get_space().x_dof(K, i % K.size());
 	          point hat_x_n = hat_x[i % K.size()];
-		  point x_1 = (2*x_p+x_n)/3.; 
-		  point x_2 = (x_p+2*x_n)/3.; 
-		  Float u0_1 = evaluate((2*hat_x_p+hat_x_n)/3., K.index());
-		  Float u0_2 = evaluate((hat_x_p+2*hat_x_n)/3., K.index());
+		  point x_1 = (2.*x_p+x_n)/3.; 
+		  point x_2 = (x_p+2.*x_n)/3.; 
+		  Float u0_1 = evaluate((2.*hat_x_p+hat_x_n)/3., K.index());
+		  Float u0_2 = evaluate((hat_x_p+2.*hat_x_n)/3., K.index());
 		  Float u0_n = at(dof0(i % K.size()));
 		  gdat << x_1 << "\t" << u0_1 << endl;
 		  gdat << x_2 << "\t" << u0_2 << endl;
