@@ -68,7 +68,7 @@ void mtv_element (ostream& s, const geo_element& g, geo::const_iterator_node x,
 	    x[g[0]].put(s, 2); s << '\t' << z << endl;
 	    break;
 	  default:
-	    error_macro ("mtv_element: unexpected element `" << g.type() << "'");
+	    error_macro ("mtv_element: unexpected element `" << g.variant() << "'");
 	}
 	s << endl;
 }
@@ -321,7 +321,7 @@ field::plotmtv2d_P1d (
 	case 't' :
 	case 'q' :
 	  {
-	    size_type n_dof = _V.get_basis().size(K.type()) ;
+	    size_type n_dof = _V.get_basis().size(K.variant()) ;
 	    tiny_vector<size_type> dof(n_dof) ;
 	    _V.set_dof(K, dof) ;
 	    for (size_type i_loc_dof = 0; i_loc_dof < n_dof; i_loc_dof++)
@@ -396,7 +396,7 @@ field::plotmtv2d_P2 (
 	{
 	case 't' :
 	  {
-	    size_type n_dof = _V.get_basis().size(K.type()) ;
+	    size_type n_dof = _V.get_basis().size(K.variant()) ;
 	    tiny_vector<size_type> dof(n_dof) ;
 	    _V.set_dof(K, dof) ;
 	      mtv_point( mtv, _V.x_dof(K, 0), at(dof(0)) ) ;
@@ -418,7 +418,7 @@ field::plotmtv2d_P2 (
 	  }
 	case 'q' :
 	  {
-	    size_type n_dof = _V.get_basis().size(K.type()) ;
+	    size_type n_dof = _V.get_basis().size(K.variant()) ;
 	    tiny_vector<size_type> dof(n_dof) ;
 	    _V.set_dof(K, dof) ;
 	      mtv_point( mtv, _V.x_dof(K, 0), at(dof(0)) ) ;
