@@ -145,6 +145,9 @@ public :
     void evaluate (const point& x, Float& result) const;
     void evaluate (const point& x, point& result) const;
     void evaluate (const point& x, tensor& result) const;
+    void evaluate (const point& x, Float& result, bool& is_inside, size_t i_comp = 0) const;
+    void evaluate (const point& x, point& result, bool& is_inside) const;
+    void evaluate (const point& x, tensor& result, bool& is_inside) const;
 
 //! accessors & modifiers by components, or vector & tensor valued:
 //!       Float  u = uh.at (i_dof);
@@ -209,7 +212,6 @@ public :
     std::ostream& put_vtk_tensor (std::ostream& vtk,
     	const std::string& name = "tensors", bool put_header = true) const;
     void check () const;
-    int gnuplot2d_velocity (const std::string& basename, plot_options& opt) const;
  
 // specific:
 
@@ -272,10 +274,11 @@ public:
     // some low-level outputs:
     void extract_line_path (const std::vector<size_t>& mask, std::vector<point>& x, std::vector<Float>& y) const;
     void put_gnuplot1d_data (std::ostream& gdat) const;
-protected: 
+    int gnuplot2d_velocity (const std::string& basename, plot_options& opt) const;
     int gnuplot1d    (const std::string& basename, bool execute, bool clean, bool verbose
 	    	     ) const;
     int gnuplot2d_elevation (const std::string& basename, plot_options& opt) const;
+protected: 
     int vtk2d_Pk     (const std::string& basename, bool execute, bool clean, bool verbose,
 		      bool grid = false, bool fill = false) const;
     int vtk3d_Pk     (const std::string& basename, bool execute, bool clean, bool verbose
@@ -475,6 +478,9 @@ field::field (const space& V, const Float& init_value)
    _V.freeze();
    u.resize(V.n_unknown(), init_value);
    b.resize(V.n_blocked(), init_value);
+   if (V.get_basis().family() == element_constant::Hermite 
+   	&& (init_value!=0 && init_value != std::numeric_limits<Float>::max() ) )
+   	warning_macro("Hermite dofs are also set to " << init_value << ", you may want to use interpolate rather");
 }
 inline
 field::size_type
