@@ -36,6 +36,7 @@
 #include "rheolef/field.h"
 #include "rheolef/blas2.h"
 #include "rheolef/csr-algo-amulx.h"
+#include "rheolef/banded_level_set.h"
 
 #include "form_assembly.h"
 using namespace std;
@@ -71,7 +72,6 @@ form::form (const space& X, const space& Y, const string& name, bool locked_boun
     X_.freeze();
     Y_.freeze();
     form_element form_e = get_function(name, X, Y);
-
     if (!X.is_on_boundary_domain() && !Y.is_on_boundary_domain()) {
        form_assembly (*this, form_e, locked_boundaries);
     } else {
@@ -134,6 +134,14 @@ form::form (const space& X, const space& Y, const string& name, const domain& d,
     form_e.set_use_coordinate_system_weight(use_coordinate_system_weight);
     form_bdr_assembly (*this, form_e, d);
 }
+form::form (const space& X, const space& Y, const std::string& name, const band& bh)
+: X_(X), Y_(Y), _for_locked_boundaries(false), uu(), ub(), bu(), bb()
+{
+    X_.freeze();
+    Y_.freeze();
+    form_element form_e = get_function(name, X, Y);
+    form_band_assembly (*this, form_e, bh);
+}
 form::form (const form_diag& d) 
 : X_(d.get_space()), Y_(d.get_space()),
   _for_locked_boundaries(false),
