@@ -303,8 +303,8 @@ ostream&
 georep::put_cemagref (ostream& out, const field& z, bool store_z) const
 {
    // fortran likes a decimal-point character in floating-point
-   ios::fmtflags have_showpoint = (out.flags() & ios::showpoint);
-   out.setf(ios::showpoint);
+   std::ios::fmtflags have_showpoint = (out.flags() & std::ios::showpoint);
+   out.setf(std::ios::showpoint);
 
    size_type undef = numeric_limits<size_type>::max();
    may_have_version_2();
@@ -474,7 +474,7 @@ georep::put_cemagref (ostream& out, const field& z, bool store_z) const
     }
     if (!have_showpoint) {
 	// restaure context
-        out.unsetf(ios::showpoint);
+        out.unsetf(std::ios::showpoint);
     }
     return out;
 }
