@@ -526,7 +526,7 @@ georep::sort_interface (const domain& d, const interface& bc) const
 	if (d_index==bc.element_of_known_normal)
 	{
 	    check_macro(attached_dir!=-1,"Attached direction not set !" << S.size());
-	    bc.set_actual_order( ((attached_dir==0)?1:-1)
+	    bc.set_actual_order( Float((attached_dir==0)?1:-1)
 	    	*(_x.begin()[(*id)[1]] - _x.begin()[(*id)[0]]));
 	    //	    cerr << "$$ Actual order : " << ((attached_dir==0)?1:-1)*(_x.begin()[(*id)[1]] - _x.begin()[(*id)[0]]) << "( dir " << ((attached_dir==0)?1:-1) << " )"<< endl;
 	    actual_order_is_set=true;
@@ -641,16 +641,16 @@ georep::tangent_spline (const space& Nh, const domain& d,
   if (bc.first_tangent_imposed())
     {
      t0=bc.first_tangent();
-     u[0]=2*(h[0]);
-     v[0]=6*(b[0]-t0);
-     u[1]=2*(h[0]+h[1])-sqr(h[0])/u[0];
-     v[1]=6*(b[1]-b[0])- (h[0]/u[0])*v[0];
+     u[0]=2.*(h[0]);
+     v[0]=6.*(b[0]-t0);
+     u[1]=2.*(h[0]+h[1])-sqr(h[0])/u[0];
+     v[1]=6.*(b[1]-b[0])- (h[0]/u[0])*v[0];
      start_loop =0;
     }
   else 
     {
-     u[1]=2*(h[0]+h[1]);
-     v[1]=6*(b[1]-b[0]);
+     u[1]=2.*(h[0]+h[1]);
+     v[1]=6.*(b[1]-b[0]);
      start_loop=1 ;
     }
   for (i=2; i<=(n-1); i++)
@@ -662,14 +662,14 @@ georep::tangent_spline (const space& Nh, const domain& d,
    { 
     tn=bc.last_tangent();
     n_loop=n ;
-    u[n]=2*h[n-1]-sqr(h[n-1])/u[n-1] ;
-    v[n]= 6*(tn-b[n-1])-h[n-1]/u[n-1]*v[n-1];
+    u[n]=2.*h[n-1]-sqr(h[n-1])/u[n-1] ;
+    v[n]=6.*(tn-b[n-1])-h[n-1]/u[n-1]*v[n-1];
    }
   else 
    { 
     n_loop=n-1;
-    u[n]=2*h[n-1]-sqr(h[n-1])/u[n-1] ;
-    v[n]= 6*(tn-b[n-1])-h[n-1]/u[n-1]*v[n-1];
+    u[n]=2.*h[n-1]-sqr(h[n-1])/u[n-1] ;
+    v[n]=6.*(tn-b[n-1])-h[n-1]/u[n-1]*v[n-1];
    }
       
 
@@ -678,9 +678,8 @@ georep::tangent_spline (const space& Nh, const domain& d,
   else z[n]=1./u[n]*v[n];
      for (int j=n-1; j>=int(start_loop); j--)
        {
-       z[j]=1./u[j]*( v[j] -h[j]*z[j+1] );
-     
-       w[j]=-h[j]/6 *(z[j+1]-z[j]) +b[j];
+       z[j]=1./u[j]*(v[j] -h[j]*z[j+1]);
+       w[j]=-h[j]/6.*(z[j+1]-z[j]) +b[j];
       
        }
   if (!bc.first_tangent_imposed()){z[0]=point(0,0);w[0]=-h[0]/6 *(z[1]-z[0]) +b[0];}
@@ -839,16 +838,16 @@ georep::plane_curvature_spline (const space& Nh, const domain& d,
   if (bc.first_tangent_imposed())
     {
      t0=bc.first_tangent();
-     u[0]=2*(h[0]);
-     v[0]=6*(b[0]-t0);
-     u[1]=2*(h[0]+h[1])-sqr(h[0])/u[0];
-     v[1]=6*(b[1]-b[0])- (h[0]/u[0])*v[0];
+     u[0]=2.*(h[0]);
+     v[0]=6.*(b[0]-t0);
+     u[1]=2.*(h[0]+h[1])-sqr(h[0])/u[0];
+     v[1]=6.*(b[1]-b[0])- (h[0]/u[0])*v[0];
      start_loop =0;
     }
   else 
     {
-     u[1]=2*(h[0]+h[1]);
-     v[1]=6*(b[1]-b[0]);
+     u[1]=2.*(h[0]+h[1]);
+     v[1]=6.*(b[1]-b[0]);
      start_loop=1 ;
     }
   for (i=2; i<=(n-1); i++)
@@ -860,14 +859,14 @@ georep::plane_curvature_spline (const space& Nh, const domain& d,
    { 
     tn=bc.last_tangent();
     n_loop=n ;
-    u[n]=2*h[n-1]-sqr(h[n-1])/u[n-1] ;
-    v[n]= 6*(tn-b[n-1])-h[n-1]/u[n-1]*v[n-1];
+    u[n]=2.*h[n-1]-sqr(h[n-1])/u[n-1] ;
+    v[n]=6.*(tn-b[n-1])-h[n-1]/u[n-1]*v[n-1];
    }
   else 
    { 
     n_loop=n-1;
-    u[n]=2*h[n-1]-sqr(h[n-1])/u[n-1] ;
-    v[n]= 6*(tn-b[n-1])-h[n-1]/u[n-1]*v[n-1];
+    u[n]=2.*h[n-1]-sqr(h[n-1])/u[n-1] ;
+    v[n]=6.*(tn-b[n-1])-h[n-1]/u[n-1]*v[n-1];
    }
       
 
@@ -878,7 +877,7 @@ georep::plane_curvature_spline (const space& Nh, const domain& d,
        {
        z[j]=1./u[j]*( v[j] -h[j]*z[j+1] );
      
-       w[j]=-h[j]/6 *(z[j+1]-z[j]) +b[j];
+       w[j]=-h[j]/6.*(z[j+1]-z[j]) +b[j];
       
        }
   if (!bc.first_tangent_imposed()){z[0]=point(0,0);w[0]=-h[0]/6 *(z[1]-z[0]) +b[0];}
