@@ -144,7 +144,7 @@ get_boundary_triangles_mmg3d (istream& is, vector<domain>& domains,
 warning_macro ("n_tri = " << n_bdr_triangles);
   map<size_t, vector<tiny_element> > domain_map;
   tiny_element K;
-  K.set_type (reference_element::t);
+  K.set_variant (reference_element::t);
   for (size_type j = 0; is.good() && j < n_bdr_triangles; j++) {
     size_type r;
     is >> K[0] >> K[1] >> K[2] >> r;
@@ -246,7 +246,7 @@ warning_macro("Tetrahedra...");
 	 for (; s.good() && iter_elt != last_elt; iter_elt++, K_idx++) {
 
       	    geo_element& K = (*iter_elt);
-      	    K.set_type (n_vert_per_elt, _dim);
+      	    K.set_variant (n_vert_per_elt, _dim);
       	    K.set_index(K_idx) ;
       	    for (size_type i = 0 ; i < n_vert_per_elt; i++) {
 		s >> K[i];
@@ -259,7 +259,7 @@ warning_macro("Tetrahedra...");
       	    }
             // TODO: get region number and build 2d-domains
             size_type dummy; s >> dummy;
-           _count_element [K.type()]++;
+           _count_element [K.variant()]++;
       	   _count_geo     [_dim]++;
 	 }
       } else if (label == "End") {
@@ -452,7 +452,7 @@ georep::put_mmg3d (ostream& os, bool only_boundary) const
     if ((*iter).dimension() == dimension() - 1) n_bdr_triangle += (*iter).size();
   }
   bool is_boundary_mesh = false;
-  if (n_bdr_triangle == 0 && n_tetraedra() == 0) {
+  if (n_bdr_triangle == 0 && n_tetrahedra() == 0) {
     // boundary mesh: no domains, all triangle in the main element list
     n_bdr_triangle = n_triangle();
     is_boundary_mesh = true;
@@ -482,8 +482,8 @@ georep::put_mmg3d (ostream& os, bool only_boundary) const
   //
   // elements
   //
-  if (!only_boundary && n_tetraedra() != 0) {
-    os << endl << "Tetrahedra" << endl << n_tetraedra() << endl;
+  if (!only_boundary && n_tetrahedra() != 0) {
+    os << endl << "Tetrahedra" << endl << n_tetrahedra() << endl;
     for (const_iterator iter_k = begin(); iter_k != end(); iter_k++) {
       const geo_element& K = *iter_k;
       if (K.size() != 4) continue;
