@@ -33,7 +33,7 @@
 using namespace std;
 namespace rheolef { 
 
-#ifdef _COMMENT_
+#ifndef VTK_EMPTY_CELL
 // from vtk-3.1.2/common/vtkCellType.h:
 #define VTK_EMPTY_CELL 0
 #define VTK_VERTEX 1
@@ -53,7 +53,7 @@ namespace rheolef {
 
 #define VTK_PARAMETRIC_CURVE 51
 #define VTK_PARAMETRIC_SURFACE 52
-#endif // _COMMENT_
+#endif // VTK
 
 static
 size_t
@@ -132,11 +132,11 @@ georep::get_vtk_polydata (istream& poly)
     while (poly.good() && iter_e != last_e) {
         size_type p;
         poly >> ws >> p;
-        (*iter_e).set_type(p, dom_dim);
+        (*iter_e).set_variant(p, dom_dim);
         for (size_type i = 0 ; i < p; i++)
             poly >> (*iter_e)[i] ;
         _count_geo     [(*iter_e).dimension()]++;
-        _count_element [(*iter_e).type()]++;
+        _count_element [(*iter_e).variant()]++;
         ++iter_e;
     }
     return poly;
@@ -227,7 +227,7 @@ ostream& georep::put_vtk_P2_iso_P1 (ostream& vtk) const
   if (dimension() == 2) {
     n_internal = n_quadrangle();
   } if (dimension() == 3) {
-    n_internal = n_prism() + n_hexaedra();
+    n_internal = n_quadrangle() + n_hexaedra();
   }
   vtk << "POINTS " << n_node() + n_edge() + n_internal << " float\n";
   vtk << endl;
@@ -235,28 +235,70 @@ ostream& georep::put_vtk_P2_iso_P1 (ostream& vtk) const
   // put nodes
   for (const_iterator_node i = begin_node(); i != end_node(); i++)
       vtk << *i << endl;
-  vtk << endl;
 
   // put middle-edge nodes
   vector<size_type> v1(n_edge());
   vector<size_type> v2(n_edge());
+  vector<bool>      marked_edg (n_edge(), false);
   for (const_iterator i = begin(); i != end(); i++) {
-      const geo_element& K = *i;
-      for (size_type i = 0; i < K.n_edge(); i++) {
-         v1 [K.edge(i)] = K.subgeo_vertex (1, i, 0);
-         v2 [K.edge(i)] = K.subgeo_vertex (1, i, 1);
-      }
+    const geo_element& K = *i;
+    for (size_type loc_iedg = 0; loc_iedg < K.n_edge(); loc_iedg++) {
+      size_type iedg = K.edge(loc_iedg);
+      if (marked_edg[iedg]) continue;
+      marked_edg[iedg] = true;
+      v1 [iedg] = K.subgeo_vertex (1, loc_iedg, 0);
+      v2 [iedg] = K.subgeo_vertex (1, loc_iedg, 1);
+    }
   }
   const_iterator_node p = begin_node();
-  for (size_type j = 0; j < n_edge(); j++) {
-      vtk << 0.5*(p[v1[j]] + p[v2[j]]) << "\n" ;
+  for (size_type iedg = 0; iedg < n_edge(); iedg++) {
+      vtk << 0.5*(p[v1[iedg]] + p[v2[iedg]]) << endl;
   }
-  // put internal-nodes
+  // put quadrangle internal-nodes
   if (dimension() == 2 && n_quadrangle() != 0) {
     for (const_iterator i = begin(); i != end(); i++) {
       const geo_element& K = *i;
-      if (K.type() != geo_element::q) continue;
-      vtk << 0.25*(p[K[0]] + p[K[1]] + p[K[2]] + p[K[3]]) << "\n" ;
+      if (K.variant() != geo_element::q) continue;
+      vtk << 0.25*(p[K[0]] + p[K[1]] + p[K[2]] + p[K[3]]) << endl;
+    }
+  }
+  // 3d quadrangular faces are not represented: build internal node by scanning volume elements
+  if (dimension() == 3 && n_quadrangle() != 0) {
+    vector<bool>  marked_qua (n_quadrangle(), false);
+    vector<point> xqua       (n_quadrangle());
+    for (const_iterator i = begin(); i != end(); i++) {
+      const geo_element& K = *i;
+      if (K.variant() == geo_element::T) {
+	continue;
+      } else if (K.variant() == geo_element::H || K.variant() == geo_element::P) {
+	// prism: the two tri faces are numbered first, the three quad faces are numbered last
+	size_type loc_ifac0 = (K.variant() == geo_element::H) ? 0 : 2;
+	size_type loc_nfac  = (K.variant() == geo_element::H) ? 6 : 5;
+	for (size_type loc_ifac = loc_ifac0; loc_ifac < loc_nfac; loc_ifac++) {
+          size_type iqua = K.face(loc_ifac) - n_triangle();
+          if (marked_qua [iqua]) continue;
+	  marked_qua [iqua] = true;
+	  xqua[iqua] = point(0,0,0);
+	  for (size_type jloc = 0; jloc < 4; jloc++) {
+	    xqua[iqua] += p[K.subgeo_vertex (2, loc_ifac, jloc)];
+	  }
+	  xqua[iqua] /= 4;
+        }
+      } else {
+        error_macro ("P2_iso_P1: element type `"<<K.name()<<"' not yet supported");
+      }
+    }
+    for (size_type iqua = 0; iqua < n_quadrangle(); iqua++) {
+      vtk << xqua[iqua] << endl;
+    }
+  }
+  // put hexa internal-nodes
+  if (dimension() == 3 && n_hexaedra() != 0) {
+    for (const_iterator i = begin(); i != end(); i++) {
+      const geo_element& K = *i;
+      if (K.variant() != geo_element::H) continue;
+      vtk << 0.125*(p[K[0]] + p[K[1]] + p[K[2]] + p[K[3]]
+                  + p[K[4]] + p[K[5]] + p[K[6]] + p[K[7]]) << endl;
     }
   }
   vtk << endl ;
@@ -267,19 +309,20 @@ ostream& georep::put_vtk_P2_iso_P1 (ostream& vtk) const
   for (const_iterator i = begin(); i != end(); i++) {
       const geo_element& K = *i;
       switch (K.name()) {
-	case 'p' : sz += 1; ndata +=  2; break;  // 1 p
-	case 'e' : sz += 2; ndata +=  6; break;  // 2 e
-	case 't' : sz += 4; ndata += 16; break;  // 4 t
-	case 'q' : sz += 4; ndata += 20; break;  // 4 q
-	case 'T' : sz += 8; ndata += 40; break;  // 8 T
-        default  : error_macro ("P2-iso-P1: element `" 
-			<< K.name() << "' not supported -- sorry.");
-                   break;
+	case 'p' : sz += 1; ndata +=     1+1 ; break;  // 1 p
+	case 'e' : sz += 2; ndata +=  2*(2+1); break;  // 2 e
+	case 't' : sz += 4; ndata +=  4*(3+1); break;  // 4 t
+	case 'q' : sz += 4; ndata +=  4*(4+1); break;  // 4 q
+	case 'T' : sz += 8; ndata +=  8*(4+1); break;  // 8 T
+	case 'P' : sz += 8; ndata +=  8*(6+1); break;  // 8 P
+	case 'H' : sz += 8; ndata +=  8*(8+1); break;  // 8 H
+        default  : error_macro ("P2-iso-P1: unexpected element `" << K.name() << "'"); break;
      }
   }
   vtk << "CELLS " << sz << " " << ndata << endl;
   size_type nn = n_node();
   size_type ne = n_edge();
+  size_type nf = n_face();
   size_type E [12];
   for (const_iterator i = begin(); i != end(); i++) {
       const geo_element& K = *i;
@@ -324,7 +367,64 @@ ostream& georep::put_vtk_P2_iso_P1 (ostream& vtk) const
 		;
 	    break;
 	}
-        default : break;
+	case 'P' : { // 8 H
+	    // prism: the two tri faces are numbered first, the three quad faces are numbered last
+	    // Hyp: face triangle are numbered first; create internal nodes
+            size_type F [3];
+            for (size_type iloc = 2; iloc < 5; iloc++) {
+              size_type iqua = K.face(iloc) - n_triangle();
+              F[iloc-2] = nn + ne + iqua;
+            }
+	    // Hyp: volume tetra are numbered first, then prism & hexa; create internal node
+	    vtk << "6\t" << K[0] << " " << E[0] << " " << E[2] << " "
+	                 << E[3] << " " << F[1] << " " << F[0] << endl
+	        << "6\t" << E[1] << " " << E[2] << " " << E[0] << " "
+	                 << F[2] << " " << F[0] << " " << F[1] << endl
+	        << "6\t" << E[0] << " " << K[1] << " " << E[1] << " "
+	                 << F[1] << " " << E[4] << " " << F[2] << endl
+	        << "6\t" << E[2] << " " << E[1] << " " << K[2] << " "
+	                 << F[0] << " " << F[2] << " " << E[5] << endl
+	        << "6\t" << E[3] << " " << F[1] << " " << F[0] << " "
+	                 << K[3] << " " << E[6] << " " << E[8] << endl
+	        << "6\t" << F[2] << " " << F[0] << " " << F[1] << " "
+	                 << E[7] << " " << E[8] << " " << E[6] << endl
+	        << "6\t" << F[1] << " " << E[4] << " " << F[2] << " "
+	                 << E[6] << " " << K[4] << " " << E[7] << endl
+	        << "6\t" << F[0] << " " << F[2] << " " << E[5] << " "
+	                 << E[8] << " " << E[7] << " " << K[5] << endl;
+	    break;
+	}
+	case 'H' : { // 8 H
+	    // Hyp: face triangle are numbered first; create internal nodes
+            size_type F [6];
+            for (size_type iloc = 0; iloc < 6; iloc++) {
+              size_type iqua = K.face(iloc) - n_triangle();
+              F[iloc] = nn + ne + iqua;
+            }
+	    // Hyp: volume tetra are numbered first, then prism & hexa; create internal node
+            size_type nqua = n_quadrangle();
+            size_type ihex = K.index() - n_tetrahedra() - n_prism();
+            size_type C0 = nn + ne + nqua + ihex;
+	    vtk << "8\t" << K[0] << " " << E[0] << " " << F[0] << " " << E[3] << " "
+	                 << E[4] << " " << F[2] << " " <<  C0  << " " << F[1] << endl
+	        << "8\t" << E[0] << " " << K[1] << " " << E[1] << " " << F[0] << " "
+	                 << F[2] << " " << E[5] << " " << F[4] << " " <<  C0  << endl
+	        << "8\t" << F[0] << " " << E[1] << " " << K[2] << " " << E[2] << " "
+	                 <<  C0  << " " << F[4] << " " << E[6] << " " << F[5] << endl
+	        << "8\t" << E[3] << " " << F[0] << " " << E[2] << " " << K[3] << " "
+	                 << F[1] << " " <<  C0  << " " << F[5] << " " << E[7] << endl
+	        << "8\t" << E[4] << " " << F[2] << " " <<  C0  << " " << F[1] << " "
+	                 << K[4] << " " << E[8] << " " << F[3] << " " << E[11]<< endl
+	        << "8\t" << F[2] << " " << E[5] << " " << F[4] << " " <<  C0  << " "
+	                 << E[8] << " " << K[5] << " " << E[9] << " " << F[3] << endl
+	        << "8\t" <<  C0  << " " << F[4] << " " << E[6] << " " << F[5] << " "
+	                 << F[3] << " " << E[9] << " " << K[6] << " " << E[10]<< endl
+	        << "8\t" << F[1] << " " <<  C0  << " " << F[5] << " " << E[7] << " "
+	                 << E[11]<< " " << F[3] << " " << E[10]<< " " << K[7] << endl
+		;
+	    break;
+	}
+        default  : error_macro ("P2-iso-P1: unexpected element `" << K.name() << "'"); break;
       }
   }
   vtk << endl;
@@ -334,12 +434,14 @@ ostream& georep::put_vtk_P2_iso_P1 (ostream& vtk) const
       size_type ncell     = 0;
       size_type cell_type = 0;
       switch (K.name()) {
-	case 'p' : ncell = 1; cell_type = 1; break;
-	case 'e' : ncell = 2; cell_type = 3; break;
-	case 't' : ncell = 4; cell_type = 5; break;
-	case 'q' : ncell = 4; cell_type = 9; break;
-	case 'T' : ncell = 8; cell_type = 10; break;
-        default : break;
+	case 'p' : ncell = 1; cell_type = VTK_VERTEX; break;
+	case 'e' : ncell = 2; cell_type = VTK_LINE; break;
+	case 't' : ncell = 4; cell_type = VTK_TRIANGLE; break;
+	case 'q' : ncell = 4; cell_type = VTK_QUAD; break;
+	case 'T' : ncell = 8; cell_type = VTK_TETRA; break;
+	case 'P' : ncell = 8; cell_type = VTK_WEDGE; break;
+	case 'H' : ncell = 8; cell_type = VTK_HEXAHEDRON; break;
+        default  : error_macro ("P2-iso-P1: unexpected element `" << K.name() << "'"); break;
       }
       for (size_type k = 0; k < ncell; k++) vtk << cell_type << endl;
   }
