@@ -89,11 +89,11 @@ georep::set_coordinate_system (const string& name)
 // ============================================================================
 
 georep::georep(const georep& g)
- : occurence(),
-   Vector<geo_element>(g),
+ : Vector<geo_element>(g),
    _name(g._name),
    _number(g._number),
    _serial_number(g._serial_number),
+   _zero_level_set_number(0),
    _dim(g._dim),
    _coord_sys(g._coord_sys),
    _x(g._x),
@@ -111,7 +111,7 @@ georep::georep(const georep& g)
 {
     for (size_type i = 0; i < 4; i++)
   	_count_geo[i] = g._count_geo[i];
-    for (size_type i = 0; i < reference_element::max_size; i++)
+    for (size_type i = 0; i < reference_element::max_variant; i++)
   	_count_element[i] = g._count_element[i];
 }
 // ----------------------------------------------------------------------------
@@ -122,14 +122,14 @@ void
 georep::reset_counters ()
 {
    std::fill(_count_geo, _count_geo+4, 0);
-   std::fill(_count_element, _count_element+reference_element::max_size, 0);
+   std::fill(_count_element, _count_element+reference_element::max_variant, 0);
 }
 georep::georep(const string& a_file_name, const string& coord_sys_name)
-  : occurence(),
-    Vector<geo_element>(),
+  : Vector<geo_element>(),
     _name(), 
     _number(numeric_limits<size_type>::max()),
     _serial_number(numeric_limits<size_type>::max()),
+    _zero_level_set_number(0),
     _dim(0), 
     _coord_sys(fem_helper::coordinate_system(coord_sys_name)),
     _x(), 
@@ -200,11 +200,11 @@ georep::georep(const string& a_file_name, const string& coord_sys_name)
 // ----------------------------------------------------------------------------
 
 georep::georep (const nodelist_type& p, const georep& g)
- : occurence(),
-   Vector<geo_element>(g),
+ : Vector<geo_element>(g),
    _name(g._name),
    _number(numeric_limits<size_type>::max()),
    _serial_number(numeric_limits<size_type>::max()),
+   _zero_level_set_number(0),
    _dim(g._dim),
    _coord_sys(g._coord_sys),
    _x(p),
@@ -246,7 +246,7 @@ georep::georep (const nodelist_type& p, const georep& g)
   
   for (size_type i = 0; i < 4; i++)
   	_count_geo[i] = g._count_geo[i];
-  for (size_type i = 0; i < reference_element::max_size; i++)
+  for (size_type i = 0; i < reference_element::max_variant; i++)
   	_count_element[i] = g._count_element[i];
 }
 // ----------------------------------------------------------------------------
@@ -254,11 +254,11 @@ georep::georep (const nodelist_type& p, const georep& g)
 // ----------------------------------------------------------------------------
 
 georep::georep(const georep& g, const domain& d)
-  : occurence(),
-    Vector<geo_element>(d.size()),
+  : Vector<geo_element>(d.size()),
     _name(d.name()),
     _number(numeric_limits<size_type>::max()),
     _serial_number(numeric_limits<size_type>::max()),
+   _zero_level_set_number(0),
     _dim(g.dimension()),
     _coord_sys(g._coord_sys),
     _x(),
@@ -283,8 +283,7 @@ georep::georep(const georep& g, const domain& d)
   // step 1 : numbering of vertices
 
   vector<bool> node_on_d (g.n_node(), false);
-  domain::const_iterator last_side = d.end();
-  for (domain::const_iterator i = d.begin(); i != last_side; i++) {
+  for (domain::const_iterator i = d.begin(), last_side = d.end(); i != last_side; i++) {
 
       const geo_element& S = *i;
       for (size_type j = 0; j < S.size(); j++)
@@ -325,20 +324,20 @@ georep::georep(const georep& g, const domain& d)
   resize(d.size());
   size_type K_idx = 0;
   iterator iter_elt = begin(); 
-  for (domain::const_iterator iter_side = d.begin(); 
+  for (domain::const_iterator iter_side = d.begin(), last_side = d.end(); 
 	iter_side != last_side; 
 	iter_side++, K_idx++, iter_elt++) {
 
       const geo_element& S = *iter_side;
       geo_element&       K = *iter_elt;
-      K.set_type(S.type()) ;
+      K.set_variant(S.variant()) ;
       K.set_index (K_idx);
       for (size_type i = 0; i < K.size(); i++) {
   	  K[i] = new_vertex_idx [S[i]];
       }
       // update counters
       _count_geo    [K.dimension()]++;
-      _count_element[K.type()]++;
+      _count_element[K.variant()]++;
   }
   build_connectivity (*this);
 }
@@ -560,7 +559,7 @@ meshpoint
 georep::hatter (const point& x, size_type K_idx) const
 {
     const geo_element& K = element(K_idx);
-    switch(begin()[K_idx].type()) {
+    switch(begin()[K_idx].variant()) {
         case geo_element::e: {
 	    if (dimension()==1)
 	     {
@@ -616,7 +615,7 @@ georep::hatter (const point& x, size_type K_idx) const
 point
 georep::dehatter (const meshpoint& S, bool is_a_vector) const
 {
-    switch(begin()[S.element()].type())
+    switch(begin()[S.element()].variant())
      {
         case geo_element::e: {
             double a = begin_node()[begin()[S.element()][0]][0];
@@ -717,7 +716,7 @@ georep::dump (ostream& os) const
     ;
   for (size_type i = 0; i < 4; i++)
      os << "count_geo[" << i << "] = " << _count_geo[i] << endl;
-  for (size_type i = 0; i < reference_element::max_size; i++)
+  for (size_type i = 0; i < reference_element::max_variant; i++)
      os << "count_element[" << i << "] = " << _count_element[i] << endl;
 
   size_type i = 0;
@@ -802,7 +801,7 @@ ostream& georep::put(ostream& s) const
 	  const geo_element& K = *iter_elt;
 	  for (size_type i = 0; i < K.n_face(); i++) {
 	      size_type idx = K.subgeo (2, i);
-	      if (f [idx].type() == reference_element::max_size) {
+	      if (f [idx].variant() == reference_element::max_variant) {
 		// not yet builded:
 	        K.build_subgeo (2, i, f[idx]);
 	      }
@@ -975,7 +974,7 @@ georep::get_rheo(istream& is)
       is >> (*i);
       (*i).set_index (idx);
       _count_geo     [(*i).dimension()]++;
-      _count_element [(*i).type()]++;
+      _count_element [(*i).variant()]++;
   }
   size_type map_d = map_dimension();
 
@@ -1186,7 +1185,7 @@ Float
 georep::measure (const geo_element& K) const
 {
   georep::const_iterator_vertex p = begin_vertex();
-  switch (K.type()) {
+  switch (K.variant()) {
     case geo_element::p:
       return 0;
     case geo_element::e:
@@ -1226,7 +1225,7 @@ georep::measure (const geo_element& K) const
 point
 georep::normal (const geo_element& K, georep::size_type side) const
 {
-  switch (K.type()) {
+  switch (K.variant()) {
     case reference_element::e:  { // works also in 2d and 3d
       point t = vertex(K[1]) - vertex(K[0]);
       t = t/norm(t);
@@ -1240,14 +1239,14 @@ georep::normal (const geo_element& K, georep::size_type side) const
     // TODO: T, P, H...
     default:
       error_macro("normal to element not yet implemented for element type `"
-	<< K.type() << "'");
+	<< K.variant() << "'");
   }
 }
 // compute normal to a facet: triangle in 3D, etc
 point
 georep::normal (const geo_element& S) const
 {
-  switch (S.type()) {
+  switch (S.variant()) {
     case reference_element::e:  { // 2d space
       point t = vertex(S[1]) - vertex(S[0]);
       t = t/norm(t);
@@ -1263,7 +1262,7 @@ georep::normal (const geo_element& S) const
     }
     default:
       error_macro("normal to facet not yet implemented for element type `"
-	<< S.type() << "'");
+	<< S.variant() << "'");
   }
 }
 }// namespace rheolef
