@@ -81,12 +81,12 @@ protected:
 
 // data:
   size_type                                                             _degree;
-  mutable boost::array<bool,reference_element::max_variant>             _initialized;
-  mutable boost::array<std::vector<point_basic<size_type> >,
+  mutable std::array<bool,reference_element::max_variant>               _initialized;
+  mutable std::array<std::vector<point_basic<size_type> >,
 		       reference_element::max_variant>                  _monom;
-  mutable boost::array<std::vector<point_basic<T> >,
+  mutable std::array<std::vector<point_basic<T> >,
 		       reference_element::max_variant>                  _hat_xnod;
-  mutable boost::array<ublas::matrix<T>,reference_element::max_variant> _inv_vdm;
+  mutable std::array<ublas::matrix<T>,reference_element::max_variant>   _inv_vdm;
 // working array, allocated one time for all to _degree+1 size:
   mutable std::vector<point_basic<T> >                                  _hat_xm;
 };
