@@ -200,8 +200,8 @@ void
 Pk_set_ios_permutations (
     const geo_basic<T,M>& omega,
     size_t			       degree,
-    array<distributor::size_type,M>&   idof2ios_dis_idof,
-    array<distributor::size_type,M>&   ios_idof2dis_idof)
+    disarray<distributor::size_type,M>&   idof2ios_dis_idof,
+    disarray<distributor::size_type,M>&   ios_idof2dis_idof)
 {
 }
 #ifdef _RHEOLEF_HAVE_MPI
@@ -211,11 +211,11 @@ void
 Pk_set_ios_permutations (
     const geo_basic<T,distributed>&              omega,
     size_t					 degree,
-    array<distributor::size_type,distributed>&   idof2ios_dis_idof,
-    array<distributor::size_type,distributed>&   ios_idof2dis_idof)
+    disarray<distributor::size_type,distributed>&   idof2ios_dis_idof,
+    disarray<distributor::size_type,distributed>&   ios_idof2dis_idof)
 {
   typedef size_t size_type;
-  boost::array<size_type,reference_element::max_variant> loc_ndof_by_variant ;
+  std::array<size_type,reference_element::max_variant> loc_ndof_by_variant ;
   reference_element::init_local_nnode_by_variant (degree, loc_ndof_by_variant);
   omega.set_ios_permutation (loc_ndof_by_variant, idof2ios_dis_idof);
   size_type dis_ndof = idof2ios_dis_idof.ownership().dis_size();
@@ -228,8 +228,8 @@ template <class T, class M>
 void
 numbering_Pk<T,M>::set_ios_permutations (
     const geo_basic<T,M>& omega,
-    array<size_type,M>&   idof2ios_dis_idof,
-    array<size_type,M>&   ios_idof2dis_idof) const
+    disarray<size_type,M>&   idof2ios_dis_idof,
+    disarray<size_type,M>&   ios_idof2dis_idof) const
 {
     Pk_set_ios_permutations (omega, degree(), idof2ios_dis_idof, ios_idof2dis_idof);
 }
