@@ -47,8 +47,8 @@ public:
   size_type   dis_ndof (const geo_size& gs, size_type map_dim) const;
   void        dis_idof (const geo_size& gs, const geo_element& K, std::vector<size_type>& dis_idof) const;
   void set_ios_permutations (const geo_basic<T,M>& omega,
-    		array<size_type,M>&   idof2ios_dis_idof,
-    		array<size_type,M>&   ios_idof2dis_idof) const;
+    		disarray<size_type,M>&   idof2ios_dis_idof,
+    		disarray<size_type,M>&   ios_idof2dis_idof) const;
 };
 
 }// namespace rheolef
