@@ -70,8 +70,9 @@ INPUT FILE SPECIFICATION:
 
 OUTPUT FILE FORMAT OPTIONS:
   @table @code
-  @item -field
-	output field on standard output stream in field text file format.
+  @item -text
+  @itemx -field
+	output field on standard output stream in Rheolef ascii (field or geo) text file format.
 @toindex @code{gmsh}
 @fiindex @file{.gmsh} mesh file
 @fiindex @file{.gmsh_pos} data file
@@ -176,7 +177,7 @@ RENDERING OPTIONS:
     @itemx -nocut
         Cut by a specified plane.
         The cutting plane is specified by its origin point and normal vector.
-        This option requires the @code{mayavi} or @code{paraview} code.
+        This option requires the @code{paraview} code.
     @item -origin @var{float} [@var{float} [@var{float}]]
         set the origin of the cutting plane.
         Default is (0.5, 0.5, 0.5).
@@ -186,7 +187,7 @@ RENDERING OPTIONS:
     @item -iso [@var{float}]
         do draw 3d isosurface. When the optional float is not provided,
 	a median value is used.
-        This option requires the @code{mayavi} code.
+        This option requires the @code{paraview} code.
     @item -noiso
         do not draw isosurface.
     @item -n-iso @var{int}
@@ -194,8 +195,12 @@ RENDERING OPTIONS:
         regularly spaced values from fmin to fmax, the bounds
         of the field.
 @cindex projection
+    @item -proj @var{approx}
+        Convert all selected fields to approximation @var{approx} by using a L2 projection.
     @item -proj
         Convert all selected fields to Pk-continuous approximation by using a L2 projection.
+    @item -lumped-proj
+        Force P1 approximation for L2 projection and use a lumped mass matrix for it.
     @item -round [@var{float}]
         Round the input up to the specifiexd precision.
         This option, combined with @code{-field}, leads to a round filter.
@@ -290,7 +295,7 @@ EXAMPLES:
   @end example
   This command generates the cutted 2d field and its associated mesh.
   @example
-    field cube.field -iso 0.5 -plotmtv
+    field cube.field -iso 0.5
   @end example
   This command draws the isosurface.
   @example
@@ -316,7 +321,6 @@ End:
 
 # include "rheolef.h"
 # include "rheolef/iofem.h"
-# include "rheolef/rounder.h"
 using namespace rheolef;
 using namespace std;
 void usage() {
@@ -326,7 +330,7 @@ void usage() {
            << "[-Idir|-I dir] "
            << "[-catchmark string] "
            << "[-min|-max] "
-           << "[-field|-gmsh|-gmsh-pos|-bamg-bb] "
+           << "[-field|-text|-gmsh|-gmsh-pos|-bamg-bb] "
            << "[-gnuplot|-mayavi|-paraview] "
            << "[-image-format string] "
            << "[-resolution int [int]] "
@@ -343,7 +347,8 @@ void usage() {
            << "[-subdivide int] "
            << "[-comp string] "
            << "[-domain string] "
-           << "[-proj] "
+           << "[-proj [string]] "
+           << "[-lumped-proj] "
            << "[-round float] "
            << "[-velocity|-deformation] "
            << "[-elevation] "
@@ -354,7 +359,9 @@ void usage() {
 }
 // extern:
 namespace rheolef {
-  template <class T> field_basic<T,sequential> plane_cut (
+  template <class T> geo_basic<T,sequential> paraview_isosurface (
+    const field_basic<T,sequential>& uh);
+  template <class T> field_basic<T,sequential> paraview_plane_cut (
     const field_basic<T,sequential>& uh,
     const point_basic<T>&            origin,
     const point_basic<T>&            normal);
@@ -401,10 +408,12 @@ int main(int argc, char**argv) {
     field_basic<Float,sequential> uh;
     bool def_plane_cut_opt = false;
     bool def_fill_opt = false;
-    bool do_iso3d = true;
+    bool do_iso3d = false;
     std::string i_comp_name = "";
     size_t i_comp = std::numeric_limits<size_t>::max();
     bool do_proj = false;
+    string use_proj_approx = "";
+    bool do_lumped_mass = false;
     bool do_cut  = false;
     bool do_round = false;
     std::string reduce_to_domain = "";
@@ -429,6 +438,7 @@ int main(int argc, char**argv) {
         else if (argv [i][0] == '-' && argv [i][1] == 'I')  { append_dir_to_rheo_path (argv[i]+2); }
 	// output file option:
         else if (strcmp (argv[i], "-field") == 0)           { dout.os() << rheo;     render = file_render; }
+        else if (strcmp (argv[i], "-text") == 0)            { dout.os() << rheo;     render = file_render; }
         else if (strcmp (argv[i], "-gmsh") == 0)            { dout.os() << gmsh;     render = file_render; }
         else if (strcmp (argv[i], "-gmsh-pos") == 0)        { dout.os() << gmsh_pos; render = file_render; }
         else if (strcmp (argv[i], "-bamg-bb") == 0)         { dout.os() << bamg;     render = file_render; }
@@ -442,8 +452,17 @@ int main(int argc, char**argv) {
         else if (strcmp (argv[i], "-paraview")  == 0)       { dout.os() << paraview; render = paraview_render; }
 
 	// filter 
-        else if (strcmp (argv[i], "-proj") == 0)            { do_proj = true; }
-
+        else if (strcmp (argv[i], "-proj") == 0)            {
+	    do_proj = true;
+            if (i+1 < argc && argv[i+1][0] != '-') {
+              use_proj_approx = argv[++i];
+            }
+	}
+        else if (strcmp (argv[i], "-lumped-proj") == 0)     {
+	    do_proj = true;
+	    do_lumped_mass = true;
+	    use_proj_approx = "P1";
+        }
         // inquire option
         else if (strcmp (argv[i], "-min") == 0)       { show = show_min; }
         else if (strcmp (argv[i], "-max") == 0)       { show = show_max; }
@@ -624,7 +643,6 @@ int main(int argc, char**argv) {
     }
     if (uh.get_geo().map_dimension() == 3) {
       // default 3D is iso+cut and nofill; default 2D is nocut and fill...
-      if (do_iso3d)            dout.os() << iso;
       if (!def_plane_cut_opt)  dout.os() << cut;
       if (!def_fill_opt)       dout.os() << nofill;
     }
@@ -677,10 +695,30 @@ int main(int argc, char**argv) {
       const space_basic<Float,sequential>& Uh = uh.get_space();
       size_t k = Uh.degree();
       if (k == 0) k++;
-      std::string approx = "P" + itos(k);
+      std::string approx = (use_proj_approx == "") ? "P" + itos(k) : use_proj_approx;
       space_basic<Float,sequential> Vh (uh.get_geo(), approx, uh.valued());
-      form_basic<Float,sequential> m  (Vh, Vh, "mass");
-      form_basic<Float,sequential> p  (Uh, Vh, "mass");
+      test_basic<Float,sequential,details::vf_tag_10> u (Uh), v (Vh);
+      test_basic<Float,sequential,details::vf_tag_01> vt (Vh);
+      form_option_type fopt;
+      fopt.lump = do_lumped_mass;
+      form_basic<Float,sequential> m, p;
+      switch (Uh.valued_tag()) {
+        case space_constant::scalar:
+	  m = integrate(v*vt, fopt);
+	  p = integrate(u*vt);
+	  break;
+        case space_constant::vector:
+	  m = integrate(dot(v,vt), fopt);
+	  p = integrate(dot(u,vt));
+	  break;
+        case space_constant::tensor:
+        case space_constant::unsymmetric_tensor:
+	  m = integrate(ddot(v,vt), fopt);
+	  p = integrate(ddot(u,vt));
+	  break;
+	default:
+	  error_macro ("proj: unexpected valued field: " << Uh.valued());
+      }
       solver_basic<Float,sequential> sm = ldlt(m.uu());
       field_basic<Float,sequential> vh (Vh);
       vh.set_u() = sm.solve((p*uh).u());
@@ -689,7 +727,7 @@ int main(int argc, char**argv) {
     if (do_cut) {
        point origin = iofem::getorigin(cout);
        point normal = iofem::getnormal(cout);
-       uh = plane_cut (uh, origin, normal);
+       uh = paraview_plane_cut (uh, origin, normal);
        if (render == file_render) {
 	 // put field on dout: save also the cutted geo:
 	 odiststream geo_out (uh.get_geo().name(), "geo");
@@ -700,14 +738,19 @@ int main(int argc, char**argv) {
       uh = round (uh, round_prec);
     }
     if (show == show_min) {
-          cout << std::setprecision(std::numeric_limits<Float>::digits10)
-               << uh.min() << endl;
-          return 0;
+      cout << std::setprecision(std::numeric_limits<Float>::digits10)
+           << uh.min() << endl;
+      return 0;
     }
     if (show == show_max) {
-          cout << std::setprecision(std::numeric_limits<Float>::digits10)
-               << uh.max() << endl;
-          return 0;
+      cout << std::setprecision(std::numeric_limits<Float>::digits10)
+           << uh.max() << endl;
+      return 0;
+    }
+    if (do_iso3d) {
+      geo_basic<Float,sequential> iso_surface = paraview_isosurface (uh);
+      dout << iso_surface;
+      return 0;
     }
     // generates marks (mayavi support it now):
     {
