@@ -112,9 +112,6 @@ RENDER OPTIONS:
   @item -[no]lattice
   	When using a high order geometry, the lattice inside any element appears.
 	Default is on;
-  @item -subdivide int
-  	When using a high order geometry, the number of points per edge used to draw
-	a curved element. Default value is the mesh order.
   @item -[no]full
   	All internal edges appears, for 3d meshes.
 	Default is off;
@@ -175,6 +172,17 @@ OUTPUT FILE FORMAT OPTIONS:
 
 OTHERS OPTIONS:
   @table @code
+    @item -subdivide int
+@cindex mesh subdividing
+ 	Subdivide each edge in @var{k} parts,
+	where @var{k} is the prescribed argument.
+	The new vertices are numbered so that they coincide with the P@var{k} Lagrange nodes.
+	It can be combined with the @code{-geo} option to get the subdivided mesh.
+	In that case, default value is 1, i.e. no subdividing.
+	It can also be combined with a graphic option, such that @code{-gnuplot} or @code{paraview}:
+  	When dealing with a curved high order geometry, 
+  	@var{k} corresponds to the number of points per edge used to draw a curved element. 
+	In that case, this option is activated by default and value is the curved mesh order.
     @item -add-boundary
         check for a domain named "boundary"; If this domain
   	does not exists, extract the boundary of the geometry
@@ -247,11 +255,11 @@ void usage() {
            << "[-Idir|-I dir] "
            << "[-check] "
            << "[-upgrade] "
+           << "[-subdivide int] "
            << "[-if {geo,bamg,vtk}] "
            << "[-geo|-gmsh|-gnuplot|-mayavi|-paraview] "
            << "[-name string] "
            << "[-[no]full|-[no]fill|-[no]lattice] "
-           << "[-subdivide int] "
            << "[-[no]stereo|-[no]full|-[no]cut|-[no]shrink|-[no]label] "
            << "[-image-format string] "
            << "[-resolution int [int]] "
@@ -471,6 +479,14 @@ int main(int argc, char**argv) {
     if (sys_coord != "") { omega.set_coordinate_system(sys_coord); }
     if (do_add_bdry) { omega.boundary(); }
 
+    if (render == file_render) {
+      size_t nsub = iorheo::getsubdivide (std::cout);
+      if (nsub >= 2) {
+        geo_basic<Float,sequential> new_omega;
+        new_omega.build_by_subdividing (omega, nsub);
+        omega = new_omega;
+      }
+    }
     if (do_check) {
         check_macro (omega.check(bverbose), "geo check failed");
     }
