@@ -21,7 +21,7 @@
 #include "rheolef/adapt.h"
 #include "rheolef/form.h"
 #include "rheolef/field_component.h"
-#include "rheolef/field_expr_ops.h"
+#include "rheolef/field_expr_v2_linear.h"
 
 namespace rheolef {
 
@@ -116,8 +116,8 @@ hessian_criterion (
   field_component<T,M>       mh_comp [3][3];
   for (size_type i_comp = 0; i_comp < d; i_comp++) {
   for (size_type j_comp = 0; j_comp < d; j_comp++) {
-    hh_comp[i_comp][j_comp] = hh(i_comp,j_comp);
-    mh_comp[i_comp][j_comp] = mh(i_comp,j_comp);
+    hh_comp[i_comp][j_comp].proxy_assign (hh(i_comp,j_comp));
+    mh_comp[i_comp][j_comp].proxy_assign (mh(i_comp,j_comp));
   }}
   tensor_basic<T> h_value, m_value, Q, Qt;
   point_basic<T> lambda, h_local;
