@@ -23,8 +23,7 @@
 // Author: Pierre Saramito
 //
 #include "rheolef/band.h"
-#include "rheolef/field.h"
-#include "rheolef/field_indirect.h"
+#include "rheolef/field_expr_v2_linear.h"
 #include "rheolef/rheostream.h"
 
 #include <boost/numeric/ublas/matrix.hpp>
@@ -40,7 +39,7 @@ level_set_internal (
     const field_basic<T,M>&,      
     const level_set_option_type&,
     std::vector<size_t>&,
-    array<size_t,M>&);      
+    disarray<size_t,M>&);      
 
 // =========================================================================
 // part 0: utility
@@ -75,7 +74,7 @@ build_vertex_connex_component (
   //    and icc-th connex component will be marked 1+icc (icc=0,1..)
   //
   distributor element_ownership = band.sizes().ownership_by_dimension[map_dim];
-  array<size_type,M> element_mark (element_ownership, not_marked);
+  disarray<size_type,M> element_mark (element_ownership, not_marked);
   for (size_type iie = 0, ine = isolated_ie_list.size(); iie < ine; iie++) {
     element_mark [isolated_ie_list [iie]] = 0;
   }
@@ -193,7 +192,7 @@ build_vertex_connex_component (
   // => re-number icc on io_proc into merged_icc
   //
   size_type unset = std::numeric_limits<size_type>::max();
-  array<size_type,M> icc2merged_dis_icc (cc_ownership, unset);
+  disarray<size_type,M> icc2merged_dis_icc (cc_ownership, unset);
   size_type merged_dis_ncc = 0;
   if (my_proc == io_proc) {
     std::vector<size_type> tmp_icc2merged_dis_icc (cc_ownership.dis_size(), unset);
@@ -208,7 +207,7 @@ build_vertex_connex_component (
       }
       merged_dis_ncc++;
     }
-    // distribute the tmp_icc2merged_dis_icc array:
+    // distribute the tmp_icc2merged_dis_icc disarray:
     for (size_type dis_icc = 0; dis_icc < dis_ncc; dis_icc++) {
       icc2merged_dis_icc.dis_entry (dis_icc) = tmp_icc2merged_dis_icc [dis_icc];
     }
@@ -326,7 +325,7 @@ band_basic<T,M>::band_basic (
   domain_indirect_basic<M> band_indirect (lambda, "band", map_dim, comm, bnd_dom_ie_list);
   geo_basic<T,M> band_domain = geo_basic<T,M> (band_indirect, lambda); 
   // 2.2) reduce phi_h to the band domain & get its geo_domain band
-  field_basic<T,M> phi_h_band = phi_h [band_domain];
+  field_basic<T,M> phi_h_band (phi_h [band_domain]);
   _band = phi_h_band.get_geo();
   // 
   // 3) create the "zero" containing vertices xi such that phi(xi) = 0
@@ -350,7 +349,7 @@ band_basic<T,M>::band_basic (
   phi_h_band.dis_dof_update();
   distributor element_ownership = _band.sizes().ownership_by_dimension[map_dim];
   size_type not_marked = std::numeric_limits<size_type>::max();
-  array<size_type,M> is_isolated  (element_ownership, 1); // 1=true, for bool
+  disarray<size_type,M> is_isolated  (element_ownership, 1); // 1=true, for bool
   std::vector<size_type>  isolated_ie_list;
   size_type ie = 0;
   for (typename geo_basic<T,M>::const_iterator
