@@ -89,9 +89,9 @@ protected:
     mutable bool                                        _specific_value;
     const quadrature<T>*                                _p_quad; // when mode: on quadrature pointset
     basis_basic<T>                                      _nb;     // when mode: on nodal basis pointset
-    mutable boost::array<size_type, reference_element::max_variant>                   _basis_size;
-    mutable boost::array<std::vector<T>,reference_element::max_variant>               _val;
-    mutable boost::array<std::vector<point_basic<T> >,reference_element::max_variant> _grad_val;
+    mutable std::array<size_type, reference_element::max_variant>                   _basis_size;
+    mutable std::array<std::vector<T>,reference_element::max_variant>               _val;
+    mutable std::array<std::vector<point_basic<T> >,reference_element::max_variant> _grad_val;
     mutable std::vector<bool>                           _initialized;
     mutable std::vector<bool>                           _grad_initialized;
     mutable size_type                                   _curr_K_variant;
