@@ -188,17 +188,18 @@ private:
 #endif // _RHEOLEF_HAVE_VARIADIC_TEMPLATE
 // data:
 protected:
-  std::string           _parameter_name;
-  T                     _parameter_value;
-  size_type             _n_value;
-  mutable size_type     _count_value;
-  mutable std::ostream* _p_data_out;
-  mutable std::ostream* _p_ctrl_out;
-  mutable bool          _header_in_done;
-  mutable bool          _header_out_done;
-  mutable bool          _finalize_out_done;
-  mutable std::string   _to_clean;
-  std::pair<T,T>        _u_range;
+  std::string            _parameter_name;
+  T                      _parameter_value;
+  size_type              _n_value;
+  mutable size_type      _count_value;
+  mutable std::ostream*  _p_data_out;
+  mutable std::ostream*  _p_ctrl_out;
+  mutable bool           _header_in_done;
+  mutable bool           _header_out_done;
+  mutable bool           _finalize_out_done;
+  mutable std::string    _to_clean;
+  mutable std::pair<T,T> _u_range;
+  mutable std::pair<bool,bool> _have_u_range;
 };
 template <class T, class M> idiststream& operator>> (idiststream&, branch_basic<T,M>&);
 template <class T, class M> odiststream& operator<< (odiststream&, const branch_basic<T,M>&);
@@ -228,8 +229,9 @@ branch_basic<T,M>::branch_basic ()
    _header_out_done    (false),
    _finalize_out_done  (false),
    _to_clean(),
-   _u_range(std::pair<T,T>(std::numeric_limits<T>::min(),
-                           std::numeric_limits<T>::max()))
+   _u_range(std::pair<T,T>( std::numeric_limits<T>::max(),
+                           -std::numeric_limits<T>::max())),
+   _have_u_range(std::pair<bool,bool>(false,false))
 {
 }
 #ifdef _RHEOLEF_HAVE_VARIADIC_TEMPLATE
@@ -247,8 +249,9 @@ inline branch_basic<T,M>::branch_basic(const std::string& parameter_name, Args..
    _header_out_done    (false),
    _finalize_out_done  (false),
    _to_clean(),
-   _u_range(std::pair<T,T>(std::numeric_limits<T>::min(),
-                           std::numeric_limits<T>::max()))
+   _u_range(std::pair<T,T>( std::numeric_limits<T>::max(),
+                           -std::numeric_limits<T>::max())),
+   _have_u_range(std::pair<bool,bool>(false,false))
 {
     check_macro (parameter_name.length() != 0, "empty parameter name not allowed");
     fill_field_names (field_names...);
@@ -275,8 +278,9 @@ branch_basic<T,M>::branch_basic (const std::string& parameter_name, const std::s
    _header_out_done    (false),
    _finalize_out_done  (false),
    _to_clean(),
-   _u_range(std::pair<T,T>(std::numeric_limits<T>::min(),
-                           std::numeric_limits<T>::max()))
+   _u_range(std::pair<T,T>( std::numeric_limits<T>::max(),
+                           -std::numeric_limits<T>::max())),
+   _have_u_range(std::pair<bool,bool>(false,false))
 {
     check_macro(parameter_name.length() != 0, "empty parameter name not allowed");
     check_macro(u0.length() != 0, "empty field name not allowed");
@@ -297,8 +301,9 @@ branch_basic<T,M>::branch_basic (const std::string& parameter_name, const std::s
    _header_out_done    (false),
    _finalize_out_done  (false),
    _to_clean(),
-   _u_range(std::pair<T,T>(std::numeric_limits<T>::min(),
-                           std::numeric_limits<T>::max()))
+   _u_range(std::pair<T,T>( std::numeric_limits<T>::max(),
+                           -std::numeric_limits<T>::max())),
+   _have_u_range(std::pair<bool,bool>(false,false))
 {
     check_macro(parameter_name.length() != 0, "empty parameter name not allowed");
     check_macro(u0.length() != 0, "empty #1 field name not allowed");
@@ -322,8 +327,9 @@ branch_basic<T,M>::branch_basic (const std::string& parameter_name, const std::s
    _header_out_done    (false),
    _finalize_out_done  (false),
    _to_clean(),
-   _u_range(std::pair<T,T>(std::numeric_limits<T>::min(),
-                           std::numeric_limits<T>::max()))
+   _u_range(std::pair<T,T>( std::numeric_limits<T>::max(),
+                           -std::numeric_limits<T>::max())),
+   _have_u_range(std::pair<bool,bool>(false,false))
 {
     check_macro(parameter_name.length() != 0, "empty parameter name not allowed");
     check_macro(u0.length() != 0, "empty #1 field name not allowed");
@@ -387,7 +393,8 @@ inline
 void 
 branch_basic<T,M>::set_range (const std::pair<T,T>& u_range)
 {
-    _u_range = u_range;
+   _u_range = u_range;
+   _have_u_range = std::pair<bool,bool>(false,false);
 }
 // -----------------------------------------------------------------------------
 // io header wrapper
