@@ -52,12 +52,15 @@ put_header_gnuplot (odiststream& ops, const branch_basic<T,sequential>& b)
     string tmp = (do_clean ? get_tmpdir() + "/" : "");
 
     string plot_name = tmp+basename + ".plot";
+    string param_name = tmp+basename + "-visu-param.plot";
     b._to_clean = plot_name;
     b._p_ctrl_out = new_macro (ofstream(plot_name.c_str()));
     do_verbose && clog << "! file `" << plot_name << "' created" << endl;
     *(b._p_ctrl_out) << setbasename(basename)
                      << setprecision(numeric_limits<T>::digits10)
-                     << "dt_pause = 0.25 # in seconds" << endl;
+                     << "load \"" << param_name << "\"" << endl;
+    b._have_u_range.first  = (b._u_range.first  !=  std::numeric_limits<T>::max());
+    b._have_u_range.second = (b._u_range.second != -std::numeric_limits<T>::max());
 }
 template <class T>
 void
@@ -65,11 +68,12 @@ put_event_gnuplot (odiststream& ops, const branch_basic<T,sequential>& b)
 {
   typedef typename branch_basic<T,sequential>::size_type size_type;
   bool do_verbose = iorheo::getverbose(clog);
-  if (b.n_field() == 0) return;
+  size_t nfld = b.n_field();
+  if (nfld == 0) return;
   // TODO: assume all fields have the same mesh
-  const space_basic<T,sequential>&        Xh    = b[0].second.get_space();
-  const geo_basic<T,sequential>&          omega = Xh.get_geo();
-  const array<point_basic<T>,sequential>& xdof  = Xh.get_xdofs();
+  const space_basic<T,sequential>&           Xh    = b[0].second.get_space();
+  const geo_basic<T,sequential>&             omega = Xh.get_geo();
+  const disarray<point_basic<T>,sequential>& xdof  = Xh.get_xdofs();
 
   bool do_clean   = iorheo::getclean  (clog);
   string basename = iorheo::getbasename(ops.os());
@@ -78,28 +82,19 @@ put_event_gnuplot (odiststream& ops, const branch_basic<T,sequential>& b)
   // ---------------------------------------------------------
   // 1) range : as computed at the first occurence
   // -----------------------------------------------
-  size_t nfld = b.n_field();
   if (b._count_value == 0) {
-    T all_min = std::numeric_limits<T>::max();
-    T all_max = std::numeric_limits<T>::min();
+    *(b._p_ctrl_out) << "set xrange [" << omega.xmin()[0] << ":" << omega.xmax()[0] << "]" << endl;
+  }
+  if (! b._have_u_range.first || ! b._have_u_range.second) {
     for (size_t ifld = 0; ifld < nfld; ifld++) {
       const field_basic<T,sequential>& u = b[ifld].second;
-      all_min = std::min (all_min, u.min());
-      all_max = std::max (all_max, u.max());
+      if (! b._have_u_range.first) {
+        b._u_range.first  = std::min (b._u_range.first,  u.min());
+      }
+      if (! b._have_u_range.second) {
+        b._u_range.second = std::max (b._u_range.second, u.max());
+      }
     }
-    if (b._u_range.first != std::numeric_limits<T>::min()) {
-      all_min = b._u_range.first;
-    }
-    if (b._u_range.second != std::numeric_limits<T>::max()) {
-      all_max = b._u_range.second;
-    }
-    if (fabs(all_max - all_min) < 1e-7) {
-      // perhaps the solution is zero ? try to renormalize
-      // TODO: add command-line options for the range
-      all_max = all_min + 1;
-    }
-    *(b._p_ctrl_out) << "set xrange [" << omega.xmin()[0] << ":" << omega.xmax()[0] << "]" << endl
-                     << "set yrange [" << all_min << ":" << all_max << "]" << endl;
   }
   // -----------------------------------------------
   // 2) plot commands
@@ -172,6 +167,22 @@ put_finalize_gnuplot (odiststream& ops, const branch_basic<T,sequential>& b)
   }
   string tmp = (do_clean ? get_tmpdir() + "/" : "");
   //
+  // compute visu params: u_range, pause delay
+  //
+  string param_name = tmp+basename + "-visu-param.plot";
+  ofstream param (param_name.c_str());
+  if (do_verbose) clog << "! file \"" << param_name << "\" created.\n";
+  b._to_clean = b._to_clean + " " + param_name;
+  param << "duration = 30 # in seconds" << endl
+        << "n_step   = " << b._count_value << endl
+        << "dt_pause = 1.0*duration/n_step" << endl;
+  if (b._u_range.second - b._u_range.first < 1e-7) {
+      // perhaps the solution is zero ? try to renormalize
+      b._u_range.second = b._u_range.first + 1;
+  }
+  param << "set yrange [" << b._u_range.first << ":" << b._u_range.second << "]" << endl;
+  param.close();
+  //
   // run gnuplot
   //
   int status = 0;
