@@ -65,9 +65,9 @@ public:
   quadrature_option_type        _qopt;
   quadrature<T>                 _quad;
   basis_on_pointset<T>          _piola_on_quad;
-  array<index_set,M>            _ie2dis_ix;
-  array<point_basic<T>,M>       _hat_y;
-  array<point_basic<T>,M>       _yq;
+  disarray<index_set,M>         _ie2dis_ix;
+  disarray<point_basic<T>,M>    _hat_y;
+  disarray<point_basic<T>,M>    _yq;
 };
 template <class T, class M>
 class characteristic_on_quadrature : public smart_pointer<characteristic_on_quadrature_rep<T,M> > {
