@@ -21,7 +21,7 @@
 ///
 /// =========================================================================
 
-#include "rheolef/array.h"
+#include "rheolef/disarray.h"
 #include "rheolef/geo_element.h"
 #include "rheolef/geo_element_indirect.h"
 #include "rheolef/index_set.h"
@@ -37,12 +37,12 @@ template <class U, class M> class geo_basic;
 //    representation: domain_indirect_base_rep<M> and domain_indirect_rep<M>
 // ==================================================================================
 template <class M>
-class domain_indirect_base_rep : public array<geo_element_indirect,M> {
+class domain_indirect_base_rep : public disarray<geo_element_indirect,M> {
 public:
 
 // typedefs:
 
-    typedef array<geo_element_indirect,M> base;
+    typedef disarray<geo_element_indirect,M> base;
     typedef typename geo_element_indirect::size_type        size_type;
     typedef typename geo_element_indirect::orientation_type orientation_type;
     typedef typename base::iterator                     iterator_ioige;
@@ -91,7 +91,7 @@ protected:
 template <class M>
 inline
 domain_indirect_base_rep<M>::domain_indirect_base_rep()
- : array<geo_element_indirect,M>(),
+ : disarray<geo_element_indirect,M>(),
    _name(),
    _map_dim(0)
 {
@@ -152,7 +152,7 @@ public:
     template<class U>
     void build_from_data (
         const geo_rep<U,sequential>&  omega,
-        array<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >&
+        disarray<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >&
                                       d_tmp,
         std::vector<index_set>*       ball);
 
@@ -238,8 +238,8 @@ public:
 protected:
     template <class U1,class M1> friend class geo_rep; // for geo_rep::build_from_domain
 // data:
-    array<size_type,distributed>        _ioige2ini_dis_ioige;
-    array<size_type,distributed>        _ini_ioige2dis_ioige;
+    disarray<size_type,distributed>        _ioige2ini_dis_ioige;
+    disarray<size_type,distributed>        _ini_ioige2dis_ioige;
 };
 inline
 domain_indirect_rep<distributed>::domain_indirect_rep()
@@ -341,7 +341,7 @@ public:
 
     template <class U>
     domain_indirect_basic (
-        array<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >&
+        disarray<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >&
                                         d_tmp,
 	const geo_basic<U, sequential>& omega,
 	std::vector<index_set>*         ball);
