@@ -19,11 +19,10 @@
 /// 
 /// =========================================================================
 #include "rheolef/field.h"
-#include "rheolef/field_expr_ops.h"
 #include "rheolef/rheostream.h"
 #include "rheolef/iorheo.h"
 #include "rheolef/piola.h"
-#include <complex>
+#include "rheolef/field_expr_v2_linear.h"
 
 namespace rheolef {
 
@@ -37,7 +36,7 @@ field_basic<T,M>::field_basic (
  : _V (V), 
    _u (),
    _b (),
-   _dis_dof_update_needed(true)
+   _dis_dof_indexes_requires_update(true)
 {
    _u.resize (_V.iu_ownership(), init_value);
    _b.resize (_V.ib_ownership(), init_value);
@@ -52,7 +51,7 @@ field_basic<T,M>::resize (
    _V = V;
    _u.resize (_V.iu_ownership(), init_value);
    _b.resize (_V.ib_ownership(), init_value);
-   dis_dof_update_needed();
+   dis_dof_indexes_requires_update();
 }
 // ---------------------------------------------------------------------------
 // input
@@ -115,7 +114,7 @@ idiststream&
 field_basic<T,M>::get (idiststream& ids)
 {
   using namespace std;
-  dis_dof_update_needed();
+  dis_dof_indexes_requires_update();
   communicator comm = ids.comm();
   if ( ! dis_scatch (ids, comm, "\nfield")) {
     error_macro ("read field failed");
@@ -319,18 +318,14 @@ field_basic<T,M>::put (odiststream& ods) const
 // access to non-local dofs
 // ----------------------------------------------------------------------------
 template <class T, class M>
-void
-field_basic<T,M>::dis_dof_update_internal() const
-{
-  _u.set_dis_indexes (_V.ext_iu_set());
-  _b.set_dis_indexes (_V.ext_ib_set());
-}
-template <class T, class M>
 const T&
 field_basic<T,M>::dis_dof (const size_type dis_idof) const
 {
   if (is_distributed<M>::value) {
-    check_macro (! _dis_dof_update_needed, "field::dis_dof_update() need to be called before field::dis_dof(idof)");
+    if (_dis_dof_indexes_requires_update || _dis_dof_assembly_requires_update) {
+      size_type nproc = comm().size();
+      check_macro (nproc == 1, "field::dis_dof_update() need to be called before field::dis_dof(idof)");
+    }
   }
   if (ownership().is_owned (dis_idof)) {
     size_type first_idof = ownership().first_index ();
@@ -338,13 +333,48 @@ field_basic<T,M>::dis_dof (const size_type dis_idof) const
     return dof (idof);
   }
   // here dis_idof is owned by another proc
-  space_pair_type blk_iub = _V.data()._idof2blk_iub.dis_at (dis_idof); // TODO: better !
+  space_pair_type blk_iub = _V.data()._idof2blk_iub.dis_at (dis_idof); // TODO: write a better access !
   if (! blk_iub.is_blocked()) {
     return _u.dis_at (blk_iub.iub());
   } else {
     return _b.dis_at (blk_iub.iub());
   }
 }
+template <class T, class M>
+typename field_basic<T,M>::dis_reference
+field_basic<T,M>::dis_dof_entry (size_type dis_idof)
+{
+  // here dis_idof is supposed to be owned by another proc
+  dis_dof_assembly_requires_update();
+  space_pair_type blk_iub = _V.data()._idof2blk_iub.dis_at (dis_idof); // TODO: write a better access !
+  if (! blk_iub.is_blocked()) {
+    return _u.dis_entry (blk_iub.iub());
+  } else {
+    return _b.dis_entry (blk_iub.iub());
+  }
+}
+template <class T, class M>
+void
+field_basic<T,M>::dis_dof_update() const
+{
+#ifdef _RHEOLEF_HAVE_MPI
+  std::size_t nproc = ownership().comm().size();
+  if (is_distributed<M>::value && nproc > 1) {
+    std::size_t do_assembly = mpi::all_reduce (ownership().comm(), size_t(_dis_dof_assembly_requires_update), std::plus<std::size_t>());
+    std::size_t do_indexes  = mpi::all_reduce (ownership().comm(), size_t(_dis_dof_indexes_requires_update),  std::plus<std::size_t>());
+    if (do_assembly) {
+      _u.dis_entry_assembly();
+      _b.dis_entry_assembly();
+    }
+    if (do_indexes) {
+      _u.set_dis_indexes (_V.ext_iu_set());
+      _b.set_dis_indexes (_V.ext_ib_set());
+    }
+  }
+#endif // _RHEOLEF_HAVE_MPI
+  _dis_dof_indexes_requires_update = false;
+  _dis_dof_assembly_requires_update = false;
+}
 // ----------------------------------------------------------------------------
 // evaluation
 // ----------------------------------------------------------------------------
