@@ -30,7 +30,6 @@
 namespace rheolef {
 
 // forward declaration:
-template <class Expr> struct field_expr;
 template <class T, class M> class field_indirect;
 template <class T, class M> class field_indirect_const;
 template <class T, class M> class field_component;
@@ -38,6 +37,11 @@ template <class T, class M> class field_component_const;
 template <class T, class M> class field_concat_value;
 template <class T, class M> class band_basic;
 
+namespace details {
+template <class Expr> struct is_field_expr_v2_linear_arg;
+template <class Expr> struct is_field;
+} // namespace details
+
 //<field:  
 /*Class:field
 NAME:  @code{field} - piecewise polynomial finite element field
@@ -191,10 +195,12 @@ GENERAL MULTI-COMPONENT INTERFACE:
   A tensor-valued field has @code{d*(d+1)/2} components, where @code{d=omega.dimension()}.
 
 BLOCKED AND UNBLOCKED ARRAYS:
-  The field class contains two arrays of degrees-of-freedom (dof) associated
+  The field class contains two vectors of degrees-of-freedom (dof) associated
   respectively to blocked and unknown dofs. Blocked dofs corresponds to
   Dirichlet boundary conditions, as specified by space (See @pxref{space class}).
-  For simpliity, direct public access to these array is allowed, as @code{uh.b} and @code{uh.u}:
+  Access to these vectors is allowed via some accessors:
+  a read-only one, as @code{uh.u()} and @code{uh.b()},
+  and a read-and-write one, as @code{uh.set_u()} and @code{uh.set_b()},
   see @pxref{vec class}.
 
 LOW-LEVEL DEGREE-OF-FREEDOM ACCESS:
@@ -207,8 +213,8 @@ LOW-LEVEL DEGREE-OF-FREEDOM ACCESS:
 
   For performances, a STL-like iterator interface is available, with 
   @code{uh.begin_dof()} and @code{uh.end_dof()} returns iterators to the
-  arrays of dofs on the current processor.
-  See @pxref{array class} for more about distributed arrays.
+  dofs on the current processor.
+  See @pxref{disarray class} for more about distributed arrays.
 
   For convenience, @code{uh.max()}, @code{uh.min()} and @code{uh.max_abs()} 
   retuns respectively the maximum, minimum and maximum of the absolute value
@@ -239,6 +245,7 @@ public :
     typedef space_constant::valued_type     valued_type;
     typedef geo_basic  <float_type,M>       geo_type;
     typedef space_basic<float_type,M>       space_type;
+    typedef typename vec<T,M>::dis_reference dis_reference;
     class iterator;
     class const_iterator;
 
@@ -254,6 +261,10 @@ public :
 	const space_type& V, 
 	const T& init_value = std::numeric_limits<T>::max());
 
+    field_basic<T,M>& operator=  (const T&);
+    field_basic<T,M>& operator=  (const field_basic<T,M>&);
+
+#ifdef TO_CLEAN
     field_basic                   (const field_indirect<T,M>&);
     field_basic<T, M>& operator=  (const field_indirect<T,M>&);
     field_basic                   (const field_indirect_const<T,M>&);
@@ -262,9 +273,22 @@ public :
     field_basic<T, M>& operator=  (const field_component<T,M>&);
     field_basic                   (const field_component_const<T,M>&);
     field_basic<T, M>& operator=  (const field_component_const<T,M>&);
-    template <class Expr> field_basic                   (const field_expr<Expr>&);
-    template <class Expr> field_basic<T, M>& operator=  (const field_expr<Expr>&);
-    field_basic<T, M>& operator=  (const T&);
+#endif // TO_CLEAN
+
+    // linear expressions:
+    template <class Expr, class Sfinae
+                    = typename std::enable_if<
+			     details::is_field_expr_v2_linear_arg<Expr>::value
+			&& ! details::is_field<Expr>::value
+                      >::type>
+    field_basic (const Expr& expr);
+
+    template <class Expr, class Sfinae
+                    = typename std::enable_if<
+			     details::is_field_expr_v2_linear_arg<Expr>::value
+			&& ! details::is_field<Expr>::value
+                      >::type>
+    field_basic<T, M>& operator=  (const Expr&);
 
 // initializer list (c++ 2011):
 
@@ -284,10 +308,10 @@ public :
 
 // accessors & modifiers to unknown & blocked parts:
 
-    const vec<T,M>&     u() const { dis_dof_update_needed(); return _u; }
-    const vec<T,M>&     b() const { dis_dof_update_needed(); return _b; }
-          vec<T,M>& set_u()       { return _u; }
-          vec<T,M>& set_b()       { return _b; }
+    const vec<T,M>&     u() const { return _u; }
+    const vec<T,M>&     b() const { return _b; }
+          vec<T,M>& set_u()       { dis_dof_indexes_requires_update(); return _u; }
+          vec<T,M>& set_b()       { dis_dof_indexes_requires_update(); return _b; }
 
 // accessors to extremas:
 
@@ -320,6 +344,9 @@ public :
           T& dof (size_type idof);
     const T& dof (size_type idof) const;
     const T& dis_dof (size_type dis_idof) const;
+    // write access to non-local dis_idof changes to others procs
+    dis_reference dis_dof_entry (size_type dis_idof);
+
     iterator begin_dof();
     iterator end_dof();
     const_iterator begin_dof() const;
@@ -367,14 +394,15 @@ public:
         const quadrature_option_type& qopt);
 
 protected:
-    void dis_dof_update_internal() const;
-    void dis_dof_update_needed() const;
+    void dis_dof_indexes_requires_update() const;
+    void dis_dof_assembly_requires_update() const;
 
 // data:
-    space_type   _V;
-    vec<T,M>     _u;
-    vec<T,M>     _b;
-    mutable bool _dis_dof_update_needed;
+            space_type   _V;
+    mutable vec<T,M>     _u;
+    mutable vec<T,M>     _b;
+    mutable bool         _dis_dof_indexes_requires_update;
+    mutable bool         _dis_dof_assembly_requires_update;
 };
 template <class T, class M>
 idiststream& operator >> (odiststream& ips, field_basic<T,M>& u);
@@ -392,8 +420,8 @@ typedef field_basic<Float,sequential> field_sequential;
 template <class T, class M>
 class field_basic<T,M>::iterator {
 protected:
-  typedef typename vec<T,M>::iterator                       data_t; // random acess
-  typedef typename array<space_pair_type,M>::const_iterator iter_t; // forward access
+  typedef typename vec<T,M>::iterator                          data_t; // random acess
+  typedef typename disarray<space_pair_type,M>::const_iterator iter_t; // forward access
 public:
 
 // typedefs:
@@ -432,7 +460,11 @@ public:
   bool operator== (const iterator& j) const { return _blk_iub_iter == j._blk_iub_iter; }
   bool operator!= (const iterator& j) const { return ! operator== (j); }
 protected:
+#ifdef TO_CLEAN
+  // CLANG problem
   template <class T1, class M1> friend class field_basic<T1,M1>::const_iterator;
+#endif // TO_CLEAN
+  friend class const_iterator;
 // data:
   iter_t _blk_iub_iter;
   data_t _u;
@@ -443,7 +475,7 @@ inline
 typename field_basic<T,M>::iterator
 field_basic<T,M>::begin_dof ()
 {
-  dis_dof_update_needed();
+  dis_dof_indexes_requires_update();
   return iterator (_V.data()._idof2blk_iub.begin(), _u.begin(), _b.begin());
 }
 template <class T, class M>
@@ -451,7 +483,7 @@ inline
 typename field_basic<T,M>::iterator
 field_basic<T,M>::end_dof ()
 {
-  dis_dof_update_needed();
+  dis_dof_indexes_requires_update();
   return iterator (_V.data()._idof2blk_iub.end(), _u.begin(), _b.begin());
 }
 // =================================================================================
@@ -460,8 +492,8 @@ field_basic<T,M>::end_dof ()
 template <class T, class M>
 class field_basic<T,M>::const_iterator {
 protected:
-  typedef typename vec<T,M>::const_iterator                 data_t;
-  typedef typename array<space_pair_type,M>::const_iterator iter_t;
+  typedef typename vec<T,M>::const_iterator                    data_t;
+  typedef typename disarray<space_pair_type,M>::const_iterator iter_t;
 public:
 
 // typedefs:
@@ -531,22 +563,33 @@ field_basic<T,M>::field_basic ()
  : _V(),
    _u(),
    _b(),
-   _dis_dof_update_needed(true)
+   _dis_dof_indexes_requires_update(true),
+   _dis_dof_assembly_requires_update(false)
 {
 }
 template <class T, class M>
-void
-field_basic<T,M>::dis_dof_update_needed() const
+inline
+field_basic<T,M>&
+field_basic<T,M>::operator=  (const field_basic<T,M>& x)
 {
-  _dis_dof_update_needed = true;
+  _V.operator= (x._V);
+  _u.operator= (x._u);
+  _b.operator= (x._b);
+   _dis_dof_indexes_requires_update =  x._dis_dof_indexes_requires_update;
+  _dis_dof_assembly_requires_update = x._dis_dof_assembly_requires_update;
+  return *this;
 }
 template <class T, class M>
 void
-field_basic<T,M>::dis_dof_update() const
+field_basic<T,M>::dis_dof_indexes_requires_update() const
 {
-  if (!_dis_dof_update_needed) return; 
-  _dis_dof_update_needed = false;
-  if (is_distributed<M>::value) dis_dof_update_internal();
+  _dis_dof_indexes_requires_update = true;
+}
+template <class T, class M>
+void
+field_basic<T,M>::dis_dof_assembly_requires_update() const
+{
+  _dis_dof_assembly_requires_update = true;
 }
 template<class T, class M>
 inline
@@ -555,7 +598,7 @@ field_basic<T,M>::operator=  (const T& value)
 {
   check_macro (stamp() != "", "field=constant : uninitialized field in affectation");
   std::fill (begin_dof(), end_dof(), value);
-  dis_dof_update_needed();
+  dis_dof_indexes_requires_update();
   return *this;
 }
 template <class T, class M>
@@ -563,7 +606,7 @@ inline
 T& 
 field_basic<T,M>::dof (size_type idof)
 {
-  dis_dof_update_needed();
+  dis_dof_indexes_requires_update();
   if (! _V.is_blocked(idof)) {
     return _u [_V.iub(idof)]; 
   } else {
