@@ -54,8 +54,6 @@ struct field_component {
 
 namespace rheolef {
 
-template<class Expr> class field_expr; // forward declaration
-
 // =========================================================================
 // field_component
 // =========================================================================
@@ -66,8 +64,10 @@ public:
 // typename:
 
   typedef typename field_basic<T,M>::size_type      size_type;
-  typedef T                                         scalar_type;
   typedef T                                         value_type;
+  typedef M                                         memory_type;
+  typedef typename scalar_traits<T>::type           scalar_type;
+  typedef typename float_traits<T>::type            float_type;
   typedef typename field_basic<T,M>::iterator       iterator;
   typedef typename field_basic<T,M>::const_iterator const_iterator;
 
@@ -76,12 +76,18 @@ public:
   field_component ();
   field_component (field_basic<T,M>&     uh, size_type i_comp);
   field_component (field_component<T,M>& uh, size_type i_comp);
-  field_component<T,M>& operator= (const field_component<T,M>& uh_comp);
-  field_component<T,M>& operator= (const field_basic<T,M>& uh);
-  template<class Expr>
-  field_component<T,M>& operator= (const field_expr<Expr>& expr);
+
   const T& operator= (const T& alpha);
 
+  template <class Expr,
+            class Sfinae = typename std::enable_if<details::is_field_expr_v2_linear_arg<Expr>::value>::type>
+  field_component<T,M>& operator=  (const Expr&);
+
+  // explicit copy cstor (avoid simple copy of the proxy; see nfem/ptst/field_comp_assign_tst.cc )
+  field_component<T,M>& operator= (const field_component<T,M>& expr) {
+	return this -> template  operator=<field_component<T,M> > (expr);
+  }
+
 // high-level accessors & modifiers:
 
   field_indirect<T,M> operator[] (const geo_basic<T,M>& dom);
@@ -108,6 +114,8 @@ public:
   const_iterator begin_dof() const { return const_iterator(_start); }
   const_iterator end_dof() const   { return const_iterator(_last); }
 
+// advanced usage:
+  field_component<T,M>& proxy_assign (field_component<T,M>&& uh_comp);
 protected:
 // data:
   space_constitution<T,M>        _constit;     // at this level
@@ -124,8 +132,10 @@ public:
 // typename:
 
   typedef typename field_basic<T,M>::size_type      size_type;
-  typedef T                                         scalar_type;
   typedef T                                         value_type;
+  typedef M                                         memory_type;
+  typedef typename scalar_traits<T>::type           scalar_type;
+  typedef typename float_traits<T>::type            float_type;
   typedef typename field_basic<T,M>::const_iterator const_iterator;
 
 // allocators:
@@ -133,7 +143,6 @@ public:
   field_component_const ();
   field_component_const (const field_basic<T,M>& uh, size_type i_comp);
   field_component_const (const field_component<T,M>& uh_comp);
-  field_component_const<T,M>& operator= (const field_component_const<T,M>& uh_comp);
   const space_constitution<T,M>& get_constitution() const { return _constit; }
   std::string stamp() const { return _constit.stamp(); }
   const distributor& ownership() const { return _constit.ownership(); }	
@@ -145,11 +154,16 @@ public:
   const T& dof (size_type idof) const { return _start [idof]; }
   const_iterator begin_dof() const { return const_iterator(_start); }
   const_iterator end_dof() const   { return const_iterator(_last); }
+
+// advanced usage:
+  field_component_const<T,M>& proxy_assign (const field_component_const<T,M>& uh_comp);
 protected:
 // data:
   space_constitution<T,M>        _constit;     // at this level
   const_iterator                 _start;
   const_iterator                 _last;
+private:
+  field_component_const<T,M>& operator= (const field_component_const<T,M>& uh_comp);
 };
 // =========================================================================
 // inlined
@@ -232,22 +246,31 @@ field_component_const<T,M>::field_component_const (const field_component<T,M>& u
 }
 template<class T, class M>
 inline
-field_component<T,M>&
-field_component<T,M>::operator= (const field_component<T,M>& uh_comp)
+field_component_const<T,M>&
+field_component_const<T,M>::operator= (const field_component_const<T,M>& uh_comp)
 {
-  _constit = uh_comp._constit;
-  _start   = uh_comp._start;
-  _last    = uh_comp._last;
+  // avoided at compile time: is private
+  fatal_macro ("try to assign const field in field[i_comp] = field[j_comp]");
   return *this;
 }
 template<class T, class M>
 inline
 field_component_const<T,M>&
-field_component_const<T,M>::operator= (const field_component_const<T,M>& uh_comp)
+field_component_const<T,M>::proxy_assign (const field_component_const<T,M>& uh_comp)
 {
-  _constit = uh_comp._constit;
-  _start   = uh_comp._start;
-  _last    = uh_comp._last;
+   _constit = uh_comp.get_constitution();
+   _start   = uh_comp.begin_dof();
+   _last    = uh_comp.end_dof();
+  return *this;
+}
+template<class T, class M>
+inline
+field_component<T,M>&
+field_component<T,M>::proxy_assign (field_component<T,M>&& uh_comp)
+{
+   _constit = uh_comp.get_constitution();
+   _start   = uh_comp.begin_dof();
+   _last    = uh_comp.end_dof();
   return *this;
 }
 template<class T, class M>
@@ -255,7 +278,7 @@ inline
 field_component<T,M>
 field_basic<T,M>::operator[] (size_type i_comp) 
 {
-  dis_dof_update_needed();
+  dis_dof_indexes_requires_update();
   return field_component<T,M> (*this, i_comp);
 }
 template<class T, class M>
@@ -274,66 +297,12 @@ field_basic<T,M>::operator[] (size_type i_comp) const
 }
 template<class T, class M>
 inline
-field_basic<T,M>&
-field_basic<T,M>::operator=  (const field_component_const<T,M>& uh_comp)
-{
-  if (stamp() == "") {
-    resize (uh_comp.get_space());
-  } else {
-    check_macro (stamp() == uh_comp.stamp(), "incompatible spaces "
-        << stamp() << " and " << uh_comp.stamp()
-        << " in field = field[i_comp]");
-  }
-  dis_dof_update_needed();
-  std::copy (uh_comp.begin_dof(), uh_comp.end_dof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
-field_component<T,M>&
-field_component<T,M>::operator= (const field_basic<T,M>& uh)
-{
-  check_macro (stamp() == uh.stamp(), "incompatible spaces "
-        << stamp() << " and " << uh.stamp()
-        << " in field[i_comp] = field");
-  std::copy (uh.begin_dof(), uh.end_dof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
 const T&
 field_component<T,M>::operator= (const T& alpha)
 {
   std::fill (begin_dof(), end_dof(), alpha);
   return alpha;
 }
-template<class T, class M>
-inline
-field_basic<T,M>&
-field_basic<T,M>::operator=  (const field_component<T,M>& uh_comp)
-{
-  return operator= (field_component_const<T,M>(uh_comp));
-}
-template<class T, class M>
-inline
-field_basic<T,M>::field_basic (const field_component<T,M>& uh_comp)
- : _V(),
-   _u(),
-   _b(),
-   _dis_dof_update_needed(true)
-{
-  operator= (uh_comp);
-}
-template<class T, class M>
-inline
-field_basic<T,M>::field_basic (const field_component_const<T,M>& uh_comp)
- : _V(),
-   _u(),
-   _b(),
-   _dis_dof_update_needed(true)
-{
-  operator= (uh_comp);
-}
 #ifdef TODO
 // TODO: as: field vh; din >> vh ; uh[i_comp] = vh;
 template <class T, class M>
