@@ -104,6 +104,38 @@ general_field_evaluate (
 {
   value = tensor_field_evaluate (uh, bops, hat_K, dis_idof, q);
 }
+template<class T, class M>
+inline
+void
+general_field_evaluate (
+  const field_basic<T,M>&       uh,
+  const basis_on_pointset<T>&   bops,
+  reference_element             hat_K,
+  const std::vector<size_t>&    dis_idof,
+  size_t                        q,
+  tensor3_basic<T>&              value)
+{
+  fatal_macro ("tensor3: not yet");
+#ifdef TODO
+  value = tensor3_field_evaluate (uh, bops, hat_K, dis_idof, q);
+#endif // TODO
+}
+template<class T, class M>
+inline
+void
+general_field_evaluate (
+  const field_basic<T,M>&       uh,
+  const basis_on_pointset<T>&   bops,
+  reference_element             hat_K,
+  const std::vector<size_t>&    dis_idof,
+  size_t                        q,
+  tensor4_basic<T>&              value)
+{
+  fatal_macro ("tensor4: not yet");
+#ifdef TODO
+  value = tensor4_field_evaluate (uh, bops, hat_K, dis_idof, q);
+#endif // TODO
+}
 // -----------------------------------------------------
 // homogeneous multi-component case: get the i-th value
 // -----------------------------------------------------
