@@ -38,13 +38,13 @@ class field_indirect_const;
 template <class T, class M = rheo_default_memory_model>
 class field_indirect {
 public:
-//protected:
-
 // typedefs
 
   typedef typename field_basic<T,M>::size_type size_type;
-  typedef T                                    scalar_type;
-  typedef T                                    value_type; // TO_CLEAN !
+  typedef T                                    value_type;
+  typedef M                                    memory_type;
+  typedef typename scalar_traits<value_type>::type    scalar_type;
+  typedef typename float_traits <scalar_type>::type   float_type;
   class iterator;
   class const_iterator;
 
@@ -56,20 +56,23 @@ public:
       _dom(dom),
       _indirect(_V.build_indirect_array (_W, dom)),
       _val(uh.begin_dof())
-    {
-    }
+    {}
 
   field_indirect (field_component<T,M>& uh, const geo_basic<T,M>& dom);
 
-// accessors & modifiers:
-public:
-
   const T& operator=  (const T& alpha);
-  field_indirect<T,M>& operator= (const field_basic<T,M>& expr);
-  field_indirect<T,M>& operator= (const field_indirect<T,M>& expr);
-  field_indirect<T,M>& operator= (const field_indirect_const<T,M>& expr);
 
-//protected:
+  template <class Expr,
+            class Sfinae = typename std::enable_if<details::is_field_expr_v2_linear_arg<Expr>::value>::type>
+  field_indirect<T,M>& operator= (const Expr&);
+
+  // explicit copy cstor (avoid simple copy of the proxy; see nfem/ptst/field_comp_assign_tst.cc )
+  field_indirect<T,M>& operator= (const field_indirect<T,M>& expr) {
+	return this -> template  operator=<field_indirect<T,M> > (expr);
+  }
+
+// accessors:
+
   const distributor& ownership() const { return _indirect.ownership(); }
   const communicator& comm() const { return ownership().comm(); }
   size_type     ndof() const { return ownership().size(); }
@@ -90,9 +93,15 @@ protected:
   space_basic<T,M>                      _V;
   space_basic<T,M>                      _W;
   geo_basic<T,M>                        _dom;
-  array<size_type,M>                    _indirect; // temporary
+  disarray<size_type,M>                 _indirect; // temporary
   typename field_basic<T,M>::iterator   _val;      // iterator = reference on an external variable uh
 						   // => cstor is protected : prevent copy outside the field class
+#ifdef TO_CLEAN
+private:
+  // force the usage of template<Expr> oerator=(Expr)
+  field_indirect<T,M>& operator= (const field_basic<T,M>& expr);
+  field_indirect<T,M>& operator= (const field_indirect_const<T,M>& expr);
+#endif // TO_CLEAN
 };
 template<class T, class M>
 inline
@@ -104,40 +113,24 @@ field_indirect<T,M>::operator=  (const T& alpha)
 }
 template<class T, class M>
 inline
-field_indirect<T,M>&
-field_indirect<T,M>::operator=  (const field_basic<T,M>& expr)
-{
-  check_macro (_V.valued_tag() == space_constant::scalar, "field[domain]: unsupported non-scalar field");
-  check_macro (stamp() == expr.stamp(), "field[domain] = field : incompatible spaces "
-		<< stamp() << " and " << expr.stamp());
-  algo::copy_n (expr.begin_dof(), expr.ndof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
-field_indirect<T,M>&
-field_indirect<T,M>::operator=  (const field_indirect<T,M>& expr)
-{
-  check_macro (_V.valued_tag() == space_constant::scalar, "field[domain]: unsupported non-scalar field");
-  check_macro (stamp() == expr.stamp(), "field[domain] = field[domain]: incompatible spaces "
-		<< stamp() << " and " << expr.stamp());
-  algo::copy_n (expr.begin_dof(), expr.ndof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
 std::string
 field_indirect<T,M>::stamp() const
 {
-  // e.g. "P1(square.left)", an unique signature for field_expr<Expr> size-like checks
-  return _V.get_numbering().name() + "(" + _V.get_geo().name() + "[" + _dom.name() + "])";
+  // e.g. "P1(square[left]", an unique signature for field_expr<Expr> size-like checks
+  if (_dom.variant() != geo_abstract_base_rep<T>::geo_domain) {
+    // usual domain:
+    return _V.get_numbering().name() + "(" + _V.get_geo().name() + "[" + _dom.name() + "])";
+  } else {
+    // geo_domain: from space or band, has already index as "square[left]"
+    return _V.get_numbering().name() + "(" + _dom.name() + ")";
+  }
 }
 template<class T, class M>
 inline
 field_indirect<T,M>
 field_basic<T,M>::operator[] (const geo_basic<T,M>& dom)
 {
-  dis_dof_update_needed();
+  dis_dof_indexes_requires_update();
   return field_indirect<T,M> (*this, dom);
 }
 template<class T, class M>
@@ -145,35 +138,9 @@ inline
 field_indirect<T,M>
 field_basic<T,M>::operator[] (std::string dom_name)
 {
-  dis_dof_update_needed();
+  dis_dof_indexes_requires_update();
   return operator[] (get_space().get_geo().operator[] (dom_name));
 }
-template<class T, class M>
-inline
-field_basic<T,M>&
-field_basic<T,M>::operator=  (const field_indirect<T,M>& expr)
-{
-  if (stamp() == "") {
-    resize (expr.get_space());
-  } else {
-    check_macro (stamp() == expr.stamp(), "incompatible spaces "
-	<< stamp() << " and " << expr.stamp()
-	<< " in field = field[domain]");
-  }
-  dis_dof_update_needed();
-  algo::copy_n (expr.begin_dof(), expr.ndof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
-field_basic<T,M>::field_basic (const field_indirect<T,M>& expr)
- : _V(),
-   _u(),
-   _b(),
-   _dis_dof_update_needed(true)
-{
-    operator= (expr);
-}
 // =================================================================================
 // field_indirect::iterator
 // =================================================================================
@@ -188,7 +155,7 @@ public:
   typedef T*                                pointer;
   typedef std::ptrdiff_t                    difference_type;
 // allocator:
-  iterator (typename array<size_type,M>::const_iterator idof_iter, typename field_basic<T,M>::iterator val)
+  iterator (typename disarray<size_type,M>::const_iterator idof_iter, typename field_basic<T,M>::iterator val)
     : _idof_iter(idof_iter), _val(val) {}
  
 // accessors & modifiers:
@@ -202,7 +169,7 @@ public:
   bool operator!= (const iterator& j) const { return ! operator== (j); }
 protected:
 // data:
-  typename array<size_type,M>::const_iterator _idof_iter;
+  typename disarray<size_type,M>::const_iterator _idof_iter;
   typename field_basic<T,M>::iterator         _val;
 };
 template<class T, class M>
@@ -233,7 +200,7 @@ public:
   typedef const T*                          pointer;
   typedef std::ptrdiff_t                    difference_type;
 // allocator:
-  const_iterator (typename array<size_type,M>::const_iterator idof_iter, typename field_basic<T,M>::const_iterator val)
+  const_iterator (typename disarray<size_type,M>::const_iterator idof_iter, typename field_basic<T,M>::const_iterator val)
     : _idof_iter(idof_iter), _val(val) {}
  
 // accessors & modifiers:
@@ -246,7 +213,7 @@ public:
   bool operator!= (const const_iterator& j) const { return ! operator== (j); }
 protected:
 // data:
-  typename array<size_type,M>::const_iterator _idof_iter;
+  typename disarray<size_type,M>::const_iterator _idof_iter;
   typename field_basic<T,M>::const_iterator   _val;
 };
 template<class T, class M>
@@ -278,6 +245,7 @@ public:
   typedef typename field_basic<T,M>::size_type size_type;
   typedef T                                    scalar_type;
   typedef T                                    value_type; // TO_CLEAN !
+  typedef M                                    memory_type;
   class const_iterator;
 
 // allocators:
@@ -318,7 +286,7 @@ protected:
   space_basic<T,M>                            _V;
   space_basic<T,M>                            _W;
   geo_basic<T,M>                              _dom;
-  array<size_type,M>                          _indirect; // temporary
+  disarray<size_type,M>                       _indirect; // temporary
   typename field_basic<T,M>::const_iterator   _val;      // iterator = reference on an external variable uh
 				   		         // thus cstor is protected to prevent copy outside the field class
 };
@@ -327,8 +295,13 @@ inline
 std::string
 field_indirect_const<T,M>::stamp() const
 {
-  // e.g. "P1(square.left)", an unique signature for field_expr<Expr> size-like checks
-  return _V.get_numbering().name() + "(" + _V.get_geo().name() + "[" + _dom.name() + "])";
+  if (_dom.variant() != geo_abstract_base_rep<T>::geo_domain) {
+    // usual domain:
+    return _V.get_numbering().name() + "(" + _V.get_geo().name() + "[" + _dom.name() + "])";
+  } else {
+    // geo_domain: from space or band, has already index as "square[left]"
+    return _V.get_numbering().name() + "(" + _dom.name() + ")";
+  }
 }
 template<class T, class M>
 inline
@@ -344,43 +317,6 @@ field_basic<T,M>::operator[] (std::string dom_name) const
 {
   return operator[] (get_space().get_geo().operator[] (dom_name));
 }
-template<class T, class M>
-inline
-field_basic<T,M>::field_basic (const field_indirect_const<T,M>& expr)
- : _V(),
-   _u(),
-   _b(),
-   _dis_dof_update_needed(true)
-{
-    operator= (expr);
-}
-template<class T, class M>
-inline
-field_basic<T,M>&
-field_basic<T,M>::operator=  (const field_indirect_const<T,M>& expr)
-{
-  if (stamp() == "") {
-    resize (expr.get_space());
-  } else {
-    check_macro (stamp() == expr.stamp(), "incompatible spaces "
-	<< stamp() << " and " << expr.stamp()
-	<< " in field = field[domain]");
-  }
-  dis_dof_update_needed();
-  algo::copy_n (expr.begin_dof(), expr.ndof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
-field_indirect<T,M>&
-field_indirect<T,M>::operator=  (const field_indirect_const<T,M>& expr)
-{
-  check_macro (_V.valued_tag() == space_constant::scalar, "field[domain]: unsupported non-scalar field");
-  check_macro (stamp() == expr.stamp(), "field[domain] = field[domain]: incompatible spaces "
-		<< stamp() << " and " << expr.stamp());
-  algo::copy_n (expr.begin_dof(), expr.ndof(), begin_dof());
-  return *this;
-}
 // =================================================================================
 // field_indirect_const::const_iterator
 // =================================================================================
@@ -397,7 +333,7 @@ public:
   typedef std::ptrdiff_t                    difference_type;
 
 // allocator:
-  const_iterator (typename array<size_type,M>::const_iterator idof_iter, typename field_basic<T,M>::const_iterator val)
+  const_iterator (typename disarray<size_type,M>::const_iterator idof_iter, typename field_basic<T,M>::const_iterator val)
     : _idof_iter(idof_iter), _val(val) {}
  
 // accessors & modifiers:
@@ -410,8 +346,8 @@ public:
   bool operator!= (const const_iterator& j) const { return ! operator== (j); }
 protected:
 // data:
-  typename array<size_type,M>::const_iterator _idof_iter;
-  typename field_basic<T,M>::const_iterator   _val;
+  typename disarray<size_type,M>::const_iterator _idof_iter;
+  typename field_basic<T,M>::const_iterator      _val;
 };
 template<class T, class M>
 inline
