@@ -26,22 +26,21 @@
 // date: 12 may 1997  update: 23 oct 2011
 //
 #include "rheolef/field.h"
-#include "rheolef/field_expr_ops.h"
-#include "rheolef/field_nonlinear_expr_ops.h"
-#include "rheolef/interpolate.h"
 #include "rheolef/piola.h"
 #include "rheolef/rheostream.h"
 #include "rheolef/iorheo.h"
 #include "rheolef/field_evaluate.h"
 #include "rheolef/space_component.h"
+#include "rheolef/interpolate.h"
+
 namespace rheolef { 
 using namespace std;
 
 // extern:
 template <class T> odiststream& geo_put_vtk (odiststream& ods, const geo_basic<T,sequential>& omega,
-	const numbering<T,sequential>& my_numb, const array<point_basic<T>,sequential>& my_node, bool append_data);
+	const numbering<T,sequential>& my_numb, const disarray<point_basic<T>,sequential>& my_node, bool append_data);
 template <class T> odiststream& geo_put_vtk (odiststream& ods, const geo_basic<T,sequential>& omega,
-	size_t my_order, const array<point_basic<T>,sequential>& my_node, bool append_data);
+	size_t my_order, const disarray<point_basic<T>,sequential>& my_node, bool append_data);
 
 // when uh is P0 on a P1 mesh, compute uh on a P1d field, such that
 // xdofs coincide locally on each element with mesh nodes
@@ -119,7 +118,7 @@ put_vtk_vector_values (odiststream& ods, const field_basic<T,sequential>& uh, st
   size_type n_comp = uh.size();
   std::vector<field_component_const<T,sequential> > uh_comp (n_comp);
   for (size_type i_comp = 0; i_comp < n_comp; i_comp++) {
-    uh_comp[i_comp] = uh[i_comp];
+    uh_comp[i_comp].proxy_assign (uh[i_comp]);
   }
   space_basic<T,sequential> Xh (uh.get_geo(), uh.get_approx());
   field_basic<T,sequential> norm_uh = interpolate (Xh, norm(uh));
