@@ -27,16 +27,12 @@
 //
 # include "rheolef/field.h"
 # include "rheolef/field_indirect.h"
-# include "rheolef/field_expr.h"
-# include "rheolef/field_expr_ops.h"
-# include "rheolef/field_nonlinear_expr_ops.h"
-# include "rheolef/interpolate.h"
 # include "rheolef/field_evaluate.h"
 # include "rheolef/piola.h"
-# include "rheolef/rounder.h"
 # include "rheolef/rheostream.h"
-
 # include "field_seq_visu_gnuplot_internal.h"
+# include "rheolef/interpolate.h"
+# include "rheolef/rounder.h"
 
 namespace rheolef {
 
@@ -420,9 +416,9 @@ visu_gnuplot_vector (odiststream& ods, const field_basic<T,sequential>& uh)
   size_type n_comp = uh.size();
   std::vector<field_component_const<T,sequential> > uh_comp (n_comp);
   for (size_type i_comp = 0; i_comp < n_comp; i_comp++) {
-    uh_comp[i_comp] = uh[i_comp];
+    uh_comp[i_comp].proxy_assign (uh[i_comp]);
   }
-  array<point_basic<T>, sequential> x = omega.get_nodes();
+  disarray<point_basic<T>, sequential> x = omega.get_nodes();
   for (size_type inod = 0, nnod = x.size(); inod < nnod; inod++) {
     point_basic<T> vi;
     for (size_type i_comp = 0; i_comp < n_comp; i_comp++) {
