@@ -25,6 +25,10 @@
 //
 // date: 12 may 1997  update: 23 oct 2011
 //
+// note on december 2015: mayavi scripts appears to
+// have change without backward compatibility, so
+// the present scripts becomes obsolete
+//
 #include "rheolef/field.h"
 #include "rheolef/piola.h"
 #include "rheolef/rheostream.h"
@@ -79,7 +83,7 @@ visu_vtk_mayavi (odiststream& ops, const field_basic<T,sequential>& uh)
   bool black_and_white = iorheo::getblack_and_white(os);
   bool stereo    = iorheo::getstereo(os);
   bool volume    = iorheo::getvolume(os);
-  bool iso       = iorheo::getiso(os);
+  bool iso       = true;
   bool cut       = iorheo::getcut(os);
   bool grid       = iorheo::getgrid(os);
   string format   = iorheo::getimage_format(os);
@@ -320,7 +324,7 @@ plane_cut (
         // project in 1D space
         gamma_cut.set_dimension (1);
         point_basic<T> tangent = point_basic<T>(normal[1], -normal[0]);
-	array<node_type,sequential> node = gamma_cut.get_nodes();
+	disarray<node_type,sequential> node = gamma_cut.get_nodes();
         for (size_type i = 0, n = node.size(); i < n; i++) {
 	  node[i] = point_basic<T> (dot(node[i], tangent), 0);
         }
@@ -334,7 +338,7 @@ plane_cut (
         t1 = t1 - dot(t1,normal)*normal;
         t1 = t1 / norm(t1);
         point_basic<T> t2 = vect(normal,t1);
-	array<node_type,sequential> node = gamma_cut.get_nodes();
+	disarray<node_type,sequential> node = gamma_cut.get_nodes();
         for (size_type i = 0, n = node.size(); i < n; i++) {
 	  node[i] = point_basic<T> (dot(node[i] - origin, t1), dot(node[i] - origin, t2), 0);
         }
@@ -351,10 +355,17 @@ plane_cut (
   //     SCALARS scalars float
   //     LOOKUP_TABLE default
   // -------------------------------
-  scatch (vtk_polydata, "POINT_DATA");
-  scatch (vtk_polydata, "SCALARS");
+  string data_type;
+  while (true) {
+    vtk_polydata >> data_type;
+    if ((data_type == "POINT_DATA") || 
+        (data_type == "CELL_DATA" )) {
+      break;
+    }
+  }
   scatch (vtk_polydata, "default");
-  space_basic<T,sequential> V_cut (gamma_cut, "P1");
+  string approx = (data_type == "POINT_DATA") ? "P1" : "P0";
+  space_basic<T,sequential> V_cut (gamma_cut, approx);
   field_basic<T,sequential> u_cut (V_cut);
   u_cut.set_u().get_values (ips_vtk_polydata);
   return u_cut;
