@@ -54,7 +54,7 @@ assembly_dis_idof (
   size_type dis_ie0 = K.master(0),
             dis_ie1 = K.master(1);
   check_macro (dis_ie0 != std::numeric_limits<size_type>::max(),
-          "unexpected isolated mesh side K="<<K);
+          "unexpected isolated mesh side K.dis_ie="<<K.dis_ie());
   if (dis_ie1 == std::numeric_limits<size_type>::max()) {
     // boundary side K
     const geo_element& L = X.get_geo().dis_get_geo_element (map_d+1, dis_ie0);
