@@ -32,7 +32,8 @@ namespace rheolef {
 //  A = {a, b};			// matrix & vector
 // =========================================================================
 template <class T, class M>
-struct form_concat_value {
+class form_concat_value {
+public:
 // typedef:
  typedef enum { scalar, field, field_transpose, form} variant_type;
 // allocators:
@@ -57,7 +58,8 @@ public:
  variant_type      variant;
 };
 template <class T, class M>
-struct form_concat_line {
+class form_concat_line {
+public:
 // typedef:
  typedef typename form_basic<T,M>::size_type   size_type;
  typedef form_concat_value<T,M>                value_type;
