@@ -224,7 +224,8 @@ geo_base_rep<T,M>::dis_get_geo_element (size_type dim, size_type dis_ige) const
   // element is owned by another proc ; get its variant and then its index-variant igev
   size_type variant  = _gs.dis_ige2variant  (dim, dis_ige);
   size_type dis_igev = _gs.dis_ige2dis_igev (dim, variant, dis_ige);
-  return _geo_element [variant].dis_at (dis_igev);
+  typename geo_base_rep<T,M>::const_reference res = _geo_element [variant].dis_at (dis_igev);
+  return res;
 }
 // =========================================================================
 // geo_base_rep members
@@ -406,7 +407,7 @@ geo_base_rep<T,M>::piola (const geo_element& K, const node_type& hat_x) const
   return x;
 }
 // ----------------------------------------------------------------------------
-// set order & resize node array ; internal node are not computed
+// set order & resize node disarray ; internal node are not computed
 // since they depend on the curved boundary information (cad data)
 // that is not aivailable here
 // ----------------------------------------------------------------------------
@@ -420,7 +421,7 @@ geo_rep<T,M>::reset_order (size_type new_order)				\
   size_type dis_nnod = base::_numbering.dis_ndof (base::_gs, base::_map_dimension); \
   size_type     nnod = base::_numbering.ndof     (base::_gs, base::_map_dimension); \
   base::_gs.node_ownership = distributor (nnod, base::comm(), nnod);	\
-  array<point_basic<T>, M> new_node (base::_gs.node_ownership);		\
+  disarray<point_basic<T>, M> new_node (base::_gs.node_ownership);		\
   for (size_type iv = 0, nv = base::_gs.ownership_by_dimension[0].size(); iv < nv; iv++) { \
     new_node [iv] = base::_node [iv];					\
   }									\
