@@ -55,7 +55,7 @@
                 geo_domain_rep<T,M>          : data + methods for compacted geometry on domain
 */
 #include "rheolef/geo_element.h"
-#include "rheolef/array.h"
+#include "rheolef/disarray.h"
 #include "rheolef/hack_array.h"
 #include "rheolef/geo_size.h"
 #include "rheolef/point.h"
@@ -326,28 +326,28 @@ public:
     virtual const domain_indirect_basic<sequential>& get_domain_indirect (const std::string& name) const = 0;
     virtual void  insert_domain_indirect (const domain_indirect_basic<sequential>& dom) const = 0;
 
-    virtual const array<node_type,sequential>& get_nodes() const = 0;
-    virtual void set_nodes (const array<node_type,sequential>&) = 0;
+    virtual const disarray<node_type,sequential>& get_nodes() const = 0;
+    virtual void set_nodes (const disarray<node_type,sequential>&) = 0;
 
     virtual void locate (
-                const array<point_basic<T>, sequential>&    x,
-                      array<size_type, sequential>&         dis_ie,
+                const disarray<point_basic<T>, sequential>&    x,
+                      disarray<size_type, sequential>&         dis_ie,
                 bool  do_check = false) const = 0;
     virtual void trace_ray_boundary (
-                const array<point_basic<T>,sequential>&     x,
-                const array<point_basic<T>,sequential>&     v,
-                      array<size_type, sequential>&         dis_ie,
-                      array<point_basic<T>,sequential>&     y,
+                const disarray<point_basic<T>,sequential>&     x,
+                const disarray<point_basic<T>,sequential>&     v,
+                      disarray<size_type, sequential>&         dis_ie,
+                      disarray<point_basic<T>,sequential>&     y,
                 bool  do_check = false) const = 0;
     virtual void trace_move (
-                const array<point_basic<T>,sequential>&     x,
-                const array<point_basic<T>,sequential>&     v,
-                      array<size_type, sequential>&         dis_ie,
-                      array<point_basic<T>,sequential>&     y) const = 0;
+                const disarray<point_basic<T>,sequential>&     x,
+                const disarray<point_basic<T>,sequential>&     v,
+                      disarray<size_type, sequential>&         dis_ie,
+                      disarray<point_basic<T>,sequential>&     y) const = 0;
     virtual void nearest (
-                const array<point_basic<T>,sequential>&     x,
-                      array<point_basic<T>,sequential>&     x_nearest,
-                      array<size_type, sequential>&         dis_ie) const = 0;
+                const disarray<point_basic<T>,sequential>&     x,
+                      disarray<point_basic<T>,sequential>&     x_nearest,
+                      disarray<size_type, sequential>&         dis_ie) const = 0;
 };
 #ifdef _RHEOLEF_HAVE_MPI
 template <class T>
@@ -381,34 +381,34 @@ public:
     virtual const domain_indirect_basic<distributed>& get_domain_indirect (const std::string& name) const = 0;
     virtual void insert_domain_indirect (const domain_indirect_basic<distributed>& dom) const = 0;
 
-    virtual const array<node_type,distributed>& get_nodes() const = 0;
-    virtual void set_nodes (const array<node_type,distributed>&) = 0;
+    virtual const disarray<node_type,distributed>& get_nodes() const = 0;
+    virtual void set_nodes (const disarray<node_type,distributed>&) = 0;
 
     virtual void locate (
-                const array<point_basic<T>,distributed>&     x,
-                      array<size_type, distributed>&         dis_ie,
+                const disarray<point_basic<T>,distributed>&     x,
+                      disarray<size_type, distributed>&         dis_ie,
                 bool  do_check = true) const = 0;
     virtual void trace_ray_boundary (
-                const array<point_basic<T>,distributed>&     x,
-                const array<point_basic<T>,distributed>&     v,
-                      array<size_type, distributed>&         dis_ie,
-                      array<point_basic<T>,distributed>&     y,
+                const disarray<point_basic<T>,distributed>&     x,
+                const disarray<point_basic<T>,distributed>&     v,
+                      disarray<size_type, distributed>&         dis_ie,
+                      disarray<point_basic<T>,distributed>&     y,
                 bool  do_check = false) const = 0;
     virtual void trace_move (
-                const array<point_basic<T>,distributed>&     x,
-                const array<point_basic<T>,distributed>&     v,
-                      array<size_type, distributed>&         dis_ie,
-                      array<point_basic<T>,distributed>&     y) const = 0;
+                const disarray<point_basic<T>,distributed>&     x,
+                const disarray<point_basic<T>,distributed>&     v,
+                      disarray<size_type, distributed>&         dis_ie,
+                      disarray<point_basic<T>,distributed>&     y) const = 0;
     virtual void nearest (
-                const array<point_basic<T>,distributed>&     x,
-                      array<point_basic<T>,distributed>&     x_nearest,
-                      array<size_type, distributed>&         dis_ie) const = 0;
+                const disarray<point_basic<T>,distributed>&     x,
+                      disarray<point_basic<T>,distributed>&     x_nearest,
+                      disarray<size_type, distributed>&         dis_ie) const = 0;
 
 // utility:
 
     virtual void set_ios_permutation (
-    	boost::array<size_type,reference_element::max_variant>& loc_ndof_by_variant,
-    	array<size_type,distributed>&                           idof2ios_dis_idof) const = 0;
+    	std::array<size_type,reference_element::max_variant>& loc_ndof_by_variant,
+    	disarray<size_type,distributed>&                        idof2ios_dis_idof) const = 0;
 };
 #endif // _RHEOLEF_HAVE_MPI
 // =========================================================================
@@ -442,8 +442,8 @@ public:
 
     void build_from_list (
       const geo_basic<T,M>&                               lambda,
-      const array<point_basic<T>,M>&                      node_list,
-      const boost::array<array<geo_element_auto<heap_allocator<size_type> >,M>,
+      const disarray<point_basic<T>,M>&                   node_list,
+      const std::array<disarray<geo_element_auto<heap_allocator<size_type> >,M>,
                          reference_element::max_variant>& elt_list);
 
     ~geo_base_rep ();
@@ -484,9 +484,9 @@ public:
     void             dis_inod (const geo_element& K, std::vector<size_type>& dis_inod) const
 	{ _numbering.dis_idof (_gs, K, dis_inod); }
     node_type piola (const geo_element& K, const node_type& hat_x) const;
-    const array<node_type,M>& get_nodes() const { return _node; }
+    const disarray<node_type,M>& get_nodes() const { return _node; }
 
-    void set_nodes (const array<node_type,M>& x) { _node = x; _node.reset_dis_indexes(); compute_bbox(); }
+    void set_nodes (const disarray<node_type,M>& x) { _node = x; _node.reset_dis_indexes(); compute_bbox(); }
     size_type n_domain_indirect () const { return _domains.size(); }
     bool have_domain_indirect (const std::string& name) const;
     const domain_indirect_basic<M>& get_domain_indirect (size_type i) const { return _domains[i]; }
@@ -560,7 +560,7 @@ public:
 protected:
     void compute_bbox();
     void init_neighbour() const;
-    template<class U> friend void add_ball_externals (const geo_base_rep<U,M>&, const array<index_set,M>&);
+    template<class U> friend void add_ball_externals (const geo_base_rep<U,M>&, const disarray<index_set,M>&);
 
 // data:
 // 0) header:
@@ -568,14 +568,14 @@ protected:
     size_type                                _version;
     size_type                                _serial_number;
 // 1) connectivity:
-    hack_array<geo_element_hack,M>           _geo_element [reference_element::max_variant];
+    std::array<hack_array<geo_element_hack,M>, reference_element::max_variant> _geo_element;
     size_type                                _map_dimension;
     geo_size                                 _gs; // counters by geo_element dimension: 0,1,2,3
     mutable std::vector<domain_indirect_basic<M> > _domains;
     bool				     _have_connectivity; // e.g.list of  edges in a 2d triangular mesh
     mutable bool			     _have_neighbour; // inter-element connectivity
 // 2) coordinates:
-    array<node_type, M>                      _node;
+    disarray<node_type, M>                   _node;
     size_type                                _dimension;
     coordinate_type                          _sys_coord;
     node_type				     _xmin; // bounding box
@@ -663,6 +663,11 @@ geo_abstract_base_rep<T>::end (size_type dim) const
 /// @brief sequential mesh representation
 // =========================================================================
 template <class T, class M> class geo_rep {};
+template <class T, class M>
+void geo_build_by_subdividing (
+            geo_rep  <T,M>&            new_omega,
+      const geo_basic<T,M>&            old_omega,
+      typename geo_rep<T,M>::size_type k);
 
 template <class T>
 class geo_rep<T,sequential> : public geo_base_rep<T,sequential> {
@@ -690,8 +695,8 @@ public:
     // build from_list (for level set)
     geo_rep (
       const geo_basic<T,sequential>&                      lambda,
-      const array<point_basic<T>,sequential>&             node_list,
-      const boost::array<array<geo_element_auto<heap_allocator<size_type> >,sequential>,
+      const disarray<point_basic<T>,sequential>&          node_list,
+      const std::array<disarray<geo_element_auto<heap_allocator<size_type> >,sequential>,
                          reference_element::max_variant>& elt_list);
 
     void build_from_domain (
@@ -702,24 +707,24 @@ public:
 // abstract accessors redefined:
 
     void locate (
-                const array<point_basic<T>, sequential>&    x,
-                      array<size_type, sequential>&         dis_ie,
+                const disarray<point_basic<T>, sequential>&    x,
+                      disarray<size_type, sequential>&         dis_ie,
                 bool do_check = false) const;
     void trace_ray_boundary (
-                const array<point_basic<T>,sequential>&     x,
-                const array<point_basic<T>,sequential>&     v,
-                      array<size_type, sequential>&         dis_ie,
-                      array<point_basic<T>,sequential>&     y,
+                const disarray<point_basic<T>,sequential>&     x,
+                const disarray<point_basic<T>,sequential>&     v,
+                      disarray<size_type, sequential>&         dis_ie,
+                      disarray<point_basic<T>,sequential>&     y,
                 bool  do_check = false) const;
     void trace_move (
-                const array<point_basic<T>,sequential>&     x,
-                const array<point_basic<T>,sequential>&     v,
-                      array<size_type, sequential>&         dis_ie,
-                      array<point_basic<T>,sequential>&     y) const;
+                const disarray<point_basic<T>,sequential>&     x,
+                const disarray<point_basic<T>,sequential>&     v,
+                      disarray<size_type, sequential>&         dis_ie,
+                      disarray<point_basic<T>,sequential>&     y) const;
     void nearest (
-                const array<point_basic<T>,sequential>&     x,
-                      array<point_basic<T>,sequential>&     x_nearest,
-                      array<size_type, sequential>&         dis_ie) const;
+                const disarray<point_basic<T>,sequential>&     x,
+                      disarray<point_basic<T>,sequential>&     x_nearest,
+                      disarray<size_type, sequential>&         dis_ie) const;
 
 // herited accessors:
 
@@ -758,10 +763,11 @@ public:
 // modifier:
 
     void reset_order (size_type order);
+    void build_by_subdividing (const geo_basic<T,sequential>& omega, size_type k);
     void build_from_data (
         const geo_header&                                               hdr,
-        const array<node_type, sequential>&                             node,
-              boost::array<array<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>&
+        const disarray<node_type, sequential>&                             node,
+              std::array<disarray<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>&
 									tmp_geo_element,
         bool do_upgrade);
 
@@ -770,30 +776,37 @@ protected:
     idiststream& get_standard (idiststream&, const geo_header&);
     idiststream& get_upgrade  (idiststream&, const geo_header&);
     void build_connectivity (
-  	boost::array<array<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element);
+  	std::array<disarray<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element);
 
     void build_connectivity_sides (
 		size_type side_dim, 
-  		boost::array<array<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element);
+  		std::array<disarray<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element);
     void set_element_side_index (size_type side_dim);
     void domain_set_side_part1 (
                 const domain_indirect_rep<sequential>&    indirect,
                 const geo_abstract_rep<T,sequential>&     bgd_omega,
                 size_type                                 sid_dim,
-                array<size_type,sequential>&              bgd_isid2dom_dis_isid,
-                array<size_type,sequential>&              dom_isid2bgd_isid,
-                array<size_type,sequential>&              dom_isid2dom_ios_dis_isid,
+                disarray<size_type,sequential>&           bgd_isid2dom_dis_isid,
+                disarray<size_type,sequential>&           dom_isid2bgd_isid,
+                disarray<size_type,sequential>&           dom_isid2dom_ios_dis_isid,
     		size_type                                 size_by_variant [reference_element::max_variant]);
     void domain_set_side_part2 (
                 const domain_indirect_rep<sequential>&    indirect,
                 const geo_abstract_rep<T,sequential>&     bgd_omega,
-                array<size_type,sequential>&              bgd_iv2dom_dis_iv,
+                disarray<size_type,sequential>&           bgd_iv2dom_dis_iv,
                 size_type                                 sid_dim,
-                array<size_type,sequential>&              bgd_isid2dom_dis_isid,
-                array<size_type,sequential>&              dom_isid2bgd_isid,
-                array<size_type,sequential>&              dom_isid2dom_ios_dis_isid,
+                disarray<size_type,sequential>&           bgd_isid2dom_dis_isid,
+                disarray<size_type,sequential>&           dom_isid2bgd_isid,
+                disarray<size_type,sequential>&           dom_isid2dom_ios_dis_isid,
     		size_type                                 size_by_variant [reference_element::max_variant]);
     void build_external_entities () {} // for distributed compat
+
+// friends:
+
+  friend void geo_build_by_subdividing<> (
+            geo_rep<T,sequential>&              new_omega,
+      const geo_basic<T,sequential>&            old_omega,
+      typename geo_rep<T,sequential>::size_type k);
 };
 #ifdef _RHEOLEF_HAVE_MPI
 // =========================================================================
@@ -831,8 +844,8 @@ public:
     // build from_list (for level set)
     geo_rep (
       const geo_basic<T,distributed>&                     lambda,
-      const array<point_basic<T>,distributed>&            node_list,
-      const boost::array<array<geo_element_auto<heap_allocator<size_type> >,distributed>,
+      const disarray<point_basic<T>,distributed>&         node_list,
+      const std::array<disarray<geo_element_auto<heap_allocator<size_type> >,distributed>,
                          reference_element::max_variant>& elt_list);
 
 // abstract accessors defined:
@@ -844,24 +857,24 @@ public:
     size_type             ios_ige2dis_ige (size_type dim, size_type ios_ige) const;
     const geo_size&  ios_sizes() const { return _ios_gs; }
     void locate (
-                const array<point_basic<T>,distributed>&     x,
-                      array<size_type, distributed>&         dis_ie,
+                const disarray<point_basic<T>,distributed>&     x,
+                      disarray<size_type, distributed>&         dis_ie,
                       bool do_check = false) const;
     void trace_ray_boundary (
-                const array<point_basic<T>,distributed>&     x,
-                const array<point_basic<T>,distributed>&     v,
-                      array<size_type, distributed>&         dis_ie,
-                      array<point_basic<T>,distributed>&     y,
+                const disarray<point_basic<T>,distributed>&     x,
+                const disarray<point_basic<T>,distributed>&     v,
+                      disarray<size_type, distributed>&         dis_ie,
+                      disarray<point_basic<T>,distributed>&     y,
                 bool  do_check = false) const;
     void trace_move (
-                const array<point_basic<T>,distributed>&     x,
-                const array<point_basic<T>,distributed>&     v,
-                      array<size_type, distributed>&         dis_ie,
-                      array<point_basic<T>,distributed>&     y) const;
+                const disarray<point_basic<T>,distributed>&     x,
+                const disarray<point_basic<T>,distributed>&     v,
+                      disarray<size_type, distributed>&         dis_ie,
+                      disarray<point_basic<T>,distributed>&     y) const;
     void nearest (
-                const array<point_basic<T>,distributed>&     x,
-                      array<point_basic<T>,distributed>&     x_nearest,
-                      array<size_type, distributed>&         dis_ie) const;
+                const disarray<point_basic<T>,distributed>&     x,
+                      disarray<point_basic<T>,distributed>&     x_nearest,
+                      disarray<size_type, distributed>&         dis_ie) const;
 
 // herited accessors:
 
@@ -891,6 +904,7 @@ public:
 // modifier:
 
     void reset_order (size_type order);
+    void build_by_subdividing (const geo_basic<T,distributed>& omega, size_type k);
 
 // i/o:
 
@@ -903,8 +917,8 @@ public:
 // utilities:
 
     void set_ios_permutation (
-    	boost::array<size_type,reference_element::max_variant>& loc_ndof_by_variant,
-    	array<size_type,distributed>&                           idof2ios_dis_idof) const;
+    	std::array<size_type,reference_element::max_variant>& loc_ndof_by_variant,
+    	disarray<size_type,distributed>&                      idof2ios_dis_idof) const;
 
 protected:
 // internal:
@@ -914,29 +928,36 @@ protected:
                 const domain_indirect_rep<distributed>&    indirect,
                 const geo_abstract_rep<T,distributed>&     bgd_omega,
                 size_type                                  sid_dim,
-                array<size_type>&                          bgd_isid2dom_dis_isid,
-                array<size_type>&                          dom_isid2bgd_isid,
-                array<size_type>&                          dom_isid2dom_ios_dis_isid,
+                disarray<size_type>&                       bgd_isid2dom_dis_isid,
+                disarray<size_type>&                       dom_isid2bgd_isid,
+                disarray<size_type>&                       dom_isid2dom_ios_dis_isid,
     		size_type                                  size_by_variant [reference_element::max_variant]);
     void domain_set_side_part2 (
                 const domain_indirect_rep<distributed>&    indirect,
                 const geo_abstract_rep<T,distributed>&     bgd_omega,
-                array<size_type>&                          bgd_iv2dom_dis_iv,
+                disarray<size_type>&                          bgd_iv2dom_dis_iv,
                 size_type                                  sid_dim,
-                array<size_type>&                          bgd_isid2dom_dis_isid,
-                array<size_type>&                          dom_isid2bgd_isid,
-                array<size_type>&                          dom_isid2dom_ios_dis_isid,
+                disarray<size_type>&                       bgd_isid2dom_dis_isid,
+                disarray<size_type>&                       dom_isid2bgd_isid,
+                disarray<size_type>&                       dom_isid2dom_ios_dis_isid,
     		size_type                                  size_by_variant [reference_element::max_variant]);
 
     void node_renumbering (const distributor& ios_node_ownership);
 
 // data:
-    array<size_type>             _inod2ios_dis_inod;  // permutation for node
-    array<size_type>             _ios_inod2dis_inod;  // reverse permutation for node
-    array<size_type>             _ios_ige2dis_ige[4]; // reverse permutation for geo_element[dim]
+    disarray<size_type>          _inod2ios_dis_inod;  // permutation for node
+    disarray<size_type>          _ios_inod2dis_inod;  // reverse permutation for node
+    std::array<disarray<size_type>, 4> _ios_ige2dis_ige; // reverse permutation for geo_element[dim]
     geo_size                     _ios_gs;
-    array<size_type>             _igev2ios_dis_igev [reference_element::max_variant];
-    array<size_type>             _ios_igev2dis_igev [reference_element::max_variant];
+    std::array<disarray<size_type>,reference_element::max_variant> _igev2ios_dis_igev;
+    std::array<disarray<size_type>,reference_element::max_variant> _ios_igev2dis_igev;
+
+// friends:
+
+  friend void geo_build_by_subdividing<> (
+            geo_rep<T,distributed>&              new_omega,
+      const geo_basic<T,distributed>&            old_omega,
+      typename geo_rep<T,distributed>::size_type k);
 };
 #endif // _RHEOLEF_HAVE_MPI
 
@@ -1000,8 +1021,8 @@ public:
     // build from_list (for level set)
     geo_basic (
       const geo_basic<T,sequential>&                      lambda,
-      const array<point_basic<T>,sequential>&             node_list,
-      const boost::array<array<geo_element_auto<heap_allocator<size_type> >,sequential>,
+      const disarray<point_basic<T>,sequential>&          node_list,
+      const std::array<disarray<geo_element_auto<heap_allocator<size_type> >,sequential>,
                          reference_element::max_variant>& elt_list)
     : base (new_macro(rep_geo_rep(lambda,node_list,elt_list))) {}
 
@@ -1039,7 +1060,7 @@ public:
     void dis_inod (const geo_element& K, std::vector<size_type>& dis_inod) const {
     		return base::data().dis_inod(K,dis_inod); }
     node_type piola (const geo_element& K, const node_type& hat_x) const { return base::data().piola (K, hat_x); }
-    const array<node_type,sequential>& get_nodes() const { return base::data().get_nodes(); }
+    const disarray<node_type,sequential>& get_nodes() const { return base::data().get_nodes(); }
     size_type dis_inod2dis_iv (size_type dis_inod) const { return base::data().dis_inod2dis_iv(dis_inod); }
 
     size_type n_domain_indirect () const { return base::data().n_domain_indirect (); }
@@ -1067,8 +1088,8 @@ public:
 		size_type dis_ie_guest = std::numeric_limits<size_type>::max()) const
 		{ return base::data().dis_locate (x, dis_ie_guest); }
     void locate (	
-		const array<point_basic<T>, sequential>& x,
-		array<size_type, sequential>& dis_ie) const
+		const disarray<point_basic<T>, sequential>& x,
+		disarray<size_type, sequential>& dis_ie) const
     		{ return base::data().locate (x, dis_ie); }
     size_type seq_trace_move (
                 const point_basic<T>&     x,
@@ -1081,16 +1102,16 @@ public:
                       point_basic<T>&     y) const
     					{ return base::data().dis_trace_move (x,v,y); }
     void trace_ray_boundary (
-                const array<point_basic<T>,sequential>&     x,
-                const array<point_basic<T>,sequential>&     v,
-                      array<size_type, sequential>&         dis_ie,
-                      array<point_basic<T>,sequential>&     y) const
+                const disarray<point_basic<T>,sequential>&     x,
+                const disarray<point_basic<T>,sequential>&     v,
+                      disarray<size_type, sequential>&         dis_ie,
+                      disarray<point_basic<T>,sequential>&     y) const
     					{ return base::data().trace_ray_boundary (x,v,dis_ie,y); }
     void trace_move (
-                const array<point_basic<T>,sequential>&     x,
-                const array<point_basic<T>,sequential>&     v,
-                      array<size_type, sequential>&         dis_ie,
-                      array<point_basic<T>,sequential>&     y) const
+                const disarray<point_basic<T>,sequential>&     x,
+                const disarray<point_basic<T>,sequential>&     v,
+                      disarray<size_type, sequential>&         dis_ie,
+                      disarray<point_basic<T>,sequential>&     y) const
     					{ return base::data().trace_move (x,v,dis_ie,y); }
     size_type seq_nearest (
                 const point_basic<T>&    x,
@@ -1101,9 +1122,9 @@ public:
                       point_basic<T>&    x_nearest) const
     					{ return base::data().dis_nearest (x, x_nearest); }
     void nearest (
-                const array<point_basic<T>,sequential>&     x,
-                      array<point_basic<T>,sequential>&     x_nearest,
-                      array<size_type, sequential>&         dis_ie) const
+                const disarray<point_basic<T>,sequential>&     x,
+                      disarray<point_basic<T>,sequential>&     x_nearest,
+                      disarray<size_type, sequential>&         dis_ie) const
     					{ base::data().nearest (x, x_nearest, dis_ie); }
 
 // modifiers:
@@ -1114,11 +1135,12 @@ public:
     void reset_order (size_type order);
     void set_coordinate_system (coordinate_type sys_coord);
     void set_coordinate_system (std::string sys_coord_name) { set_coordinate_system (space_constant::coordinate_system(sys_coord_name)); }
-    void set_nodes (const array<node_type,sequential>& x);
+    void set_nodes (const disarray<node_type,sequential>& x);
+    void build_by_subdividing (const geo_basic<T,sequential>& omega, size_type k);
     void build_from_data (
         const geo_header&                                               hdr,
-        const array<node_type, sequential>&                             node,
-              boost::array<array<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>&
+        const disarray<node_type, sequential>&                          node,
+              std::array<disarray<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>&
 									tmp_geo_element,
         bool do_upgrade);
 
@@ -1246,8 +1268,8 @@ public:
     // build from_list (for level set)
     geo_basic (
       const geo_basic<T,distributed>&                     lambda,
-      const array<point_basic<T>,distributed>&                   node_list,
-      const boost::array<array<geo_element_auto<heap_allocator<size_type> >,distributed>,
+      const disarray<point_basic<T>,distributed>&                   node_list,
+      const std::array<disarray<geo_element_auto<heap_allocator<size_type> >,distributed>,
                          reference_element::max_variant>& elt_list)
     : base (new_macro(rep_geo_rep(lambda,node_list,elt_list))) {}
 
@@ -1296,15 +1318,7 @@ public:
     void dis_inod (const geo_element& K, std::vector<size_type>& dis_inod) const {
     		return base::data().dis_inod(K,dis_inod); }
     node_type piola (const geo_element& K, const node_type& hat_x) const { return base::data().piola (K, hat_x); }
-    const array<node_type,distributed>& get_nodes() const { return base::data().get_nodes(); }
-    void set_nodes (const array<node_type,distributed>& x);
-    void reset_order (size_type order);
-    size_type dis_inod2dis_iv (size_type dis_inod) const { return base::data().dis_inod2dis_iv(dis_inod); }
-    void set_coordinate_system (coordinate_type sys_coord);
-    void set_coordinate_system (std::string sys_coord_name) { set_coordinate_system (space_constant::coordinate_system(sys_coord_name)); }
-    void set_dimension (size_type dim);
-    void set_serial_number (size_type i);
-    void set_name (std::string name);
+    const disarray<node_type,distributed>& get_nodes() const { return base::data().get_nodes(); }
 
     size_type n_domain_indirect () const { return base::data().n_domain_indirect (); }
     bool have_domain_indirect (const std::string& name) const { return base::data().have_domain_indirect (name); }
@@ -1330,7 +1344,7 @@ public:
 		const point_basic<T>& x,
 		size_type dis_ie_guest = std::numeric_limits<size_type>::max()) const
 		{ return base::data().dis_locate (x, dis_ie_guest); }
-    void locate (const array<point_basic<T>, distributed>& x, array<size_type, distributed>& dis_ie) const
+    void locate (const disarray<point_basic<T>, distributed>& x, disarray<size_type, distributed>& dis_ie) const
     		{ return base::data().locate (x, dis_ie); }
     size_type seq_trace_move (
                 const point_basic<T>&     x,
@@ -1343,16 +1357,16 @@ public:
                       point_basic<T>&     y) const
     					{ return base::data().dis_trace_move (x,v,y); }
     void trace_ray_boundary (
-                const array<point_basic<T>,distributed>&     x,
-                const array<point_basic<T>,distributed>&     v,
-                      array<size_type, distributed>&         dis_ie,
-                      array<point_basic<T>,distributed>&     y) const
+                const disarray<point_basic<T>,distributed>&     x,
+                const disarray<point_basic<T>,distributed>&     v,
+                      disarray<size_type, distributed>&         dis_ie,
+                      disarray<point_basic<T>,distributed>&     y) const
     					{ return base::data().trace_ray_boundary (x,v,dis_ie,y); }
     void trace_move (
-                const array<point_basic<T>,distributed>&     x,
-                const array<point_basic<T>,distributed>&     v,
-                      array<size_type, distributed>&         dis_ie,
-                      array<point_basic<T>,distributed>&     y) const
+                const disarray<point_basic<T>,distributed>&     x,
+                const disarray<point_basic<T>,distributed>&     v,
+                      disarray<size_type, distributed>&         dis_ie,
+                      disarray<point_basic<T>,distributed>&     y) const
     					{ return base::data().trace_move (x,v,dis_ie,y); }
     size_type seq_nearest (
                 const point_basic<T>&    x,
@@ -1363,10 +1377,21 @@ public:
                       point_basic<T>&    x_nearest) const
     					{ return base::data().dis_nearest (x, x_nearest); }
     void nearest (
-                const array<point_basic<T>,distributed>&     x,
-                      array<point_basic<T>,distributed>&     x_nearest,
-                      array<size_type, distributed>&         dis_ie) const
+                const disarray<point_basic<T>,distributed>&     x,
+                      disarray<point_basic<T>,distributed>&     x_nearest,
+                      disarray<size_type, distributed>&         dis_ie) const
     					{ base::data().nearest (x, x_nearest, dis_ie); }
+// modifiers:
+
+    void set_nodes (const disarray<node_type,distributed>& x);
+    void reset_order (size_type order);
+    size_type dis_inod2dis_iv (size_type dis_inod) const { return base::data().dis_inod2dis_iv(dis_inod); }
+    void set_coordinate_system (coordinate_type sys_coord);
+    void set_coordinate_system (std::string sys_coord_name) { set_coordinate_system (space_constant::coordinate_system(sys_coord_name)); }
+    void set_dimension (size_type dim);
+    void set_serial_number (size_type i);
+    void set_name (std::string name);
+    void build_by_subdividing (const geo_basic<T,distributed>& omega, size_type k);
 
 // extended accessors:
 
@@ -1376,6 +1401,7 @@ public:
     size_type     size()              const { return size     (map_dimension()); }
     size_type dis_size()              const { return dis_size (map_dimension()); }
     size_type     n_vertex()          const { return size     (0); }
+    size_type dis_n_vertex()          const { return dis_size (0); }
     const_reference operator[] (size_type ie) const	
 		{ return get_geo_element (map_dimension(), ie); }
 
@@ -1406,8 +1432,8 @@ public:
 // utilities:
 
     void set_ios_permutation (
-    	boost::array<size_type,reference_element::max_variant>& loc_ndof_by_variant,
-    	array<size_type,distributed>&                           idof2ios_dis_idof) const
+    	std::array<size_type,reference_element::max_variant>& loc_ndof_by_variant,
+    	disarray<size_type,distributed>&                      idof2ios_dis_idof) const
      { base::data().set_ios_permutation (loc_ndof_by_variant, idof2ios_dis_idof); }
 };
 //>verbatim:
@@ -1494,10 +1520,10 @@ geo_basic<T,M>::save (std::string filename) const				\
 #define _RHEOLEF_set_nodes(M)                                              	\
 template <class T>								\
 void										\
-geo_basic<T,M>::set_nodes (const array<node_type,M>& x)				\
+geo_basic<T,M>::set_nodes (const disarray<node_type,M>& x)			\
 {										\
   geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot set_name on geo_domains");			\
+  check_macro (ptr != 0, "cannot set_nodes on geo_domains");			\
   ptr->set_nodes(x);								\
 }
 #define _RHEOLEF_reset_order(M)                                              	\
@@ -1506,7 +1532,7 @@ void										\
 geo_basic<T,M>::reset_order (size_type order)					\
 {										\
   geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot set_name on geo_domains");			\
+  check_macro (ptr != 0, "cannot reset_order on geo_domains");			\
   ptr->reset_order(order);							\
 }
 #define _RHEOLEF_set_coordinate_system(M)                                    	\
@@ -1515,7 +1541,7 @@ void										\
 geo_basic<T,M>::set_coordinate_system (coordinate_type sys_coord)		\
 {										\
   geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot set_name on geo_domains");			\
+  check_macro (ptr != 0, "cannot set_coordinate_system on geo_domains");	\
   ptr->set_coordinate_system(sys_coord);					\
 }
 #define _RHEOLEF_set_dimension(M)	                                    	\
@@ -1524,7 +1550,7 @@ void										\
 geo_basic<T,M>::set_dimension (size_type dim)					\
 {										\
   geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot set_name on geo_domains");			\
+  check_macro (ptr != 0, "cannot set_dimension on geo_domains");		\
   ptr->set_dimension(dim);							\
 }
 #define _RHEOLEF_set_serial_number(M)	                                    	\
@@ -1533,7 +1559,7 @@ void										\
 geo_basic<T,M>::set_serial_number (size_type i)					\
 {										\
   geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot set_name on geo_domains");			\
+  check_macro (ptr != 0, "cannot set_serial_number on geo_domains");		\
   ptr->set_serial_number(i);							\
 }
 #define _RHEOLEF_set_name(M)		                                    	\
@@ -1549,15 +1575,26 @@ geo_basic<T,M>::set_name (std::string name)					\
 template <class T>								\
 void										\
 geo_basic<T,M>::build_from_data (						\
-  const geo_header&                     hdr,					\
-  const array<node_type, sequential>&   node,					\
-        boost::array<array<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element, \
+  const geo_header&               hdr,						\
+  const disarray<node_type, M>&   node,						\
+        std::array<disarray<geo_element_auto<heap_allocator<size_type> >,M, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element, \
   bool do_upgrade)								\
 {										\
   geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot set_name on geo_domains");			\
+  check_macro (ptr != 0, "cannot build_from_data on geo_domains");		\
   ptr->build_from_data (hdr, node, tmp_geo_element, do_upgrade);		\
 }
+#define _RHEOLEF_build_by_subdividing(M)		                        \
+template <class T>								\
+void										\
+geo_basic<T,M>::build_by_subdividing (						\
+  const geo_basic<T,M>& omega, 							\
+  size_type k)									\
+{										\
+  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
+  check_macro (ptr != 0, "cannot build_by_subdividing on geo_domains");		\
+  ptr->build_by_subdividing (omega, k);						\
+}
 
 _RHEOLEF_save(sequential)
 _RHEOLEF_set_nodes(sequential)
@@ -1567,6 +1604,7 @@ _RHEOLEF_set_dimension(sequential)
 _RHEOLEF_set_serial_number(sequential)
 _RHEOLEF_set_name(sequential)
 _RHEOLEF_build_from_data(sequential)
+_RHEOLEF_build_by_subdividing(sequential)
 #ifdef _RHEOLEF_HAVE_MPI
 _RHEOLEF_save(distributed)
 _RHEOLEF_set_nodes(distributed)
@@ -1575,6 +1613,10 @@ _RHEOLEF_set_coordinate_system(distributed)
 _RHEOLEF_set_dimension(distributed)
 _RHEOLEF_set_serial_number(distributed)
 _RHEOLEF_set_name(distributed)
+_RHEOLEF_build_by_subdividing(distributed)
+#ifdef TODO
+_RHEOLEF_build_from_data(distributed)
+#endif // TODO
 #endif // _RHEOLEF_HAVE_MPI
 #undef _RHEOLEF_set_nodes
 #undef _RHEOLEF_reset_order
@@ -1582,6 +1624,7 @@ _RHEOLEF_set_name(distributed)
 #undef _RHEOLEF_set_dimension
 #undef _RHEOLEF_set_name
 #undef _RHEOLEF_build_from_data
+#undef _RHEOLEF_build_by_subdividing
 // ==============================================================================
 // inlined: geo<T,M>
 // ==============================================================================
