@@ -97,7 +97,7 @@ public:
 
     size_type n_node() const { return _omega.n_node(); }
     const node_type& node (size_type inod) const { return _omega.node (inod); }
-    const array<node_type,M>& get_nodes() const { return _omega.get_nodes(); }
+    const disarray<node_type,M>& get_nodes() const { return _omega.get_nodes(); }
     const node_type& xmin () const { return _omega.xmin (); }
     const node_type& xmax () const { return _omega.xmax (); }
     const T& hmin () const { return _omega.hmin (); }
@@ -126,7 +126,7 @@ public:
     const geo_size&      sizes() const;
     const geo_size&  ios_sizes() const;
     odiststream& put (odiststream& ops) const;
-    void set_nodes (const array<node_type,M>&);
+    void set_nodes (const disarray<node_type,M>&);
     void reset_order (size_type order);
     bool check(bool verbose) const;
     size_type seq_locate(
@@ -136,8 +136,8 @@ public:
 		const point_basic<T>&     x,
 		size_type                 dis_ie_guest = std::numeric_limits<size_type>::max()) const;
     void locate (
-                const array<point_basic<T>,M>& x,
-                      array<size_type,M>&      dis_ie,
+                const disarray<point_basic<T>,M>& x,
+                      disarray<size_type,M>&      dis_ie,
                 bool do_check = false) const;
     size_type seq_trace_move (
                 const point_basic<T>&     x,
@@ -148,15 +148,15 @@ public:
                 const point_basic<T>&     v,
                       point_basic<T>&     y) const;
     void trace_move (
-                const array<point_basic<T>,M>&     x,
-                const array<point_basic<T>,M>&     v,
-                      array<size_type, M>&         dis_ie,
-                      array<point_basic<T>,M>&     y) const;
+                const disarray<point_basic<T>,M>&     x,
+                const disarray<point_basic<T>,M>&     v,
+                      disarray<size_type, M>&         dis_ie,
+                      disarray<point_basic<T>,M>&     y) const;
     void trace_ray_boundary (
-                const array<point_basic<T>,M>&     x,
-                const array<point_basic<T>,M>&     v,
-                      array<size_type, M>&         dis_ie,
-                      array<point_basic<T>,M>&     y,
+                const disarray<point_basic<T>,M>&     x,
+                const disarray<point_basic<T>,M>&     v,
+                      disarray<size_type, M>&         dis_ie,
+                      disarray<point_basic<T>,M>&     y,
                 bool do_check = false) const;
     size_type seq_nearest (
                 const point_basic<T>&    x,
@@ -165,9 +165,9 @@ public:
                 const point_basic<T>&    x,
                       point_basic<T>&    x_nearest) const;
     void nearest (
-                const array<point_basic<T>,M>&     x,
-                      array<point_basic<T>,M>&     x_nearest,
-                      array<size_type, M>&         dis_ie) const;
+                const disarray<point_basic<T>,M>&     x,
+                      disarray<point_basic<T>,M>&     x_nearest,
+                      disarray<size_type, M>&         dis_ie) const;
 protected:
 // data:
     domain_indirect_basic<M>   _indirect;
@@ -241,8 +241,8 @@ public:
     size_type         dis_ige2ios_dis_ige (size_type dim, size_type dis_ige) const;
     size_type             ios_ige2dis_ige (size_type dim, size_type ios_ige) const;
     void set_ios_permutation (
-        boost::array<size_type,reference_element::max_variant>& loc_ndof_by_variant,
-        array<size_type,distributed>&                           idof2ios_dis_idof) const;
+        std::array<size_type,reference_element::max_variant>& loc_ndof_by_variant,
+        disarray<size_type,distributed>&                           idof2ios_dis_idof) const;
 };
 #endif // _RHEOLEF_HAVE_MPI
 // ========================================================================
