@@ -70,8 +70,8 @@ geo_domain_indirect_rep<T,distributed>::ios_ige2dis_ige (size_type dim, size_typ
 template<class T>
 void
 geo_domain_indirect_rep<T,distributed>::set_ios_permutation (
-        boost::array<size_type,reference_element::max_variant>& loc_ndof_by_variant,
-        array<size_type,distributed>&                           idof2ios_dis_idof) const
+        std::array<size_type,reference_element::max_variant>& loc_ndof_by_variant,
+        disarray<size_type,distributed>&                      idof2ios_dis_idof) const
 {
   fatal_macro ("set_ios_permutation: not yet");
 }
