@@ -35,9 +35,9 @@ geo_rep<T,distributed>::domain_set_side_part1 (
     const domain_indirect_rep<distributed>&    indirect, 
     const geo_abstract_rep<T,distributed>&     bgd_omega,
     size_type                                  sid_dim,
-    array<size_type>&                          bgd_isid2dom_dis_isid,
-    array<size_type>&                          dom_isid2bgd_isid,
-    array<size_type>&                          dom_isid2dom_ios_dis_isid,
+    disarray<size_type>&                       bgd_isid2dom_dis_isid,
+    disarray<size_type>&                       dom_isid2bgd_isid,
+    disarray<size_type>&                       dom_isid2dom_ios_dis_isid,
     size_type                                  size_by_variant [reference_element::max_variant])
 {
   if (sid_dim != 0 && base::_map_dimension <= sid_dim) return;
@@ -46,8 +46,8 @@ geo_rep<T,distributed>::domain_set_side_part1 (
   // 1) side compact re-numbering
   // ------------------------------------------------------------------------
   // 1.1 loop on elements and mark used sides
-  array<size_type> bgd_isid_is_on_domain     (bgd_omega.geo_element_ownership(sid_dim), 0); // logical, init to "false"
-  array<size_type> bgd_ios_isid_is_on_domain (bgd_omega.geo_element_ios_ownership(sid_dim), 0);
+  disarray<size_type> bgd_isid_is_on_domain     (bgd_omega.geo_element_ownership(sid_dim), 0); // logical, init to "false"
+  disarray<size_type> bgd_ios_isid_is_on_domain (bgd_omega.geo_element_ios_ownership(sid_dim), 0);
   for (size_type ioige = 0, noige = indirect.size(); ioige < noige; ioige++) {
     size_type ige = indirect.oige (ioige).index();
     const geo_element& bgd_K = bgd_omega.get_geo_element (base::_map_dimension, ige);
@@ -102,8 +102,8 @@ geo_rep<T,distributed>::domain_set_side_part1 (
   // 1.5 numbering dom_ios_isid & permutation: bgd_ios_isid <--> dom_ios_isid
   distributor dom_ios_isid_ownership (distributor::decide, comm, dom_ios_nsid);
   size_type first_dom_ios_dis_isid = dom_ios_isid_ownership.first_index();
-  array<size_type> bgd_ios_isid2dom_ios_dis_isid (bgd_omega.geo_element_ios_ownership(sid_dim), std::numeric_limits<size_type>::max());
-  array<size_type> dom_ios_isid2bgd_ios_isid (dom_ios_isid_ownership, std::numeric_limits<size_type>::max());
+  disarray<size_type> bgd_ios_isid2dom_ios_dis_isid (bgd_omega.geo_element_ios_ownership(sid_dim), std::numeric_limits<size_type>::max());
+  disarray<size_type> dom_ios_isid2bgd_ios_isid (dom_ios_isid_ownership, std::numeric_limits<size_type>::max());
   for (size_type dom_ios_isid = 0, bgd_ios_isid = 0, bgd_ios_nsid = bgd_omega.geo_element_ios_ownership(sid_dim).size(); bgd_ios_isid < bgd_ios_nsid; bgd_ios_isid++) {
     if (bgd_ios_isid_is_on_domain[bgd_ios_isid] == 0) continue;
     size_type dom_ios_dis_isid = first_dom_ios_dis_isid + dom_ios_isid;
@@ -112,7 +112,7 @@ geo_rep<T,distributed>::domain_set_side_part1 (
     dom_ios_isid++;
   }
   // 1.6 permutation: bgd_isid --> dom_ios_isid
-  array<size_type> bgd_isid2dom_ios_dis_isid (bgd_omega.geo_element_ownership(sid_dim), std::numeric_limits<size_type>::max());
+  disarray<size_type> bgd_isid2dom_ios_dis_isid (bgd_omega.geo_element_ownership(sid_dim), std::numeric_limits<size_type>::max());
   for (size_type dom_ios_isid = 0; dom_ios_isid < dom_ios_nsid; dom_ios_isid++) {
     size_type bgd_ios_isid = dom_ios_isid2bgd_ios_isid [dom_ios_isid];
     size_type dom_ios_dis_isid = dom_ios_isid + first_dom_ios_dis_isid;
@@ -156,11 +156,11 @@ void
 geo_rep<T,distributed>::domain_set_side_part2 (
     const domain_indirect_rep<distributed>&    indirect, 
     const geo_abstract_rep<T,distributed>&     bgd_omega,
-    array<size_type>&                          bgd_iv2dom_dis_iv,
+    disarray<size_type>&                       bgd_iv2dom_dis_iv,
     size_type                                  sid_dim,
-    array<size_type>&                          bgd_isid2dom_dis_isid,
-    array<size_type>&                          dom_isid2bgd_isid,
-    array<size_type>&                          dom_isid2dom_ios_dis_isid,
+    disarray<size_type>&                       bgd_isid2dom_dis_isid,
+    disarray<size_type>&                       dom_isid2bgd_isid,
+    disarray<size_type>&                       dom_isid2dom_ios_dis_isid,
     size_type                                  size_by_variant [reference_element::max_variant])
 {
   if (sid_dim != 0 && base::_map_dimension <= sid_dim) return;
@@ -257,7 +257,7 @@ geo_rep<T,distributed>::domain_set_side_part2 (
 
     3) numbering dom_iv 
      & permutation: bgd_iv --> dom_iv
-    array bgd_iv2dom_iv [bgd_iv_ownership]
+    disarray bgd_iv2dom_iv [bgd_iv_ownership]
     dom_iv = 0
     for bdg_iv = ...
       if bgd_iv_is_on_domain [bgd_iv] then
@@ -273,7 +273,7 @@ geo_rep<T,distributed>::domain_set_side_part2 (
 
     5) numbering dom_ios_iv 
      & permutation: bgd_ios_iv --> dom_ios_iv
-    array bgd_ios_iv2dom_ios_iv [bgd_ios_iv_ownership]
+    disarray bgd_ios_iv2dom_ios_iv [bgd_ios_iv_ownership]
     dom_ios_iv = 0
     for bdg_ios_iv = ...
       if bgd_ios_iv_is_on_domain [bgd_ios_iv] then
@@ -281,7 +281,7 @@ geo_rep<T,distributed>::domain_set_side_part2 (
         dom_ios_iv++
 
     6) permutation: bgd_iv --> dom_ios_iv
-    array bgd_iv2dom_ios_dis_iv   [bgd_iv_ownership]
+    disarray bgd_iv2dom_ios_dis_iv   [bgd_iv_ownership]
     for bdg_ios_iv = ...
       if bgd_ios_iv_is_on_domain [bgd_ios_iv] then
         dom_ios_iv = bgd_ios_iv2dom_ios_iv [bgd_ios_iv]
@@ -290,8 +290,8 @@ geo_rep<T,distributed>::domain_set_side_part2 (
     bgd_iv2dom_ios_dis_iv.assembly
 
     7) permutations: dom_ios_iv <--> dom_iv
-    array dom_ios_iv2dom_dis_iv   [dom_iv_ownership]
-    array dom_iv2dom_ios_dis_iv   [dom_ios_iv_ownership]
+    disarray dom_ios_iv2dom_dis_iv   [dom_iv_ownership]
+    disarray dom_iv2dom_ios_dis_iv   [dom_ios_iv_ownership]
     for bdg_iv = ...
       if bgd_iv_is_on_domain [bgd_iv] then
         dom_iv = bgd_iv2dom_iv [bgd_iv]
@@ -324,9 +324,9 @@ geo_rep<T,distributed>::build_from_domain (
   // ------------------------------------------------------------------------
   // 1) _geo_element[0]: compact renumbering
   // ------------------------------------------------------------------------
-  boost::array<array<size_type,distributed>,4>  bgd_ige2dom_dis_ige;
-  boost::array<array<size_type,distributed>,4>  dom_ige2bgd_ige;
-  array<size_type> dom_isid2dom_ios_dis_isid [4];
+  std::array<disarray<size_type,distributed>,4>  bgd_ige2dom_dis_ige;
+  std::array<disarray<size_type,distributed>,4>  dom_ige2bgd_ige;
+  disarray<size_type> dom_isid2dom_ios_dis_isid [4];
   domain_set_side_part1 (indirect, bgd_omega, 0,
 	bgd_ige2dom_dis_ige[0], dom_ige2bgd_ige[0],
         dom_isid2dom_ios_dis_isid [0], size_by_variant);
@@ -387,7 +387,7 @@ geo_rep<T,distributed>::build_from_domain (
   // 5) count nodes & set   base::_gs.node_ownership
   //  => then dis_iv2dis_inod works (used at step 6)
   // ------------------------------------------------------------------------
-  boost::array<size_type,reference_element::max_variant> loc_nnod_by_variant ;
+  std::array<size_type,reference_element::max_variant> loc_nnod_by_variant ;
   reference_element::init_local_nnode_by_variant (base::order(), loc_nnod_by_variant);
   size_type nnod = 0;
   for (size_type variant = 0;
@@ -450,14 +450,14 @@ geo_rep<T,distributed>::build_from_domain (
      Notice that this "ini" domain_indirect numbering becomes the "ios" for the geo_domain.
      Also, the new numbering is denoted by "dom" for geo_domain.
      Thus, there are at least two solutions for geo_domain :
-     1) on non-mixed domains, the variant array is not necessary, and assembly communications also
+     1) on non-mixed domains, the variant disarray is not necessary, and assembly communications also
         can be avoided. Just identify the used variant related to map_dimension and store its
         number from dom_ige_domain.size in _ios_ownership_by_variant[].
      2) on mixed domains & for sid_dim=2,3 :
         via the new "dom_ige" numbering, access physically to elements and store variants in:
-		array<size_t> dom_variant (dom_ige_ownership)
+		disarray<size_t> dom_variant (dom_ige_ownership)
 	then, permut it using ios_ige2dom_dis_ige and get
-		array<size_t> ios_variant (ios_ige_ownership)
+		disarray<size_t> ios_variant (ios_ige_ownership)
 	finaly, count variants and store it in
   		_ios_ownership_by_variant[]
    */
@@ -617,7 +617,7 @@ geo_rep<T,distributed>::build_from_domain (
 
   // 11.b) copy _node[] from bgd_omega.node[]
   base::_node.resize (dom_node_ownership);
-  array<size_type> dom_inod2bgd_inod (dom_node_ownership, std::numeric_limits<size_type>::max());
+  disarray<size_type> dom_inod2bgd_inod (dom_node_ownership, std::numeric_limits<size_type>::max());
   size_type dom_inod = 0;
   size_type first_bgd_inod_v = 0;
   for (size_type dim = 0; dim <= base::_map_dimension; dim++) {
