@@ -32,9 +32,9 @@ geo_rep<T,sequential>::domain_set_side_part1 (
     const domain_indirect_rep<sequential>&    indirect, 
     const geo_abstract_rep<T,sequential>&     bgd_omega,
     size_type                                 sid_dim,
-    array<size_type,sequential>&              bgd_isid2dom_dis_isid,
-    array<size_type,sequential>&              dom_isid2bgd_isid,
-    array<size_type,sequential>&              dom_isid2dom_ios_dis_isid,
+    disarray<size_type,sequential>&           bgd_isid2dom_dis_isid,
+    disarray<size_type,sequential>&           dom_isid2bgd_isid,
+    disarray<size_type,sequential>&           dom_isid2dom_ios_dis_isid,
     size_type                                 size_by_variant [reference_element::max_variant])
 {
   if (sid_dim != 0 && base::_map_dimension <= sid_dim) return;
@@ -43,7 +43,7 @@ geo_rep<T,sequential>::domain_set_side_part1 (
   // 1) side compact re-numbering
   // ------------------------------------------------------------------------
   // 1.1 loop on elements and mark used sides
-  array<size_type,sequential> bgd_isid_is_on_domain     (bgd_omega.geo_element_ownership(sid_dim), 0); // logical, init to "false"
+  disarray<size_type,sequential> bgd_isid_is_on_domain     (bgd_omega.geo_element_ownership(sid_dim), 0); // logical, init to "false"
   for (size_type ioige = 0, noige = indirect.size(); ioige < noige; ioige++) {
     size_type ige = indirect.oige (ioige).index();
     const geo_element& bgd_K = bgd_omega.get_geo_element (base::_map_dimension, ige);
@@ -106,11 +106,11 @@ void
 geo_rep<T,sequential>::domain_set_side_part2 (
     const domain_indirect_rep<sequential>&    indirect, 
     const geo_abstract_rep<T,sequential>&     bgd_omega,
-    array<size_type,sequential>&              bgd_iv2dom_dis_iv,
+    disarray<size_type,sequential>&              bgd_iv2dom_dis_iv,
     size_type                                 sid_dim,
-    array<size_type,sequential>&              bgd_isid2dom_dis_isid,
-    array<size_type,sequential>&              dom_isid2bgd_isid,
-    array<size_type,sequential>&              dom_isid2dom_ios_dis_isid,
+    disarray<size_type,sequential>&           bgd_isid2dom_dis_isid,
+    disarray<size_type,sequential>&           dom_isid2bgd_isid,
+    disarray<size_type,sequential>&           dom_isid2dom_ios_dis_isid,
     size_type                                 size_by_variant [reference_element::max_variant])
 {
   if (sid_dim != 0 && base::_map_dimension <= sid_dim) return;
@@ -171,9 +171,9 @@ geo_rep<T,sequential>::build_from_domain (
   // ----------------------------------------------------
   // 1) _geo_element[0]: compact re-numbering
   // ----------------------------------------------------
-  array<size_type,sequential> dom_isid2dom_ios_dis_isid [4];
-  boost::array<array<size_type,sequential>,4>  bgd_ige2dom_dis_ige;
-  boost::array<array<size_type,sequential>,4>  dom_ige2bgd_ige;
+  disarray<size_type,sequential> dom_isid2dom_ios_dis_isid [4];
+  std::array<disarray<size_type,sequential>,4>  bgd_ige2dom_dis_ige;
+  std::array<disarray<size_type,sequential>,4>  dom_ige2bgd_ige;
   domain_set_side_part1 (indirect, bgd_omega, 0,
         bgd_ige2dom_dis_ige[0], dom_ige2bgd_ige[0],
         dom_isid2dom_ios_dis_isid [0], size_by_variant);
@@ -221,7 +221,7 @@ geo_rep<T,sequential>::build_from_domain (
   // 5) count nodes & set   base::_gs.node_ownership
   //  => then dis_iv2dis_inod works (used at step 6)
   // ------------------------------------------------------------------------
-  boost::array<size_type,reference_element::max_variant> loc_nnod_by_variant ;
+  std::array<size_type,reference_element::max_variant> loc_nnod_by_variant ;
   reference_element::init_local_nnode_by_variant (base::order(), loc_nnod_by_variant);
   size_type nnod = 0;
   for (size_type variant = 0;
@@ -276,7 +276,7 @@ geo_rep<T,sequential>::build_from_domain (
   //    node(inod) { return bgd_omega.node(inod2bgd_inod(inod))}
   // ------------------------------------------------------------------------
   base::_node.resize (dom_node_ownership);
-  array<size_type,sequential> dom_inod2bgd_inod (dom_node_ownership, std::numeric_limits<size_type>::max());
+  disarray<size_type,sequential> dom_inod2bgd_inod (dom_node_ownership, std::numeric_limits<size_type>::max());
   size_type dom_inod = 0;
   size_type first_bgd_inod_v = 0;
   for (size_type dim = 0; dim <= base::_map_dimension; dim++) {
