@@ -159,7 +159,7 @@ public:
     node[0] = a0;
     node[1] = b0;
     node[2] = c0;
-    is_bdry_edg.assign (false);
+    is_bdry_edg.fill (false);
     is_bdry_edg [loc_curved_iedg] = true;
   }
 // accessor:
@@ -203,10 +203,10 @@ protected:
     }
   }
 // data:
-  boost::array<point_basic<T>,3> node;
+  std::array<point_basic<T>,3> node;
   point_basic<T> center;
   T radius;
-  boost::array<bool,3> is_bdry_edg;
+  std::array<bool,3> is_bdry_edg;
 };
 #ifdef TO_CLEAN
 // ====================================================================================
@@ -297,9 +297,9 @@ public:
     node[1] = b0;
     node[2] = c0;
     node[3] = d0;
-    is_bdry_fac.assign(false);
-    is_bdry_edg.assign(false);
-    is_curved_fac.assign(false);
+    is_bdry_fac.fill(false);
+    is_bdry_edg.fill(false);
+    is_curved_fac.fill(false);
   }
 // modifiers:
   void set_boundary_face (size_t loc_ifac_curved)
@@ -346,18 +346,18 @@ public:
 	}
     */
     // 1) compute the baycentric coordinates: lambda_i(xj) = delta_ij
-    boost::array<T,4> l;
+    std::array<T,4> l;
     l[0] = 1 - hat_x[0] - hat_x[1] - hat_x[2];
     l[1] = hat_x[0];
     l[2] = hat_x[1];
     l[3] = hat_x[2];
 
     // 2) compute the contribution of all faces
-    boost::array<size_t,3> S;       // table of local vertices indexes
-    boost::array<bool,4>   is_on_S; // when vertex is on S
+    std::array<size_t,3> S;       // table of local vertices indexes
+    std::array<bool,4>   is_on_S; // when vertex is on S
     point_basic<T> x_all_faces (0,0,0);
     for (size_t loc_ifac = 0; loc_ifac < 4; loc_ifac++) {
-      is_on_S.assign (false);
+      is_on_S.fill (false);
       for (size_t loc_ifac_jv = 0; loc_ifac_jv < 3; loc_ifac_jv++) {
         S[loc_ifac_jv] = reference_element_T::subgeo_local_node (1, 2, loc_ifac, loc_ifac_jv);
         is_on_S [S[loc_ifac_jv]] = true;
@@ -452,12 +452,12 @@ protected:
   point_basic<T> f_bd  (const point_basic<T>& x) const { return x; }
   point_basic<T> f_cd  (const point_basic<T>& x) const { return x; }
 // data:
-  boost::array<point_basic<T>,4> node;
+  std::array<point_basic<T>,4> node;
   point_basic<T> center;
   T radius;
-  boost::array<bool,6> is_bdry_edg;
-  boost::array<bool,4> is_bdry_fac;
-  boost::array<bool,4> is_curved_fac;
+  std::array<bool,6> is_bdry_edg;
+  std::array<bool,4> is_bdry_fac;
+  std::array<bool,4> is_curved_fac;
 };
 // ====================================================================================
 // TODO: hexahedron with a curved face
