@@ -30,9 +30,10 @@
 namespace rheolef {
 
 extern
-array<size_t>
+disarray<size_t>
 geo_mpi_partition (
-  hack_array<geo_element_hack> ios_geo_element [reference_element::max_variant],
+  const std::array<hack_array<geo_element_hack>,reference_element::max_variant>&
+				  ios_geo_element,
   const distributor&              ownership_by_dimension,
   size_t                          map_dim,
   size_t                          dis_nv);
@@ -58,7 +59,8 @@ void end_redirect (std::ostream& strm, std::string="") {
 static
 distributor
 build_true_ios_ge_ownership_by_dimension (
-    const hack_array<geo_element_hack>      ios_geo_element [reference_element::max_variant],
+    const std::array<hack_array<geo_element_hack>,reference_element::max_variant>&
+    					       ios_geo_element,
 	  size_t			       side_dim)
 {
   using namespace std;
@@ -81,7 +83,8 @@ static
 void
 build_apparent_ios_ownership(
 // input:
-  hack_array<geo_element_hack> ios_geo_element [reference_element::max_variant],
+  const std::array<hack_array<geo_element_hack>,reference_element::max_variant>&
+				  ios_geo_element,
   size_t                          side_dim,
 // output:
   distributor&                    ios_ownership,
@@ -130,12 +133,13 @@ build_apparent_ios_ownership(
 void
 geo_element_renumbering_part1_new (
 // input:
-  hack_array<geo_element_hack> ios_geo_element [reference_element::max_variant],
+  const std::array<hack_array<geo_element_hack>,reference_element::max_variant>&
+ 			       ios_geo_element,
   const geo_size&              ios_gs, // TODO: not used...
   size_t                       S_dim,
 // output:
-  boost::array<std::vector<size_t>, 4>&                        massive_partition_by_dimension,
-  boost::array<array<size_t>, reference_element::max_variant>& partition_by_variant)
+  std::array<std::vector<size_t>, 4>&                           massive_partition_by_dimension,
+  std::array<disarray<size_t>, reference_element::max_variant>& partition_by_variant)
 {
   typedef size_t size_type;
   distributor ios_vertex_ownership = ios_geo_element [reference_element::p].ownership();
@@ -145,7 +149,7 @@ geo_element_renumbering_part1_new (
   // 1) K_ball(X) := { K; X is a vertex of K }
   // ------------------------------------------------------------------------
   index_set empty_set; // TODO: add a global allocator to empty_set
-  array<index_set,distributed> K_ball (ios_vertex_ownership, empty_set);
+  disarray<index_set,distributed> K_ball (ios_vertex_ownership, empty_set);
   size_type K_dim = S_dim + 1;
   size_type K_ios_ige = 0;
   distributor true_K_ios_ge_ownership = build_true_ios_ge_ownership_by_dimension (ios_geo_element, K_dim);
@@ -179,7 +183,7 @@ geo_element_renumbering_part1_new (
                  S_variant < reference_element:: last_variant_by_dimension(S_dim); S_variant++) {
     distributor ios_gev_ownership  = ios_geo_element [S_variant].ownership();
     for (size_type ios_igev = 0, ios_ngev = ios_gev_ownership.size(); ios_igev < ios_ngev; ios_igev++) {
-      geo_element& S = ios_geo_element [S_variant] [ios_igev];
+      const geo_element& S = ios_geo_element [S_variant] [ios_igev];
       for (size_type iloc = 0, nloc = S.size(); iloc < nloc; iloc++) {
         size_type ios_dis_iv = S[iloc];
         if (! ios_vertex_ownership.is_owned (ios_dis_iv)) {
@@ -202,7 +206,7 @@ geo_element_renumbering_part1_new (
     distributor ios_gev_ownership  = ios_geo_element [S_variant].ownership();
     size_type   first_ios_dis_igev = ios_gev_ownership.first_index();
     for (size_type ios_igev = 0, ios_ngev = ios_gev_ownership.size(); ios_igev < ios_ngev; ios_igev++, S_ios_ige++) {
-      geo_element& S = ios_geo_element [S_variant] [ios_igev];
+      const geo_element& S = ios_geo_element [S_variant] [ios_igev];
       index_set K_ios_ige_set = K_ball.dis_at (S[0]);
       for (size_type iloc = 0, nloc = S.size(); iloc < nloc; iloc++) {
         K_ios_ige_set.inplace_intersection (K_ball.dis_at(S[iloc]));
@@ -229,7 +233,7 @@ geo_element_renumbering_part1_new (
 	massive_partition_by_dimension[S_dim].begin().operator->(),
 	mpi::maximum<size_type>());
   // ------------------------------------------------------------------------
-  // 5) copy the massive_partition_by_dimension into a distributed array "partition", variant by variant
+  // 5) copy the massive_partition_by_dimension into a distributed disarray "partition", variant by variant
   // ------------------------------------------------------------------------
   size_type S_ios_dis_ige = first_S_ios_dis_ige;
   for (size_type S_variant = reference_element::first_variant_by_dimension(S_dim);
@@ -247,18 +251,23 @@ geo_element_renumbering_part1_new (
 void
 geo_element_renumbering_part2 (
  // input:
-    const hack_array<geo_element_hack>         ios_geo_element [reference_element::max_variant],
+    const std::array<hack_array<geo_element_hack>,reference_element::max_variant>&
+                                               ios_geo_element,
     const geo_size&			       ios_gs,
 	  size_t			       dis_nv,
 	  size_t			       side_dim,
  // output:
-          hack_array<geo_element_hack>         geo_element [reference_element::max_variant],
+          std::array<hack_array<geo_element_hack>,reference_element::max_variant>&
+       					       geo_element,
           geo_size&			       gs,
-          array<size_t>                        igev2ios_dis_igev [reference_element::max_variant],
-          array<size_t>                        ios_igev2dis_igev [reference_element::max_variant],
-          array<size_t>                        ios_ige2dis_ige   [4],
+          std::array<disarray<size_t>,reference_element::max_variant>&
+                                               igev2ios_dis_igev,
+          std::array<disarray<size_t>,reference_element::max_variant>&
+                                               ios_igev2dis_igev,
+          std::array<disarray<size_t>,4>&      ios_ige2dis_ige,
  // tmp:
-     boost::array<array<size_t>, reference_element::max_variant>& partition_by_variant)
+          std::array<disarray<size_t>, reference_element::max_variant>& 
+                                               partition_by_variant)
 {
   typedef geo_element::size_type size_type;
   typedef hack_array<geo_element_hack>::iterator             iterator_by_variant;
@@ -426,7 +435,7 @@ geo_rep<T,distributed>::set_element_side_index (size_type side_dim)
   // 1) ball(X) := { E; X is a vertex of E }
   // ------------------------------------------------------------------------
   index_set empty_set; // TODO: add a global allocator to empty_set
-  array<index_set,distributed> ball [reference_element::max_variant];
+  disarray<index_set,distributed> ball [reference_element::max_variant];
   for (size_type variant = reference_element::first_variant_by_dimension(side_dim);
                  variant < reference_element:: last_variant_by_dimension(side_dim); variant++) {
     ball [variant].resize (vertex_ownership, empty_set);
@@ -485,7 +494,7 @@ geo_rep<T,distributed>::set_element_side_index (size_type side_dim)
       }
     }
     // 2.2) scan ball(dis_iv) for external sides
-    typedef array<index_set>::scatter_map_type map_type;
+    typedef disarray<index_set>::scatter_map_type map_type;
     const map_type& ball_dis  = ball [variant].get_dis_map_entries();
     for (typename map_type::const_iterator iter_b = ball_dis.begin(), last_b = ball_dis.end(); iter_b != last_b; iter_b++) {
       size_type             dis_iv = (*iter_b).first;
@@ -522,7 +531,7 @@ geo_rep<T,distributed>::set_element_side_index (size_type side_dim)
           size_type loc_jv0 = K.subgeo_local_vertex (side_dim, loc_isid, 0);
           S_inod [0] = K[loc_jv0];
           S_iv   [0] = base::dis_inod2dis_iv (S_inod[0]);
-          const array<index_set,distributed>& ball_S_variant = ball [S_variant];
+          const disarray<index_set,distributed>& ball_S_variant = ball [S_variant];
           index_set igev_set = ball_S_variant.dis_at (S_iv[0]);
   	  for (size_type sid_jloc = 1, sid_nloc = S_size; sid_jloc < sid_nloc; sid_jloc++) { 
             size_type loc_jv = K.subgeo_local_vertex (side_dim, loc_isid, sid_jloc);
@@ -565,8 +574,8 @@ geo_rep<T,distributed>::set_element_side_index (size_type side_dim)
 template <class T>
 void
 geo_rep<T,distributed>::set_ios_permutation (
-    boost::array<size_type,reference_element::max_variant>& local_ndof_by_variant,
-    array<size_type,distributed>&                           idof2ios_dis_idof) const
+    std::array<size_type,reference_element::max_variant>& local_ndof_by_variant,
+    disarray<size_type,distributed>&                      idof2ios_dis_idof) const
 {
   // 1) count & resize
   size_type ndof = 0;
@@ -599,7 +608,7 @@ template <class T>
 void
 geo_rep<T,distributed>::node_renumbering (const distributor& ios_node_ownership)
 {
-  boost::array<size_type,reference_element::max_variant> loc_ndof_by_variant;
+  std::array<size_type,reference_element::max_variant> loc_ndof_by_variant;
   reference_element::init_local_nnode_by_variant (base::order(), loc_ndof_by_variant);
   set_ios_permutation (loc_ndof_by_variant, _inod2ios_dis_inod);
 }
@@ -646,13 +655,13 @@ geo_rep<T,distributed>::get (idiststream& ips)
   //
   size_type ios_size_by_variant [reference_element::max_variant];
   std::fill (ios_size_by_variant, ios_size_by_variant+reference_element::max_variant, 0);
-  array<node_type> ios_node (dis_nnod);
+  disarray<node_type> ios_node (dis_nnod);
   ios_node.get_values (ips, _point_get<T>(base::_dimension));
   check_macro (ips.good(), "bad input stream for geo.");
   //
   // 1.3) get elements
   //
-  hack_array<geo_element_hack> ios_geo_element [reference_element::max_variant];
+  std::array<hack_array<geo_element_hack>, reference_element::max_variant> ios_geo_element;
   size_type ios_nv = 0;
   if (base::_map_dimension == 0) {
     ios_nv = ios_node.size();
@@ -778,20 +787,20 @@ geo_rep<T,distributed>::get (idiststream& ips)
   true_ios_ownership_by_dimension [base::_map_dimension] 
    = build_true_ios_ge_ownership_by_dimension (ios_geo_element, base::_map_dimension);
 
-  array<size_type> partition = geo_mpi_partition (
+  disarray<size_type> partition = geo_mpi_partition (
     ios_geo_element,
     true_ios_ownership_by_dimension [base::_map_dimension],
     base::_map_dimension,
     dis_nv);
 
   // copy partition into partition_by_variant[]:
-  boost::array<array<size_t>, reference_element::max_variant> partition_by_variant;
+  std::array<disarray<size_t>, reference_element::max_variant> partition_by_variant;
   {
-    typename array<size_type>::const_iterator iter = partition.begin();
+    typename disarray<size_type>::const_iterator iter = partition.begin();
     for (size_type variant = reference_element::first_variant_by_dimension(base::_map_dimension);
                    variant < reference_element:: last_variant_by_dimension(base::_map_dimension); variant++) {
       partition_by_variant [variant].resize (ios_geo_element [variant].ownership());
-      for (typename array<size_type>::iterator iter_by_var = partition_by_variant [variant].begin(),
+      for (typename disarray<size_type>::iterator iter_by_var = partition_by_variant [variant].begin(),
 	                                       last_by_var = partition_by_variant [variant].end(); 
 				               iter_by_var != last_by_var; iter_by_var++, iter++) {
 	 *iter_by_var = *iter;
@@ -812,7 +821,7 @@ geo_rep<T,distributed>::get (idiststream& ips)
 
 
   // copy partition into massive_partition_by_dimension[map_dim]:
-  boost::array<std::vector<size_t>, 4>  massive_partition_by_dimension;
+  std::array<std::vector<size_t>, 4>  massive_partition_by_dimension;
   {
     std::vector<size_t>  tmp_massive_partition (dis_ne, 0);
     size_type true_first_dis_ige = true_ios_ownership_by_dimension [base::_map_dimension].first_index();
@@ -849,7 +858,7 @@ geo_rep<T,distributed>::get (idiststream& ips)
     size_type ios_dis_iv = first_ios_dis_iv + ios_iv;
     partition_by_variant [reference_element::p] [ios_iv] = massive_partition_by_dimension[0] [ios_dis_iv];
   }
-  array<size_type> iv2ios_dis_iv;
+  disarray<size_type> iv2ios_dis_iv;
   ios_geo_element [reference_element::p].repartition (
         partition_by_variant [reference_element::p],
         base::_geo_element [reference_element::p],
@@ -861,7 +870,7 @@ geo_rep<T,distributed>::get (idiststream& ips)
   base::_gs.ownership_by_variant   [reference_element::p] = vertex_ownership;
   base::_gs.first_by_variant       [reference_element::p] = distributor (0, base::comm(), 0);
   //
-  // 3.2) set the element[0] array 
+  // 3.2) set the element[0] disarray 
   //
   size_type first_dis_iv = vertex_ownership.first_index();
   size_type  last_dis_iv = vertex_ownership.last_index();
@@ -908,7 +917,7 @@ geo_rep<T,distributed>::get (idiststream& ips)
   distributor node_ownership = _inod2ios_dis_inod.ownership();
   base::_gs.node_ownership = node_ownership;
   // ------------------------------------------------------------------------
-  // 7) redistribute the nodes : from ios_node[] to node() arrays
+  // 7) redistribute the nodes : from ios_node[] to node() disarrays
   // ------------------------------------------------------------------------
   _ios_inod2dis_inod.resize (ios_node.ownership(), std::numeric_limits<size_type>::max());
   _inod2ios_dis_inod.reverse_permutation (_ios_inod2dis_inod);
@@ -916,7 +925,7 @@ geo_rep<T,distributed>::get (idiststream& ips)
   // ------------------------------------------------------------------------
   // 8) propagate new node numbering
   // ------------------------------------------------------------------------
-  // 8.1) build new node array:  base::_node
+  // 8.1) build new node disarray:  base::_node
   base::_node.resize (node_ownership);
   ios_node.permutation_apply (_ios_inod2dis_inod, base::_node);
   // 
