@@ -83,7 +83,7 @@ geo_nearest<T,M>::dis_nearest (
 template <class T, class M>
 class geo_nearest_abstract_rep {
 public:
-  typedef typename array<T,M>::size_type size_type;
+  typedef typename disarray<T,M>::size_type size_type;
   virtual ~geo_nearest_abstract_rep() {}
   virtual void initialize (const geo_base_rep<T,M>& omega) const = 0;
   virtual size_type seq_nearest (
@@ -137,15 +137,15 @@ protected:
   typedef typename Kernel::Point_2               Point_2;
 
 // data:
-  mutable CGAL::Point_set_2<Kernel>              _point_set;
-  mutable rheolef::array<index_set,M>            _ball;
+  mutable CGAL::Point_set_2<Kernel>        _point_set;
+  mutable disarray<index_set,M>            _ball;
 };
 template<class T, class M>
 static
 void
 build_ball (
 	const geo_base_rep<T,M>&     omega,
-        rheolef::array<index_set,M>& ball)
+        disarray<index_set,M>&       ball)
 {
   typedef typename geo_basic<T,M>::size_type size_type;
   // 1) build ball(xi) := { K; xi is a vertex of K }
@@ -347,9 +347,9 @@ static
 void
 sequential_nearest (
   const geo_base_rep<T,M>&           omega,
-  const array<point_basic<T>,M>&     x,
-        array<point_basic<T>,M>&     x_nearest,
-        array<std::size_t, M>&       dis_ie)
+  const disarray<point_basic<T>,M>&  x,
+        disarray<point_basic<T>,M>&  x_nearest,
+        disarray<std::size_t, M>&    dis_ie)
 {
   typedef typename geo_base_rep<T,M>::size_type size_type;
   dis_ie.resize (x.ownership());
@@ -368,9 +368,9 @@ sequential_nearest (
 template <class T>
 void
 geo_rep<T,sequential>::nearest (
-  const array<point_basic<T>,sequential>&     x,
-        array<point_basic<T>,sequential>&     x_nearest,
-        array<size_type, sequential>&         dis_ie) const
+  const disarray<point_basic<T>,sequential>&     x,
+        disarray<point_basic<T>,sequential>&     x_nearest,
+        disarray<size_type, sequential>&         dis_ie) const
 {
   sequential_nearest (*this, x, x_nearest, dis_ie);
 }
@@ -378,9 +378,9 @@ geo_rep<T,sequential>::nearest (
 template <class T>
 void
 geo_rep<T,distributed>::nearest (
-  const array<point_basic<T>,distributed>&     x,
-        array<point_basic<T>,distributed>&     x_nearest,
-        array<size_type, distributed>&         dis_ie) const
+  const disarray<point_basic<T>,distributed>&     x,
+        disarray<point_basic<T>,distributed>&     x_nearest,
+        disarray<size_type, distributed>&         dis_ie) const
 {
   size_type nproc = base::comm().size();
   if (nproc == 1) {
@@ -445,9 +445,9 @@ geo_base_rep<T,M>::dis_nearest (
 template <class T>
 void
 geo_rep<T,sequential>::nearest (
-  const array<point_basic<T>, sequential>& x,
-        array<point_basic<T>, sequential>& x_nearest,
-        array<size_type, sequential>&      dis_ie) const
+  const disarray<point_basic<T>, sequential>& x,
+        disarray<point_basic<T>, sequential>& x_nearest,
+        disarray<size_type, sequential>&      dis_ie) const
 {
   fatal_macro ("geo: nearest not available (HINT: recompile Rheolef with the CGAL library)");
 }
@@ -455,9 +455,9 @@ geo_rep<T,sequential>::nearest (
 template <class T>
 void
 geo_rep<T,distributed>::nearest (
-  const array<point_basic<T>, distributed>& x,
-        array<point_basic<T>, distributed>& x_nearest,
-        array<size_type, distributed>&      dis_ie,
+  const disarray<point_basic<T>, distributed>& x,
+        disarray<point_basic<T>, distributed>& x_nearest,
+        disarray<size_type, distributed>&      dis_ie,
 	// dis_ie(ix) can contains a guest for x in K=omega[dis_ie(ix)]
   bool do_check) const
 {
