@@ -57,7 +57,7 @@ geo_rep<T,sequential>::set_element_side_index (size_type side_dim)
   // 1) ball(X) := { E; X is a vertex of E }
   // ------------------------------------------------------------------------
   index_set empty_set; // TODO: add a global allocator to empty_set
-  array<index_set,sequential> ball (geo_element_ownership(0), empty_set);
+  disarray<index_set,sequential> ball (geo_element_ownership(0), empty_set);
   {
     size_type isid = 0;
     for (const_iterator iter = begin(side_dim), last = end(side_dim); iter != last; iter++, isid++) {
