@@ -47,8 +47,8 @@ static
 void
 build_domains (
   size_t                                           dom_dim,
-  const array<geo_element_auto<A>, sequential, A>& elt,
-  const array<size_t, sequential, A>&              elt_bamg_dom_id,
+  const disarray<geo_element_auto<A>, sequential, A>& elt,
+  const disarray<size_t, sequential, A>&           elt_bamg_dom_id,
   const std::vector<std::string>&                  dom_name,
   const geo_basic<T,sequential>&                   omega,
   vector<index_set>*                               ball)
@@ -57,8 +57,8 @@ build_domains (
   typedef typename geo_basic<T,sequential>::size_type size_type;
   typedef pair<size_type,size_type>                   pair_t;
   typedef geo_element_auto<A>                         element_t;
-  typedef array<element_t, sequential, A>             e_array_t;
-  typedef array<size_type, sequential, A>             i_array_t;
+  typedef disarray<element_t, sequential, A>          e_array_t;
+  typedef disarray<size_type, sequential, A>          i_array_t;
   typedef map<size_type, pair_t, less<size_type>, A>  map_t;
 
   // -------------------------------------------------------------------
@@ -82,7 +82,7 @@ build_domains (
   }
   size_type ndom = bamg_id2idom.size();
   // -------------------------------------------------------------------
-  // 2) check that ndom matches the domain name array size
+  // 2) check that ndom matches the domain name disarray size
   // -------------------------------------------------------------------
   if (ndom != dom_name.size()) {
      warning_macro ("geo::get_bamg: "
@@ -92,7 +92,7 @@ build_domains (
      error_macro("HINT: check domain name file (.dmn)");
   }
   // -------------------------------------------------------------------
-  // 3) create domain array: loop on elements
+  // 3) create domain disarray: loop on elements
   // -------------------------------------------------------------------
   element_t dummy_elt (reference_element::p, 0, alloc);
   vector<e_array_t, A> domain  (ndom, e_array_t(0, dummy_elt, alloc), alloc);
@@ -131,15 +131,15 @@ template <class T, class A>
 static
 void
 build_vertex_domains (
-  const array<size_t, sequential, A>&              edg_bdr_bamg_dom_id,
-  const array<size_t, sequential, A>&              vert_bamg_dom_id,
+  const disarray<size_t, sequential, A>&              edg_bdr_bamg_dom_id,
+  const disarray<size_t, sequential, A>&              vert_bamg_dom_id,
   const std::vector<std::string>&                  dom_name,
   const geo_basic<T,sequential>&                   omega,
   vector<index_set>*                               ball)
 {
   if (dom_name.size() == 0) return;
   typedef geo_element_auto<A>                         element_t;
-  typedef array<element_t, sequential, A>             v_array_t;
+  typedef disarray<element_t, sequential, A>             v_array_t;
   A alloc = edg_bdr_bamg_dom_id.get_allocator(); 
   element_t dummy_elt (reference_element::p, 0, alloc);
   // -------------------------------------------------------------------
@@ -208,9 +208,9 @@ geo_get_bamg (idiststream& ips, geo_basic<T,sequential>& omega)
   // ------------------------------------------------------------------------
   typedef heap_allocator<size_type>             alloc_t;
   typedef geo_element_auto<alloc_t>             element_t;
-  typedef array<node_type, sequential>          n_array_t;
-  typedef array<element_t, sequential, alloc_t> e_array_t;
-  typedef array<size_type, sequential, alloc_t> i_array_t;
+  typedef disarray<node_type, sequential>          n_array_t;
+  typedef disarray<element_t, sequential, alloc_t> e_array_t;
+  typedef disarray<size_type, sequential, alloc_t> i_array_t;
 
   alloc_t alloc;
   n_array_t vertex;
@@ -219,7 +219,7 @@ geo_get_bamg (idiststream& ips, geo_basic<T,sequential>& omega)
   i_array_t tri_bamg_dom_id;
   i_array_t qua_bamg_dom_id;
   e_array_t edg_bdr;
-  boost::array<e_array_t, reference_element::max_variant>  tmp_geo_element;
+  std::array<e_array_t, reference_element::max_variant>  tmp_geo_element;
   string label;
   while (is.good() && label != "End") {
     is >> label;
