@@ -170,7 +170,7 @@ raw_put_prism (ostream& vtk,
 template <class T>
 static
 void
-put_prism (ostream& vtk, const geo_element& K, const numbering<T,sequential>& my_numb, const geo_basic<T,sequential>& omega, const array<point_basic<Float>,sequential>& my_node)
+put_prism (ostream& vtk, const geo_element& K, const numbering<T,sequential>& my_numb, const geo_basic<T,sequential>& omega, const disarray<point_basic<Float>,sequential>& my_node)
 {
   typedef typename geo_basic<T,sequential>::size_type size_type;
   typedef point_basic<size_type>                      ilat;
@@ -243,7 +243,7 @@ put_hexahedron (ostream& vtk, const geo_element& K, const numbering<T,sequential
 template <class T>
 static
 void
-put (ostream& vtk, const geo_element& K, const numbering<T,sequential>& my_numb, const geo_basic<T,sequential>& omega, const array<point_basic<Float>,sequential>& my_node)
+put (ostream& vtk, const geo_element& K, const numbering<T,sequential>& my_numb, const geo_basic<T,sequential>& omega, const disarray<point_basic<Float>,sequential>& my_node)
 {
   switch (K.variant()) {
    case reference_element::p: vtk << "1\t" << K[0] << endl; break;
@@ -287,7 +287,7 @@ put (ostream& vtk, const geo_element& K, const numbering<T,sequential>& my_numb,
 // TODO: P3 geo with P2 field: draw on the P3 lattice and re-interpolate the field !
 template <class T>
 odiststream&
-geo_put_vtk (odiststream& ops, const geo_basic<T,sequential>& omega, const numbering<T,sequential>& my_numb, const array<point_basic<T>,sequential>& my_node, bool append_data)
+geo_put_vtk (odiststream& ops, const geo_basic<T,sequential>& omega, const numbering<T,sequential>& my_numb, const disarray<point_basic<T>,sequential>& my_node, bool append_data)
 {
   //
   // 0) pre-requises
@@ -315,16 +315,16 @@ geo_put_vtk (odiststream& ops, const geo_basic<T,sequential>& omega, const numbe
   //
   size_type map_dim  = omega.map_dimension();
   // count pass, since omega.sizes is not yet valid when omega is a geo_domain_indirect...
-  boost::array<size_type,reference_element::max_variant> size_by_variant;
-  size_by_variant.assign (0);
+  std::array<size_type,reference_element::max_variant> size_by_variant;
+  size_by_variant.fill (0);
   for (size_type ie = 0, ne = omega.size(); ie < ne; ie++) {
     const geo_element& K = omega.get_geo_element (map_dim, ie);
     size_by_variant [K.variant()]++;
   }
   size_type ncell = 0;
   size_type ndata = 0;
-  boost::array<size_type,reference_element::max_variant> loc_ncell;
-  boost::array<size_type,reference_element::max_variant> loc_ndata;
+  std::array<size_type,reference_element::max_variant> loc_ncell;
+  std::array<size_type,reference_element::max_variant> loc_ndata;
   for (size_type variant = reference_element::first_variant_by_dimension(map_dim);
                  variant < reference_element:: last_variant_by_dimension(map_dim); variant++) {
     size_type d = reference_element::dimension(variant);
@@ -345,7 +345,7 @@ geo_put_vtk (odiststream& ops, const geo_basic<T,sequential>& omega, const numbe
   //
   // 4) put cell types
   //
-  boost::array<size_type,reference_element::max_variant> cell_type;
+  std::array<size_type,reference_element::max_variant> cell_type;
   cell_type [reference_element::p] = VTK_VERTEX;
   cell_type [reference_element::e] = VTK_LINE;
   cell_type [reference_element::t] = VTK_TRIANGLE;
@@ -375,14 +375,14 @@ geo_put_vtk (odiststream& ops, const geo_basic<T,sequential>& omega, const numbe
 }
 template <class T>
 odiststream&
-geo_put_vtk (odiststream& ops, const geo_basic<T,sequential>& omega, size_t my_order, const array<point_basic<T>,sequential>& my_node, bool append_data)
+geo_put_vtk (odiststream& ops, const geo_basic<T,sequential>& omega, size_t my_order, const disarray<point_basic<T>,sequential>& my_node, bool append_data)
 {
   numbering<T,sequential> my_numb ("P" + itos(my_order));
   return geo_put_vtk (ops, omega, my_numb, my_node, append_data);
 }
 template <class T>
 odiststream&
-geo_put_vtk (odiststream& ops, const geo_basic<T,sequential>& omega, size_t my_order, const array<point_basic<T>,sequential>& my_node)
+geo_put_vtk (odiststream& ops, const geo_basic<T,sequential>& omega, size_t my_order, const disarray<point_basic<T>,sequential>& my_node)
 {
   return geo_put_vtk (ops, omega, my_order, my_node, true);
 }
@@ -401,9 +401,9 @@ geo_put_vtk (odiststream& ops, const geo_basic<T,sequential>& omega)
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
-template odiststream& geo_put_vtk<Float> (odiststream&, const geo_basic<Float,sequential>&, const numbering<Float,sequential>&, const array<point_basic<Float>,sequential>&, bool);
-template odiststream& geo_put_vtk<Float> (odiststream&, const geo_basic<Float,sequential>&, size_t, const array<point_basic<Float>,sequential>&, bool);
-template odiststream& geo_put_vtk<Float> (odiststream&, const geo_basic<Float,sequential>&, size_t, const array<point_basic<Float>,sequential>&);
+template odiststream& geo_put_vtk<Float> (odiststream&, const geo_basic<Float,sequential>&, const numbering<Float,sequential>&, const disarray<point_basic<Float>,sequential>&, bool);
+template odiststream& geo_put_vtk<Float> (odiststream&, const geo_basic<Float,sequential>&, size_t, const disarray<point_basic<Float>,sequential>&, bool);
+template odiststream& geo_put_vtk<Float> (odiststream&, const geo_basic<Float,sequential>&, size_t, const disarray<point_basic<Float>,sequential>&);
 template odiststream& geo_put_vtk<Float> (odiststream&, const geo_basic<Float,sequential>&);
 
 }// namespace rheolef
