@@ -36,11 +36,11 @@ namespace rheolef {
 template <class T>
 void
 geo_rep<T,sequential>::build_connectivity(
-  boost::array<array<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element)
+  std::array<disarray<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element)
 {
   typedef geo_element_auto<heap_allocator<size_type> > element_t;
-  typedef array<element_t,sequential,heap_allocator<size_type> > array_t;
-  typedef typename array_t::const_iterator const_iterator_by_variant_tmp;
+  typedef disarray<element_t,sequential,heap_allocator<size_type> > disarray_t;
+  typedef typename disarray_t::const_iterator const_iterator_by_variant_tmp;
   size_type map_dim = geo_base_rep<T,sequential>::_map_dimension;
   if (map_dim <= 1) return;
   build_connectivity_sides (map_dim-1, tmp_geo_element); 
@@ -50,11 +50,11 @@ template <class T>
 void
 geo_rep<T,sequential>::build_connectivity_sides (
   size_type                             side_dim,
-  boost::array<array<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element)
+  std::array<disarray<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element)
 {
   typedef geo_element_auto<heap_allocator<size_type> > element_t;
-  typedef array<element_t,sequential,heap_allocator<size_type> > array_t;
-  typedef typename array_t::const_iterator const_iterator_by_variant_tmp;
+  typedef disarray<element_t,sequential,heap_allocator<size_type> > disarray_t;
+  typedef typename disarray_t::const_iterator const_iterator_by_variant_tmp;
   if (side_dim == 0) return;
   // ------------------------------------------------------------------------
   // 1) count sides
@@ -69,7 +69,7 @@ geo_rep<T,sequential>::build_connectivity_sides (
   size_type map_dim = geo_base_rep<T,sequential>::_map_dimension;
   size_type nsid = 0;
   {
-   array<index_set,sequential> ball_S (geo_element_ownership(0), empty_set);
+   disarray<index_set,sequential> ball_S (geo_element_ownership(0), empty_set);
    for (size_type variant = reference_element::first_variant_by_dimension(map_dim);
                  variant < reference_element:: last_variant_by_dimension(map_dim); variant++) {
     for (const_iterator_by_variant_tmp iter = tmp_geo_element [variant].begin(),
@@ -126,7 +126,7 @@ geo_rep<T,sequential>::build_connectivity_sides (
   {
    size_type count_by_variant [reference_element::max_variant];
    std::fill (count_by_variant, count_by_variant+reference_element::max_variant, 0);
-   array<index_set,sequential> ball_S (geo_element_ownership(0), empty_set);
+   disarray<index_set,sequential> ball_S (geo_element_ownership(0), empty_set);
    nsid = 0;
    for (size_type variant = reference_element::first_variant_by_dimension(map_dim);
                   variant < reference_element:: last_variant_by_dimension(map_dim); variant++) {
@@ -196,7 +196,7 @@ geo_rep<T,sequential>::get_upgrade (
   // 1) get nodes
   // ------------------------------------------------------------------------
   size_type nnod = hdr.dis_size_by_dimension [0];
-  array<node_type, sequential> node (nnod);
+  disarray<node_type, sequential> node (nnod);
   if (hdr.dimension > 0) {
     node.get_values (ips, _point_get<T>(hdr.dimension));
     check_macro (ips.good(), "bad input stream for geo.");
@@ -205,14 +205,14 @@ geo_rep<T,sequential>::get_upgrade (
   // 2) get elements
   // ------------------------------------------------------------------------
   typedef geo_element_auto<heap_allocator<size_type> > element_t;
-  typedef array<element_t, sequential, heap_allocator<size_type> > array_t;
+  typedef disarray<element_t, sequential, heap_allocator<size_type> > disarray_t;
   heap_allocator<size_type> alloc;
-  boost::array<array_t, reference_element::max_variant>  tmp_geo_element;
+  std::array<disarray_t, reference_element::max_variant>  tmp_geo_element;
   if (hdr.map_dimension > 0) {
     for (size_type variant = reference_element::first_variant_by_dimension(hdr.map_dimension);
                    variant < reference_element:: last_variant_by_dimension(hdr.map_dimension); variant++) {
       geo_element_auto<heap_allocator<size_type> > init_val (variant, hdr.order, alloc);
-      tmp_geo_element [variant] = array_t (hdr.dis_size_by_variant [variant], init_val, alloc);
+      tmp_geo_element [variant] = disarray_t (hdr.dis_size_by_variant [variant], init_val, alloc);
 #ifdef TO_CLEAN
       tmp_geo_element [variant].resize (hdr.dis_size_by_variant [variant], init_val);
 #endif // TO_CLEAN
@@ -239,16 +239,16 @@ template <class T>
 void
 geo_rep<T,sequential>::build_from_data (
   const geo_header&                   hdr,
-  const array<node_type, sequential>& node,
-        boost::array<array<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>&
+  const disarray<node_type, sequential>& node,
+        std::array<disarray<geo_element_auto<heap_allocator<size_type> >,sequential, heap_allocator<size_type> >, reference_element::max_variant>&
 				      tmp_geo_element,
   bool  			      do_upgrade)
 {
   using namespace std;
   typedef geo_element_auto<heap_allocator<size_type> > element_t;
-  typedef array<element_t, sequential, heap_allocator<size_type> > array_t;
-  typedef typename array_t::const_iterator const_iterator_by_variant_tmp;
-  typedef typename array_t::iterator       iterator_by_variant_tmp;
+  typedef disarray<element_t, sequential, heap_allocator<size_type> > disarray_t;
+  typedef typename disarray_t::const_iterator const_iterator_by_variant_tmp;
+  typedef typename disarray_t::iterator       iterator_by_variant_tmp;
   // ------------------------------------------------------------------------
   // 1) get header
   // ------------------------------------------------------------------------
@@ -299,7 +299,7 @@ geo_rep<T,sequential>::build_from_data (
         for (size_type d = 0; d <= base::_map_dimension; d++) { 
           for (size_type loc_inod = K.first_inod(d), loc_nnod = K.last_inod(d); loc_inod < loc_nnod; loc_inod++) {
             check_macro (K[loc_inod] < nnod, "inod K["<<loc_inod<<"]="<<K[loc_inod]
-		<<" is out of range [0:"<<nnod<<"[; K="<<K);
+		<<" is out of range [0:"<<nnod<<"[; K.dis_ie="<<K.dis_ie());
             node_subgeo_dim [K[loc_inod]] = d;
           }
         }
@@ -432,7 +432,7 @@ geo_rep<T,sequential>::build_from_data (
     }
 #endif // TO_CLEAN
     // 9.2. apply the new node numbering to the node table
-    array<point_basic<T>,sequential> new_node (base::_node.ownership());
+    disarray<point_basic<T>,sequential> new_node (base::_node.ownership());
     for (size_type inod = 0, nnod = base::_node.size(); inod < nnod; inod++) {
       size_type new_inod = inod2new_inod [inod];
       new_node [new_inod] = base::_node [inod];
