@@ -287,6 +287,7 @@ visu_gnuplot (odiststream& ops, const geo_basic<T,sequential>& omega)
   bool   full     = iorheo::getfull(os);    // all edges & !faces in 3d
   bool   lattice  = iorheo::getlattice(os); // face & volume lattices
   bool   reader_on_stdin  = iorheo::getreader_on_stdin(os);
+  bool   color    = iorheo::getcolor(os);
   string format   = iorheo::getimage_format(os);
   size_type subdivide = iorheo::getsubdivide(os);
   if (basename.length() == 0) basename = "output";
@@ -394,7 +395,8 @@ visu_gnuplot (odiststream& ops, const geo_basic<T,sequential>& omega)
   //
   if (show_volumes) {
     filename = tmp+basename + "-vol.gdat";
-    if (!first_plot_line) plot << ",\\" << endl; first_plot_line = false;
+    if (!first_plot_line) plot << ",\\" << endl;
+    first_plot_line = false;
     plot << "  \"" << filename << "\" u 1:2:3:(0.0) title \"volumes\" with l lc 3 lw 1";
 
     filelist = filelist + " " + filename;
@@ -412,7 +414,8 @@ visu_gnuplot (odiststream& ops, const geo_basic<T,sequential>& omega)
   //
   if (show_faces) {
     filename = tmp+basename + "-fac.gdat";
-    if (!first_plot_line) plot << ",\\" << endl; first_plot_line = false;
+    if (!first_plot_line) plot << ",\\" << endl;
+    first_plot_line = false;
     plot << "  \"" << filename << "\" title \"faces\" with l lc 3 lw 1";
 
     filelist = filelist + " " + filename;
@@ -430,7 +433,8 @@ visu_gnuplot (odiststream& ops, const geo_basic<T,sequential>& omega)
   //
   if (show_edges) {
     filename = tmp+basename + "-edg.gdat";
-    if (!first_plot_line) plot << ",\\" << endl; first_plot_line = false;
+    if (!first_plot_line) plot << ",\\" << endl;
+    first_plot_line = false;
     plot << "  \"" << filename << "\" title \"edges\" with l lc 1 lw 1.5";
 
     filelist = filelist + " " + filename;
@@ -447,7 +451,8 @@ visu_gnuplot (odiststream& ops, const geo_basic<T,sequential>& omega)
   // plot vertices
   //
   if (show_vertices) {
-    if (!first_plot_line) plot << ",\\" << endl; first_plot_line = false;
+    if (!first_plot_line) plot << ",\\" << endl;
+    first_plot_line = false;
     plot << "  \"" << tmp+basename << "-ver.gdat\" title \"vertices\" with p lc 0";
 
     filename = tmp+basename + "-ver.gdat";
@@ -476,7 +481,8 @@ visu_gnuplot (odiststream& ops, const geo_basic<T,sequential>& omega)
         if (dim == 3) continue; // TODO: only d=0,1,2 domains yet
   
         filename = tmp+basename + "-dom-" + dom.name() + ".gdat";
-        if (!first_plot_line) plot << ",\\" << endl; first_plot_line = false;
+        if (!first_plot_line) plot << ",\\" << endl;
+        first_plot_line = false;
         plot << "  \"" << filename + "\" title \"" << dom.name() << "\"";
         if (dom.map_dimension() == 0) {
           plot << " with p";
