@@ -77,7 +77,7 @@ visu_vtk_mayavi (odiststream& ops, const geo_basic<T,sequential>& omega)
   bool black_and_white = iorheo::getblack_and_white(os);
   bool stereo    = iorheo::getstereo(os);
   bool full      = iorheo::getfull(os);
-  bool iso       = iorheo::getiso(os);
+  bool iso       = true;
   bool cut       = iorheo::getcut(os);
   bool volume    = iorheo::getvolume(os);
   bool grid       = iorheo::getgrid(os);
