@@ -61,21 +61,27 @@ geo_base_rep<T,M>::seq_trace_move (
     check_macro (dis_ie != std::numeric_limits<size_type>::max(), "invalid ray computation");
     return dis_ie;
   }
-#ifdef TO_CLEAN
-  // x was outside Omega ? most of the time, y is exactly on the boundary:
-  // dirty hack: project y on the bbox of the boundary:
-  //  - this works in 1d when Omega is simply connected
-  //  - this works in 2d & 3d when Omega is a rectangle or a paralellotope...
-  // TODO: boundary projection in the multi-connected case with: y = omega.nearest(x+v)
-  for (size_t i = 0; i < _dimension; i++) {
-    y[i] = (v[i] < 0) ? _xmin[i] : _xmax[i];
-  }
-#endif // TO_CLEAN
   // x is on the boundary and also y (tangential velocity)
   dis_ie = _locator.seq_locate (*this,y);
   if (dis_ie != std::numeric_limits<size_type>::max()) {
     return dis_ie;
   } 
+  // x was outside Omega ? most of the time, y is exactly on the boundary:
+  // boundary projection in the multi-connected case with: y = omega.nearest(x+v)
+  point_basic<T> y_nearest;
+  dis_ie = seq_nearest (y, y_nearest);
+  if (dis_ie != std::numeric_limits<size_type>::max()) {
+    y = y_nearest;
+    return dis_ie;
+  } 
+#ifdef TO_CLEAN
+  // old and dirty hack: project y on the bbox of the boundary:
+  //  - this works in 1d when Omega is simply connected
+  //  - this works in 2d & 3d when Omega is a rectangle or a paralellotope...
+  for (size_t i = 0; i < _dimension; i++) {
+    y[i] = (v[i] < 0) ? _xmin[i] : _xmax[i];
+  }
+#endif // TO_CLEAN
   // machine precision problem ?
   error_macro ("invalid seq_trace_move");
   return std::numeric_limits<size_type>::max();
@@ -106,15 +112,15 @@ geo_base_rep<T,M>::dis_trace_move (
   return std::numeric_limits<size_type>::max();
 }
 // --------------------------------------------------------------------------
-// 2) arrays x & v : groups comms in the distributed case
+// 2) disarrays x & v : groups comms in the distributed case
 // --------------------------------------------------------------------------
 template <class T>
 void
 geo_rep<T,sequential>::trace_move (
-                const array<point_basic<T>,sequential>&     x,
-                const array<point_basic<T>,sequential>&     v,
-		      array<size_type, sequential>&         dis_ie,
-                      array<point_basic<T>,sequential>&     y) const
+                const disarray<point_basic<T>,sequential>&     x,
+                const disarray<point_basic<T>,sequential>&     v,
+		      disarray<size_type, sequential>&         dis_ie,
+                      disarray<point_basic<T>,sequential>&     y) const
 {
   check_macro (x.ownership() == v.ownership(), "invalid ranges for x and v argumenst");
   dis_ie.resize (x.ownership());
@@ -128,10 +134,10 @@ geo_rep<T,sequential>::trace_move (
 template <class T>
 void
 geo_rep<T,distributed>::trace_move (
-                const array<point_basic<T>,distributed>&     x,
-                const array<point_basic<T>,distributed>&     v,
-		      array<size_type, distributed>&         dis_ie, // in: guest; out: localized
-                      array<point_basic<T>,distributed>&     y) const
+                const disarray<point_basic<T>,distributed>&     x,
+                const disarray<point_basic<T>,distributed>&     v,
+		      disarray<size_type, distributed>&         dis_ie, // in: guest; out: localized
+                      disarray<point_basic<T>,distributed>&     y) const
 {
   trace_macro("trace_move...");
   check_macro (x.ownership() == v.ownership(), "invalid ranges for x and v argumenst");
@@ -162,10 +168,10 @@ geo_rep<T,distributed>::trace_move (
     trace_macro("trace_move done(1)");
     return;
   }
-  array<point_basic<T> > fld_x (fld_ownership);
-  array<point_basic<T> > fld_v (fld_ownership);
-  array<point_basic<T> > fld_y (fld_ownership);
-  array<size_type>  fld_dis_ie (fld_ownership, std::numeric_limits<size_type>::max());
+  disarray<point_basic<T> > fld_x (fld_ownership);
+  disarray<point_basic<T> > fld_v (fld_ownership);
+  disarray<point_basic<T> > fld_y (fld_ownership);
+  disarray<size_type>  fld_dis_ie (fld_ownership, std::numeric_limits<size_type>::max());
   typename std::list<size_type>::const_iterator iter = failed.begin();
   for (size_type fld_i = 0, fld_n = fld_x.size(); fld_i < fld_n; ++fld_i, ++iter) {
     size_type i = *iter;
