@@ -174,7 +174,7 @@ geo_trace_ray_boundary<T,M>::dis_trace_ray_boundary (
 template <class T, class M>
 class geo_trace_ray_boundary_abstract_rep {
 public:
-  typedef typename array<T,M>::size_type size_type;
+  typedef typename disarray<T,M>::size_type size_type;
   virtual ~geo_trace_ray_boundary_abstract_rep() {}
   virtual void initialize (const geo_base_rep<T,M>& omega) const = 0;
   virtual bool seq_trace_ray_boundary     (
@@ -572,15 +572,15 @@ geo_trace_ray_boundary<T,M>::make_ptr (const geo_base_rep<T,M>& omega)
   }
 }
 // ---------------------------------------------------------------------
-// 4) array interface (more efficient in the distributed case)
+// 4) disarray interface (more efficient in the distributed case)
 // ---------------------------------------------------------------------
 template <class T>
 void
 geo_rep<T,sequential>::trace_ray_boundary (
-                const array<point_basic<T>,sequential>&     x,
-                const array<point_basic<T>,sequential>&     v,
-                      array<size_type, sequential>&         dis_ie,
-                      array<point_basic<T>,sequential>&     y,
+                const disarray<point_basic<T>,sequential>&     x,
+                const disarray<point_basic<T>,sequential>&     v,
+                      disarray<size_type, sequential>&         dis_ie,
+                      disarray<point_basic<T>,sequential>&     y,
 		bool  do_check) const
 {
   for (size_type i = 0, n = x.size(); i < n; i++) {
@@ -600,10 +600,10 @@ geo_rep<T,sequential>::trace_ray_boundary (
 template <class T>
 void
 geo_rep<T,distributed>::trace_ray_boundary (
-                const array<point_basic<T>,distributed>&     x,
-                const array<point_basic<T>,distributed>&     v,
-                      array<size_type, distributed>&         dis_ie,
-                      array<point_basic<T>,distributed>&     y,
+                const disarray<point_basic<T>,distributed>&     x,
+                const disarray<point_basic<T>,distributed>&     v,
+                      disarray<size_type, distributed>&         dis_ie,
+                      disarray<point_basic<T>,distributed>&     y,
 		bool  do_check) const
 {
   trace_macro ("ray_boundary...");
@@ -702,7 +702,7 @@ geo_rep<T,distributed>::trace_ray_boundary (
         massive_merged.begin().operator->(),
         id_pt_minimum<T>());
 
-  // 5) store the local range into the distributed array dis_ie:
+  // 5) store the local range into the distributed disarray dis_ie:
   iter = failed.begin();
   for (size_type fld_dis_i = first_fld_dis_i; fld_dis_i < last_fld_dis_i; ++fld_dis_i, ++iter) {
     size_type i  = *iter;
@@ -761,10 +761,10 @@ geo_trace_ray_boundary<T,M>::dis_trace_ray_boundary (
 template <class T>
 void
 geo_rep<T,sequential>::trace_ray_boundary (
-                const array<point_basic<T>,sequential>&     x,
-                const array<point_basic<T>,sequential>&     v,
-                      array<size_type, sequential>&         dis_ie,
-                      array<point_basic<T>,sequential>&     y,
+                const disarray<point_basic<T>,sequential>&     x,
+                const disarray<point_basic<T>,sequential>&     v,
+                      disarray<size_type, sequential>&         dis_ie,
+                      disarray<point_basic<T>,sequential>&     y,
 		bool  do_check) const
 {
   fatal_macro ("geo: trace_ray_boundary not available (HINT: recompile Rheolef with the CGAL library)");
@@ -773,10 +773,10 @@ geo_rep<T,sequential>::trace_ray_boundary (
 template <class T>
 void
 geo_rep<T,distributed>::trace_ray_boundary (
-                const array<point_basic<T>,distributed>&     x,
-                const array<point_basic<T>,distributed>&     v,
-                      array<size_type, distributed>&         dis_ie,
-                      array<point_basic<T>,distributed>&     y,
+                const disarray<point_basic<T>,distributed>&     x,
+                const disarray<point_basic<T>,distributed>&     v,
+                      disarray<size_type, distributed>&         dis_ie,
+                      disarray<point_basic<T>,distributed>&     y,
 		bool  do_check) const
 {
   fatal_macro ("geo: trace_ray_boundary not available (HINT: recompile Rheolef with the CGAL library)");
