@@ -29,7 +29,7 @@
 // date: 12 march 2012
 //
 #include "rheolef/point.h"
-#include "rheolef/array.h"
+#include "rheolef/disarray.h"
 
 namespace rheolef {
 
@@ -40,7 +40,7 @@ template <class T, class M> class geo_trace_ray_boundary_abstract_rep;
 template <class T, class M>
 class geo_trace_ray_boundary {
 public:
-  typedef typename array<T,M>::size_type size_type;
+  typedef typename disarray<T,M>::size_type size_type;
   geo_trace_ray_boundary() : _ptr(0) {}
   geo_trace_ray_boundary(const geo_trace_ray_boundary<T,M>&) { _ptr = 0; }
   geo_trace_ray_boundary<T,M>& operator= (const geo_trace_ray_boundary<T,M>&) { _ptr = 0; return *this; }
