@@ -21,22 +21,51 @@
 /// 
 /// =========================================================================
 // 
-// interpolation
+// interpolation of functions and nonlinear expressions
+// also re-interpolation of fields and linear expressions
 //
+// author: Pierre.Saramito@imag.fr
+//
+// date: 15 september 2015
+//
+// Notes; use template expressions and SFINAE techiques
+//   The interpolation operator is required, as in
+//   1/uh and uh*vh that do not belong to Xh when uh, vh in Xh
+//
+// SUMMARY:
+// 1. implementation
+// 1.1. scalar-valued result field
+// 1.2. vector-valued case
+// 1.3. tensor-valued case
+// 1.4. undeterminated-valued case: determined at run-time
+// 1.5. interface of the internal interpolate() function
+// 2. the interpolate() function
+// 2.1. nonlinear expression and function/functor
+// 2.2. re-interpolation of fields and linear field expressions
+
 #include "rheolef/field.h"
-#include "rheolef/field_nonlinear_expr.h"
+#include "rheolef/field_expr_v2_nonlinear.h"
 namespace rheolef {
 
+namespace details {
 // --------------------------------------------------------------------------
-// interpolate a general nonlinear expression
+// 1. implementation: general nonlinear expr
 // --------------------------------------------------------------------------
-// function template partial specialization is not allowed --> class-function
+// notes:
+// * function template partial specialization is not allowed --> use class-function
+// * interpolation on boundary domain spaces (geo_domain) could generate
+//   some communications (see interpolate_dom[234]_tst.cc for tests)
+// * interpolation of functions and functor are be performed in all cases
+//   without communications, see below for this implementation.
+//   here we suppose a general nonlinear expression that is interpolated
+//   by using a loop on mesh elements
+//
 template<class T, class M, class Expr, class Result, class Status = typename details::is_equal<Result,typename Expr::value_type>::type>
 struct interpolate_internal_check {
   field_basic<T,M>
   operator() (
-    const space_basic<T,M>&           Xh,
-    const field_nonlinear_expr<Expr>& expr) const
+    const space_basic<T,M>&  Xh,
+    const Expr&              expr) const
 {
   trace_macro ("Expr="<<pretty_typename_macro(Expr));
   trace_macro ("Result="<<typename_macro(Result));
@@ -45,48 +74,51 @@ struct interpolate_internal_check {
   fatal_macro ("invalid type resolution");
   return field_basic<T,M>();
 }};
-// scalar-valued result field
+// 1.1. scalar-valued result field
 template<class T, class M, class Expr>
-struct interpolate_internal_check<T,M,Expr,T,mpl::true_> {
+struct interpolate_internal_check<T,M,Expr,T,std::true_type> {
   field_basic<T,M>
   operator() (
-    const space_basic<T,M>&           Xh,
-    const field_nonlinear_expr<Expr>& expr) const
+    const space_basic<T,M>&  Xh,
+    const Expr&              expr) const
 {
+  check_macro (Xh.valued_tag() == space_constant::scalar,
+	"interpolate: invalid "<<Xh.valued()<<"-valued space and scalar function");
   typedef typename field_basic<T,M>::size_type size_type;
   bool is_homogeneous = expr.initialize (Xh);
   expr.template valued_check<T>();
-  trace_macro ("is_homogeneous: " << is_homogeneous);
   const geo_basic<T,M>& omega = Xh.get_geo();
   field_basic<T,M> uh (Xh, std::numeric_limits<T>::max());
   typename field_basic<T,M>::iterator random_iter_uh = uh.begin_dof();
   std::vector<size_type> dis_idof;
   distributor ownership = Xh.ownership();
   size_type first_dis_idof = ownership.first_index();
-  check_macro (Xh.valued_tag() == space_constant::scalar,
-	"interpolate: invalid "<<Xh.valued()<<"-valued space and scalar function");
   std::vector<T> value;
   for (typename geo_basic<T,M>::const_iterator
         iter_ie = omega.begin(),
         last_ie = omega.end(); iter_ie != last_ie; ++iter_ie) {
     const geo_element& K = *iter_ie;
-    expr.evaluate (K, value);
     Xh.dis_idof   (K, dis_idof);
+    expr.evaluate (K, value);
     for (size_type loc_idof = 0, loc_ndof = dis_idof.size(); loc_idof < loc_ndof; ++loc_idof) {
-      if (! ownership.is_owned (dis_idof [loc_idof])) continue;
-      size_type idof = dis_idof [loc_idof] - first_dis_idof;
-      random_iter_uh [idof] = value [loc_idof];
+      if (ownership.is_owned (dis_idof [loc_idof])) {
+        size_type idof = dis_idof [loc_idof] - first_dis_idof;
+        random_iter_uh [idof] = value [loc_idof];
+      } else {
+	uh.dis_dof_entry (dis_idof [loc_idof]) = value [loc_idof];
+      }
     }
   }
+  uh.dis_dof_update();
   return uh;
 }};
-// vector-valued case
+// 1.2. vector-valued case
 template<class T, class M, class Expr>
-struct interpolate_internal_check<T,M,Expr,point_basic<T>,mpl::true_> {
+struct interpolate_internal_check<T,M,Expr,point_basic<T>,std::true_type> {
   field_basic<T,M>
   operator() (
-    const space_basic<T,M>&           Xh,
-    const field_nonlinear_expr<Expr>& expr) const
+    const space_basic<T,M>&  Xh,
+    const Expr&              expr) const
 {
   typedef typename field_basic<T,M>::size_type size_type;
   bool is_homogeneous = expr.initialize (Xh);
@@ -98,7 +130,7 @@ struct interpolate_internal_check<T,M,Expr,point_basic<T>,mpl::true_> {
   size_type first_dis_idof = ownership.first_index();
   typename field_basic<T,M>::iterator random_iter_uh = uh.begin_dof();
   check_macro (Xh.valued_tag() == space_constant::vector,
-	"interpolate: invalid "<<Xh.valued()<<"-valued space and vector function");
+	"interpolate: incompatible "<<Xh.valued()<<"-valued space and vector function");
   std::vector<point_basic<T> > value;
   size_type dim = Xh.get_geo().dimension();
   size_type n_comp = dim;
@@ -106,28 +138,32 @@ struct interpolate_internal_check<T,M,Expr,point_basic<T>,mpl::true_> {
         iter_ie = omega.begin(),
         last_ie = omega.end(); iter_ie != last_ie; ++iter_ie) {
     const geo_element& K = *iter_ie;
-    expr.evaluate (K, value);
     Xh.dis_idof   (K, dis_idof);
+    expr.evaluate (K, value);
     size_type dis_ndof = dis_idof.size();
     size_type loc_comp_ndof = dis_ndof/n_comp;
     for (size_type loc_comp_idof = 0; loc_comp_idof < loc_comp_ndof; ++loc_comp_idof) {
       for (size_type i_comp = 0; i_comp < n_comp; ++i_comp) {
         size_type loc_idof = loc_comp_idof + i_comp*loc_comp_ndof;
-        if (! ownership.is_owned (dis_idof [loc_idof])) continue;
-        size_type idof = dis_idof [loc_idof] - first_dis_idof;
-        random_iter_uh [idof] = value [loc_comp_idof][i_comp];
+        if (ownership.is_owned (dis_idof [loc_idof])) {
+          size_type idof = dis_idof [loc_idof] - first_dis_idof;
+          random_iter_uh [idof] = value [loc_comp_idof][i_comp];
+        } else {
+	  uh.dis_dof_entry (dis_idof [loc_idof]) = value [loc_comp_idof][i_comp];
+        }
       }
     }
   }
+  uh.dis_dof_update();
   return uh;
 }};
-// tensor-valued case
+// 1.3. tensor-valued case
 template<class T, class M, class Expr>
-struct interpolate_internal_check<T,M,Expr,tensor_basic<T>,mpl::true_> {
+struct interpolate_internal_check<T,M,Expr,tensor_basic<T>,std::true_type> {
   field_basic<T,M>
   operator() (
-    const space_basic<T,M>&           Xh,
-    const field_nonlinear_expr<Expr>& expr) const
+    const space_basic<T,M>& Xh,
+    const Expr&             expr) const
 {
   typedef typename field_basic<T,M>::size_type size_type;
   bool is_homogeneous = expr.initialize (Xh);
@@ -156,35 +192,40 @@ struct interpolate_internal_check<T,M,Expr,tensor_basic<T>,mpl::true_> {
     for (size_type loc_comp_idof = 0; loc_comp_idof < loc_comp_ndof; ++loc_comp_idof) {
       for (size_type ij_comp = 0; ij_comp < n_comp; ++ij_comp) {
         size_type loc_idof = loc_comp_idof + ij_comp*loc_comp_ndof;
-        if (! ownership.is_owned (dis_idof [loc_idof])) continue;
-        size_type idof = dis_idof [loc_idof] - first_dis_idof;
         std::pair<size_type,size_type> ij
           = space_constant::tensor_subscript (space_constant::tensor, sys_coord, ij_comp);
-        random_iter_uh [idof] = value [loc_comp_idof](ij.first, ij.second);
+        if (ownership.is_owned (dis_idof [loc_idof])) {
+          size_type idof = dis_idof [loc_idof] - first_dis_idof;
+          random_iter_uh [idof] = value [loc_comp_idof](ij.first, ij.second);
+        } else {
+	  uh.dis_dof_entry (dis_idof [loc_idof]) = value [loc_comp_idof](ij.first, ij.second);
+        }
       }
     }
   }
+  uh.dis_dof_update();
   return uh;
 }};
+// 1.4. undeterminated-valued case: determined at run-time
 template<class T, class M, class Expr, class Status>
 struct interpolate_internal_check<T,M,Expr,undeterminated_basic<T>,Status> {
   field_basic<T,M>
   operator() (
-    const space_basic<T,M>&           Xh,
-    const field_nonlinear_expr<Expr>& expr) const 
+    const space_basic<T,M>&  Xh,
+    const Expr&              expr) const 
 {
   switch (expr.valued_tag()) {
     case space_constant::scalar: {
-	interpolate_internal_check<T,M,Expr,T,mpl::true_> eval;
+	interpolate_internal_check<T,M,Expr,T,std::true_type> eval;
 	return eval (Xh, expr);
     }
     case space_constant::vector: {
-	interpolate_internal_check<T,M,Expr,point_basic<T>,mpl::true_> eval;
+	interpolate_internal_check<T,M,Expr,point_basic<T>,std::true_type> eval;
 	return eval (Xh, expr);
     }
     case space_constant::tensor:
     case space_constant::unsymmetric_tensor: {
-	interpolate_internal_check<T,M,Expr,tensor_basic<T>,mpl::true_> eval;
+	interpolate_internal_check<T,M,Expr,tensor_basic<T>,std::true_type> eval;
 	return eval (Xh, expr);
     }
     default:
@@ -196,28 +237,28 @@ struct interpolate_internal_check<T,M,Expr,undeterminated_basic<T>,Status> {
         return field_basic<T,M>();
   }
 }};
+// 1.5. interface of the internal interpolate() function
 template<class T, class M, class Expr, class Result>
 field_basic<T,M>
 interpolate_internal (
-    const space_basic<T,M>&           Xh,
-    const field_nonlinear_expr<Expr>& expr)
+    const space_basic<T,M>& Xh,
+    const Expr&             expr)
 {
   interpolate_internal_check<T,M,Expr,Result> eval;
   return eval (Xh,expr);
 }
-// undeterminated-valued case
-template<class T, class M, class Expr>
-field_basic<T,M>
-interpolate (const space_basic<T,M>& Xh, const field_nonlinear_expr<Expr>& expr)
-{
-  typedef typename Expr::value_type result_t;
-  return interpolate_internal<T,M,Expr,result_t> (Xh, expr);
-}
+
+} // namespace details
 // --------------------------------------------------------------------------
-// implementation details of the interpolate() function
+// 2. implementation: function & functors
 // --------------------------------------------------------------------------
+// notes:
+// * interpolation of functions and functor are be performed in all cases
+//   without communications: the loop bases on Lagrange nodes directly.
+//
 namespace details {
 
+// 2.1. scalar valued
 template <class T, class M, class Function>
 field_basic<T,M>
 interpolate_tag (const space_basic<T,M>& Xh, const Function& f, const T&)
@@ -230,8 +271,10 @@ interpolate_tag (const space_basic<T,M>& Xh, const Function& f, const T&)
   for (size_type idof = 0, ndof = Xh.ndof(); idof < ndof; idof++) {
     u.dof (idof) = Xh.momentum (f, idof);
   }
+  u.dis_dof_update();
   return u;
 }
+// 2.2. vector valued
 template <class T, class M, class Function>
 field_basic<T,M>
 interpolate_tag (const space_basic<T,M>& Xh, const Function& f, const point_basic<T>&)
@@ -249,8 +292,10 @@ interpolate_tag (const space_basic<T,M>& Xh, const Function& f, const point_basi
       u.dof (idof) = value [i_comp];
     }
   }
+  u.dis_dof_update();
   return u;
 }
+// 2.2. tensor valued
 template <class T, class M, class Function>
 field_basic<T,M>
 interpolate_tag (const space_basic<T,M>& Xh, const Function& f, const tensor_basic<T>&)
@@ -272,13 +317,14 @@ interpolate_tag (const space_basic<T,M>& Xh, const Function& f, const tensor_bas
       u.dof (idof) = value (ij.first, ij.second);
     }
   }
+  u.dis_dof_update();
   return u;
 }
 
 } // namespace details
 
 // --------------------------------------------------------------------------
-// interface of the interpolate() function
+// 2. the interpolate() function
 // --------------------------------------------------------------------------
 
 /*Class:interpolate
@@ -316,48 +362,55 @@ ADVANCED EXAMPLE:
   field uh2 = interpolate (X2h, pi_h_u);
 @end example
 End: */
-//<interpolate:
-// TODO: un peu general... utiliser des specialisation des classes-fonctions:
-//	function<Float(const point&)>
-//	function<point(const point&)>
-//	function<tensor(const point&)>
-template <class T, class M, class Function>
-inline
-field_basic<T,M>
-interpolate (const space_basic<T,M>& Xh, const Function& f)
 //>interpolate:
+
+// ----------------------------------------------------
+// 2. public interface
+// ----------------------------------------------------
+// 2.1. general nonlinear expression
+template<class T, class M, class Expr>
+typename std::enable_if<
+       details::is_field_expr_v2_nonlinear_arg<Expr>::value
+  && ! details::is_field_expr_v2_linear_arg<Expr>::value
+  && ! details::is_field_function<Expr>::value
+ ,field_basic<T,M>
+>::type
+interpolate (const space_basic<T,M>& Xh, const Expr& expr)
 {
-  typedef typename Function::result_type  result_t;
-  return details::interpolate_tag (Xh, f, result_t());
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr>::type wrap_t;
+  typedef typename wrap_t::value_type result_t;
+  return details::interpolate_internal<T,M,wrap_t,result_t> (Xh, wrap_t(expr));
 }
-// specialization for scalar-valued functions:
-template <class T, class M>
+// 2.2. function & functor
+template <class T, class M, class Expr>
 inline
-field_basic<T,M>
-interpolate (const space_basic<T,M>& Xh, T (*f)(const point_basic<T>&))
+typename std::enable_if<
+  details::is_field_function<Expr>::value
+ ,field_basic<T,M>
+>::type
+interpolate (const space_basic<T,M>& Xh, const Expr& expr)
 {
-  return details::interpolate_tag (Xh, f, T());
+  typedef typename details::function_traits<Expr>::result_type result_t;
+  return details::interpolate_tag (Xh, expr, result_t());
 }
-// specialization for tensor-valued functions:
-template <class T, class M>
-inline
-field_basic<T,M>
-interpolate (const space_basic<T,M>& Xh, tensor_basic<T> (*f)(const point_basic<T>&))
-{
-  return details::interpolate_tag (Xh, f, tensor_basic<T>());
-}
-// specialization for vector-valued functions:
-template <class T, class M>
-inline
-field_basic<T,M>
-interpolate (const space_basic<T,M>& Xh, point_basic<T> (*f)(const point_basic<T>&))
-{
-  return details::interpolate_tag (Xh, f, point_basic<T>());
-}
-// specialization for re-interpoltion of fields (change of mesh, of approx, ect):
+
+// 2.3. re-interpolation of fields and linear field expressions
+//      for change of mesh, of approx, ect
 template<class T, class M>
 field_basic<T,M>
 interpolate (const space_basic<T,M>& X2h, const field_basic<T,M>& u1h);
 
+template <class T, class M, class Expr>
+inline
+typename std::enable_if<
+     details::is_field_expr_v2_linear_arg<Expr>::value
+  && ! details::is_field<Expr>::value
+ ,field_basic<T,M>
+>::type
+interpolate (const space_basic<T,M>& Xh, const Expr& expr)
+{
+  return interpolate (Xh, field_basic<T,M>(expr));
+}
+
 }// namespace rheolef
 #endif // _RHEOLEF_INTERPOLATE_H
