@@ -347,23 +347,23 @@ typedef geo_element_auto<heap_allocator<geo_element::size_type> > element_type;
 
 template <class T, class M>
 void
-gamma_list2array (
-  const std::list<point_basic<T> >&            gamma_node_list,
-  boost::array<std::list<std::pair<element_type,size_t> >, 
-               reference_element::max_variant> gamma_side_list,
-  const communicator&               comm,
-  size_t                            d,
-  array<point_basic<T>, M>&                     gamma_node,
-  boost::array<array<element_type,M>,
+gamma_list2disarray (
+  const std::list<point_basic<T> >&             gamma_node_list,
+  std::array<std::list<std::pair<element_type,size_t> >, 
+               reference_element::max_variant>  gamma_side_list,
+  const communicator&                           comm,
+  size_t                                        d,
+  disarray<point_basic<T>, M>&                  gamma_node,
+  std::array<disarray<element_type,M>,
 	       reference_element::max_variant>& gamma_side,
-  array<size_t,M>&                              sid_ie2bnd_ie)
+  disarray<size_t,M>&                           sid_ie2bnd_ie)
 {
   typedef geo_element::size_type size_type;
   // 1) nodes:
   size_type nnod = gamma_node_list.size();
   distributor gamma_node_ownership (distributor::decide, comm, nnod);
   gamma_node.resize (gamma_node_ownership);
-  typename array<point_basic<T>, M>::iterator node_iter = gamma_node.begin();
+  typename disarray<point_basic<T>, M>::iterator node_iter = gamma_node.begin();
   for (typename std::list<point_basic<T> >::const_iterator
 	iter = gamma_node_list.begin(),
 	last = gamma_node_list.end();
@@ -382,7 +382,7 @@ gamma_list2array (
     nsid += nsidv;
     element_type element_init (variant, order, alloc);
     gamma_side[variant].resize (gamma_sidv_ownership, element_init);
-    typename array<element_type, M>::iterator side_iter = gamma_side[variant].begin();
+    typename disarray<element_type, M>::iterator side_iter = gamma_side[variant].begin();
     for (typename std::list<std::pair<element_type,size_type> >::const_iterator
 	  iter = gamma_side_list[variant].begin(),
 	  last = gamma_side_list[variant].end();
@@ -394,7 +394,7 @@ gamma_list2array (
   distributor gamma_sid_ownership (distributor::decide, comm, nsid);
   const size_type undef      = std::numeric_limits<size_t>::max();
   sid_ie2bnd_ie.resize (gamma_sid_ownership, undef);
-  typename array<size_type, M>::iterator idx_iter = sid_ie2bnd_ie.begin();
+  typename disarray<size_type, M>::iterator idx_iter = sid_ie2bnd_ie.begin();
   for (size_type variant = reference_element::first_variant_by_dimension(map_dim);
                  variant < reference_element:: last_variant_by_dimension(map_dim); variant++) {
     for (typename std::list<std::pair<element_type,size_type> >::const_iterator
@@ -409,9 +409,9 @@ gamma_list2array (
 template <class T, class M>
 void
 gamma_dump (
-  const array<point_basic<T>, M>&         gamma_node,
-  const boost::array<array<element_type,M>, reference_element::max_variant>& gamma_side,
-  size_t                                  d)
+  const disarray<point_basic<T>, M>&         gamma_node,
+  const std::array<disarray<element_type,M>, reference_element::max_variant>& gamma_side,
+  size_t                                     d)
 {
   using namespace std;
   typedef geo_element::size_type size_type;
@@ -453,7 +453,7 @@ level_set_internal (
     const field_basic<T,M>&      fh,
     const level_set_option_type& opt,
     std::vector<size_t>&         bnd_dom_ie_list,
-    array<size_t,M>&             sid_ie2bnd_ie)
+    disarray<size_t,M>&          sid_ie2bnd_ie)
 {
   using namespace std;
   using namespace details;
@@ -470,7 +470,7 @@ level_set_internal (
   size_type d = lambda.dimension();
   size_type map_dim = d-1;
   heap_allocator<size_type> alloc;
-  boost::array<list<pair<element_type,size_type> >, 
+  std::array<list<pair<element_type,size_type> >, 
                reference_element::max_variant> gamma_side_list;
   list<point_basic<T> >                        gamma_node_list;
   std::vector<size_type>       j(d+1);
@@ -480,22 +480,22 @@ level_set_internal (
 
   distributor                 node_ownership = lambda.sizes().node_ownership;
   size_type                   first_dis_inod = node_ownership.first_index();
-  array<size_type>            marked_node (node_ownership, not_marked);
-  array<size_type>            extern_node (node_ownership, not_marked);
+  disarray<size_type>         marked_node (node_ownership, not_marked);
+  disarray<size_type>         extern_node (node_ownership, not_marked);
   set<size_type>              ext_marked_node_idx;
   list<to_solve>              node_to_solve;
 
   distributor                 edge_ownership = lambda.sizes().ownership_by_dimension[1];
   size_type                   first_dis_iedg = edge_ownership.first_index();
-  array<size_type>            marked_edge      (edge_ownership, not_marked);
-  array<std::pair<size_type,point_basic<T> > > 
+  disarray<size_type>         marked_edge      (edge_ownership, not_marked);
+  disarray<std::pair<size_type,point_basic<T> > > 
                               extern_edge      (edge_ownership, std::make_pair(not_marked,point_basic<T>()));
   set<size_type>              ext_marked_edge_idx;
   list<to_solve>              edge_to_solve;
 
   distributor                 face_ownership = lambda.sizes().ownership_by_dimension[2];
   size_type                   first_dis_ifac = face_ownership.first_index();
-  array<size_type>            marked_face (face_ownership, not_marked);
+  disarray<size_type>         marked_face (face_ownership, not_marked);
 
   communicator comm = node_ownership.comm();
   size_type my_proc = comm.rank();
@@ -850,7 +850,7 @@ level_set_internal (
   // ------------------------------------------------------------
   // 2.1.a) re-affect orphan node to another process where gamma use it
   distributor comm_ownership (comm.size(), comm, 1);
-  array<index_set,M> orphan_node (comm_ownership, index_set());
+  disarray<index_set,M> orphan_node (comm_ownership, index_set());
   for (size_type inod = 0, nnod = node_ownership.size(); inod < nnod; inod++) {
     if (!(extern_node [inod] != not_marked && marked_node [inod] == not_marked)) continue;
     // inod is orphan in this proc: not used for gamma (but used for lambda)
@@ -866,7 +866,7 @@ level_set_internal (
   // 2.1.b) re-affect orphan edge to another process where gamma use it
   // there could be orphan edge in 2d if lambda is a part of a regular mesh:
   // => a boundary edge can belong to another proc. This is not yet handled
-  array<index_set,M> orphan_edge (comm_ownership, index_set());
+  disarray<index_set,M> orphan_edge (comm_ownership, index_set());
   for (size_type iedg = 0, nedg = edge_ownership.size(); iedg < nedg; iedg++) {
     if (!(extern_edge [iedg].first != not_marked && marked_edge [iedg] == not_marked)) continue;
     // iedg is orphan in this proc: not used for gamma (but used for lambda)
@@ -908,9 +908,9 @@ level_set_internal (
   // ------------------------------------------------------------
   // 3) convert lists to fixed size distributed arrays
   // ------------------------------------------------------------
-  array<point_basic<T>, M>                                            gamma_node;
-  boost::array<array<element_type,M>, reference_element::max_variant> gamma_side;
-  gamma_list2array (gamma_node_list, gamma_side_list, comm, d, gamma_node, gamma_side, sid_ie2bnd_ie);
+  disarray<point_basic<T>, M>                                            gamma_node;
+  std::array<disarray<element_type,M>, reference_element::max_variant> gamma_side;
+  gamma_list2disarray (gamma_node_list, gamma_side_list, comm, d, gamma_node, gamma_side, sid_ie2bnd_ie);
   // ------------------------------------------------------------
   // 4) replace inod to dis_inod in element lists
   // ------------------------------------------------------------
@@ -964,7 +964,7 @@ level_set (
 {
   typedef geo_element::size_type size_type;
   std::vector<size_type> bnd_dom_ie_list;
-  array<size_type,M>     sid_ie2bnd_ie;
+  disarray<size_type,M>     sid_ie2bnd_ie;
   return level_set_internal (fh, opt, bnd_dom_ie_list, sid_ie2bnd_ie);
 }
 // ----------------------------------------------------------------------------
@@ -975,7 +975,7 @@ template geo_basic<T,M> level_set_internal (						\
     const field_basic<T,M>&,								\
     const level_set_option_type&,							\
     std::vector<size_t>&,								\
-    array<size_t,M>&);								\
+    disarray<size_t,M>&);								\
 template geo_basic<T,M> level_set (							\
     const field_basic<T,M>&,								\
     const level_set_option_type&);
