@@ -23,7 +23,7 @@
 #include "rheolef/geo_element.h"
 #include "rheolef/geo_size.h"
 #include "rheolef/basis.h"
-#include "rheolef/array.h"
+#include "rheolef/disarray.h"
 
 namespace rheolef { 
 
@@ -48,8 +48,8 @@ public:
   virtual size_type dis_ndof (const geo_size& gs, size_type map_dim) const = 0;
   virtual void      dis_idof (const geo_size& gs, const geo_element& K, std::vector<size_type>& dis_idof) const = 0;
   virtual void      set_ios_permutations (const geo_basic<T,M>& omega,
-    		array<size_type,M>&   idof2ios_dis_idof,
-    		array<size_type,M>&   ios_idof2dis_idof) const = 0;
+    		disarray<size_type,M>&   idof2ios_dis_idof,
+    		disarray<size_type,M>&   ios_idof2dis_idof) const = 0;
 
   static numbering_rep* make_ptr (std::string name);
 protected:
@@ -111,8 +111,8 @@ public:
   size_type dis_ndof   (const geo_size& gs, size_type map_dim) const;
   void      dis_idof   (const geo_size& gs, const geo_element& K, std::vector<size_type>& dis_idof) const;
   void set_ios_permutations (const class geo_basic<T,M>& omega,
-    		array<size_type,M>&   idof2ios_dis_idof,
-    		array<size_type,M>&   ios_idof2dis_idof) const;
+    		disarray<size_type,M>&   idof2ios_dis_idof,
+    		disarray<size_type,M>&   ios_idof2dis_idof) const;
 
 // comparator:
  
@@ -216,8 +216,8 @@ inline
 void
 numbering<T,M>::set_ios_permutations (
 	const class geo_basic<T,M>& omega,
-    	array<size_type,M>&   idof2ios_dis_idof,
-    	array<size_type,M>&   ios_idof2dis_idof) const
+    	disarray<size_type,M>&   idof2ios_dis_idof,
+    	disarray<size_type,M>&   ios_idof2dis_idof) const
 {
     return base::data().set_ios_permutations (omega, idof2ios_dis_idof, ios_idof2dis_idof);
 }
