@@ -54,10 +54,11 @@ OVERVIEW:
 */ 
 #include "rheolef/promote.h"
 #include "rheolef/undeterminated.h"
-#include "rheolef/field_functor.h" // for function<> & point_basic
+#include "rheolef/space_constant.h"
 
-#include <boost/functional.hpp>
-#include <boost/mpl/if.hpp>
+#ifdef TO_CLEAN
+#include "rheolef/field_functor.h" // for std::function<> & point_basic
+#endif // TO_CLEAN
 
 namespace rheolef { namespace details {
 
@@ -67,10 +68,10 @@ namespace rheolef { namespace details {
 template<class Op, class T1, class T2, class R>
 struct binop_error {};
 
-template <class T> struct is_error: mpl::false_ {};
+template <class T> struct is_error: std::false_type {};
 
 template<class Op, class T1, class T2, class R>
-struct is_error<binop_error<Op,T1,T2,R> >: mpl::true_ {};
+struct is_error<binop_error<Op,T1,T2,R> >: std::true_type {};
 
 // ===========================================================================
 // part 1. unary operations
@@ -83,19 +84,17 @@ template<class Function>
 struct generic_unary_traits {
   template <class Arg>
   struct result_hint {
-    typedef typename boost::unary_traits<Function>::result_type type;
+    typedef typename function_traits<Function>::result_type type;
   };
   template <class Arg, class Result>
   struct hint {
-    typedef typename boost::unary_traits<Function>::result_type   result_type;
-    typedef typename boost::remove_const<
-              typename boost::remove_reference<
-                typename boost::unary_traits<Function>::argument_type>::type>::type
+    typedef typename function_traits<Function>::result_type   result_type;
+    typedef typename std::decay<typename function_traits<Function>::template arg<0>::type>::type
             							  argument_type;
   };
   static space_constant::valued_type
   valued_tag (space_constant::valued_type) {
-    return space_constant::valued_tag_traits<typename boost::unary_traits<Function>::result_type>::value;
+    return space_constant::valued_tag_traits<typename function_traits<Function>::result_type>::value;
   }
 };
 // ----------------------------------------------------------------------------
@@ -304,23 +303,20 @@ template<class Function>
 struct generic_binary_traits {
   template <class Arg1, class Arg2>
   struct result_hint {
-    typedef typename boost::binary_traits<Function>::result_type type;
+    typedef typename function_traits<Function>::result_type type;
   };
   template <class Arg1, class Arg2, class Result>
   struct hint {
-    typedef typename boost::remove_const<
-              typename boost::remove_reference<
-                typename boost::binary_traits<Function>::first_argument_type>::type>::type
+    typedef typename std::decay<typename function_traits<Function>::template arg<0>::type>::type
             							         first_argument_type;
-    typedef typename boost::remove_const<
-              typename boost::remove_reference<
-                typename boost::binary_traits<Function>::second_argument_type>::type>::type
+    typedef typename std::decay<typename function_traits<Function>::template arg<1>::type>::type
             							         second_argument_type;
-    typedef typename boost::binary_traits<Function>::result_type         result_type;
+    typedef typename std::decay<typename function_traits<Function>::result_type>::type 
+                                                                         result_type;
   };
   static space_constant::valued_type
   valued_tag (space_constant::valued_type, space_constant::valued_type) {
-    return space_constant::valued_tag_traits<typename boost::binary_traits<Function>::result_type>::value;
+    return space_constant::valued_tag_traits<typename function_traits<Function>::result_type>::value;
   }
 };
 // ----------------------------------------------------------------------------
@@ -332,13 +328,26 @@ struct plus; // foward declaration
 
 // result type
 // -----------
-template <class A1, class A2>
+template <class A1, class A2, class Sfinae = void>
 struct plus_result {
   typedef binop_error<details::plus,A1,A2,undeterminated_basic<Float> > type;
 };
-// s+s -> s, v+v -> v, t+t -> t
+// s+s -> s
+template <class A1, class A2>
+struct plus_result<A1,A2,
+  typename std::enable_if<
+    std::is_arithmetic<A1>::value &&
+    std::is_arithmetic<A2>::value
+  >::type> 
+{
+  typedef typename promote<A1,A2>::type type;
+};
+// v+v -> v, t+t -> t
 template <class A>
-struct plus_result<A,A> {
+struct plus_result<A,A,
+  typename std::enable_if<
+    ! std::is_arithmetic<A>::value>::type>
+{
   typedef A type;
 };
 struct plus {
@@ -368,10 +377,11 @@ struct generic_binary_traits<plus> {
   // ?+a2 -> r : deduce a1
   template <class A1, class A2, class R>
   struct hint<undeterminated_basic<A1>,A2,R> {
-    typedef typename mpl::if_<details::is_equal<A2,R>,
+    typedef typename std::conditional<
+      details::is_equal<A2,R>::value,
       R,
-      binop_error<details::plus,A1,A2,R> >::type
-                                              first_argument_type;
+      binop_error<details::plus,A1,A2,R>
+    >::type                                   first_argument_type;
     typedef A2                                second_argument_type;
     typedef R                                 result_type;
   };
@@ -379,7 +389,8 @@ struct generic_binary_traits<plus> {
   template <class A1, class A2, class R>
   struct hint<A1,undeterminated_basic<A2>,R> {
     typedef A1                                first_argument_type;
-    typedef typename mpl::if_<details::is_equal<A1,R>,
+    typedef typename std::conditional<
+      details::is_equal<A1,R>::value,
       R,
       binop_error<details::plus,A1,A2,R> >::type
                                               second_argument_type;
@@ -417,7 +428,7 @@ struct generic_binary_traits<plus> {
   valued_tag (space_constant::valued_type tag1, space_constant::valued_type tag2) { 
     return (tag2 == space_constant::last_valued) ? tag1 : tag2;
   }
-  typedef mpl::true_ is_symmetric;
+  typedef std::true_type is_symmetric;
   template <class Arg1, class Arg2>
   struct result_hint {
     typedef typename hint<Arg1,Arg2,undeterminated_basic<Float> >::result_type type;
@@ -426,9 +437,15 @@ struct generic_binary_traits<plus> {
 // --------
 // x-y
 // --------
+#ifdef TO_CLEAN
 struct minus {
     template <class T> T operator() (const T& a, const T& b) const { return a-b; }
 };
+#endif // TO_CLEAN
+struct minus {
+  template <class T1, class T2> 
+  typename plus_result<T1,T2>::type operator() (const T1& a, const T2& b) const { return a-b; }
+};
 template<>
 struct generic_binary_traits<minus> {
   template <class A1, class A2, class R>
@@ -442,32 +459,35 @@ struct generic_binary_traits<minus> {
   valued_tag (space_constant::valued_type tag1, space_constant::valued_type tag2) { 
     return (tag2 == space_constant::last_valued) ? tag1 : tag2;
   }
-  typedef mpl::false_ is_symmetric;
+  typedef std::false_type is_symmetric;
 };
 // --------
 // x*y
 // --------
 /*
     result: when arg1 & arg2 are given
-      1\2 s  v  t  t3
-       s  s  v  t  t3
-       v  v  E  E  E
-       t  t  v  t  E
-       t3 t3 t  t3 E
+      1\2 s  v  t  t3 t4
+       s  s  v  t  t3 t4
+       v  v  E  E  E  E
+       t  t  v  t  E  E
+       t3 t3 t  t3 E  E
+       t4 t4 E  E  E  E
 
     arg1: deduced when arg2 & result are known
-      2\r s  v  t  t3
-       s  s  v  t  t3
-       v  E (st)t3 E
-       t  E  E (st)t3     st: indetermine'
-       t3 E  E  E  s
+      2\r s  v  t  t3  t4
+       s  s  v  t  t3  t4
+       v  E (st)t3 E   E
+       t  E  E (st)t3  E    st: indetermine'
+       t3 E  E  E  s   E
+       t4 E  E  E  E   s
 
     arg2: deduced when arg1 & result are known
-      1\r s  v  t  t3
-       s  s  v  t  t3
-       v  E  s  E  E
-       t  E  v (st)E      st: indetermine'
-       t3 E  E  v (st)
+      1\r s  v  t  t3  t4
+       s  s  v  t  t3  t4
+       v  E  s  E  E   E
+       t  E  v (st)E   E    st: indetermine'
+       t3 E  E  v (st) E
+       t4 E  E  E E    E
 
       il n'y a que deux cas ou l'arg1 est indetermine' :
             quand arg2=v et res_t=v alors arg1=s ou t
@@ -571,6 +591,58 @@ struct multiplies_result<tensor3_basic<S1>, tensor3_basic<S2> > {
   typedef typename promote<S1,S2>::type S;
   typedef binop_error<details::multiplies,tensor3_basic<S1>,tensor3_basic<S2>,undeterminated_basic<S> > type;
 };
+// s*t4 -> t4 
+template <class S>
+struct multiplies_result<S, tensor4_basic<S> > {
+  typedef tensor4_basic<S> type;
+};
+// t4*s -> t4
+template <class S>
+struct multiplies_result<tensor4_basic<S>, S> {
+  typedef tensor4_basic<S> type;
+};
+// v*t4 -> err
+template <class S1, class S2>
+struct multiplies_result<point_basic<S1>, tensor4_basic<S2> > {
+  typedef typename promote<S1,S2>::type S;
+  typedef binop_error<details::multiplies,point_basic<S1>,tensor4_basic<S2>,undeterminated_basic<S> > type;
+};
+// t*t4 -> err
+template <class S1, class S2>
+struct multiplies_result<tensor_basic<S1>, tensor4_basic<S2> > {
+  typedef typename promote<S1,S2>::type S;
+  typedef binop_error<details::multiplies,tensor_basic<S1>,tensor4_basic<S2>,undeterminated_basic<S> > type;
+};
+// t3*t4 -> err
+template <class S1, class S2>
+struct multiplies_result<tensor3_basic<S1>, tensor4_basic<S2> > {
+  typedef typename promote<S1,S2>::type S;
+  typedef binop_error<details::multiplies,tensor3_basic<S1>,tensor4_basic<S2>,undeterminated_basic<S> > type;
+};
+// t4*v -> err
+template <class S1, class S2>
+struct multiplies_result<tensor4_basic<S1>, point_basic<S2> > {
+  typedef typename promote<S1,S2>::type S;
+  typedef binop_error<details::multiplies,tensor4_basic<S1>,point_basic<S2>,undeterminated_basic<S> > type;
+};
+// t4*t -> err
+template <class S1, class S2>
+struct multiplies_result<tensor4_basic<S1>, tensor_basic<S2> > {
+  typedef typename promote<S1,S2>::type S;
+  typedef binop_error<details::multiplies,tensor4_basic<S1>,tensor_basic<S2>,undeterminated_basic<S> > type;
+};
+// t4*t3 -> err
+template <class S1, class S2>
+struct multiplies_result<tensor4_basic<S1>, tensor3_basic<S2> > {
+  typedef typename promote<S1,S2>::type S;
+  typedef binop_error<details::multiplies,tensor4_basic<S1>,tensor3_basic<S2>,undeterminated_basic<S> > type;
+};
+// t4*t4 -> err
+template <class S1, class S2>
+struct multiplies_result<tensor4_basic<S1>, tensor4_basic<S2> > {
+  typedef typename promote<S1,S2>::type S;
+  typedef binop_error<details::multiplies,tensor4_basic<S1>,tensor4_basic<S2>,undeterminated_basic<S> > type;
+};
 
 struct multiplies {
   template <class T1, class T2>
@@ -587,7 +659,7 @@ struct generic_binary_traits<multiplies> {
   // hint arg1 type
   // --------------------------
   // ?*s=s => a1=s
-  template <class A2, class R>
+  template <class A2, class R, class Sfinae = void>
   struct first_argument_hint {
     typedef typename promote<A2,R>::type type;
   };
@@ -606,6 +678,12 @@ struct generic_binary_traits<multiplies> {
   struct first_argument_hint<A2,tensor3_basic<R> > {
     typedef tensor3_basic<typename promote<A2,R>::type> type;
   };
+  // ?*s=t4 => a1=t4
+  template <class A2, class R>
+  struct first_argument_hint<A2,tensor4_basic<R>, 
+	typename std::enable_if<is_rheolef_arithmetic<A2>::value>::type> {
+    typedef tensor4_basic<typename promote<A2,R>::type> type;
+  };
   // ?*v=s => a1=err
   template <class A2, class R>
   struct first_argument_hint<point_basic<A2>,R> {
@@ -626,6 +704,11 @@ struct generic_binary_traits<multiplies> {
   struct first_argument_hint<point_basic<A2>,tensor3_basic<R> > {
     typedef binop_error<details::multiplies,undeterminated_basic<A2>,point_basic<A2>,tensor3_basic<R> > type;
   };
+  // ?*v=t4 => a1=err
+  template <class A2, class R>
+  struct first_argument_hint<point_basic<A2>,tensor4_basic<R> > {
+    typedef binop_error<details::multiplies,undeterminated_basic<A2>,point_basic<A2>,tensor4_basic<R> > type;
+  };
   // ?*t=s => a1=err
   template <class A2, class R>
   struct first_argument_hint<tensor_basic<A2>,R> {
@@ -666,89 +749,152 @@ struct generic_binary_traits<multiplies> {
   struct first_argument_hint<tensor3_basic<A2>,tensor3_basic<R> > {
     typedef typename promote<A2,R>::type type;
   };
+  // ?*t4=s => a1=E
+  template <class A2, class R>
+  struct first_argument_hint<tensor4_basic<A2>,R,
+	typename std::enable_if<is_rheolef_arithmetic<R>::value>::type> {
+    typedef typename promote<A2,R>::type S;
+    typedef binop_error<details::multiplies,undeterminated_basic<S>,tensor4_basic<A2>,R> type;
+  };
+  // ?*t4=v => a1=E
+  template <class A2, class R>
+  struct first_argument_hint<tensor4_basic<A2>,point_basic<R> > {
+    typedef typename promote<A2,R>::type S;
+    typedef binop_error<details::multiplies,undeterminated_basic<S>,tensor4_basic<A2>,point_basic<R> > type;
+  };
+  // ?*t4=t => a1=E
+  template <class A2, class R>
+  struct first_argument_hint<tensor4_basic<A2>,tensor_basic<R> > {
+    typedef typename promote<A2,R>::type S;
+    typedef binop_error<details::multiplies,undeterminated_basic<S>,tensor4_basic<A2>,tensor_basic<R> > type;
+  };
+  // ?*t4=t3 => a1=E
+  template <class A2, class R>
+  struct first_argument_hint<tensor4_basic<A2>,tensor3_basic<R> > {
+    typedef typename promote<A2,R>::type S;
+    typedef binop_error<details::multiplies,undeterminated_basic<S>,tensor4_basic<A2>,tensor3_basic<R> > type;
+  };
+  // ?*t4=t4 => a1=s
+  template <class A2, class R>
+  struct first_argument_hint<tensor4_basic<A2>,tensor4_basic<R> > {
+    typedef typename promote<A2,R>::type type;
+  };
   // --------------------------
   // hint arg2 type
   // --------------------------
   // s*?=s => a2=s
-  template <class A1, class R>
+  template <class A1, class R, class Sfinae = void>
   struct second_argument_hint {
     typedef typename promote<A1,R>::type type;
   };
-  // s*?=v => a1=v
+  // s*?=v => a2=v
   template <class A1, class R>
   struct second_argument_hint<A1,point_basic<R> > {
     typedef point_basic<typename promote<A1,R>::type> type;
   };
-  // s*?=t => a1=t
+  // s*?=t => a2=t
   template <class A1, class R>
   struct second_argument_hint<A1,tensor_basic<R> > {
     typedef tensor_basic<typename promote<A1,R>::type> type;
   };
-  // s*?=t3 => a1=t3
+  // s*?=t3 => a2=t3
   template <class A1, class R>
   struct second_argument_hint<A1,tensor3_basic<R> > {
     typedef tensor3_basic<typename promote<A1,R>::type> type;
   };
-  // v*?=s => a1=err
+  // s*?=t4 => a2=t4
+  template <class A1, class R>
+  struct second_argument_hint<A1,tensor4_basic<R>,
+	typename std::enable_if<is_rheolef_arithmetic<A1>::value>::type> {
+    typedef tensor4_basic<typename promote<A1,R>::type> type;
+  };
+  // v*?=s => a2=err
   template <class A1, class R>
   struct second_argument_hint<point_basic<A1>,R> {
     typedef binop_error<details::multiplies,point_basic<A1>,undeterminated_basic<A1>,R> type;
   };
-  // v*?=v => a1=s
+  // v*?=v => a2=s
   template <class A1, class R>
   struct second_argument_hint<point_basic<A1>,point_basic<R> > {
     typedef typename promote<A1,R>::type type;
   };
-  // v*?=t => a1=err
+  // v*?=t => a2=err
   template <class A1, class R>
   struct second_argument_hint<point_basic<A1>,tensor_basic<R> > {
     typedef binop_error<details::multiplies,tensor_basic<A1>,undeterminated_basic<A1>,tensor_basic<R> > type;
   };
-  // t*?=s => a1=err
+  // t*?=s => a2=err
   template <class A1, class R>
   struct second_argument_hint<tensor_basic<A1>,R> {
     typedef binop_error<details::multiplies,tensor_basic<A1>,undeterminated_basic<A1>,R> type;
   };
-  // t*?=v => a1=v
+  // t*?=v => a2=v
   template <class A1, class R>
   struct second_argument_hint<tensor_basic<A1>,point_basic<R> > {
     typedef point_basic<typename promote<A1,R>::type> type;
   };
-  // t*?=t => a1={s,t}=undeterminated
+  // t*?=t => a2={s,t}=undeterminated
   template <class A1, class R>
   struct second_argument_hint<tensor_basic<A1>,tensor_basic<R> > {
     typedef undeterminated_basic<typename promote<A1,R>::type> type;
   };
-  // v*?=t3 => a1=err
+  // v*?=t3 => a2=err
   template <class A1, class R>
   struct second_argument_hint<point_basic<A1>,tensor3_basic<R> > {
     typedef binop_error<details::multiplies,point_basic<A1>,undeterminated_basic<A1>,tensor3_basic<R> > type;
   };
-  // t*?=t3 => a1=err
+  // t*?=t3 => a2=err
   template <class A1, class R>
   struct second_argument_hint<tensor_basic<A1>,tensor3_basic<R> > {
     typedef binop_error<details::multiplies,tensor_basic<A1>,undeterminated_basic<A1>,tensor3_basic<R> > type;
   };
-  // t3*?=s => a1=err
+  // t3*?=s => a2=err
   template <class A1, class R>
   struct second_argument_hint<tensor3_basic<A1>,R > {
-    typedef binop_error<details::multiplies,tensor_basic<A1>,undeterminated_basic<A1>,R> type;
+    typedef binop_error<details::multiplies,tensor3_basic<A1>,undeterminated_basic<A1>,R> type;
   };
-  // t3*?=v => a1=err
+  // t3*?=v => a2=err
   template <class A1, class R>
   struct second_argument_hint<tensor3_basic<A1>,point_basic<R> > {
-    typedef binop_error<details::multiplies,tensor_basic<A1>,undeterminated_basic<A1>,point_basic<R> > type;
+    typedef binop_error<details::multiplies,tensor3_basic<A1>,undeterminated_basic<A1>,point_basic<R> > type;
   };
-  // t3*?=t => a1=v
+  // t3*?=t => a2=v
   template <class A1, class R>
   struct second_argument_hint<tensor3_basic<A1>,tensor_basic<R> > {
     typedef point_basic<typename promote<A1,R>::type> type;
   };
-  // t3*?=t3 => a1={st}
+  // t3*?=t3 => a2={st}
   template <class A1, class R>
   struct second_argument_hint<tensor3_basic<A1>,tensor3_basic<R> > {
     typedef undeterminated_basic<typename promote<A1,R>::type> type;
   };
+  // t4*?=s => a2=err
+  template <class A1, class R>
+  struct second_argument_hint<tensor4_basic<A1>,R,
+	typename std::enable_if<is_rheolef_arithmetic<R>::value>::type> {
+    typedef binop_error<details::multiplies,tensor4_basic<A1>,undeterminated_basic<A1>,R> type;
+  };
+  // t4*?=v => a2=err
+  template <class A1, class R>
+  struct second_argument_hint<tensor4_basic<A1>,point_basic<R> > {
+    typedef binop_error<details::multiplies,tensor4_basic<A1>,undeterminated_basic<A1>,point_basic<R> > type;
+  };
+  // t4*?=t => a2=err
+  template <class A1, class R>
+  struct second_argument_hint<tensor4_basic<A1>,tensor_basic<R> > {
+    typedef binop_error<details::multiplies,tensor4_basic<A1>,undeterminated_basic<A1>,tensor_basic<R> > type;
+  };
+  // t4*?=t3 => a2=err
+  template <class A1, class R>
+  struct second_argument_hint<tensor4_basic<A1>,tensor3_basic<R> > {
+    typedef binop_error<details::multiplies,tensor4_basic<A1>,undeterminated_basic<A1>,tensor3_basic<R> > type;
+  };
+  // t4*?=t4 => a2=err
+  template <class A1, class R>
+  struct second_argument_hint<tensor4_basic<A1>,tensor4_basic<R> > {
+    typedef typename promote<A1,R>::type S;
+    typedef S type;
+  };
   // --------------------------
   // hint interface
   // --------------------------
@@ -814,6 +960,13 @@ struct generic_binary_traits<multiplies> {
     typedef undeterminated_basic<A2> second_argument_type;
     typedef tensor3_basic<R>          result_type;
   };
+  // ?*? -> t4 : deduce (a1,a2)={(s,t4),(t4,s)}=?
+  template <class A1, class A2, class R>
+  struct hint<undeterminated_basic<A1>,undeterminated_basic<A2>,tensor4_basic<R> > {
+    typedef undeterminated_basic<A1> first_argument_type;
+    typedef undeterminated_basic<A2> second_argument_type;
+    typedef tensor4_basic<R>         result_type;
+  };
   // s*? -> ? : deduce (a2,r)={(s,s),(v,v),(t,t)}=?
   template <class A1, class A2, class R>
   struct hint<A1,undeterminated_basic<A2>,undeterminated_basic<R> > {
@@ -870,6 +1023,20 @@ struct generic_binary_traits<multiplies> {
     typedef tensor3_basic<A2>        second_argument_type;
     typedef tensor3_basic<R>         result_type;
   };
+  // ?*t4 -> ? : deduce (a1,r)=(s,t4)
+  template <class A1, class A2, class R>
+  struct hint<undeterminated_basic<A1>,tensor4_basic<A2>,undeterminated_basic<R> > {
+    typedef A1                       first_argument_type;
+    typedef tensor4_basic<A2>        second_argument_type;
+    typedef tensor4_basic<R>         result_type;
+  };
+  // t4*? -> ? : deduce (a2,r)=(s,t4)
+  template <class A1, class A2, class R>
+  struct hint<tensor4_basic<A1>,undeterminated_basic<A2>,undeterminated_basic<R> > {
+    typedef tensor4_basic<A2>        first_argument_type;
+    typedef A2                       second_argument_type;
+    typedef tensor4_basic<R>         result_type;
+  };
   // none types are known
   // -----------------------
   // ?*? -> ? : deduce (a1,a2,r)=?
@@ -884,24 +1051,47 @@ struct generic_binary_traits<multiplies> {
   struct result_hint {
     typedef typename hint<Arg1,Arg2,undeterminated_basic<Float> >::result_type type;
   };
-  typedef mpl::false_ is_symmetric; // tensor*vector do not commute
+  typedef std::false_type is_symmetric; // tensor*vector do not commute
 }; // generic_binary_traits<multiplies>
 // --------
 // x/y
 // --------
 struct divides; // foward declaration
 
-template <class T1, class T2> 
+template <class T1, class T2, class Sfinae = void> 
 struct divides_result {
   typedef undeterminated_basic<typename promote<typename scalar_traits<T1>::type,typename scalar_traits<T2>::type>::type> type;
 };
+// s/s -> s
+template <class T1, class T2>
+struct divides_result<T1,T2,
+  typename std::enable_if<
+    std::is_arithmetic<T1>::value &&
+    std::is_arithmetic<T2>::value
+  >::type>
+{
+  typedef typename promote<T1,T2>::type type;
+};
+// undef/undef -> undef
+template <class T1, class T2>
+struct divides_result<T1,T2,
+  typename std::enable_if<
+    is_undeterminated<T1>::value &&
+    is_undeterminated<T2>::value
+  >::type>
+{
+  typedef undeterminated_basic <typename promote<T1,T2>::type> type;
+};
+// v/v -> err ; t/t -> err
 template <class T> 
-struct divides_result<T,T> {
+struct divides_result<T,T,
+  typename std::enable_if<
+       ! is_rheolef_arithmetic<T>::value
+    && ! is_undeterminated<T>::value 
+>::type>
+{
   typedef typename scalar_traits<T>::type S;
-  typedef typename mpl::if_<details::is_scalar<T>,
-	T,
-        binop_error<details::divides,T,T,undeterminated_basic<S> > >::type
-     type;
+  typedef binop_error<details::divides,T,T,undeterminated_basic<S> > type;
 };
 template <class T>
 struct divides_result<point_basic<T>,T> {
@@ -934,6 +1124,10 @@ struct divides_result<tensor3_basic<T>,T> {
   typedef tensor3_basic<T> type;
 };
 template <class T>
+struct divides_result<tensor4_basic<T>,T> {
+  typedef tensor4_basic<T> type;
+};
+template <class T>
 struct divides_result<T, tensor3_basic<T> > {
   typedef binop_error<details::divides,T,tensor3_basic<T>,undeterminated_basic<T> > type;
 };
@@ -957,7 +1151,25 @@ struct divides_result<tensor3_basic<T1>, tensor_basic<T2> > {
   typedef typename promote<T1,T2>::type S;
   typedef binop_error<details::divides,tensor3_basic<T1>,tensor_basic<T2>,undeterminated_basic<S> > type;
 };
-
+template <class T>
+struct divides_result<T, tensor4_basic<T> > {
+  typedef binop_error<details::divides,T,tensor4_basic<T>,undeterminated_basic<T> > type;
+};
+template <class T1, class T2>
+struct divides_result<point_basic<T1>, tensor4_basic<T2> > {
+  typedef typename promote<T1,T2>::type S;
+  typedef binop_error<details::divides,point_basic<T1>,tensor4_basic<T2>,undeterminated_basic<S> > type;
+};
+template <class T1, class T2>
+struct divides_result<tensor_basic<T1>, tensor4_basic<T2> > {
+  typedef typename promote<T1,T2>::type S;
+  typedef binop_error<details::divides,tensor_basic<T1>,tensor4_basic<T2>,undeterminated_basic<S> > type;
+};
+template <class T1, class T2>
+struct divides_result<tensor3_basic<T1>, tensor4_basic<T2> > {
+  typedef typename promote<T1,T2>::type S;
+  typedef binop_error<details::divides,tensor3_basic<T1>,tensor4_basic<T2>,undeterminated_basic<S> > type;
+};
 struct divides {
   template <class T1, class T2>
   typename divides_result<T1,T2>::type
@@ -988,7 +1200,8 @@ struct generic_binary_traits<divides> {
   template <class A1, class A2, class R>
   struct hint<undeterminated_basic<A1>,A2,R> {
     typedef typename scalar_traits<A2>::type S2;
-    typedef typename mpl::if_<details::is_scalar<A2>,
+    typedef typename std::conditional<
+      details::is_scalar<A2>::value,
       R,
       binop_error<details::divides,A1,A2,R> >::type  first_argument_type;
     typedef A2                                       second_argument_type;
@@ -1001,7 +1214,8 @@ struct generic_binary_traits<divides> {
       typename scalar_traits<A1>::type,
       typename scalar_traits<R>::type>::type         S;
     typedef A1                                       first_argument_type;
-    typedef typename mpl::if_<details::is_equal<A1,R>,
+    typedef typename std::conditional<
+      details::is_equal<A1,R>::value,
       S,
       binop_error<details::divides,A1,A2,R> >::type  second_argument_type;
     typedef R                                        result_type;
@@ -1026,7 +1240,8 @@ struct generic_binary_traits<divides> {
   template <class A1, class A2, class R>
   struct hint<undeterminated_basic<A1>,A2,undeterminated_basic<R> > {
     typedef typename scalar_traits<A2>::type         S2;
-    typedef typename mpl::if_<details::is_scalar<A2>,
+    typedef typename std::conditional<
+      details::is_scalar<A2>::value,
       undeterminated_basic<A1>,
       binop_error<details::divides,A1,A2,R> >::type  first_argument_type;
     typedef A2                                       second_argument_type;
@@ -1045,7 +1260,7 @@ struct generic_binary_traits<divides> {
   valued_tag (space_constant::valued_type tag1, space_constant::valued_type tag2) { 
     return space_constant::divides_result_tag(tag1,tag2);
   }
-  typedef mpl::false_ is_symmetric;
+  typedef std::false_type is_symmetric;
 };
 // ----------------------------------------------------------------------------
 // chap 2.3. binary standard maths: pow(x,y), atan2(x,y),...
@@ -1067,49 +1282,49 @@ struct scalar_binary_traits {
     typedef typename scalar_traits<A1>::type  S1;
     typedef typename scalar_traits<A2>::type  S2;
     typedef typename scalar_traits<R>::type   S;
-    typedef typename mpl::and_<
-              mpl::or_<
+    typedef typename details::and_type<
+              details::or_type<
                 details::is_scalar<A1>
                ,is_undeterminated<A1>
       	      >
-             ,mpl::or_<
+             ,details::or_type<
                 details::is_scalar<A2>
                ,is_undeterminated<A2>
       	      >
-             ,mpl::or_<
+             ,details::or_type<
                 details::is_scalar<R>
                ,is_undeterminated<R>
       	     >
 	   >::type  				is_good;
-    typedef typename mpl::if_<
-	     is_undeterminated<A1>
-	    ,typename mpl::if_<
-	       is_good
+    typedef typename std::conditional<
+	     is_undeterminated<A1>::value
+	    ,typename std::conditional<
+	       is_good::value
               ,S1
               ,binop_error<F,A1,A2,R>
              >::type
             ,A1
            >::type                              first_argument_type;
-    typedef typename mpl::if_<
-	     is_undeterminated<A2>
-	    ,typename mpl::if_<
-	       is_good
+    typedef typename std::conditional<
+	     is_undeterminated<A2>::value
+	    ,typename std::conditional<
+	       is_good::value
               ,S2
               ,binop_error<F,A1,A2,R>
              >::type
             ,A2
            >::type                              second_argument_type;
-    typedef typename mpl::if_<
-	     is_undeterminated<R>
-	    ,typename mpl::if_<
-	       is_good
+    typedef typename std::conditional<
+	     is_undeterminated<R>::value
+	    ,typename std::conditional<
+	       is_good::value
               ,S
               ,binop_error<F,A1,A2,R>
              >::type
             ,R
            >::type                              result_type;
   };
-  typedef mpl::false_ is_symmetric;
+  typedef std::false_type is_symmetric;
 };
 #define _RHEOLEF_generic_binary_scalar(F) 		\
 struct F##_ {						\
@@ -1152,49 +1367,49 @@ struct generic_binary_traits<dot_> {
     typedef typename scalar_traits<A1>::type  S1;
     typedef typename scalar_traits<A2>::type  S2;
     typedef typename scalar_traits<R>::type   S;
-    typedef typename mpl::and_<
-              mpl::or_<
+    typedef typename details::and_type<
+              details::or_type<
                 details::is_point<A1>
                ,is_undeterminated<A1>
       	      >
-             ,mpl::or_<
+             ,details::or_type<
                 details::is_point<A2>
                ,is_undeterminated<A2>
       	      >
-             ,mpl::or_<
+             ,details::or_type<
                 details::is_scalar<R>
                ,is_undeterminated<R>
       	     >
 	   >::type  				is_good;
-    typedef typename mpl::if_<
-	     is_undeterminated<A1>
-	    ,typename mpl::if_<
-	       is_good
+    typedef typename std::conditional<
+	     is_undeterminated<A1>::value
+	    ,typename std::conditional<
+	       is_good::value
               ,point_basic<S1>
               ,binop_error<details::dot_,A1,A2,R>
              >::type
             ,A1
            >::type                              first_argument_type;
-    typedef typename mpl::if_<
-	     is_undeterminated<A2>
-	    ,typename mpl::if_<
-	       is_good
+    typedef typename std::conditional<
+	     is_undeterminated<A2>::value
+	    ,typename std::conditional<
+	       is_good::value
               ,point_basic<S2>
               ,binop_error<details::dot_,A1,A2,R>
              >::type
             ,A2
            >::type                              second_argument_type;
-    typedef typename mpl::if_<
-	     is_undeterminated<R>
-	    ,typename mpl::if_<
-	       is_good
+    typedef typename std::conditional<
+	     is_undeterminated<R>::value
+	    ,typename std::conditional<
+	       is_good::value
               ,S
               ,binop_error<details::dot_,A1,A2,R>
              >::type
             ,R
            >::type                              result_type;
   };
-  typedef mpl::true_ is_symmetric;
+  typedef std::true_type is_symmetric;
 };
 // ------------
 // ddot(x,y)
@@ -1240,20 +1455,24 @@ struct generic_binary_traits<ddot_> {
   template <class A1, class A2, class R>
   struct hint {
     typedef binop_error<ddot_,A1,A2,R> T;
-    typedef typename mpl::if_<is_undeterminated<A1>,T,A1>::type first_argument_type;
-    typedef typename mpl::if_<is_undeterminated<A2>,T,A2>::type second_argument_type;
-    typedef typename mpl::if_<is_undeterminated<R>,T,R>::type   result_type;
+    typedef typename std::conditional<is_undeterminated<A1>::value,T,A1>::type first_argument_type;
+    typedef typename std::conditional<is_undeterminated<A2>::value,T,A2>::type second_argument_type;
+    typedef typename std::conditional<is_undeterminated<R>::value, T,R> ::type result_type;
   };
   // a:b -> ?
   template <class A1, class A2, class R>
   struct hint<A1,A2,undeterminated_basic<R> > {
     typedef typename ddot_result<A1,A2>::type result_type;
-    typedef typename mpl::if_<
-	typename mpl::and_<is_undeterminated<A1>,is_error<result_type> >::type
-       ,result_type,A1>::type                 first_argument_type;
-    typedef typename mpl::if_<
-	typename mpl::and_<is_undeterminated<A2>,is_error<result_type> >::type
-       ,result_type,A2>::type                 second_argument_type;
+    typedef typename std::conditional<
+	     is_undeterminated<A1>::value
+          && is_error<result_type>::value
+       ,result_type
+       ,A1>::type                             first_argument_type;
+    typedef typename std::conditional<
+             is_undeterminated<A2>::value
+          && is_error<result_type>::value
+       ,result_type
+       ,A2>::type                             second_argument_type;
   };
   // ====================
   // A1 xor A2 is unknown
@@ -1262,7 +1481,7 @@ struct generic_binary_traits<ddot_> {
   template <class A1, class A2, class R>
   struct hint<undeterminated_basic<A1>,tensor_basic<A2>,R> {
     typedef binop_error<ddot_,A1,A2,R> E;
-    typedef typename mpl::if_<is_scalar<R>,tensor_basic<A1>,E>::type
+    typedef typename std::conditional<is_scalar<R>::value,tensor_basic<A1>,E>::type
                                               first_argument_type;
     typedef tensor_basic<A2>                  second_argument_type;
     typedef R                                 result_type;
@@ -1272,7 +1491,7 @@ struct generic_binary_traits<ddot_> {
   struct hint<tensor_basic<A1>,undeterminated_basic<A2>,R> {
     typedef binop_error<ddot_,A1,A2,R> E;
     typedef tensor_basic<A1>                  first_argument_type;
-    typedef typename mpl::if_<is_scalar<R>,tensor_basic<A2>,E>::type
+    typedef typename std::conditional<is_scalar<R>::value,tensor_basic<A2>,E>::type
                                               second_argument_type;
     typedef R                                 result_type;
   };
@@ -1297,9 +1516,9 @@ struct generic_binary_traits<ddot_> {
   template <class A1, class A2, class R>
   struct hint<undeterminated_basic<A1>,undeterminated_basic<A2>,R> {
     typedef binop_error<ddot_,A1,A2,R> E;
-    typedef typename mpl::if_<is_scalar<R>,tensor_basic<A1>,E>::type
+    typedef typename std::conditional<is_scalar<R>::value,tensor_basic<A1>,E>::type
                                               first_argument_type;
-    typedef typename mpl::if_<is_scalar<R>,tensor_basic<A2>,E>::type
+    typedef typename std::conditional<is_scalar<R>::value,tensor_basic<A2>,E>::type
                                               second_argument_type;
     typedef R                                 result_type;
   };
@@ -1353,7 +1572,7 @@ struct generic_binary_traits<ddot_> {
   struct result_hint {
     typedef typename hint<Arg1,Arg2,undeterminated_basic<Float> >::result_type type;
   };
-  typedef mpl::true_ is_symmetric;
+  typedef std::true_type is_symmetric;
 };
 // ===========================================================================
 // part 3. binders
@@ -1506,14 +1725,14 @@ struct function_wrapper<Result(Arg)> {
 #ifdef TO_CLEAN
   typedef std::pointer_to_unary_function<Arg,Result> type;
 #endif // TO_CLEAN
-  typedef function<Result(Arg)> type;
+  typedef std::function<Result(Arg)> type;
 };
 template<class Result, class Arg1, class Arg2>
 struct function_wrapper<Result(Arg1,Arg2)> {
 #ifdef TO_CLEAN
   typedef std::pointer_to_binary_function<Arg1,Arg2,Result> type;
 #endif // TO_CLEAN
-  typedef function<Result(Arg1,Arg2)> type;
+  typedef std::function<Result(Arg1,Arg2)> type;
 };
 
 template<class Function>
