@@ -18,6 +18,7 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 /// 
 /// =========================================================================
+#include "rheolef/geo_domain.h"
 #include "rheolef/piola.h"
 #include "rheolef/inv_piola.h"
 #include "rheolef/damped_newton.h"
@@ -175,7 +176,7 @@ normal_from_piola_transformation (
             const geo_element&    bgd_S     = bgd_omega.get_geo_element(0, isid);
             size_type bgd_dis_ie = bgd_S.master(0);
 	    check_macro (bgd_dis_ie != std::numeric_limits<size_type>::max(),
-	      "normal: bgd_S={"<<bgd_S<<"} without neighbours; requires neighbours initialization for mesh " << bgd_omega.name());
+	      "normal: bgd_S.dis_ie={"<<bgd_S.dis_ie()<<"} without neighbours; requires neighbours initialization for mesh " << bgd_omega.name());
             const geo_element& bgd_K = bgd_omega.dis_get_geo_element (bgd_S.dimension()+1, bgd_dis_ie);
             Float sign = (bgd_S[0] == bgd_K[1]) ? 1 : -1;
             return point_basic<T>(sign);
@@ -189,7 +190,7 @@ normal_from_piola_transformation (
             const geo_element&    bgd_S     = bgd_dom[isid]; // TODO: pas clair, differe du cas precedent ?
             size_type bgd_dis_ie = bgd_S.master(0);
 	    check_macro (bgd_dis_ie != std::numeric_limits<size_type>::max(),
-	      "normal: bgd_S={"<<bgd_S<<"} without neighbours; requires neighbours initialization for mesh " << bgd_omega.name());
+	      "normal: bgd_S.dis_ie={"<<bgd_S.dis_ie()<<"} without neighbours; requires neighbours initialization for mesh " << bgd_omega.name());
             const geo_element& bgd_K = bgd_omega.dis_get_geo_element (bgd_S.dimension()+1, bgd_dis_ie);
             Float sign = (bgd_S[0] == bgd_K[1]) ? 1 : -1;
             return point_basic<T>(sign);
