@@ -149,9 +149,9 @@ space_base_rep<T,M>::base_freeze_body () const
   // -----------------------------------------------------------------------
   // 1) loop on domains: mark blocked dofs
   // -----------------------------------------------------------------------
-  array<size_type,M> blocked_flag = _constit.build_blocked_flag();
+  disarray<size_type,M> blocked_flag = _constit.build_blocked_flag();
 
-  // copy the blocked_flag into the iub array, as the "blocked" bit:
+  // copy the blocked_flag into the iub disarray, as the "blocked" bit:
   for (size_type idof = 0, ndof = blocked_flag.size(); idof < ndof; idof++) {
     _idof2blk_iub [idof].set_blocked (blocked_flag[idof]);
   }
@@ -209,7 +209,7 @@ space_base_rep<T,M>::stamp() const
 }
 // ----------------------------------------------------------------------------
 // u["left"] 
-// => build here the requiresd temporary indirect array
+// => build here the requiresd temporary indirect disarray
 // ----------------------------------------------------------------------------
 /**
  Implementation note: there is two numbering styles
@@ -217,11 +217,11 @@ space_base_rep<T,M>::stamp() const
    bgd_idof : from the current space
    dom_idof : from a space compacted to the domain "dom", as geo_domain does
 
-  This function returns the renumbering array "dom_idof2bgd_idof".
+  This function returns the renumbering disarray "dom_idof2bgd_idof".
   It is a temporary, used at the fly when using the u[dom] syntax.
  */
 template <class T, class M>
-array<typename space_base_rep<T,M>::size_type, M>
+disarray<typename space_base_rep<T,M>::size_type, M>
 space_base_rep<T,M>::build_indirect_array (
     const space_base_rep<T,M>& Wh,	// Wh = space on domain
     const std::string&       dom_name   // redundant: contained in Wh.get_geo()
@@ -231,7 +231,7 @@ space_base_rep<T,M>::build_indirect_array (
   return build_indirect_array (Wh, bgd_gamma);
 }
 template <class T, class M>
-array<typename space_base_rep<T,M>::size_type, M>
+disarray<typename space_base_rep<T,M>::size_type, M>
 space_base_rep<T,M>::build_indirect_array (
     const space_base_rep<T,M>& Wh,	// Wh = space on domain
     const geo_basic<T,M>&      bgd_gamma2
@@ -253,7 +253,7 @@ space_base_rep<T,M>::build_indirect_array (
   size_type first_dom_dis_idof = dom_ownership.first_index();
   size_type first_bgd_dis_idof = bgd_ownership.first_index();
   std::vector<size_type> dom_dis_idofs, bgd_dis_idofs;
-  array<size_type, M> dom_idof2bgd_idof (dom_ownership, std::numeric_limits<size_type>::max());
+  disarray<size_type, M> dom_idof2bgd_idof (dom_ownership, std::numeric_limits<size_type>::max());
   for (size_type ige = 0, nge = dom_gamma.size(); ige < nge; ige++) {
     const geo_element& dom_S = dom_gamma[ige];
     const geo_element& bgd_S = bgd_gamma[ige];
