@@ -41,7 +41,7 @@ template <class T, class M> class space_component_const;
 // =====================================================================
 // TODO: compact the bool as an extra bit in size_type ?
 struct space_pair_type {
-    typedef array<size_t>::size_type size_type;
+    typedef disarray<size_t>::size_type size_type;
     space_pair_type () : _blk(false), _iub (std::numeric_limits<size_type>::max()) {}
     space_pair_type (bool blk, size_type iub) : _blk(blk), _iub(iub) {}
     bool is_blocked() const { return _blk; }
@@ -118,7 +118,7 @@ public:
     bool                 is_blocked (size_type     idof) const { freeze_guard(); return _idof2blk_iub [idof].is_blocked(); }
     size_type                   iub (size_type     idof) const { freeze_guard(); return _idof2blk_iub [idof].iub(); }
     const point_basic<T>& xdof (size_type idof) const { return _xdof [idof]; }
-    const array<point_basic<T>,M >& get_xdofs() const { return _xdof; }
+    const disarray<point_basic<T>,M >& get_xdofs() const { return _xdof; }
 
     const distributor& iu_ownership() const { freeze_guard(); return _iu_ownership; }
     const distributor& ib_ownership() const { freeze_guard(); return _ib_ownership; }
@@ -136,10 +136,10 @@ public:
     template <class Function>
     tensor_basic<T> tensor_momentum (const Function& f, size_type idof) const { return f (xdof(idof)); }
 
-    array<size_type, M> build_indirect_array (
+    disarray<size_type, M> build_indirect_array (
     	const space_base_rep<T,M>& Wh, const std::string& dom_name) const;
 
-    array<size_type, M> build_indirect_array (
+    disarray<size_type, M> build_indirect_array (
         const space_base_rep<T,M>& Wh, const geo_basic<T,M>& bgd_gamma) const;
 
 // comparator:
@@ -166,9 +166,9 @@ protected:
     virtual void freeze_body() const { return base_freeze_body(); }
 // data: lazy initialization (on demand only), thus most are mutable
     space_constitution<T,M>   _constit;
-    array<point_basic<T>,M >               _xdof;          // nodal approx only
+    disarray<point_basic<T>,M >               _xdof;          // nodal approx only
     mutable bool                           _have_freezed;
-    mutable array<space_pair_type,M>       _idof2blk_iub;  // pair (is_blocked ; iu_or_ib); use ownership
+    mutable disarray<space_pair_type,M>       _idof2blk_iub;  // pair (is_blocked ; iu_or_ib); use ownership
     mutable distributor                    _iu_ownership;  // unknown values distribution
     mutable distributor                    _ib_ownership;  // blocked values distribution
 };
@@ -248,8 +248,8 @@ protected:
     void freeze_body() const;
     void append_external_dof (const geo_basic<T,distributed>& dom, std::set<size_type>& ext_dof_set) const;
 // data:
-    array<size_type,distributed>   _idof2ios_dis_idof;   // permut to/from ios dof numbering (before geo part), for i/o
-    array<size_type,distributed>   _ios_idof2dis_idof;
+    disarray<size_type,distributed>   _idof2ios_dis_idof;   // permut to/from ios dof numbering (before geo part), for i/o
+    disarray<size_type,distributed>   _ios_idof2dis_idof;
 // mutable data, affected by freeze_*()const:
     mutable std::set<size_type>    _ext_iu_set;    // external dofs used by field::dis_dof
     mutable std::set<size_type>    _ext_ib_set;
@@ -347,7 +347,7 @@ public:
     size_type ios_idof2dis_idof (size_type ios_idof) const;
 
     const point_basic<T>& xdof (size_type idof) const;
-    const array<point_basic<T>,sequential>& get_xdofs() const;
+    const disarray<point_basic<T>,sequential>& get_xdofs() const;
 
     template <class Function>
     T momentum (const Function& f, size_type idof) const;
@@ -358,10 +358,10 @@ public:
     template <class Function>
     tensor_basic<T> tensor_momentum (const Function& f, size_type idof) const;
 
-    array<size_type, sequential> build_indirect_array (
+    disarray<size_type, sequential> build_indirect_array (
     	const space_basic<T,sequential>& Wh, const std::string& dom_name) const;
 
-    array<size_type, sequential> build_indirect_array (
+    disarray<size_type, sequential> build_indirect_array (
         const space_basic<T,sequential>& Wh, const geo_basic<T,sequential>& bgd_gamma) const;
 
     const std::set<size_type>& ext_iu_set() const { return base::data().ext_iu_set(); }
@@ -609,7 +609,7 @@ space_basic<T,sequential>::xdof (size_type idof) const
 }
 template<class T>
 inline
-const array<point_basic<T>,sequential>&
+const disarray<point_basic<T>,sequential>&
 space_basic<T,sequential>::get_xdofs() const
 {
     return base::data().get_xdofs();
@@ -699,7 +699,7 @@ public:
     size_type ios_idof2dis_idof (size_type ios_idof) const;
 
     const point_basic<T>& xdof (size_type idof) const;
-    const array<point_basic<T>,distributed>& get_xdofs() const;
+    const disarray<point_basic<T>,distributed>& get_xdofs() const;
 
     template <class Function>
     T momentum (const Function& f, size_type idof) const;
@@ -710,10 +710,10 @@ public:
     template <class Function>
     tensor_basic<T> tensor_momentum (const Function& f, size_type idof) const;
 
-    array<size_type, distributed> build_indirect_array (
+    disarray<size_type, distributed> build_indirect_array (
     	const space_basic<T,distributed>& Wh, const std::string& dom_name) const;
 
-    array<size_type, distributed> build_indirect_array (
+    disarray<size_type, distributed> build_indirect_array (
         const space_basic<T,distributed>& Wh, const geo_basic<T,distributed>& bgd_gamma) const;
 
     const std::set<size_type>& ext_iu_set() const { return base::data().ext_iu_set(); }
@@ -962,7 +962,7 @@ space_basic<T,distributed>::xdof (size_type idof) const
 }
 template<class T>
 inline
-const array<point_basic<T>,distributed>&
+const disarray<point_basic<T>,distributed>&
 space_basic<T,distributed>::get_xdofs() const
 {
     return base::data().get_xdofs();
@@ -996,7 +996,7 @@ space_basic<T,distributed>::tensor_momentum (const Function& f, size_type idof)
 #define _RHEOLEF_space_build_indirect_array(M)						\
 template<class T>									\
 inline											\
-array<typename space_basic<T,M>::size_type, M>						\
+disarray<typename space_basic<T,M>::size_type, M>					\
 space_basic<T,M>::build_indirect_array (						\
 	const space_basic<T,M>& Wh,							\
 	const std::string& dom_name) const						\
@@ -1005,7 +1005,7 @@ space_basic<T,M>::build_indirect_array (						\
 }											\
 template<class T>									\
 inline											\
-array<typename space_basic<T,M>::size_type, M>						\
+disarray<typename space_basic<T,M>::size_type, M>					\
 space_basic<T,M>::build_indirect_array (						\
 	const space_basic<T,M>& Wh,							\
 	const geo_basic<T,M>&   bgd_gamma) const					\
