@@ -34,6 +34,7 @@ valued_id [last_valued+1] = {
         "vector",
         "tensor",
         "unsymmetric_tensor",
+        "tensor3",
         "tensor4",
         "mixed",
         "undefined"
@@ -470,23 +471,26 @@ tensor4_subscript_name (
 // -----------------------------------------------------------------------
 // field*field : compute the value_type result at run time
 // -----------------------------------------------------------------------
-static const valued_type multiplies_result_tag_table [tensor+1][tensor+1] = {
-   {scalar,      vector,      tensor},
-   {vector,      last_valued, last_valued},	// v*v undef: see dot(v,v)->s or otimes(v,v)->t
-   {scalar,      vector,      tensor}		// v*t undef: see trans(v)*t
+// TODO: move it in operators.cc
+static const valued_type multiplies_result_tag_table [tensor3+1][tensor3+1] = {
+   {scalar,             vector,             tensor,             unsymmetric_tensor, tensor3},
+   {vector,             last_valued,        last_valued,        last_valued,        last_valued},
+   {tensor,             vector,             unsymmetric_tensor, unsymmetric_tensor, last_valued},
+   {unsymmetric_tensor, vector,             unsymmetric_tensor, unsymmetric_tensor, last_valued},
+   {tensor3,            unsymmetric_tensor, tensor3,            tensor3,            last_valued}  
 };
+valued_type
+multiplies_result_tag (space_constant::valued_type tag1, space_constant::valued_type tag2)
+{
+  if (tag1 > tensor3 || tag2 > tensor3) return last_valued;
+  return multiplies_result_tag_table [tag1][tag2];
+}
 static const valued_type divides_result_tag_table [tensor+1][tensor+1] = {
    {scalar,      last_valued, last_valued},
    {vector,      last_valued, last_valued},
    {tensor,      last_valued, last_valued}
 };
 valued_type
-multiplies_result_tag (space_constant::valued_type tag1, space_constant::valued_type tag2)
-{
-  if (tag1 > tensor || tag2 > tensor) return last_valued;
-  return multiplies_result_tag_table [tag1][tag2];
-}
-valued_type
 divides_result_tag (space_constant::valued_type tag1, space_constant::valued_type tag2)
 {
   if (tag1 > tensor || tag2 > tensor) return last_valued;
