@@ -24,14 +24,12 @@
 
 #include "rheolef/distributed.h"
 #include "rheolef/undeterminated.h"
-#include "rheolef/field_functor.h"
+#include "rheolef/field_expr_v2_utilities.h"
+#include <type_traits>
 
-#include <boost/type_traits/is_class.hpp>
-#include <boost/type_traits/is_function.hpp>
-#include <boost/mpl/bool.hpp>
-#include <boost/mpl/and.hpp>
-#include <boost/mpl/or.hpp>
-#include <boost/mpl/not.hpp>
+#ifdef TO_CLEAN
+#include "rheolef/field_functor.h"
+#endif // TO_CLEAN
 
 // ---------------------------------------------------------------------------
 // utility
@@ -42,30 +40,92 @@ namespace rheolef {
 namespace details {
 
 // is_equal : used by type resolution and by is_symmetric 
-template <class T1, class T2> struct is_equal      : mpl::false_ {};
-template <class T>            struct is_equal<T,T> : mpl::true_ {};
+template <class T1, class T2> struct is_equal      : std::false_type {};
+template <class T>            struct is_equal<T,T> : std::true_type {};
 
 // switch for a constant, or a pointer-to-function or a class-function:
-template<class T> struct is_scalar            : boost::mpl::false_ {};
-template<>        struct is_scalar<int>       : boost::mpl::true_ {};
-template<>        struct is_scalar<const int> : boost::mpl::true_ {};
-template<>        struct is_scalar<size_t>    : boost::mpl::true_ {};
-template<>        struct is_scalar<Float>     : boost::mpl::true_ {};
+template<class T> struct is_scalar            : std::false_type {};
+template<>        struct is_scalar<int>       : std::true_type {};
+template<>        struct is_scalar<const int> : std::true_type {};
+template<>        struct is_scalar<size_t>    : std::true_type {};
+template<>        struct is_scalar<Float>     : std::true_type {};
 
-template<class T> struct is_point                  : boost::mpl::false_ {};
-template<class T> struct is_point<point_basic<T> > : boost::mpl::true_ {};
+template<class T> struct is_point                  : std::false_type {};
+template<class T> struct is_point<point_basic<T> > : std::true_type {};
 
-template<class T> struct is_tensor                   : boost::mpl::false_ {};
-template<class T> struct is_tensor<tensor_basic<T> > : boost::mpl::true_ {};
+template<class T> struct is_tensor                   : std::false_type {};
+template<class T> struct is_tensor<tensor_basic<T> > : std::true_type {};
 
-template<class T> struct is_tensor3                    : boost::mpl::false_ {};
-template<class T> struct is_tensor3<tensor3_basic<T> > : boost::mpl::true_ {};
+template<class T> struct is_tensor3                    : std::false_type {};
+template<class T> struct is_tensor3<tensor3_basic<T> > : std::true_type {};
 
-template<class T> struct is_tensor4                    : boost::mpl::false_ {};
-template<class T> struct is_tensor4<tensor4_basic<T> > : boost::mpl::true_ {};
+template<class T> struct is_tensor4                    : std::false_type {};
+template<class T> struct is_tensor4<tensor4_basic<T> > : std::true_type {};
 
-} // namespace details
+// TODO: move it in field_expr_v2_linear.h
+// any possible value for an homogeneous field, as involved in expression
+template <class ValueType>
+struct is_field_expr_v2_constant 
+: or_type<
+     is_rheolef_arithmetic<ValueType>
+    ,is_point<ValueType>
+    ,is_tensor<ValueType>
+    ,is_tensor3<ValueType>
+    ,is_tensor4<ValueType>
+  >
+{};
 
+} // namespace details 
+// ---------------------------------------------------------------------------
+// argument promote, for template expression (binders, etc)
+// ---------------------------------------------------------------------------
+namespace details {
+template <class T1, class T2, class Sfinae = void>
+struct field_promote_first_argument:  promote<T1,T2> {};
+template <class T1, class T2, class Sfinae = void>
+struct field_promote_second_argument: promote<T1,T2> {};
+
+#define _RHEOLEF_field_promote_argument(tensor)						\
+template<class T1, class T2>							\
+struct field_promote_first_argument<tensor##_basic<T1>, T2,				\
+  typename std::enable_if<							\
+	is_rheolef_arithmetic<T1>::value					\
+     &&	is_rheolef_arithmetic<T2>::value					\
+  >::type									\
+> {										\
+	using type = tensor##_basic<typename promote<T1,T2>::type>; };		\
+template <class T1, class T2>							\
+struct field_promote_first_argument<T1,tensor##_basic<T2>,				\
+  typename std::enable_if<							\
+	is_rheolef_arithmetic<T1>::value					\
+     &&	is_rheolef_arithmetic<T2>::value					\
+  >::type									\
+> {										\
+	using type = typename promote<T1,T2>::type; };				\
+template <class T1, class T2>							\
+struct field_promote_second_argument<tensor##_basic<T1>, T2,				\
+  typename std::enable_if<							\
+	is_rheolef_arithmetic<T1>::value					\
+     &&	is_rheolef_arithmetic<T2>::value					\
+  >::type									\
+> {										\
+	using type = typename promote<T1,T2>::type; };				\
+template <class T1, class T2>							\
+struct field_promote_second_argument<T1,tensor##_basic<T2>,				\
+  typename std::enable_if<							\
+	is_rheolef_arithmetic<T1>::value					\
+     &&	is_rheolef_arithmetic<T2>::value					\
+  >::type									\
+> {										\
+	using type = tensor##_basic<typename promote<T1,T2>::type>; };
+
+_RHEOLEF_field_promote_argument(point)
+_RHEOLEF_field_promote_argument(tensor)
+_RHEOLEF_field_promote_argument(tensor3)
+_RHEOLEF_field_promote_argument(tensor4)
+#undef _RHEOLEF_field_promote_argument
+
+} // namespace details 
 // -------------------------------------------------------------
 // coordinate system helper
 // -------------------------------------------------------------
@@ -249,40 +309,40 @@ valued_type    divides_result_tag (valued_type tag1, valued_type tag2);
 namespace details {
   // build a function that returns a constant
   template<class T1, class T2>
-  struct f_constant : field_functor<f_constant<T1,T2>,T2 > {
-    const T2& operator() (const T1& x) const { return c; }
+  struct f_constant {
+    T2 operator() (const T1& x) const { return c; }
     f_constant (const T2& c0) : c(c0) {}
-    T2 c;
+    const T2 c;
   };
   template<class F> struct is_vector_function :
-    boost::mpl::and_ <
-        boost::is_class<F>
+    and_type <
+        std::is_class<F>
        ,is_point<typename F::result_type>
     > {};
   template<class T> struct is_vector_function<point_basic<T> (const point_basic<T>)>
-  	: boost::mpl::true_ {};
+  	: std::true_type {};
 
   template<class E> class field_nonlinear_expr;
-  template<class E> struct is_expr                           : boost::mpl::false_ {};
-  template<class E> struct is_expr<field_nonlinear_expr<E> > : boost::mpl::true_ {};
+  template<class E> struct is_expr                           : std::false_type {};
+  template<class E> struct is_expr<field_nonlinear_expr<E> > : std::true_type {};
 
   template<class C>
   struct is_constant :
-        boost::mpl::or_ <
+        or_type <
           is_scalar<C>
          ,is_point<C>
         > {};
 
   template<class F>
   struct is_function :
-    boost::mpl::and_ <
-      boost::mpl::or_ <
-        boost::is_class<F>
-       ,boost::is_pointer<F>
-       ,boost::is_function<F>
+    and_type <
+      or_type <
+        std::is_class<F>
+       ,std::is_pointer<F>
+       ,std::is_function<F>
       >
-     ,boost::mpl::not_ <
-        boost::mpl::or_ <
+     ,not_type <
+        or_type <
           is_scalar<F>
          ,is_point<F>
          ,is_expr<F>
@@ -292,7 +352,7 @@ namespace details {
   {};
   template<class F>
   struct result_type {
-    typedef typename F::result_type type;
+    typedef typename function_traits<F>::result_type type;
   };
   template<class T, class R>
   struct result_type<R(const point_basic<T>&)> {
