@@ -19,6 +19,7 @@
 /// 
 /// =========================================================================
 
+#include "rheolef/geo_domain.h"
 #include "rheolef/space.h"
 #include "rheolef/space_mult.h"
 #include "rheolef/piola.h"
@@ -242,7 +243,7 @@ space_constitution_rep<T,M>::do_act (const space_act& act)
 template <class T, class M>
 void
 space_scalar_constitution_rep<T,M>::build_blocked_flag (
-  array<size_type,M>& blocked_flag, // array<bool,M> not supported
+  disarray<size_type,M>& blocked_flag, // disarray<bool,M> not supported
   const distributor&  comp_ownership,
   const distributor&  start_by_component) const
 {
@@ -289,7 +290,7 @@ space_scalar_constitution_rep<T,M>::build_blocked_flag (
 template <class T, class M>
 void
 space_constitution_rep<T,M>::build_blocked_flag_recursive (
-  array<size_type,M>&             blocked_flag, // array<bool,M> not supported
+  disarray<size_type,M>&             blocked_flag, // disarray<bool,M> not supported
   const std::vector<distributor>& start_by_component,
   size_type&                      i_comp) const
 {
@@ -306,10 +307,10 @@ space_constitution_rep<T,M>::build_blocked_flag_recursive (
   }
 }
 template <class T, class M>
-array<typename space_constitution_rep<T,M>::size_type,M>
+disarray<typename space_constitution_rep<T,M>::size_type,M>
 space_constitution_rep<T,M>::build_blocked_flag() const
 {
-  array<size_type,M> blocked_flag (ownership(), 0); // array<bool,M> not supported
+  disarray<size_type,M> blocked_flag (ownership(), 0); // disarray<bool,M> not supported
   size_type i_comp = 0;
   build_blocked_flag_recursive (blocked_flag, _start_by_component, i_comp);
   blocked_flag.dis_entry_assembly();
@@ -376,14 +377,14 @@ space_constitution_rep<T,M>::ios_ndof () const
 template <class T, class M>
 void
 space_constitution_rep<T,M>::set_ios_permutation_recursion (
-	array<size_type,M>& idof2ios_dis_idof, 
+	disarray<size_type,M>& idof2ios_dis_idof, 
 	size_type&          comp_start_idof,
 	size_type&          comp_start_dis_idof) const
 {
   if (!_is_hier) {
     // non-hierarchical case:
-    array<size_type,M> comp_idof2ios_dis_idof; 
-    array<size_type,M> comp_ios_idof2dis_idof; 
+    disarray<size_type,M> comp_idof2ios_dis_idof; 
+    disarray<size_type,M> comp_ios_idof2dis_idof; 
     // TODO: avoid allocating comp_idof2ios_dis_idof: numbering supports directly comp_start_{dis_}idof
     // TODO: avoid invert permut here: numbering support no invert perm arg
     _scalar_constit.get_numbering().set_ios_permutations (_scalar_constit.get_geo(), comp_idof2ios_dis_idof, comp_ios_idof2dis_idof);
@@ -413,8 +414,8 @@ space_constitution_rep<T,M>::set_ios_permutation_recursion (
 template <class T, class M>
 void
 space_constitution_rep<T,M>::set_ios_permutations (
-    array<size_type,M>& idof2ios_dis_idof,
-    array<size_type,M>& ios_idof2dis_idof) const
+    disarray<size_type,M>& idof2ios_dis_idof,
+    disarray<size_type,M>& ios_idof2dis_idof) const
 {
   if (!_is_hier) {
     // non-hierarchical case: direct
@@ -597,6 +598,12 @@ space_constitution_rep<T,M>::continuous_append_external_dof (
     }
   }
 }
+// discontinuous case:
+// Limiters uses dofs of all neighbours elements accross the partition boundary.
+// Notice that some sides along the partition bdry are managed by another proc.
+// Thus loop on all internal elements, searching for a partition boundary side
+// and visit its neihbour.
+// Use marks for avoiding to visit several times the same internal side.
 template <class T, class M>
 void
 space_constitution_rep<T,M>::discontinuous_append_external_dof (
@@ -608,12 +615,13 @@ space_constitution_rep<T,M>::discontinuous_append_external_dof (
   size_type dim     = dom.dimension();
   size_type map_dim = dom.map_dimension();
   if (dim > map_dim) {
-    // 3d surfacic mesh or 2d lineique mesh are not yet treated for the DG method
+    // 3d surface mesh or 2d lineique mesh are not yet treated for the DG method
     // TODO: compute neighbours for such meshes
     return;
   }
   if (dom.name() != dom.get_background_geo().name()) {
-    // e.g. geo-domain, as omega["east"] in transmission.cc, are not yet treated for the DG method
+    // e.g. geo-domain, as omega["east"] in transmission.cc,
+    // are not yet treated for the DG method
     // TODO: treat also geo-domains
     return;
   }
@@ -624,16 +632,32 @@ space_constitution_rep<T,M>::discontinuous_append_external_dof (
   distributor comp_ownership = ownership();
   size_type comp_dis_ndof    = comp_ownership.dis_size();
   std::vector<size_type> comp_dis_idof1;
-  for (size_type isid = 0, nsid = dom.size(sid_dim); isid < nsid; isid++) {
-    const geo_element& S = dom.get_geo_element (sid_dim, isid);
-    for (size_type i_master = 0; i_master < 2; i_master++) {
-      size_type dis_ie = S.master(i_master); // two possible Ki such that S is a side of Ki
+  distributor elt_ownership = dom.sizes().ownership_by_dimension[map_dim];
+  distributor sid_ownership = dom.sizes().ownership_by_dimension[sid_dim];
+  size_type first_dis_is = sid_ownership.first_index();
+  disarray<size_type, M> is_marked_side (sid_ownership, 0); // boolean: 0,1 
+  for (typename geo_basic<T,M>::const_iterator iter_K0 = dom.begin(map_dim),
+					       last_K0 = dom.end(map_dim); 
+					       iter_K0 != last_K0; ++iter_K0) {
+    const geo_element& K0 = *iter_K0;
+    for (size_type is_loc = 0, ns_loc = K0.n_subgeo(sid_dim); is_loc < ns_loc; ++is_loc) {
+      size_type dis_is = (map_dim == 1) ? K0[is_loc] : ((map_dim == 2) ? K0.edge(is_loc) : K0.face(is_loc));
+      if (sid_ownership.is_owned (dis_is) && is_marked_side [dis_is - first_dis_is]) continue;
+      if (sid_ownership.is_owned (dis_is)) is_marked_side [dis_is - first_dis_is] = 1;
+      // notice that a side that is not managed by the current proc is a partition boundary one
+      // and will be visited only one time.
+      const geo_element& S = dom.dis_get_geo_element (sid_dim, dis_is);
+      // get the neighbour K such that S is a side at the interface beteen K and K0
+      size_type dis_ie = (S.master(0) != K0.dis_ie()) ? S.master(0) : S.master(1);
       if (dis_ie == std::numeric_limits<size_type>::max()) continue; // S is on the boundary
+      if (elt_ownership.is_owned (dis_ie)) continue;
+      // here: element K is  neighbour, outside of the partition boundary
       const geo_element& K = dom.dis_get_geo_element (map_dim, dis_ie);
       dis_idof (K, comp_dis_idof1);
       for (size_type loc_idof = 0, loc_ndof = comp_dis_idof1.size(); loc_idof < loc_ndof; loc_idof++) {
         size_type comp_dis_idof = comp_dis_idof1 [loc_idof];
-        assert_macro (comp_dis_idof < comp_dis_ndof, "idof " << comp_dis_idof1 [loc_idof] << " out of range[0:"<< comp_dis_ndof << "[");
+        assert_macro (comp_dis_idof < comp_dis_ndof, 
+		"idof " << comp_dis_idof1 [loc_idof] << " out of range[0:"<< comp_dis_ndof << "[");
         if (! comp_ownership.is_owned (comp_dis_idof)) {
           size_type iproc = comp_ownership.find_owner (comp_dis_idof);
           size_type comp_first_dis_idof = comp_ownership.first_index(iproc);
@@ -644,7 +668,7 @@ space_constitution_rep<T,M>::discontinuous_append_external_dof (
           size_type first_dis_idof = dof_ownership.first_index(iproc);
           size_type dis_idof = first_dis_idof + idof;
           assert_macro (! dof_ownership.is_owned (dis_idof), "unexpected dis_idof="<<dis_idof<<" in range ["
-		<< first_dis_idof << ":" << dof_ownership.last_index() << "[");
+  		<< first_dis_idof << ":" << dof_ownership.last_index() << "[");
           ext_dof_set.insert (dis_idof);
         }
       }
