@@ -111,7 +111,7 @@ public:
     size_type internal_dis_ndof() const;
     communicator internal_comm() const;
     void build_blocked_flag (
-      array<size_type,M>& blocked_flag,
+      disarray<size_type,M>& blocked_flag,
       const distributor&  comp_ownership,
       const distributor&  start_by_component) const;
 protected:
@@ -240,8 +240,8 @@ public:
 // utility:
 
     void set_ios_permutations (
-        array<size_type,M>& idof2ios_dis_idof,
-        array<size_type,M>& ios_idof2dis_idof) const;
+        disarray<size_type,M>& idof2ios_dis_idof,
+        disarray<size_type,M>& ios_idof2dis_idof) const;
 
 // comparator:
 
@@ -276,17 +276,17 @@ public:
 	size_type&                comp_start_dis_idof) const;
     void init_start_by_component();
     void build_blocked_flag_recursive (
-      array<size_type,M>&             blocked_flag, // array<bool,M> not supported
+      disarray<size_type,M>&             blocked_flag, // disarray<bool,M> not supported
       const std::vector<distributor>& start_by_component,
       size_type&                      i_comp) const;
-    array<size_type,M> build_blocked_flag() const;
+    disarray<size_type,M> build_blocked_flag() const;
 
 protected:
     friend class space_constitution<T,M>;
     void hierarchy_guard() const { check_macro ( _is_hier, "invalid access to a non-hierarchical constitution"); }
     void scalar_guard()   const { check_macro (!_is_hier, "invalid access to a hierarchical constitution"); }
     void set_ios_permutation_recursion (
-	array<size_type,M>& idof2ios_dis_idof, 
+	disarray<size_type,M>& idof2ios_dis_idof, 
 	size_type&          comp_start_idof,
 	size_type&          comp_start_dis_idof) const;
 // data:
@@ -340,7 +340,7 @@ public:
     void do_act         (const space_act& act)       { base::data().do_act(act); }
     void block   (const domain_indirect_basic<M>& dom) { do_act (space_act(dom.name(), space_act::block)); }
     void unblock (const domain_indirect_basic<M>& dom) { do_act (space_act(dom.name(), space_act::unblock)); }
-    array<size_type,M> build_blocked_flag() const { return base::data().build_blocked_flag(); }
+    disarray<size_type,M> build_blocked_flag() const { return base::data().build_blocked_flag(); }
     void compute_external_dofs (std::set<size_type>& ext_dof_set) const
     					{ base::data().compute_external_dofs(ext_dof_set); }
     bool is_hierarchical() const { return base::data().is_hierarchical(); }
@@ -366,8 +366,8 @@ public:
 // utility:
 
     void set_ios_permutations (
-        array<size_type,M>& idof2ios_dis_idof,
-        array<size_type,M>& ios_idof2dis_idof) const
+        disarray<size_type,M>& idof2ios_dis_idof,
+        disarray<size_type,M>& ios_idof2dis_idof) const
         { base::data().set_ios_permutations (idof2ios_dis_idof, ios_idof2dis_idof); }
     size_type internal_ndof()        const { return base::data().internal_ndof(); }
     size_type internal_dis_ndof()    const { return base::data().internal_dis_ndof(); }
@@ -381,7 +381,7 @@ protected:
 // internal:
     friend class space_constitution_rep<T,M>;
     void set_ios_permutation_recursion (
-	array<size_type,M>& idof2ios_dis_idof, 
+	disarray<size_type,M>& idof2ios_dis_idof, 
 	size_type&          comp_start_idof,
 	size_type&          comp_start_dis_idof) const
         { base::data().set_ios_permutation_recursion (idof2ios_dis_idof, comp_start_idof, comp_start_dis_idof); }
