@@ -112,6 +112,11 @@ static size_t insert (const std::string& str) {
 #define YYFREE   ::free
 
 #include "space_constitution_yacc.cc"
+
+// avoid re-definition of YY_NULL within flex
+#ifdef YY_NULL
+#undef YY_NULL
+#endif
 #include "space_constitution_lex.cc"
 
 static yyFlexLexer input_space_constitution;
