@@ -18,6 +18,7 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 /// 
 /// =========================================================================
+#include "rheolef/geo_domain.h"
 #include "rheolef/test.h"
 
 namespace rheolef {
@@ -130,12 +131,12 @@ test_rep<T,M>::element_initialize (const geo_element& K) const
 	// omits "inner(u)" on a sides-domain => assume a boundary side
         size_type L_map_d = K.dimension() + 1;
         check_macro (L_map_d == _dom.map_dimension(),
-	  "unexpected dimension for side {"<<K<<"} in domain "<<_dom.name());
+	  "unexpected dimension for side K.dis_ie={"<<K.dis_ie()<<"} in domain "<<_dom.name());
         check_macro (K.master(1) == std::numeric_limits<size_type>::max(),
-          "unexpected non-boundary side K="<<K);
+          "unexpected non-boundary side K.dis_ie="<<K.dis_ie());
         size_type L_dis_ie = K.master(0);
         check_macro (L_dis_ie != std::numeric_limits<size_type>::max(),
-          "unexpected isolated side K="<<K);
+          "unexpected isolated side K.dis_ie="<<K.dis_ie());
         const geo_element& L = _dom.dis_get_geo_element (L_map_d, L_dis_ie);
         _tilde_L = L.variant();
         _dom.dis_inod (L, _dis_inod_K);
@@ -154,7 +155,7 @@ test_rep<T,M>::element_initialize (const geo_element& K) const
     // as the zero level set isosurface
     size_type first_dis_ie = _gh.level_set().sizes().ownership_by_dimension [K.dimension()].first_index();
     size_type K_ie = K.dis_ie() - first_dis_ie;
-    check_macro (K.dis_ie() >= first_dis_ie, "unexpected intersected side element K="<<K);
+    check_macro (K.dis_ie() >= first_dis_ie, "unexpected intersected side element K.dis_ie="<<K.dis_ie());
     size_type L_ie = _gh.sid_ie2bnd_ie (K_ie);
     const geo_element& L = _gh.band() [L_ie];
     _tilde_L = L.variant();
