@@ -25,6 +25,7 @@
 #include "rheolef/band.h"
 #include "rheolef/piola.h"
 #include "rheolef/vf_tag.h"
+// TODO: #include "rheolef/field_expr_v2_variational_tag.h"
 
 namespace rheolef {
 
@@ -255,13 +256,13 @@ public :
     			{ base::data().curl_basis_evaluate (hat_K, q, opt, value); }
 
     template<class ValueType>
-    void valued_check() const      { base::data().valued_check<ValueType>(); }
+    void valued_check() const      { base::data().template valued_check<ValueType>(); }
     template<class ValueType>
-    void grad_valued_check() const { base::data().grad_valued_check<ValueType>(); }
+    void grad_valued_check() const { base::data().template grad_valued_check<ValueType>(); }
     template<class ValueType>
-    void div_valued_check() const  { base::data().div_valued_check<ValueType>(); }
+    void div_valued_check() const  { base::data().template div_valued_check<ValueType>(); }
     template<class ValueType>
-    void curl_valued_check() const { base::data().curl_valued_check<ValueType>(); }
+    void curl_valued_check() const { base::data().template curl_valued_check<ValueType>(); }
 };
 typedef test_basic<Float,rheo_default_memory_model,details::vf_tag_01> test;
 typedef test_basic<Float,rheo_default_memory_model,details::vf_tag_10> trial;
