@@ -19,13 +19,17 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
-NPROC_MAX=${NPROC_MAX-"1"}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
+NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 #
 # compose with functions
 #
-echo "      not yet (skipped)"
-exit 0
+
+#echo "      not yet (skipped)"
+#exit 0
+
+loop_mpirun "./compose_tst $SRCDIR/carre-v2.geo >/dev/null 2>/dev/null"
+
