@@ -24,6 +24,11 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"7"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
+if test x"${QD_EXT}" != x""; then
+  echo "      not yet (skiped when QD lib is active)"
+  exit 0
+fi
+
 status=0
 
 loop_mpirun "./field_comp_tst < $SRCDIR/field_multi_io_tst.valid 2>/dev/null | diff -Bw $SRCDIR/field_comp_tst.valid - >/dev/null"
