@@ -24,6 +24,11 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"2"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
+if test x"${QD_EXT}" != x""; then
+  echo "      not yet (skiped when QD lib is active)"
+  exit 0
+fi
+
 status=0
 
 L="
@@ -40,7 +45,7 @@ my_cube_TPH-5-v2
 "
 
 for geo in $L; do
-  loop_mpirun "./field_expr3_tst ${SRCDIR}/$geo right 2>/dev/null | diff interpolate_dom-$geo-right-P1.field - >/dev/null"
+  loop_mpirun "./field_expr3_tst ${SRCDIR}/$geo right 2>/dev/null | diff $SRCDIR/interpolate_dom-$geo-right-P1.field - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 
