@@ -24,6 +24,11 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"2"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
+if test x"${QD_EXT}" != x""; then
+  echo "      not yet (skiped when QD lib is active)"
+  exit 0
+fi
+
 status=0
 
 L="
@@ -33,7 +38,7 @@ cube-gmsh-v2
 "
 
 for geo in $L; do
-  loop_mpirun "./field_expr4_tst ${SRCDIR}/$geo right 2>/dev/null | diff field_expr4-$geo-P1.field - >/dev/null"
+  loop_mpirun "./field_expr4_tst ${SRCDIR}/$geo right 2>/dev/null | diff $SRCDIR/field_expr4-$geo-P1.field - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 
