@@ -24,8 +24,10 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"2"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-#echo "      not yet (skipped)"
-#exit 0
+if test x"${QD_EXT}" != x""; then
+  echo "      not yet (skiped when QD lib is active)"
+  exit 0
+fi
 
 status=0
 
@@ -36,7 +38,7 @@ cube-gmsh-v2
 "
 
 for geo in $L; do
-  loop_mpirun "./field_expr5_tst ${SRCDIR}/$geo right 2>/dev/null | diff field_expr5-$geo-P1.field - >/dev/null"
+  loop_mpirun "./field_expr5_tst ${SRCDIR}/$geo right 2>/dev/null | diff $SRCDIR/field_expr5-$geo-P1.field - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 
