@@ -24,8 +24,10 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"8"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-#echo "      (not yet)"
-#exit 0
+if test x"${QD_EXT}" != x""; then
+  echo "      not yet (skiped when QD lib is active)"
+  exit 0
+fi
 
 status=0
 
