@@ -35,45 +35,30 @@ struct cp {
   point operator() (const point&) const { return point(7,8,9); }
 };
 
-struct gs : field_functor<gs,Float> {
+struct gs {
   Float operator() (const point&) const { return Float(7); }
 };
-struct gp : field_functor<gp,point> {
+struct gp {
   point operator() (const point&) const { return point(7,9,11); }
 };
-struct gt : field_functor<gt,tensor> {
+struct gt {
   tensor operator() (const point&) const { return otimes(point(1,2,3),point(4,5,6)); }
 };
 
 template<class T, class R>
 void surcharge (R(*f)(const point_basic<T>&)) { cout << "R-valued true function=" << f(point()) << endl; }
 
-template<class F, class R>
-void surcharge (const field_functor<F,R>& f) { cout << "R-valued functor=" << f(point()) << endl; }
+template<class F>
+typename
+std::enable_if<
+  details::is_functor<F>::value
+ ,void
+>::type
+surcharge (const F& f) { cout << "R-valued functor=" << f(point()) << endl; }
 
 void surcharge (const function<Float(const point_basic<Float>&)>& f) { cout << "scalar-valued class function=" << f(point()) << endl; }
 
 
-#ifdef NOT_USED
-template<class T>
-void surcharge (T(*f)(const point_basic<T>&)) { cout << "scalar-valued true function=" << f(point()) << endl; }
-template<class T>
-void surcharge (point_basic<T>(*f)(const point_basic<T>&)) { cout << "vector-valued true function=" << f(point()) << endl; }
-template<class T>
-void surcharge (tensor_basic<T>(*f)(const point_basic<T>&)) { cout << "tensor-valued true function=" << f(point()) << endl; }
-#endif // NOT_USED
-
-#ifdef NOT_USED
-template<class F>
-void surcharge (const field_functor<F,Float>& f) { cout << "scalar-valued functor=" << f(point()) << endl; }
-
-template<class F>
-void surcharge (const field_functor<F,point>& f) { cout << "vector-valued functor=" << f(point()) << endl; }
-
-template<class F>
-void surcharge (const field_functor<F,tensor>& f) { cout << "tensor-valued functor=" << f(point()) << endl; }
-#endif // NOT_USED
-
 #ifdef BUG
 // class-fct arg cannot be template:
 template<class T>
