@@ -18,26 +18,33 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ///
 /// =========================================================================
-//  given u1h on a mesh omega1, re-interpolate it on a mesh omega2 as u2h
+// given u1h on a mesh omega1, re-interpolate it on a mesh omega2 as u2h
+// point-valued version
+// 	see field_reinterpolate_tst.cc
 //
-// usage: prog omega1 omega2
+// usage: prog omega1 omega2 1e-7 -expression
 //
 #include "rheolef.h"
 using namespace rheolef;
 using namespace std;
-point u(const point& x) { return point(-x[0]+x[1]+x[2],
-                                        x[0]-x[1]+x[2],
-                                        x[0]+x[1]-x[2]); }
+struct u {
+  point operator() (const point& x) const
+	{ return point(-x[0]+x[1]+x[2],
+                        x[0]-x[1]+x[2],
+                        x[0]+x[1]-x[2]); }
+};
 int main(int argc, char**argv) {
   environment rheolef (argc,argv);
-  Float tol = 1e-7;
   geo omega1 (argv[1]);
   geo omega2 (argv[2]);
+  Float tol       = (argc > 3) ?    atof(argv[3]) : 1e-7;
+  bool  use_expr  = (argc > 4) ? (string(argv[4]) == "-expression") : false;
   space V1h (omega1, "P1", "vector");
   space V2h (omega2, "P1", "vector");
-  field u1h     = interpolate (V1h, u);
+  field u1h     = interpolate (V1h, u());
   field u2h     = interpolate (V2h, u1h);
-  field u2h_bis = interpolate (V2h, u);
+  field u2h_bis = use_expr ? interpolate (V2h, u()*1)  // expression -> element-based Lagrange interpolate version
+                           : interpolate (V2h, u());   // function   -> xdof-based Lagrange interpolate version
   field eh = u2h - u2h_bis;
   Float err = sqrt(dual(eh,eh));
   derr << "err = " << err << endl;
