@@ -19,21 +19,29 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-GEODIR=$SRCDIR
 TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
-NPROC_MAX=${NPROC_MAX-"8"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
+GEODIR=$SRCDIR
+NPROC_MAX=${NPROC_MAX-"3"}
+SHOW_BUG_REINTERPOLATE=${SHOW_BUG_REINTERPOLATE=-"false"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
+if $SHOW_BUG_REINTERPOLATE; then
+  method_list="function expression"
+else
+  method_list="function"
+fi
+
 status=0
+tol="1e-7"
+for method in ${method_list}; do
+  loop_mpirun "./field_multi_reinterpolate_tst $GEODIR/line-3-bdry.geo $GEODIR/line-20-bdry.geo $tol -$method >/dev/null 2>/dev/null"
+  if test $? -ne 0; then status=1; fi
 
-loop_mpirun "./field_multi_reinterpolate_tst $GEODIR/line-3-bdry.geo $GEODIR/line-20-bdry.geo >/dev/null 2>/dev/null"
-if test $? -ne 0; then status=1; fi
-
-loop_mpirun "./field_multi_reinterpolate_tst $GEODIR/carre-10-bdry-v2 $GEODIR/carre-bamg-q-dom-v2 >/dev/null 2>/dev/null"
-if test $? -ne 0; then status=1; fi
-
-loop_mpirun "./field_multi_reinterpolate_tst $GEODIR/cube-5-bdry-v2.geo $GEODIR/cube-H-6-dom-v2.geo >/dev/null 2>/dev/null"
-if test $? -ne 0; then status=1; fi
+  loop_mpirun "./field_multi_reinterpolate_tst $GEODIR/carre-10-bdry-v2 $GEODIR/carre-bamg-q-dom-v2 $tol -$method >/dev/null 2>/dev/null"
+  if test $? -ne 0; then status=1; fi
 
+  loop_mpirun "./field_multi_reinterpolate_tst $GEODIR/cube-5-bdry-v2.geo $GEODIR/cube-H-6-dom-v2.geo $tol -$method >/dev/null 2>/dev/null"
+  if test $? -ne 0; then status=1; fi
+done
 exit $status
