@@ -22,22 +22,31 @@
 TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
 SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
 GEODIR=$SRCDIR
-NPROC_MAX=${NPROC_MAX-"8"}
+NPROC_MAX=${NPROC_MAX-"3"}
+SHOW_BUG_REINTERPOLATE=${SHOW_BUG_REINTERPOLATE=-"false"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
+if ${SHOW_BUG_REINTERPOLATE}; then
+  method_list="function expression"
+else
+  method_list="function"
+fi
+
 status=0
 
-loop_mpirun "./field_reinterpolate_tst $GEODIR/line-3-bdry.geo $GEODIR/line-20-bdry.geo >/dev/null 2>/dev/null"
-if test $? -ne 0; then status=1; fi
+for method in ${method_list}; do
+  loop_mpirun "./field_reinterpolate_tst $GEODIR/line-3-bdry.geo $GEODIR/line-20-bdry.geo 1e-7 -$method >/dev/null 2>/dev/null"
+  if test $? -ne 0; then status=1; fi
 
-loop_mpirun "./field_reinterpolate_tst $GEODIR/carre-10-bdry-v2 $GEODIR/carre-bamg-q-dom-v2 >/dev/null 2>/dev/null"
-if test $? -ne 0; then status=1; fi
+  loop_mpirun "./field_reinterpolate_tst $GEODIR/carre-10-bdry-v2 $GEODIR/carre-bamg-q-dom-v2 1e-7 -$method >/dev/null 2>/dev/null"
+  if test $? -ne 0; then status=1; fi
 
-loop_mpirun "./field_reinterpolate_tst $GEODIR/cube-5-bdry-v2.geo $GEODIR/cube-H-6-dom-v2.geo >/dev/null 2>/dev/null"
-if test $? -ne 0; then status=1; fi
+  loop_mpirun "./field_reinterpolate_tst $GEODIR/cube-5-bdry-v2.geo $GEODIR/cube-H-6-dom-v2.geo 1e-7 -$method > /dev/null 2>/dev/null"
+  if test $? -ne 0; then status=1; fi
 
-# TODO: nearest with distributed memory and 3D case:
-run "./field_reinterpolate_tst $GEODIR/circle_p1-v2.geo $GEODIR/circle-10-fix-P1.geo 0.006 >/dev/null 2>/dev/null"
-if test $? -ne 0; then status=1; fi
+  # TODO: nearest with distributed memory and 3D case:
+  run "./field_reinterpolate_tst $GEODIR/circle_p1-v2.geo $GEODIR/circle-10-fix-P1.geo 0.006 >/dev/null 2>/dev/null"
+  if test $? -ne 0; then status=1; fi
+done
 
 exit $status
