@@ -19,22 +19,17 @@
 ///
 /// =========================================================================
 #include "rheolef.h"
-#include "rheolef/test.h"
-#include "rheolef/field_vf_assembly.h"
-#include "rheolef/field_vf_expr.h"
-#include "rheolef/field_vf_expr_ops.h"
-// ----------------------------------------------------------------------
 using namespace rheolef;
 using namespace std;
-struct f1 : field_functor<f1,Float> {
+struct f1 {
   Float operator() (const point& x) const { return sqrt(fabs(x[0])); }
 };
-struct f2 : field_functor<f2,point> {
+struct f2 {
   f2(size_t d) : _v() { _v[d-1] = -1; }
   point operator() (const point& x) const { return _v; }
   point _v;
 };
-struct rotation : field_functor<rotation,point> {
+struct rotation {
   rotation(size_t d1) : d(d1) {}
   point operator() (const point& x) const {
     // return (d==1) ? point(x[0]) : point(x[1], -x[0]); } // BUG
@@ -101,12 +96,18 @@ int main(int argc, char**argv) {
   size_t nproc = comm.size();
   bool tst_charact
    = ( d == 1 ||
-      (d == 2 && Xh.degree() <= 2 && omega.sizes().ownership_by_variant[reference_element::q].dis_size() == 0) ||
+      (d == 2 && Xh.degree() <= 2 && omega.sizes().ownership_by_variant[reference_element::q].dis_size() == 0));
+
+#ifdef TODO
+  // TODO: when d==3: characteristic method calls now nearest that is not implemented in 3D
+  // => fatal(../../../rheolef/nfem/plib/geo_nearest.cc,323): unsupported dimension d=3
       (d == 3 && Xh.degree() <= 1 && nproc == 1 &&
 	  omega.sizes().ownership_by_variant[reference_element::P].dis_size() == 0 &&
 	  omega.sizes().ownership_by_variant[reference_element::H].dis_size() == 0));
+#endif //
+  warning_macro ("tst_charact="<<tst_charact);
 
-#if (__GNUC__ == 4) && (__GNUC_MINOR__ == 7) // TODO_GXX48
+#if (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 7) // TODO_GXX48
   if (tst_charact) {
     // scalar-valued convected field
     field uh = interpolate (Xvh, f2(d));
@@ -116,7 +117,7 @@ int main(int argc, char**argv) {
     quadrature_option_type qloba;
     qloba.set_family(quadrature_option_type::gauss_lobatto);
     qloba.set_order(Xh.degree());
-    field l4h_old = riesz (Xh, compose(phi_h, X), qloba);
+    field l4h_old = riesz (Xh, compose(phi_h, X),   qloba);
     field l4h_new = integrate (compose(phi_h, X)*v, qloba);
 #ifdef TO_CLEAN
     derr << "l4h(old)="<<l4h_old;
