@@ -1,15 +1,10 @@
 #include "rheolef.h"
+
 using namespace std;
 using namespace rheolef;
-struct f : field_functor<f,Float> {
+struct f {
   Float operator() (const point& x) const { return x[0]; }
 };
-template <class Expr>
-field_nonlinear_expr<Expr>
-make_expr (const Expr& e) {
-  typedef field_nonlinear_expr<Expr> type;
-  return type(e);
-}
 int main (int argc, char **argv){
   environment rheolef(argc,argv);
   geo omega (argv[1]);
@@ -44,12 +39,7 @@ int main (int argc, char **argv){
   Float Nu = 0.5;
   Float Ra = 0.5;
   Float alpha = 0;
-  field tmp1 = id_top+2*alpha;
-  form m3_top = integrate ("top", u*v*(Nu + Ra*(tmp1*(id_top+alpha))));
-#ifdef TODO
-  // TODO: compile pb with boost::proto 1.54 & field_expr (linear) when expanding tmp1 as:
   form m3_top = integrate ("top", u*v*(Nu + Ra*(id_top+2*alpha)*(sqr(id_top+alpha) + sqr(alpha))));
-#endif // TODO
   field mr3b = m3_top*one;
   field e3h = mr1a - mr3b;
   Float err3 = e3h.max_abs();
