@@ -45,7 +45,7 @@ using namespace std;
 struct my_inv : unary_function<Float,Float> {
   Float operator() (const Float& z) const { return 1/z; }
 };
-struct inv_weight : field_functor<inv_weight,Float> {
+struct inv_weight {
   Float operator() (const point& x) const {
     switch(d) {
       case 1:  return sqrt(x[0]*(1-x[0]));
