@@ -29,7 +29,7 @@ void put (const geo_basic<Float,sequential>& omega, size_t order, bool check_tet
   point center(0,0);
   Float radius = 1;
   bool have_quad = false;
-  array<point,sequential> node = omega.get_nodes();
+  disarray<point,sequential> node = omega.get_nodes();
   std::cout << std::setprecision(7)
             << "set xrange ["<<omega.xmin()[0]<<":"<<omega.xmax()[0]<<"]" << std::endl
             << "set yrange ["<<omega.xmin()[1]<<":"<<omega.xmax()[1]<<"]" << std::endl
