@@ -18,17 +18,19 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ///
 /// =========================================================================
+// load a mesh and reprint it
+// if input domains are formated in version=1, upgrade it in version=2
 # include "rheolef/geo.h"
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv)
 {
-    environment distributed(argc, argv);
+    environment rheolef(argc, argv);
     geo_basic<Float,sequential> omega;
     if (argc > 1) {
       omega.load (argv[1]);
     } else {
-      dcin >> omega;
+      din >> omega;
     }
-    dcout << omega;
+    dout << omega;
 }
