@@ -29,7 +29,7 @@ struct my_norm2_fun : unary_function<point,Float> {
 // --------------------------------------------------------------------
 // vector test
 // --------------------------------------------------------------------
-struct vf2 : field_functor<vf2,point> {
+struct vf2 {
   point operator() (const point& x) const { return point(x[0],x[1]); }
 };
 // --------------------------------------------------------------------
