@@ -19,9 +19,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
-NPROC_MAX=${NPROC_MAX-"7"}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
+NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 if test x"${QD_EXT}" != x""; then
@@ -44,8 +44,10 @@ my_cube_TPH-5-v2
 "
 for geo in $L; do
  for Pk in P1 P2 P3; do
-  loop_mpirun "./interpolate_dom2_tst ${SRCDIR}/$geo.geo $Pk left 1e-8 2>/dev/null | diff $SRCDIR/interpolate_dom2-$geo-$Pk.field - >/dev/null"
-  if test $? -ne 0; then status=1; fi
+   for method in function expression; do
+     loop_mpirun "./interpolate_dom2_tst ${SRCDIR}/$geo.geo $Pk left 1e-8 -$method 2>/dev/null | diff $SRCDIR/interpolate_dom2-$geo-$Pk.field - >/dev/null"
+     if test $? -ne 0; then status=1; fi
+   done
  done
 done
 
