@@ -19,7 +19,6 @@
 ///
 /// =========================================================================
 #include "rheolef.h"
-#include "rheolef/rounder.h"
 using namespace rheolef;
 using namespace std;
 size_t N;
@@ -31,5 +30,5 @@ int main(int argc, char**argv) {
   Float prec = (argc > 3) ? atof(argv[3]) : 1e-10;
   N = omega.dimension();
   field fh = interpolate(Vh, f);
-  dout << field(compose(rounder(prec),fh));
+  dout << round (fh, prec);
 }
