@@ -59,6 +59,7 @@ typ_val(Float,"s")
 typ_val(point,"v")
 typ_val(tensor,"t")
 typ_val(tensor3,"t3")
+typ_val(tensor4,"t4")
 typ_val(undeterminated_basic<Float>,"U")
 typ_val(details::plus,"+")
 typ_val(details::minus,"-")
@@ -166,18 +167,27 @@ void show_deduce() {
   show_result<Op,Float,point>(); 
   show_result<Op,Float,tensor>(); 
   show_result<Op,Float,tensor3>(); 
+  show_result<Op,Float,tensor4>(); 
   show_result<Op,point,Float>(); 
   show_result<Op,point,point>(); 
   show_result<Op,point,tensor>(); 
   show_result<Op,point,tensor3>(); 
+  show_result<Op,point,tensor4>(); 
   show_result<Op,tensor,Float>(); 
   show_result<Op,tensor,point>(); 
   show_result<Op,tensor,tensor>(); 
   show_result<Op,tensor,tensor3>(); 
+  show_result<Op,tensor,tensor4>(); 
   show_result<Op,tensor3,Float>(); 
   show_result<Op,tensor3,point>(); 
   show_result<Op,tensor3,tensor>(); 
   show_result<Op,tensor3,tensor3>(); 
+  show_result<Op,tensor3,tensor4>(); 
+  show_result<Op,tensor4,Float>(); 
+  show_result<Op,tensor4,point>(); 
+  show_result<Op,tensor4,tensor>(); 
+  show_result<Op,tensor4,tensor3>(); 
+  show_result<Op,tensor4,tensor4>(); 
   dout << endl;
 
   // 2) deduction du 1er arg quand on connait le 2nd et le resultat
@@ -185,18 +195,27 @@ void show_deduce() {
   show_arg1<Op,Float,point>(); 
   show_arg1<Op,Float,tensor>(); 
   show_arg1<Op,Float,tensor3>(); 
+  show_arg1<Op,Float,tensor4>(); 
   show_arg1<Op,point,Float>(); 
   show_arg1<Op,point,point>(); 
   show_arg1<Op,point,tensor>(); 
   show_arg1<Op,point,tensor3>(); 
+  show_arg1<Op,point,tensor4>(); 
   show_arg1<Op,tensor,Float>(); 
   show_arg1<Op,tensor,point>(); 
   show_arg1<Op,tensor,tensor>(); 
   show_arg1<Op,tensor,tensor3>(); 
+  show_arg1<Op,tensor,tensor4>(); 
   show_arg1<Op,tensor3,Float>(); 
   show_arg1<Op,tensor3,point>(); 
   show_arg1<Op,tensor3,tensor>(); 
   show_arg1<Op,tensor3,tensor3>(); 
+  show_arg1<Op,tensor3,tensor4>(); 
+  show_arg1<Op,tensor4,Float>(); 
+  show_arg1<Op,tensor4,point>(); 
+  show_arg1<Op,tensor4,tensor>(); 
+  show_arg1<Op,tensor4,tensor3>(); 
+  show_arg1<Op,tensor4,tensor4>(); 
   dout << endl;
 
   // 3) deduction du 2nd arg quand on connait le 1er et le resultat
@@ -204,18 +223,27 @@ void show_deduce() {
   show_arg2<Op,Float,point>(); 
   show_arg2<Op,Float,tensor>(); 
   show_arg2<Op,Float,tensor3>(); 
+  show_arg2<Op,Float,tensor4>(); 
   show_arg2<Op,point,Float>(); 
   show_arg2<Op,point,point>(); 
   show_arg2<Op,point,tensor>(); 
   show_arg2<Op,point,tensor3>(); 
+  show_arg2<Op,point,tensor4>(); 
   show_arg2<Op,tensor,Float>(); 
   show_arg2<Op,tensor,point>(); 
   show_arg2<Op,tensor,tensor>();
   show_arg2<Op,tensor,tensor3>();
+  show_arg2<Op,tensor,tensor4>();
   show_arg2<Op,tensor3,Float>(); 
   show_arg2<Op,tensor3,point>(); 
   show_arg2<Op,tensor3,tensor>();
   show_arg2<Op,tensor3,tensor3>();
+  show_arg2<Op,tensor3,tensor4>();
+  show_arg2<Op,tensor4,Float>(); 
+  show_arg2<Op,tensor4,point>(); 
+  show_arg2<Op,tensor4,tensor>();
+  show_arg2<Op,tensor4,tensor3>();
+  show_arg2<Op,tensor4,tensor4>();
   dout << endl;
 
   // 4) deduction de a1 & a2 quand on connait le resultat
@@ -223,6 +251,7 @@ void show_deduce() {
   show_from_result<Op,point>(); 
   show_from_result<Op,tensor>(); 
   show_from_result<Op,tensor3>(); 
+  show_from_result<Op,tensor4>(); 
   dout << endl;
 
   // 5) deduction de a2 & r quand on connait a1
@@ -230,6 +259,7 @@ void show_deduce() {
   show_from_arg1<Op,point>(); 
   show_from_arg1<Op,tensor>(); 
   show_from_arg1<Op,tensor3>(); 
+  show_from_arg1<Op,tensor4>(); 
   dout << endl;
 
   // 6) deduction de a1 & r quand on connait a2
@@ -237,6 +267,7 @@ void show_deduce() {
   show_from_arg2<Op,point>(); 
   show_from_arg2<Op,tensor>(); 
   show_from_arg2<Op,tensor3>(); 
+  show_from_arg2<Op,tensor4>(); 
   dout << endl;
 
   // 7) deduction de a1, a2 & r quand ne connait rien
