@@ -19,9 +19,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
-NPROC_MAX=${NPROC_MAX-"8"}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
+NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}
