@@ -19,9 +19,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
-NPROC_MAX=${NPROC_MAX-"7"}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
+NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
@@ -32,6 +32,7 @@ space_constitution_io_vector.valid
 space_constitution_io_mixed.valid
 space_constitution_io_complex.valid
 "
+export RHEOPATH=".:${SRCDIR}"
 for x in $L; do
   loop_mpirun "./space_constitution_io_tst < ${SRCDIR}/$x 2>/dev/null | diff -Bw $SRCDIR/$x - >/dev/null"
   if test $? -ne 0; then status=1; fi
