@@ -19,13 +19,12 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
+TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+. "${TOP_SRCDIR}/config/loop_mpirun.sh"
+
 status=0
-echo "    ./gauss_lobatto_chebyschev_tst ..."
 for R in 1 2 3 4 5 6 7 8; do
-    #echo "    ./gauss_lobatto_chebyschev_tst $R"
-    ./gauss_lobatto_chebyschev_tst $R >/dev/null 2>/dev/null
-    if test $? -ne 0; then echo "      *NO*"; status=1; fi
+    run "./gauss_lobatto_chebyschev_tst $R >/dev/null 2>/dev/null"
+    if test $? -ne 0; then status=1; fi
 done
 exit $status
-
-
