@@ -29,9 +29,14 @@
 using namespace rheolef;
 using namespace std;
 int main (int argc, char **argv) {
-        size_t R     = argc > 1 ? atoi(argv[1]) : 5;
-        Float  alpha = argc > 2 ? atof(argv[2]) : 0;
-        Float  beta  = argc > 3 ? Float(atof(argv[3])) : alpha;
+#ifdef _RHEOLEF_HAVE_QD
+        unsigned int oldcw;
+        fpu_fix_start(&oldcw);
+#endif // _RHEOLEF_HAVE_QD
+        size_t R    = argc > 1 ? atoi(argv[1]) : 5;
+        Float alpha = argc > 2 ? atof(argv[2]) : 0;
+        Float beta  = argc > 3 ? Float(atof(argv[3])) : alpha;
+        Float tol   = argc > 4 ? Float(atof(argv[4])) : sqrt(numeric_limits<Float>::epsilon());
 	vector<Float> zeta (R);
 	jacobi_roots (R, alpha, beta, zeta.begin());
 	cout << setprecision (numeric_limits<Float>::digits10)
@@ -46,7 +51,9 @@ int main (int argc, char **argv) {
 	    cout << r << "\t" << zeta[r] << endl;
 	    err = std::max (err, fabs(P(zeta[r])));
         }
-	Float tol = 1e-7;
 	if (err >= tol) cerr << "err = " << err << endl;
+#ifdef _RHEOLEF_HAVE_QD
+        fpu_fix_end(&oldcw);
+#endif // _RHEOLEF_HAVE_QD
         return err < tol ? 0 : 1;
 }
