@@ -18,7 +18,7 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ///
 /// =========================================================================
-# include <rheolef/compiler.h>
+# include "rheolef/compiler.h"
 using namespace rheolef;
 using namespace std;
 // 
@@ -72,6 +72,10 @@ int main (int argc, char**argv)
     // machine-dependent precision
     int digits10 = numeric_limits<Float>::digits10;
     cout << setprecision(digits10);
+#ifdef _RHEOLEF_HAVE_QD
+    unsigned int oldcw;
+    fpu_fix_start(&oldcw);
+#endif // _RHEOLEF_HAVE_QD
 
     // default triangle
     int type = TRI;
@@ -181,7 +185,7 @@ int main (int argc, char**argv)
     // geometry
     for( i= 0 ; i <= nx ; i++ )
       for( j= 0 ; j <= ny ; j++ )
-	cout << (B-A)*i/Float(nx)+A << " " << (D-C)*j/Float(ny)+C << "\n" ;
+	cout << Float((B-A)*i)/Float(nx)+A << " " << Float((D-C)*j)/Float(ny)+C << "\n" ;
     cout << "\n" ;
 
     // connectivity
@@ -279,5 +283,7 @@ int main (int argc, char**argv)
                  << "\ndomain\nleft_top\n1 0 1\n"     << no(0, ny) << endl
 		 << endl;
     }
-    return 0;
+#ifdef _RHEOLEF_HAVE_QD
+  fpu_fix_end(&oldcw);
+#endif // _RHEOLEF_HAVE_QD
 }
