@@ -23,7 +23,11 @@ SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}
 
 status=0
 
-command="../bin/mkgeo_grid_3d 20 > box-20.geo"
+echo "      obsolete (skipping)"
+exit 0
+
+
+command="../sbin/mkgeo_grid_3d 20 > box-20.geo"
 echo "      $command"
 eval        $command
 
