@@ -130,7 +130,7 @@ csr<T>::csr (const asr<T>& b)
 #if !defined(_RHEOLEF_HAVE_SPOOLES) && !defined(_RHEOLEF_HAVE_TAUCS) && !defined(_RHEOLEF_HAVE_UMFPACK)
 template<class T>
 csrrep<T>::csrrep (const ssk<T>& b)
-: occurence(), IA(b.nrow()+1), JA(0), A(0), NCOL(b.ncol())
+: IA(b.nrow()+1), JA(0), A(0), NCOL(b.ncol())
 {
     typename csr<T>::size_type nnzsky, _nnz;
 
