@@ -20,7 +20,7 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 /// 
 /// =========================================================================
-#include "rheolef/array.h"
+#include "rheolef/disarray.h"
 #include "rheolef/pair_set.h"
 #include "rheolef/diststream.h"
 // -------------------------------------------------------------
@@ -37,7 +37,7 @@ SYNOPSYS:
   Associative sparse matrix container, used during FEM assembling process.
 IMPLEMENTATION NOTE:
   Elements are stored row by row using the pair_set class bqsed on the STL map class.
-  Implementation of asr uses array<pair_set>
+  Implementation of asr uses disarray<pair_set>
 AUTHORS:
     LMC-IMAG, 38041 Grenoble cedex 9, France
    | Pierre.Saramito@imag.fr
@@ -46,12 +46,12 @@ End:
 */
 //<verbatim:
 template<class T, class M = rheo_default_memory_model, class A = std::allocator<T> >
-class asr : public array<pair_set<T,A>, M, A> {
+class asr : public disarray<pair_set<T,A>, M, A> {
 public:
 // typedefs:
 
     typedef pair_set<T,A>          	     row_type;
-    typedef array<row_type,M,A>              base;
+    typedef disarray<row_type,M,A>           base;
     typedef typename base::size_type         size_type;
     typedef M                                memory_type;
 
