@@ -27,8 +27,6 @@
 #include "rheolef/scatter_message.h"
 #include "rheolef/pair_util.h"
 
-#include <boost/bind.hpp>
-
 namespace rheolef {
 
 // -------------------------------------------------------------
@@ -56,7 +54,7 @@ public:
     csr_rep (const csr_rep<T,sequential>& a);
     template<class A> void build_from_asr (const asr<T,sequential,A>& a);
     template<class A> explicit csr_rep    (const asr<T,sequential,A>& a);
-    template<class A> void build_from_diag (const array_rep<T,sequential,A>& d);
+    template<class A> void build_from_diag (const disarray_rep<T,sequential,A>& d);
 
     const distributor& row_ownership() const { return _row_ownership; }
     const distributor& col_ownership() const { return _col_ownership; }
@@ -156,7 +154,7 @@ public:
     template<class A> explicit csr_rep (const asr<T,distributed,A>& a);
     template<class A> void build_from_asr  (const asr<T,distributed,A>& a);
     void resize (const distributor& row_ownership, const distributor& col_ownership, size_type nnz1 = 0);
-    template<class A> void build_from_diag (const array_rep<T,distributed,A>& d);
+    template<class A> void build_from_diag (const disarray_rep<T,distributed,A>& d);
 
     const distributor& row_ownership() const { return base::_row_ownership; }
     const distributor& col_ownership() const { return base::_col_ownership; }
