@@ -209,10 +209,11 @@ csr_concat_line<T,M>::build_csr_pass1 (
 template <class T, class M>
 void
 csr_concat_line<T,M>::build_csr_pass2 (
-    asr<T,M>&                       a,
-    const std::vector<distributor>& col_start_by_component,
-    size_type                       row_start_comp_i,
-    size_type                       row_start_comp_dis_i) const
+    asr<T,M>&                                            a,
+    const std::vector<std::pair<size_type,size_type> >&  col_sizes,
+    const std::vector<distributor>&                      col_start_by_component,
+    size_type                                            row_start_comp_i,
+    size_type                                            row_start_comp_dis_i) const
 {
   communicator comm = a.row_ownership().comm();
   size_type first_dis_i = a.row_ownership().first_index();
@@ -221,7 +222,9 @@ csr_concat_line<T,M>::build_csr_pass2 (
   size_type last_proc = comm.size() - 1;
   size_type col_start_comp_dis_j = 0;
   size_type j_comp = 0;
+  trace_macro ("j_comp loop...");
   for (typename std::list<value_type>::const_iterator iter = _l.begin(); iter != _l.end(); ++iter, j_comp++) {
+    trace_macro ("j_comp="<<j_comp<<" starts...");
     const value_type& x = *iter;
     switch (x.variant) {
       case value_type::matrix: {
@@ -233,7 +236,7 @@ csr_concat_line<T,M>::build_csr_pass2 (
           for (typename csr<T,M>::const_data_iterator p = dia_ia[i]; p < dia_ia[i+1]; p++) {
             size_type j = (*p).first;
             size_type dis_j = first_dis_j + col_start_comp_j + j;
-	    a.dis_entry (dis_i, dis_j) = (*p).second;
+	    a.dis_entry (dis_i, dis_j) += (*p).second;
           }
 	  if (is_distributed<M>::value && x.m.ext_nnz() != 0) {
             for (typename csr<T,M>::const_data_iterator p = ext_ia[i]; p < ext_ia[i+1]; p++) {
@@ -245,10 +248,11 @@ csr_concat_line<T,M>::build_csr_pass2 (
               size_type col_start_comp_j_iproc = col_start_by_component[j_comp].size(iproc);
               size_type first_dis_j_iproc      = a.col_ownership().first_index(iproc);
               size_type dis_j = first_dis_j_iproc + col_start_comp_j_iproc + j;
-	      a.dis_entry (dis_i, dis_j) = (*p).second;
+	      a.dis_entry (dis_i, dis_j) += (*p).second;
             }
           }
         }
+        trace_macro ("jcomp="<<j_comp<<": matrix: cols=["<<col_start_comp_dis_j<<":"<<col_start_comp_dis_j+x.m.col_ownership().dis_size()<<"[");
         col_start_comp_dis_j += x.m.col_ownership().dis_size();
         break;
       } 
@@ -258,10 +262,11 @@ csr_concat_line<T,M>::build_csr_pass2 (
           size_type dis_i = row_start_comp_dis_i + i;
           size_type dis_j = col_start_comp_dis_j + x.vv[i].ownership().first_index();
           for (typename vec<T,M>::const_iterator iter = x.vv[i].begin(), last = x.vv[i].end(); iter != last; iter++, dis_j++) {
-	    if (*iter != 0) a.dis_entry (dis_i, dis_j) = *iter;
+	    if (*iter != 0) a.dis_entry (dis_i, dis_j) += *iter;
           }
         }
         if (x.vv.size() > 0) {
+          trace_macro ("jcomp="<<j_comp<<": vector_vec: cols=["<<col_start_comp_dis_j<<":"<<col_start_comp_dis_j+x.vv[0].ownership().dis_size()<<"[");
           col_start_comp_dis_j += x.vv[0].ownership().dis_size();
         }
         break;
@@ -271,8 +276,9 @@ csr_concat_line<T,M>::build_csr_pass2 (
         for (size_type j = 0, n = x.vv.size(); j < n; j++) {
           size_type dis_i = row_start_comp_i       + first_dis_i;
           size_type dis_j = col_start_comp_dis_j;
+          trace_macro ("jcomp="<<j_comp<<": vector_vec_trans: cols=["<<col_start_comp_dis_j<<":"<<col_start_comp_dis_j+x.vv.size()<<"[");
           for (typename vec<T,M>::const_iterator iter = x.vv[j].begin(), last = x.vv[j].end(); iter != last; iter++, dis_i++) {
-	    if (*iter != 0) a.dis_entry (dis_i, dis_j) = *iter;
+	    if (*iter != 0) a.dis_entry (dis_i, dis_j) += *iter;
           }
           col_start_comp_dis_j++;
         }
@@ -283,7 +289,7 @@ csr_concat_line<T,M>::build_csr_pass2 (
         size_type dis_i = row_start_comp_i       + first_dis_i;
         size_type dis_j = col_start_comp_dis_j;
         for (typename vec<T,M>::const_iterator iter = x.v.begin(), last = x.v.end(); iter != last; iter++, dis_i++) {
-	  if (*iter != 0) a.dis_entry (dis_i, dis_j) = *iter;
+	  if (*iter != 0) a.dis_entry (dis_i, dis_j) += *iter;
         }
         col_start_comp_dis_j++;
         break;
@@ -293,7 +299,7 @@ csr_concat_line<T,M>::build_csr_pass2 (
         size_type dis_i = row_start_comp_dis_i + 0;
         size_type dis_j = col_start_comp_dis_j + x.v.ownership().first_index();
         for (typename vec<T,M>::const_iterator iter = x.v.begin(), last = x.v.end(); iter != last; iter++, dis_j++) {
-	  if (*iter != 0) a.dis_entry (dis_i, dis_j) = *iter;
+	  if (*iter != 0) a.dis_entry (dis_i, dis_j) += *iter;
         }
         col_start_comp_dis_j += x.v.ownership().dis_size();
         break;
@@ -302,13 +308,16 @@ csr_concat_line<T,M>::build_csr_pass2 (
         if (x.s != 0 && comm.rank() == comm.size() - 1) { 
           size_type dis_i = row_start_comp_dis_i + 0;
           size_type dis_j = col_start_comp_dis_j;
-	  a.dis_entry (dis_i, dis_j) = x.s;
+	  a.dis_entry (dis_i, dis_j) += x.s;
         }
-        col_start_comp_dis_j++;
+        trace_macro ("jcomp="<<j_comp<<": scalar: cols=["<<col_start_comp_dis_j<<":"<<col_start_comp_dis_j+1<<"[");
+        col_start_comp_dis_j += col_sizes[j_comp].second;
         break;
       }
     }
+    trace_macro ("j_comp="<<j_comp<<" done");
   }
+  trace_macro ("j_comp loop done");
 }
 // ------------------------------
 // merge passes 1 & 2
@@ -329,7 +338,7 @@ csr_concat_line<T,M>::build_csr() const
   std::vector<distributor> col_start_by_component;
   build_csr_pass1 (row_sizes, col_sizes, comm, row_ownership, col_ownership, col_start_by_component);
   asr<T,M> a (row_ownership, col_ownership);
-  build_csr_pass2 (a, col_start_by_component);
+  build_csr_pass2 (a, col_sizes, col_start_by_component);
   a.dis_entry_assembly();
   return csr<T,M>(a);
 }
@@ -385,7 +394,7 @@ csr_concat<T,M>::build_csr() const
   i_comp = 0;
   for (typename std::list<line_type>::const_iterator iter = _l.begin(); iter != _l.end(); ++iter, ++i_comp) {
     const line_type& line = *iter;
-    line.build_csr_pass2 (a, col_start_by_component, row_start_comp_i, row_start_comp_dis_i);
+    line.build_csr_pass2 (a, col_sizes, col_start_by_component, row_start_comp_i, row_start_comp_dis_i);
     row_start_comp_i     += row_sizes[i_comp].first;
     row_start_comp_dis_i += row_sizes[i_comp].second;
   }
