@@ -55,7 +55,8 @@ trans (const std::vector<vec<T,M> >& w) {
 }
  
 template <class T, class M>
-struct csr_concat_value {
+class csr_concat_value {
+public:
 // typedef:
  typedef enum { scalar, vector, vector_transpose, vector_vec, vector_vec_transpose, matrix} variant_type;
 // allocators:
@@ -80,7 +81,8 @@ public:
 };
 
 template <class T, class M>
-struct csr_concat_line {
+class csr_concat_line {
+public:
 // typedef:
  typedef typename csr<T,M>::size_type   size_type;
  typedef csr_concat_value<T,M>          value_type;
@@ -176,7 +178,8 @@ RHEOLEF_csr_cstor(distributed)
 //        {trans(u), 3.2} };
 // =========================================================================
 template <class T, class M>
-struct csr_concat {
+class csr_concat {
+public:
 // typedef:
  typedef typename csr<T,M>::size_type   size_type;
  typedef csr_concat_line<T,M>           line_type;
