@@ -23,10 +23,9 @@
 #ifdef _RHEOLEF_HAVE_MPI
 #include "rheolef/dis_macros.h"
 #include "rheolef/csr.h"
-
-#include "rheolef/asr_to_csr_dist_logical.h"
-#include "rheolef/csr_to_asr.h"
 #include "rheolef/asr_to_csr.h"
+#include "rheolef/asr_to_csr_dist_logical.h"
+
 #include "rheolef/csr_amux.h"
 #include "rheolef/csr_cumul_trans_mult.h"
 #include "rheolef/mpi_scatter_init.h"
@@ -64,25 +63,29 @@ struct op_dis_j2jext_t : unary_function<Pair1,Pair2> {
 	RandomIterator t1, t2;
 };
 // ----------------------------------------------------------------------------
-// member class functions
+// allocators
 // ----------------------------------------------------------------------------
 template<class T>
-csr_mpi_rep<T>::csr_mpi_rep()
-  : csr_seq_rep<T>(),
+csr_rep<T,distributed>::csr_rep()
+  : base(),
     _ext(),
     _jext2dis_j(0),
     _dis_nnz(0),
+    _dis_ext_nnz(0),
+    _scatter_initialized(false),
     _from(),
     _to(),
     _buffer()
 {
 }
 template<class T>
-csr_mpi_rep<T>::csr_mpi_rep(const csr_mpi_rep<T>& a)
-  : csr_seq_rep<T>(a),
+csr_rep<T,distributed>::csr_rep(const csr_rep<T,distributed>& a)
+  : base(a),
     _ext(a._ext),
     _jext2dis_j(a._jext2dis_j),
     _dis_nnz(a._dis_nnz),
+    _dis_ext_nnz(a._dis_ext_nnz),
+    _scatter_initialized(a._scatter_initialized),
     _from(a._from),
     _to(a._to),
     _buffer(a._buffer)
@@ -91,33 +94,22 @@ csr_mpi_rep<T>::csr_mpi_rep(const csr_mpi_rep<T>& a)
 }
 template<class T>
 void
-csr_mpi_rep<T>::resize (const distributor& row_ownership, const distributor& col_ownership, size_type nnz1)
+csr_rep<T,distributed>::resize (const distributor& row_ownership, const distributor& col_ownership, size_type nnz1)
 {
-  csr_seq_rep<T>::resize (row_ownership, col_ownership, nnz1);
-  _ext.resize            (row_ownership, col_ownership, 0); // note: the _ext part will be resized elsewhere
-}
-template<class T>
-csr_mpi_rep<T>::csr_mpi_rep(const asr_mpi_rep<T>& a)
-  : csr_seq_rep<T>(),
-    _ext (),
-    _jext2dis_j(),
-    _dis_nnz(),
-    _from(),
-    _to(),
-    _buffer()
-{
-    build_from_asr (a);
+  base::resize (row_ownership, col_ownership, nnz1);
+  _ext.resize  (row_ownership, col_ownership, 0); // note: the _ext part will be resized elsewhere
+  _scatter_initialized = false;
 }
 template<class T>
+template<class A>
 void
-csr_mpi_rep<T>::build_from_asr (const asr_mpi_rep<T>& a)
+csr_rep<T,distributed>::build_from_asr (const asr<T,distributed,A>& a)
 {
-    csr_seq_rep<T>::resize (a.row_ownership(), a.col_ownership(), 0);
+    base::resize (a.row_ownership(), a.col_ownership(), 0);
     _ext.resize            (a.row_ownership(), a.col_ownership(), 0);
-    _dis_nnz = a.dis_nnz();
 
     distributor::tag_type tag = distributor::get_new_tag();
-    typedef typename asr_mpi_rep<T>::row_type row_type;
+    typedef typename asr<T>::row_type row_type;
     typedef typename row_type::value_type      const_pair_type; 
     typedef pair<size_type,T>                  pair_type; 
     is_dia_t<size_type, const_pair_type> 
@@ -135,11 +127,10 @@ csr_mpi_rep<T>::build_from_asr (const asr_mpi_rep<T>& a)
     size_type nnzdia = a.nnz() - nnzext;
     size_type ncoldia = col_ownership().size();
     size_type ncolext = colext.size();
-    csr_seq_rep<T>::resize(a.row_ownership(), a.col_ownership(), nnzdia);
+    base::resize(a.row_ownership(), a.col_ownership(), nnzdia);
     _ext.resize           (a.row_ownership(), a.col_ownership(), nnzext);
     _jext2dis_j.resize (ncolext);
     copy (colext.begin(), colext.end(), _jext2dis_j.begin());
-    _buffer.resize(ncolext);
     //
     // step 3: copy values
     //   column indexes of a   in 0..dis_ncol
@@ -152,8 +143,8 @@ csr_mpi_rep<T>::build_from_asr (const asr_mpi_rep<T>& a)
         a.end(), 
         is_dia, 
         op_dia,
-	csr_seq_rep<T>::begin(), 
-	csr_seq_rep<T>::_data.begin());
+	base::begin(), 
+	base::_data.begin());
 
     // step 3.b: copy ext part
     unary_negate<is_dia_t<size_type, const_pair_type> > 
@@ -163,11 +154,26 @@ csr_mpi_rep<T>::build_from_asr (const asr_mpi_rep<T>& a)
     asr_to_csr (
         a.begin(), a.end(), is_ext, op_dis_j2jext,
 	_ext.begin(), _ext._data.begin());
-    //
-    // step 3. messages building for A*x
-    //
-    vector<size_type> id(_jext2dis_j.size());
-    for (size_type i = 0; i < id.size(); i++) id[i] = i;
+
+    // compute _dis_nnz:
+    _dis_nnz = a.dis_nnz();
+    _dis_ext_nnz = mpi::all_reduce (comm(), _ext.nnz(), std::plus<size_type>());
+    _scatter_initialized = false;
+#ifdef TO_CLEAN
+    _dis_nnz = mpi::all_reduce (comm(), nnz() + _ext.nnz(), std::plus<size_type>());
+    check_macro (_dis_nnz == a.dis_nnz(), "build_from_asr: mistake: asr::dis_nnz="<<a.dis_nnz()
+		<< " while _dis_nnz="<<_dis_nnz);
+#endif // TO_CLEAN
+}
+// messages building for A*x and trans(A)*x
+template<class T>
+void
+csr_rep<T,distributed>::_scatter_init() const
+{
+    vector<size_type> id (_jext2dis_j.size());
+    for (size_type i = 0, n = id.size(); i < n; i++) id[i] = i;
+
+    distributor::tag_type tag = distributor::get_new_tag();
 
     mpi_scatter_init(
         _jext2dis_j.size(),
@@ -180,60 +186,32 @@ csr_mpi_rep<T>::build_from_asr (const asr_mpi_rep<T>& a)
 	row_ownership().comm(),
         _from,
         _to);
+
+    _buffer.resize(_jext2dis_j.size());
 }
-template<class T>
-void
-csr_mpi_rep<T>::to_asr(asr_mpi_rep<T>& b) const
-{
-    typedef pair<size_type,T>                              pair_type; 
-    typedef typename asr_mpi_rep<T>::row_type::value_type const_pair_type;
-    op_dia_t<pair_type,const_pair_type> op_dia(col_ownership().first_index());
-    typename vector_of_iterator<pair_type>::const_iterator b1 = csr_seq_rep<T>::begin();
-    typename vector_of_iterator<pair_type>::const_iterator e1 = csr_seq_rep<T>::end();
-    const pair_type*  d1 = csr_seq_rep<T>::_data.begin().operator->();
-    csr_to_asr (
-        b1,
-        e1,
-        d1,
-        op_dia,
-        b.begin().operator->());
-    op_ext2glob_t <pair_type, const_pair_type, typename vector<size_type>::const_iterator> 
-	op_ext2glob(_jext2dis_j.begin());
-    csr_to_asr (
-         _ext.begin(),
-         _ext.begin() + _ext.size(),
-         _ext._data.begin().operator->(),
-         op_ext2glob,
-         b.begin().operator->());
-}
-template<class T>
-idiststream& 
-csr_mpi_rep<T>::get (idiststream& ips)
-{
-    asr_mpi_rep<Float> a;
-    a.get (ips);
-    build_from_asr (a);
-    return ips;
-}
+// ----------------------------------------------------------------------------
+// io
+// ----------------------------------------------------------------------------
 template<class T>
 odiststream& 
-csr_mpi_rep<T>::put (odiststream& ops) const
+csr_rep<T,distributed>::put (odiststream& ops) const
 {
     // put all on io_proc 
     size_type io_proc = odiststream::io_proc();
     size_type my_proc = comm().rank();
     distributor a_row_ownership (dis_nrow(), comm(), (my_proc == io_proc ? dis_nrow() : 0));
     distributor a_col_ownership (dis_ncol(), comm(), (my_proc == io_proc ? dis_ncol() : 0));
-    asr_mpi_rep<T> a (a_row_ownership, a_col_ownership);
-    size_type i0 = row_ownership().first_index();
-    size_type j0 = col_ownership().first_index();
+    typedef std::allocator<T> A; // TODO: use heap_alloc for asr
+    asr<T,distributed,A> a (a_row_ownership, a_col_ownership);
+    size_type first_dis_i = row_ownership().first_index();
+    size_type first_dis_j = col_ownership().first_index();
     if (nnz() != 0) {
       const_iterator ia = begin(); 
       for (size_type i = 0; i < nrow(); i++) {
         for (const_data_iterator p = ia[i]; p < ia[i+1]; p++) {
 	  const size_type& j   = (*p).first;
 	  const T&         val = (*p).second;
-          a.dis_entry (i+i0, j+j0) = val;
+          a.dis_entry (i+first_dis_i, j+first_dis_j) += val;
         }
       }
     }
@@ -243,20 +221,19 @@ csr_mpi_rep<T>::put (odiststream& ops) const
         for (const_data_iterator p = ext_ia[i]; p < ext_ia[i+1]; p++) {
 	  const size_type& j   = (*p).first;
 	  const T&         val = (*p).second;
-          a.dis_entry (i+i0, _jext2dis_j[j]) = val;
+          a.dis_entry (i+first_dis_i, _jext2dis_j[j]) += val;
         }
       }
     }
-    a.dis_entry_assembly_begin();
-    a.dis_entry_assembly_end();
+    a.dis_entry_assembly();
     if (my_proc == io_proc) {
-      a.asr_seq_rep<T>::put (ops);
+      a.put_seq (ops);
     }
     return ops;
 }
 template<class T>
 void
-csr_mpi_rep<T>::dump (const string& name) const
+csr_rep<T,distributed>::dump (const string& name) const
 {
     odiststream ops;
     std::string filename = name + itos(comm().rank());
@@ -267,11 +244,11 @@ csr_mpi_rep<T>::dump (const string& name) const
     put(ops);
 }
 // ----------------------------------------------------------------------------
-// basic linear algebra
+// blas2: basic linear algebra
 // ----------------------------------------------------------------------------
 template<class T>
 void
-csr_mpi_rep<T>::mult(
+csr_rep<T,distributed>::mult(
     const vec<T,distributed>& x,
     vec<T,distributed>&       y)
     const
@@ -281,6 +258,9 @@ csr_mpi_rep<T>::mult(
 
     distributor::tag_type tag = distributor::get_new_tag();
 
+    // initialize _from and _to scatter messages
+    _scatter_init_guard(); 
+
     // send x to others
     mpi_scatter_begin (
 	x.begin().operator->(),
@@ -293,8 +273,8 @@ csr_mpi_rep<T>::mult(
 
     // y := dia*x
     csr_amux (
-        csr_seq_rep<T>::begin(), 
-        csr_seq_rep<T>::end(), 
+        base::begin(), 
+        base::end(), 
         x.begin(), 
         set_op<T,T>(), 
         y.begin());
@@ -314,19 +294,23 @@ csr_mpi_rep<T>::mult(
 }
 template<class T>
 void
-csr_mpi_rep<T>::trans_mult(
+csr_rep<T,distributed>::trans_mult(
     const vec<T,distributed>& x,
     vec<T,distributed>&       y)
     const
 {
     check_macro (x.size() == nrow(), "csr.trans_mult(vec): incompatible csr("<<nrow()<<","<<ncol()<<") and vec("<<x.size()<<")");
+
+    // initialize _from and _to scatter messages
+    _scatter_init_guard(); 
+
     y.resize (col_ownership());
 
     // y = dia*x
     std::fill (y.begin(), y.end(), T(0));
     csr_cumul_trans_mult (
-        csr_seq_rep<T>::begin(), 
-        csr_seq_rep<T>::end(), 
+        base::begin(), 
+        base::end(), 
         x.begin(), 
         set_add_op<T,T>(),
         y.begin());
@@ -361,11 +345,14 @@ csr_mpi_rep<T>::trans_mult(
 	tag, 
 	col_ownership().comm());
 }
+// ----------------------------------------------------------------------------
+// blas3: basic linear algebra
+// ----------------------------------------------------------------------------
 template<class T>
-csr_mpi_rep<T>&
-csr_mpi_rep<T>::operator*= (const T& lambda)
+csr_rep<T,distributed>&
+csr_rep<T,distributed>::operator*= (const T& lambda)
 {
-  csr_seq_rep<T>::operator*= (lambda);
+  base::operator*= (lambda);
   _ext.operator*= (lambda);
   return *this;
 }
@@ -378,16 +365,16 @@ csr_mpi_rep<T>::operator*= (const T& lambda)
 template<class T, class BinaryOp>
 void
 csr_ext_add (
-    const csr_seq_rep<T>& a, const std::vector<typename csr<T>::size_type>& jext_a2dis_j,
-    const csr_seq_rep<T>& b, const std::vector<typename csr<T>::size_type>& jext_b2dis_j,
-          csr_seq_rep<T>& c,       std::vector<typename csr<T>::size_type>& jext_c2dis_j,
+    const csr_rep<T,sequential>& a, const std::vector<typename csr<T>::size_type>& jext_a2dis_j,
+    const csr_rep<T,sequential>& b, const std::vector<typename csr<T>::size_type>& jext_b2dis_j,
+          csr_rep<T,sequential>& c,       std::vector<typename csr<T>::size_type>& jext_c2dis_j,
     BinaryOp binop)
 {
-    typedef typename csr_mpi_rep<T>::size_type size_type;
-    typedef typename csr_mpi_rep<T>::iterator iterator;
-    typedef typename csr_mpi_rep<T>::const_iterator const_iterator;
-    typedef typename csr_mpi_rep<T>::data_iterator data_iterator;
-    typedef typename csr_mpi_rep<T>::const_data_iterator const_data_iterator;
+    typedef typename csr_rep<T,distributed>::size_type size_type;
+    typedef typename csr_rep<T,distributed>::iterator iterator;
+    typedef typename csr_rep<T,distributed>::const_iterator const_iterator;
+    typedef typename csr_rep<T,distributed>::data_iterator data_iterator;
+    typedef typename csr_rep<T,distributed>::const_data_iterator const_data_iterator;
     typedef std::pair<size_type,T>             pair_type; 
     //
     // first pass: compute nnz_c and resize
@@ -441,10 +428,10 @@ csr_ext_add (
 		iter_jva++;
 		iter_jvb++;
 	    } else if (dis_ja < dis_jb) {
-		*iter_jvc++ = op_dis_j2jext_c (pair_type(dis_ja, (*iter_jva).second));
+		*iter_jvc++ = op_dis_j2jext_c (pair_type(dis_ja, binop((*iter_jva).second, T(0))));
 		iter_jva++;
             } else {
-		*iter_jvc++ = op_dis_j2jext_c (pair_type(dis_jb, (*iter_jvb).second));
+		*iter_jvc++ = op_dis_j2jext_c (pair_type(dis_jb, binop(T(0),(*iter_jvb).second)));
 		iter_jvb++;
             }
   	}
@@ -454,9 +441,9 @@ csr_ext_add (
 template<class T>
 template<class BinaryOp>
 void
-csr_mpi_rep<T>::assign_add (
-    const csr_mpi_rep<T>& a, 
-    const csr_mpi_rep<T>& b,
+csr_rep<T,distributed>::assign_add (
+    const csr_rep<T,distributed>& a, 
+    const csr_rep<T,distributed>& b,
     BinaryOp binop)
 {
     check_macro (a.dis_nrow() == b.dis_nrow() && a.dis_ncol() == b.dis_ncol(),
@@ -467,8 +454,7 @@ csr_mpi_rep<T>::assign_add (
 	<<b.nrow()<<","<<b.ncol()<<")");
 
     // 1) the diagonal part:
-    csr_seq_rep<T>::assign_add (a, b, binop);
-    _dis_nnz = mpi::all_reduce (comm(), nnz(), std::plus<size_type>());
+    base::assign_add (a, b, binop);
 
     // 2) the extra-diagonal part:
     csr_ext_add (
@@ -477,8 +463,11 @@ csr_mpi_rep<T>::assign_add (
           _ext,   _jext2dis_j,
         binop);
 
-    _dis_nnz += mpi::all_reduce (comm(), _ext.nnz(), std::plus<size_type>());
+    _dis_nnz     = mpi::all_reduce (comm(), nnz() + _ext.nnz(), std::plus<size_type>());
+    _dis_ext_nnz = mpi::all_reduce (comm(),         _ext.nnz(), std::plus<size_type>());
+    _scatter_initialized = false;
 
+#ifdef TO_CLEAN
     // 3) scatter init for a*x :
     vector<size_type> id(_jext2dis_j.size());
     for (size_type i = 0; i < id.size(); i++) id[i] = i;
@@ -496,18 +485,19 @@ csr_mpi_rep<T>::assign_add (
 	row_ownership().comm(),
         _from,
         _to);
+#endif // TO_CLEAN
 }
 // ----------------------------------------------------------------------------
 // trans(a)
 // ----------------------------------------------------------------------------
 template<class T>
 void
-csr_mpi_rep<T>::build_transpose (csr_mpi_rep<T>& b) const
+csr_rep<T,distributed>::build_transpose (csr_rep<T,distributed>& b) const
 {
   //
   // first: assembly all _ext parts of the a matrix in b=trans(a)
   //
-  asr_mpi_rep<T> b_ext (col_ownership(), row_ownership());
+  asr<T> b_ext (col_ownership(), row_ownership());
   size_type first_i = row_ownership().first_index();
   const_iterator ext_ia = ext_begin();
   for (size_type i = 0, n = nrow(); i < n; i++) {
@@ -515,28 +505,202 @@ csr_mpi_rep<T>::build_transpose (csr_mpi_rep<T>& b) const
     for (const_data_iterator p = ext_ia[i], last_p = ext_ia[i+1]; p < last_p; p++) {
       size_type dis_j = jext2dis_j ((*p).first);
       const T& val    = (*p).second;
-      b_ext.dis_entry (dis_j, dis_i) = val;
+      b_ext.dis_entry (dis_j, dis_i) += val;
     }
   }
-  b_ext.dis_entry_assembly_begin();
-  b_ext.dis_entry_assembly_end();
+  b_ext.dis_entry_assembly();
   b.build_from_asr (b_ext);
   //
   // second: add all _diag parts
   //
-  csr_seq_rep<T>::build_transpose (b);
+  base::build_transpose (b);
   //
   // third: update dis_nnz by adding all diag nnz
   //
-  b._dis_nnz += mpi::all_reduce (comm(), csr_seq_rep<T>::nnz(), std::plus<size_type>());
+  b._dis_nnz     = mpi::all_reduce (comm(), b.nnz() + b._ext.nnz(), std::plus<size_type>());
+  b._dis_ext_nnz = mpi::all_reduce (comm(),           b._ext.nnz(), std::plus<size_type>());
+  b._scatter_initialized = false;
+}
+// ----------------------------------------------------------------------------
+// set symmetry by check
+// ----------------------------------------------------------------------------
+template<class T>
+void
+csr_rep<T,distributed>::set_symmetry_by_check (const T& tol) const
+{
+  if (dis_nrow() != dis_ncol()) {
+    set_symmetry(false);
+    return;
+  }
+  // check if |a-trans(a)| == 0 up to machine prec
+  csr_rep<T,distributed> at, d;
+  build_transpose (at);
+  d.assign_add (*this, at, std::minus<T>());
+  set_symmetry (d.max_abs() <= tol);
+}
+// ----------------------------------------------------------------------------
+// expression c=a*b with a temporary c=*this
+// ----------------------------------------------------------------------------
+template<class T>
+void
+csr_rep<T,distributed>::assign_mult (
+    const csr_rep<T,distributed>& a, 
+    const csr_rep<T,distributed>& b)
+{
+  // TODO: distributed csr*csr could be simplified
+  // TODO: when a._jext2dis_j.size()==0 on all procs: no comms needed
+  // TODO: and the sequential algo could be used
+  check_macro (a.col_ownership() == b.row_ownership(),
+	"incompatible csr([0:"<<a.nrow()<<"|"<<a.dis_nrow()<<"[x"
+	               <<"[0:"<<a.ncol()<<"|"<<a.dis_ncol()<<"[)"
+	            "*csr([0:"<<b.nrow()<<"|"<<b.dis_nrow()<<"[x"
+	               <<"[0:"<<b.ncol()<<"|"<<b.dis_ncol()<<"[)");
+  //
+  // 1) compress a non-empty column indexes numbering: creates a_zip_j numbering
+  //
+  size_type a_dia_ncol = a.col_ownership().size();
+  size_type a_ext_ncol = a._jext2dis_j.size();  // number of external columns; compressed
+  size_type first_a_dis_j = a.col_ownership().first_index();
+  std::map<size_type,size_type> a_dis_j2a_zip_j;
+  size_type a_zip_j = 0;
+  for (size_type jext = 0; jext < a_ext_ncol && a._jext2dis_j [jext] < first_a_dis_j; jext++, a_zip_j++) { 
+    // row < local row index
+    size_type dis_j = a._jext2dis_j [jext];
+    a_dis_j2a_zip_j [dis_j] = a_zip_j;
+  }
+  size_type jext_up = a_zip_j;
+  for (size_type j = 0; j < a_dia_ncol; j++, a_zip_j++) {
+    // local rows
+    size_type dis_j = first_a_dis_j + j;
+    a_dis_j2a_zip_j [dis_j] = a_zip_j;
+  }
+  for (size_type jext = jext_up; jext < a_ext_ncol; jext++, a_zip_j++) {
+    // row > local row index
+    size_type dis_j = a._jext2dis_j [jext];
+    a_dis_j2a_zip_j [dis_j] = a_zip_j;
+  }
+  size_type a_zip_ncol = a_dia_ncol + a_ext_ncol;
+  //
+  // 2) create a seq matrix B_seq = submatrix of B by taking rows of B that equal to nonzero col of A
+  //    requiers comms
+  //
+  typedef std::allocator<T> A; // TODO: use heap_alloc for asr
+  A alloc;
+  // 2.1) convert b in asr distributed format
+  asr<T,distributed,A> b_asr (b, alloc);
+  // 2.2) make available all external columns that are used in a
+  b_asr.set_dis_indexes (a._jext2dis_j);
+  // 2.3) convert local part of b_asr into b_asr_zip
+  distributor a_zip_col_ownership (distributor::decide, b.comm(), a_zip_ncol);
+  distributor b_zip_row_ownership = a_zip_col_ownership;
+  asr<T,sequential,A> b_asr_zip (b_zip_row_ownership, b.col_ownership());
+  size_type first_dis_j = b.row_ownership().first_index();
+  size_type j = 0;
+  for (typename asr<T,distributed,A>::const_iterator
+          iter = b_asr.begin(),
+          last = b_asr.end(); iter != last; ++iter, ++j) {
+    typedef typename asr<T,distributed,A>::row_type row_type;
+    size_type       dis_j = first_dis_j + j;
+    size_type       zip_j = a_dis_j2a_zip_j [dis_j];
+    const row_type& row   = *iter;
+    for (typename row_type::const_iterator
+            row_iter = row.begin(),
+            row_last = row.end(); row_iter != row_last; ++row_iter) {
+      size_type dis_k = (*row_iter).first;
+      const T&  value = (*row_iter).second;
+      b_asr_zip.semi_dis_entry (zip_j, dis_k) = value;
+    }
+  }
+  // 2.4) convert external part of b_asr into b_asr_zip
+  typedef typename asr<T,distributed,A>::scatter_map_type ext_row_type;
+  const ext_row_type& b_ext_row_map = b_asr.get_dis_map_entries();
+  for (typename ext_row_type::const_iterator
+          iter = b_ext_row_map.begin(),
+          last = b_ext_row_map.end(); iter != last; ++iter) {
+    typedef typename asr<T,distributed,A>::row_type row_type;
+    size_type       dis_j = (*iter).first;
+    size_type       zip_j = a_dis_j2a_zip_j [dis_j];
+    const row_type& row   = (*iter).second;
+    for (typename row_type::const_iterator
+            row_iter = row.begin(),
+            row_last = row.end(); row_iter != row_last; ++row_iter) {
+      size_type dis_k = (*row_iter).first;
+      const T&  value = (*row_iter).second;
+      b_asr_zip.semi_dis_entry (zip_j, dis_k) = value;
+    }
+  }
+  b_asr_zip.dis_entry_assembly(); // recount nnz
+  // 2.5) convert b_asr_zip into csr: b_zip
+  csr<T,sequential> b_zip (b_asr_zip);
+  //
+  // 3) create a seq matrix a_zip = submatrix of A by compressing all local cols of A
+  //    no comms requiered: a_zip := zip(a_dia, a_ext)
+  //
+  // 3.1) assembly a local asr matrix
+  asr<T,sequential> a_asr_zip (a.row_ownership(), a_zip_col_ownership);
+  size_type first_dis_i = a.row_ownership().first_index();
+  const_iterator dia_ia = a.begin();
+  const_iterator ext_ia = a.ext_begin(); 
+  for (size_type i = 0, n = a.nrow(); i < n; ++i) {
+    size_type dis_i = first_dis_i + i;
+    for (const_data_iterator p = dia_ia[i], last_p = dia_ia[i+1]; p != last_p; ++p) {
+      size_type j     = (*p).first;
+      const T&  value = (*p).second;
+      size_type dis_j = first_dis_j + j;
+      size_type zip_j = a_dis_j2a_zip_j [dis_j];
+      a_asr_zip.semi_dis_entry (i, zip_j) += value;
+    }
+    if (a.ext_nnz() == 0) continue;
+    for (const_data_iterator p = ext_ia[i], last_p = ext_ia[i+1]; p != last_p; ++p) {
+      size_type jext  = (*p).first;
+      const T&  value = (*p).second;
+      size_type dis_j = a._jext2dis_j [jext];
+      size_type zip_j = a_dis_j2a_zip_j [dis_j];
+      a_asr_zip.semi_dis_entry (i, zip_j) += value;
+    }
+  }
+  a_asr_zip.dis_entry_assembly();
+  // 3.2) convert to sequential csr
+  csr<T,sequential> a_zip (a_asr_zip);
+  //
+  // 4) compute the product sequentially (no comms requiered)
+  //
+  csr<T,sequential> c_zip = a_zip*b_zip;
+  //
+  // 5) create mpi matrix C by concatenating C_tmp on all procs
+  //    no comms requiered: C = (C_dia,C_ext) = dispatch(C_tmp)
+  // 5.1) assembly in distributed asr
+  asr<T,distributed> c_asr_zip (a.row_ownership(), b.col_ownership());
+  const_iterator ic = c_zip.begin();
+  for (size_type i = 0, n = c_zip.nrow(); i < n; ++i) {
+    size_type dis_i = first_dis_i + i;
+    for (const_data_iterator p = ic[i], last_p = ic[i+1]; p != last_p; ++p) {
+      size_type dis_k = (*p).first;
+      const T&  value = (*p).second;
+      c_asr_zip.semi_dis_entry (i, dis_k) += value;
+    }
+  }
+  c_asr_zip.dis_entry_assembly();
+  // 5.2) copy c_zip intro c_asr_zip
+  build_from_asr (c_asr_zip);
 }
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
-template class csr_mpi_rep<Float>;
-template void csr_mpi_rep<Float>::assign_add (
-	const csr_mpi_rep<Float>&, const csr_mpi_rep<Float>&, std::plus<Float>);
-template void csr_mpi_rep<Float>::assign_add (
-	const csr_mpi_rep<Float>&, const csr_mpi_rep<Float>&, std::minus<Float>);
+#define _RHEOLEF_istanciate(T) 							\
+template class csr_rep<T,distributed>;							\
+template void csr_rep<T,distributed>::assign_add (					\
+	const csr_rep<T,distributed>&,							\
+        const csr_rep<T,distributed>&, 							\
+              std::plus<T>);							\
+template void csr_rep<T,distributed>::assign_add (					\
+	const csr_rep<T,distributed>&,							\
+        const csr_rep<T,distributed>&,							\
+              std::minus<T>);							\
+template void csr_rep<T,distributed>::build_from_asr (const asr<T,distributed,std::allocator<T> >&); \
+template void csr_rep<T,distributed>::build_from_asr (const asr<T,distributed,heap_allocator<T> >&);
+
+_RHEOLEF_istanciate(Float)
+
 } // namespace rheolef
 # endif // _RHEOLEF_HAVE_MPI
