@@ -39,17 +39,17 @@ SYNOPSIS:
 EXAMPLE:
    A sample usage writes:
    @example
-     # include "rheolef/array.h"
+     # include "rheolef/disarray.h"
      # include "rheolef/dis_accumulate.h"
      int main(int argc, char**argv) {
          environment distributed (argc, argv);
          unsigned int n = 100;
-         array<double> x(n, 2.0);
+         disarray<double> x(n, 2.0);
          double sum = dis_accumulate(x.begin(),x.size(),x.comm());
          dout << "dot(x,1) = " << sum << endl;
      }
    @end example
-SEE ALSO: "array"(1)
+SEE ALSO: "disarray"(1)
 AUTHORS:
     LMC-IMAG, 38041 Grenoble cedex 9, France
    | Pierre.Saramito@imag.fr
