@@ -41,12 +41,12 @@ SYNOPSIS:
 EXAMPLE:
    A sample usage writes:
    @example
-     # include "rheolef/array.h"
+     # include "rheolef/disarray.h"
      # include "rheolef/dis_inner_product.h"
      int main(int argc, char**argv) {
           environment distributed(argc, argv);
          unsigned int n = 100;
-         array<double> x(n, 2.0);
+         disarray<double> x(n, 2.0);
          double norme2_x = dis_inner_product(x.begin(),x.begin(),x.size(),x.comm());
          dout << "dot(x,x) = " << norme2_x << endl;
      }
@@ -57,7 +57,7 @@ IMPLEMENTATION NOTE:
    expression template approach generates iterators as expression
    tree and a comparison like "first1 != last1" becomes complex and
    requires a recursive inspection.
-SEE ALSO: "array"(1)
+SEE ALSO: "disarray"(1)
 AUTHORS:
     LMC-IMAG, 38041 Grenoble cedex 9, France
    | Pierre.Saramito@imag.fr
