@@ -243,8 +243,11 @@ inline bool odiststream::nop() { return size_type(_comm.rank()) != io_proc(); }
 template <class T>
 inline
 odiststream&
-operator << (odiststream& s, T x) {
-    if (s.nop()) return s; s.os() << x; return s;
+operator << (odiststream& s, T x)
+{
+    if (s.nop()) return s;
+    s.os() << x;
+    return s;
 }
 define_sequential_odiststream_macro(char)
 define_sequential_odiststream_macro(int)
