@@ -25,7 +25,7 @@
 
 namespace rheolef {
 
-environment::environment (int& argc, char**& argv)
+environment::environment (int& argc, char**& argv, const environment_option_type& opt)
  : _oldcw(0)
 {
 #ifdef _RHEOLEF_HAVE_QD
@@ -63,44 +63,41 @@ bool environment::finalized() {
   MPI_Finalized(&flag);
   return flag != 0;
 }
-environment::environment (int& argc, char**& argv)
- : _has_init(false), _oldcw(0)
+environment::environment (int& argc, char**& argv, const environment_option_type& opt)
+ : _rheolef_has_init(false), _oldcw(0)
 {
-#ifdef _RHEOLEF_HAVE_QD
-  fpu_fix_start(&_oldcw);
-#endif // _RHEOLEF_HAVE_QD
   if (!initialized()) {
-// TODO: when openmpi do not use threads: could be tested at configure time
-#undef  _RHEOLEF_DO_NOT_USE_THREADS
-#ifdef  _RHEOLEF_DO_NOT_USE_THREADS
-    warning_macro ("mpi_init: thread not allowed");
-    int status = MPI_Init(&argc, &argv);
-#else // !_RHEOLEF_DO_NOT_USE_THREADS
-    int thread_level_inq = MPI_THREAD_SINGLE; // Only one thread will execute.
-    // int thread_level_inq = MPI_THREAD_MULTIPLE; // when scotch has thread support
-    int thread_level;
-    trace_macro ("thread_level_inq="<<thread_level_inq<<"...");
-    int status = MPI_Init_thread(&argc, &argv, thread_level_inq, &thread_level);
-    trace_macro ("thread_level="<<thread_level <<", thread_level_inq="<<thread_level_inq);
-#ifdef TO_CLEAN
-    trace_macro (provided >= MPI_THREAD_MULTIPLE, "MPI implementation is not thread-safe"); // with openmpi at least
-#endif // TO_CLEAN
-#endif // _RHEOLEF_DO_NOT_USE_THREADS
+    int status = 0;
+    if (opt.thread_level == environment_option_type::no_thread) {
+      status = MPI_Init (&argc, &argv);
+    } else {
+      int obtained_thread_level;
+      status = MPI_Init_thread (&argc, &argv, opt.thread_level, &obtained_thread_level);
+      if (obtained_thread_level != opt.thread_level) {
+        warning_macro ("mpi_init: obtained thread level="<<obtained_thread_level <<" while asking for thread level="<<opt.thread_level);
+      }
+    }
     check_macro (status == MPI_SUCCESS, "mpi init failed");
-    _has_init = true;
   }
+  if (!_rheolef_has_init) {
+#ifdef _RHEOLEF_HAVE_QD
+    fpu_fix_start(&_oldcw);
+#endif // _RHEOLEF_HAVE_QD
+
 #ifdef _RHEOLEF_HAVE_OBSOLETE_MPI_V1
-  MPI_Errhandler_set   (MPI_COMM_WORLD, MPI_ERRORS_RETURN);
+    MPI_Errhandler_set      (MPI_COMM_WORLD, MPI_ERRORS_RETURN);
 #else
-  MPI_Comm_set_errhandler (MPI_COMM_WORLD, MPI_ERRORS_RETURN);
+    MPI_Comm_set_errhandler (MPI_COMM_WORLD, MPI_ERRORS_RETURN);
 #endif
+    _rheolef_has_init = true;
+  }
 }
 environment::~environment()
 {
 #ifdef _RHEOLEF_HAVE_QD
   fpu_fix_end(&_oldcw);
 #endif // _RHEOLEF_HAVE_QD
-  if (_has_init && !finalized()) {
+  if (_rheolef_has_init && !finalized()) {
     boost::mpi::detail::mpi_datatype_cache().clear();
     MPI_Finalize();
   }
