@@ -28,11 +28,49 @@
 #include "rheolef/distributed.h"
 #include <boost/optional.hpp>
 
+/*Class:environment
+NAME:  @code{environment} - rheolef initialization (@PACKAGE@-@VERSION@)
+SYNOPSYS:
+  This class is mainly used to initialize the MPI library: it
+  should be called juste after the @code{main(argc,argv)} declaration
+  as in:
+  @example
+    #include "rheolef.h"
+    using namespace rheolef;
+    int main(int argc, char**argv) @{
+      environment rheolef (argc, argv);
+      ...
+    @}
+  @end example
+  An optional third argument of the @code{environment} constructor
+  allows to set the MPI thread feature. By default, its value
+  is MPI_THREAD_SINGLE, as defined in @code{mpi.h}.
+  Other possible values are related to MPI multi-threaded, see
+  the MPI documentation for more details.
+
+AUTHORS: Pierre.Saramito@imag.fr
+DATE:   29 september 2015
+End:
+*/
+
 namespace rheolef {
+
+struct environment_option_type {
+  static const int no_thread = 100;
+#ifdef _RHEOLEF_HAVE_MPI
+  static const int default_thread = MPI_THREAD_SINGLE;
+#else // _RHEOLEF_HAVE_MPI
+  static const int default_thread = 0;
+#endif // _RHEOLEF_HAVE_MPI
+  environment_option_type() : thread_level (default_thread) {}
+  int thread_level ;
+};
+
 #ifndef _RHEOLEF_HAVE_MPI
+
 class environment {
 public:
-  environment (int& argc, char**& argv);
+  environment (int& argc, char**& argv, const environment_option_type& opt = environment_option_type());
   ~environment();
 protected:
   unsigned int _oldcw;
@@ -40,7 +78,7 @@ protected:
 #else
 class environment {
 public:
-  explicit environment (int& argc, char**& argv);
+  explicit environment (int& argc, char**& argv, const environment_option_type& opt = environment_option_type());
   ~environment();
   static bool initialized();
   static bool finalized();
@@ -51,8 +89,8 @@ public:
   static boost::optional<int> io_rank();
   static std::string processor_name();
 private:
-  bool _has_init;
-  unsigned int _oldcw;
+  bool             _rheolef_has_init;
+  unsigned int     _oldcw;
   static const int _num_reserved_tags = 1;
 };
 #endif // _RHEOLEF_HAVE_MPI
