@@ -22,9 +22,9 @@
 /// =========================================================================
 // wrapper for std::set<size_t>: union as a+b and a += b and others goodies
 //
-// motivation: this class is usefull for array<index_set,M> to send/receive variable-sized
+// motivation: this class is usefull for disarray<index_set,M> to send/receive variable-sized
 // lists via MPI correctly
-// array<index_set,M> is used by the geo class to manage connectivity
+// disarray<index_set,M> is used by the geo class to manage connectivity
 // and compute neighbours
 //
 // author: Pierre.Saramito@imag.fr
@@ -35,9 +35,9 @@
 #include "rheolef/pretty_name.h"
 #include "rheolef/container_traits.h"
 
+#ifdef _RHEOLEF_HAVE_MPI
 #include <boost/serialization/set.hpp>
 #include <boost/serialization/base_object.hpp>
-#ifdef _RHEOLEF_HAVE_MPI
 #endif // _RHEOLEF_HAVE_MPI
 
 namespace rheolef {
@@ -47,8 +47,8 @@ NAME:  index_set - a set of indexes (@PACKAGE@-@VERSION@)
 SYNOPSYS:       
     A class for: l = @{1,3,...9@} i.e. a wrapper for STL @code{set<size_t>} with 
     some assignment operators, such as l1 += l2.
-    This class is suitable for use with the @code{array<T>} class, as @code{array<index_set>}
-    (@pxref{array class}).
+    This class is suitable for use with the @code{disarray<T>} class, as @code{disarray<index_set>}
+    (@pxref{disarray class}).
 AUTHOR: Pierre.Saramito@imag.fr
 DATE: date: 23 march 2011
 End:
@@ -93,27 +93,29 @@ public:
 
 // boost mpi:
 
+#ifdef _RHEOLEF_HAVE_MPI
   template <class Archive>
   void serialize (Archive& ar, const unsigned int version);
+#endif // _RHEOLEF_HAVE_MPI
 };
 //>verbatim:
 
-// operator += for array::assembly
+// operator += for disarray::assembly
 template <class T>
 struct index_set_add_op : std::binary_function<T,T,T> {
     T& operator()(T& x, const T&                      y) const { return x += y; }
     T& operator()(T& x, const typename T::value_type& y) const { return x += y; }
 };
-// for boost mpi and array<index_set>:
+// for boost mpi and disarray<index_set>:
 template <> struct default_set_op<index_set> {
   typedef index_set_add_op<index_set> type;
 };
-template <> struct is_container<index_set> : boost::mpl::true_ {
-  typedef boost::mpl::true_ type;
+template <> struct is_container<index_set> : std::true_type {
+  typedef std::true_type type;
 };
 #ifdef _RHEOLEF_HAVE_MPI
-template <> struct is_container_of_mpi_datatype<index_set> : boost::mpl::true_ {
-  typedef boost::mpl::true_ type;
+template <> struct is_container_of_mpi_datatype<index_set> : std::true_type {
+  typedef std::true_type type;
 };
 #endif // _RHEOLEF_HAVE_MPI
 // -------------------------------------------------------------------
@@ -153,14 +155,14 @@ index_set::operator+= (size_type dis_i)
   base::insert (dis_i);
   return *this;
 }
+#ifdef _RHEOLEF_HAVE_MPI
 template <class Archive>
 void
 index_set::serialize (Archive& ar, const unsigned int version)
 {
   ar & boost::serialization::base_object<base>(*this);
-#ifdef _RHEOLEF_HAVE_MPI
-#endif // _RHEOLEF_HAVE_MPI
 }
+#endif // _RHEOLEF_HAVE_MPI
 
 } // namespace rheolef
 #endif // _RHEOLEF_INDEX_SET_H
