@@ -42,44 +42,25 @@ DATE:   23 march 1999
 END:
 */
 
-
-template <
-    class InputIterator, 
-    class OutputIterator, 
-    class SetOp, 
-    class Container,
-    class Tag,
-    class Comm>
-void
-mpi_scatter_end(
-    InputIterator            		x,
-    OutputIterator           		y,
-    scatter_message<Container>& 	from,
-    scatter_message<Container>& 	to,
-    SetOp		     		op,
-    Tag                      		tag,
-    Comm                     		comm)
-{
-    error_macro ("undefined scatter for " << typename_macro(Container));
-}
 //<mpi_scatter_end:
 template <
     class InputIterator, 
     class OutputIterator, 
+    class Message,
     class SetOp, 
-    class T,
     class Tag,
     class Comm>
 void
 mpi_scatter_end(
     InputIterator            		x,
     OutputIterator           		y,
-    scatter_message<std::vector<T> >& 	from,
-    scatter_message<std::vector<T> >& 	to,
+    Message&			 	from,
+    Message&			 	to,
     SetOp		     		op,
     Tag                      		tag,
     Comm                     		comm)
 {
+    typedef typename Message::base_value_type data_type; // the data type to be received by mpi
     typedef boost::transform_iterator<select2nd<size_t,mpi::request>, std::list<std::pair<size_t,mpi::request> >::iterator>
             request_iterator;
 
@@ -87,7 +68,6 @@ mpi_scatter_end(
     // 1) wait on receives and unpack receives into local space
     // -----------------------------------------------------------
     while (from.requests.size() != 0) {
-	typedef T data_type; // the data to be received are of type T
         request_iterator iter_r_waits (from.requests.begin(), select2nd<size_t,mpi::request>()),
                          last_r_waits (from.requests.end(),   select2nd<size_t,mpi::request>());
 	// waits on any receive...
@@ -101,16 +81,10 @@ mpi_scatter_end(
 	size_t i_msg_size = (size_t)i_msg_size_opt.get();
         std::list<std::pair<size_t,mpi::request> >::iterator i_pair_ptr = pair_status.second.base();
         size_t i_receive = (*i_pair_ptr).first;
-	check_macro (i_msg_size == from.starts[i_receive+1] - from.starts[i_receive], "unexpected size");
+	check_macro (i_msg_size == from.starts()[i_receive+1] - from.starts()[i_receive], "unexpected size");
 
         // unpack receives into our local space
-        msg_left_permutation_apply (
-            from.values.begin()  + from.starts[i_receive],
-            op,
-            from.indices.begin() + from.starts[i_receive],
-            from.indices.begin() + from.starts[i_receive+1],
-            y);
-
+	from.store_values (y, i_receive, op);
         from.requests.erase (i_pair_ptr);
     }
     // -----------------------------------------------------------
