@@ -219,9 +219,9 @@ mpi_scatter_init (
     std::vector<size_type> perm(receive_nproc);
     copy(index_iterator<size_type>(), index_iterator<size_type>(receive_nproc), perm.begin());
     sort_with_permutation (
-        receive_nproc,
         receive_proc.begin().operator->(),
-        perm.begin().operator->());
+        perm.begin().operator->(),
+        receive_nproc);
     // ---------------------------------------------------------------------------
     // 11) Computes the receive compresed message pattern for send(to)
     // ---------------------------------------------------------------------------
