@@ -21,7 +21,7 @@
 /// 
 /// =========================================================================
 
-#include "rheolef/vec_expr.h"
+#include "rheolef/vec_expr_v2.h"
 
 namespace rheolef {
 
