@@ -190,7 +190,7 @@ pgmres (const Matrix &A, Vector &x, const Vector &b, const Preconditioner &M,
     norm_b = 1;
   } 
   residue = norm(r);
-  if (residue  <= tol*max(1.,norm_b)) {
+  if (residue  <= tol*max(Real(1.),norm_b)) {
     tol = residue/norm_b;
     max_iter = 0;
     return 0;
@@ -216,7 +216,7 @@ pgmres (const Matrix &A, Vector &x, const Vector &b, const Preconditioner &M,
       ApplyPlaneRotation(s(i), s(i+1), cs(i), sn(i));
       residue = abs(s(i+1));
       if (p_derr) (*p_derr) << "[" << label << "] " << j << " " << residue/norm_b << std::endl;
-      if (residue  < tol*max(1.,norm_b)) {
+      if (residue  < tol*max(Real(1.),norm_b)) {
         Update(x, i, H, s, v);
         tol = residue/norm_b;
         max_iter = j;
@@ -229,7 +229,7 @@ pgmres (const Matrix &A, Vector &x, const Vector &b, const Preconditioner &M,
     beta = norm(r);
     residue = beta;
     if (p_derr) (*p_derr) << "[" << label << "] " << j << " " << residue/norm_b << std::endl;
-    if (residue < tol*max(1.,norm_b)) {
+    if (residue < tol*max(Real(1.),norm_b)) {
       tol = residue/norm_b;
       max_iter = j;
       delete [] v;
