@@ -96,7 +96,8 @@ int pminres(const Matrix &A, Vector &x, const Vector &Mb, const Preconditioner &
   Vector z = M.solve(Mr);
   Real beta2 = dot(Mr, z);
   Real norm_r = sqrt(fabs(beta2));
-  if (p_derr) (*p_derr) << "[" << label << "] #iteration residue" << std::endl;
+  if (p_derr) (*p_derr) << "[" << label << "] # norm_b=" <<norm_b<< std::endl;
+  if (p_derr) (*p_derr) << "[" << label << "] #iteration residue/norm_b" << std::endl;
   if (p_derr) (*p_derr) << "[" << label << "] 0 " << norm_r/norm_b << std::endl;
   if (beta2 < 0 || norm_r <= tol*norm_b) {
     tol = norm_r/norm_b;
@@ -158,7 +159,7 @@ int pminres(const Matrix &A, Vector &x, const Vector &Mb, const Preconditioner &
     // check residue
     norm_r *= s;
     if (p_derr) (*p_derr) << "[" << label << "] " << n << " " << norm_r/norm_b << std::endl;
-    if (norm_r <= tol*norm_b) {
+    if (norm_r <= tol*max(1.0,norm_b)) {
       tol = norm_r/norm_b;
       max_iter = n;
       return 0;
