@@ -23,8 +23,7 @@
 
 // include all for convenience
 #include "rheolef/vec.h"
-#include "rheolef/vec_expr.h"
-#include "rheolef/vec_expr_ops.h"
+#include "rheolef/vec_expr_v2.h"
 #include "rheolef/vec_concat.h"
 #include "rheolef/vec_range.h"
 #include "rheolef/csr.h"
