@@ -102,12 +102,21 @@ solver_rep<T,M>::build_lu (const csr<T,M>& a, const solver_option_type& opt)
   //bool prefer_umfpack = opt.force_seq || (a.dis_ext_nnz() == 0); // when diagonal per process
   bool prefer_cholmod = false; // prefer mumps that seems faster than cholmod, even in seq case
   bool prefer_umfpack = opt.force_seq // idem, but when building schur complement, mumps is still buggy
-                      || ((a.dis_ext_nnz() == 0) && opt.prefered_library == "umfpack"); // explicitely prefer (more robust on ill-conditioned systems)
-#else  // _RHEOLEF_HAVE_MUMPS
+                      || ((a.dis_ext_nnz() == 0) && 
+			  (opt.prefered_library == "umfpack"	
+# if !(defined( _RHEOLEF_HAVE_MUMPS_WITH_METIS) || \
+       defined( _RHEOLEF_HAVE_MUMPS_WITH_PARMETIS) || \
+       defined( _RHEOLEF_HAVE_MUMPS_WITH_SCOTCH) || \
+       defined( _RHEOLEF_HAVE_MUMPS_WITH_PTSCOTCH))
+			   // when nproc==1, prefer umfpack to mumps when mumps is compiled with poor ordering
+                           || opt.prefered_library == ""
+#endif // prefer umfpack when mumps has poor ordering
+                          ));
+#else  // !_RHEOLEF_HAVE_MUMPS
   bool prefer_cholmod = (a.dis_ext_nnz() == 0) && a.is_symmetric() && a.is_definite_positive(); // when sdp and diagonal per process
   bool prefer_umfpack = (a.dis_ext_nnz() == 0)  // when (unsym or (sym & undef)) & diag per proc
                       || (opt.prefered_library == "umfpack"); // explicitely prefer (more robust on ill-conditioned systems)
-#endif // _RHEOLEF_HAVE_MUMPS
+#endif // ! _RHEOLEF_HAVE_MUMPS
 
 #ifdef _RHEOLEF_HAVE_CHOLMOD
   if (prefer_cholmod) {
@@ -121,6 +130,7 @@ solver_rep<T,M>::build_lu (const csr<T,M>& a, const solver_option_type& opt)
 
 #ifdef _RHEOLEF_HAVE_UMFPACK
   if (prefer_umfpack) {
+    trace_macro ("use umfpack");
     // diagonal bloc per process => use umfpack
     typedef solver_umfpack_rep<T,M> rep;
     if (_ptr) delete_macro (_ptr);
@@ -130,6 +140,7 @@ solver_rep<T,M>::build_lu (const csr<T,M>& a, const solver_option_type& opt)
 #endif // _RHEOLEF_HAVE_UMFPACK
 
 #ifdef _RHEOLEF_HAVE_MUMPS
+  trace_macro ("use mumps");
   typedef solver_mumps_rep<T,M> rep;
 #elif defined(_RHEOLEF_HAVE_PASTIX)
   typedef solver_pastix_rep<T,M> rep;
