@@ -49,9 +49,10 @@
 #ifdef _RHEOLEF_HAVE_MUMPS
 #include "solver_mumps.h"
 
-#ifdef DEBUG_FROGGY
+#define DEBUG_MUMPS_SCOTCH
+#ifdef  DEBUG_MUMPS_SCOTCH
 #undef _RHEOLEF_HAVE_MUMPS_WITH_PTSCOTCH // has failed on some linear systems: prefer seq-scotch when available
-#endif // DEBUG_FROGGY
+#endif // DEBUG_MUMPS
 
 namespace rheolef {
 using namespace std;
@@ -317,10 +318,10 @@ solver_mumps_rep<T,M>::solver_mumps_rep (const csr<T,M>& a, const solver_option_
   if (is_distributed<M>::value) {
     _mumps_par.icntl[18-1] = 3; // distributed
 
-#if defined(_RHEOLEF_HAVE_MUMPS_WITH_PTSCOTCH) || defined(_RHEOLEF_HAVE_MUMPS_WITH_PARMETIS)
-    _mumps_par.icntl[28-1] = 2; // parallel ordering
-#elif defined(_RHEOLEF_HAVE_MUMPS_WITH_SCOTCH) || defined(_RHEOLEF_HAVE_MUMPS_WITH_METIS)
-    _mumps_par.icntl[28-1] = 1; // sequential ordering
+#if defined(_RHEOLEF_HAVE_MUMPS_WITH_SCOTCH) || defined(_RHEOLEF_HAVE_MUMPS_WITH_METIS)
+    _mumps_par.icntl[28-1] = 1; // sequential ordering (prefered, more robust)
+#elif defined(_RHEOLEF_HAVE_MUMPS_WITH_PTSCOTCH) || defined(_RHEOLEF_HAVE_MUMPS_WITH_PARMETIS)
+    _mumps_par.icntl[28-1] = 2; // parallel ordering (less robust, but faster)
 #endif // _RHEOLEF_HAVE_MUMPS_WITH_PTSCOTCH || _RHEOLEF_HAVE_MUMPS_WITH_PARMETIS
 
 #ifdef _RHEOLEF_HAVE_MUMPS_WITH_PTSCOTCH
@@ -357,6 +358,7 @@ solver_mumps_rep<T,M>::solver_mumps_rep (const csr<T,M>& a, const solver_option_
   }
   _mumps_par.job = 1;
   dmumps_c(&_mumps_par);
+  trace_macro ("symbolic: ordering effectively used = " << _mumps_par.infog[7-1]); // 3=scoth, etc
   check_macro (_mumps_par.infog[1-1] == 0, "mumps: error infog(1)="<<_mumps_par.infog[1-1]<<" has occured (see mumps/infog(1) documentation; infog(2)="<<_mumps_par.infog[2-1]<<")");
   update_values (a);
 }
