@@ -21,7 +21,7 @@
 /// 
 /// =========================================================================
 
-# include "rheolef/array.h"
+# include "rheolef/disarray.h"
 # include "boost/numeric/ublas/storage.hpp"
 
 namespace rheolef {
@@ -29,10 +29,14 @@ namespace rheolef {
 // for vec[range]:
 using boost::numeric::ublas::basic_range;
 using boost::numeric::ublas::range;
-template <class Expr>       struct vec_expr;
 template <class T, class M> class vec_range;
 template <class T, class M> class vec_range_const;
 
+namespace details {
+template <class Expr> struct is_vec;
+template <class Expr> struct is_vec_expr_v2_arg;
+} // namespace details
+
 // for vec = {x,y};
 template <class T, class M> class vec_concat_value;
 
@@ -52,8 +56,8 @@ EXAMPLE:
      @}
    @end example
 IMPLEMENTATION NOTE:
-   Implementation use array<T,M>.
-SEE ALSO: "array"(1)
+   Implementation use disarray<T,M>.
+SEE ALSO: "disarray"(1)
 AUTHORS: Pierre.Saramito@imag.fr
 DATE:   19 november 1998
 End:
@@ -61,26 +65,27 @@ End:
 
 //<vec:
 template <class T, class M = rheo_default_memory_model>
-class vec : public array<T, M> {
+class vec : public disarray<T, M> {
 public:
 
 // typedef:
 
-    typedef array<T, M> base;
+    typedef disarray<T, M> base;
+    typedef T                                                value_type;
     typedef typename base::size_type                         size_type;
     typedef std::ptrdiff_t                                   difference_type;
-#ifdef TODO
-    // pb compile avec boost sur foehn:
-    typedef typename base::difference_type                   difference_type;
-#endif // TODO
     typedef basic_range<size_type, difference_type>          range_type;
     typedef typename base::reference                         reference;
     typedef typename base::const_reference                   const_reference;
     typedef typename base::iterator                          iterator;
     typedef typename base::const_iterator                    const_iterator;
+    typedef typename float_traits <value_type>::type         float_type;
 
 // allocator/deallocator:
 
+    vec (const vec<T,M>&);
+    vec<T,M>& operator= (const vec<T,M>& x);
+
     vec (const distributor& ownership,
 	const T&  init_val = std::numeric_limits<T>::max());
 
@@ -100,6 +105,8 @@ public:
     const_reference operator[] (size_type i) const;
     reference       operator[] (size_type i);
 
+    T min () const;
+    T max () const;
     T max_abs () const;
 
 // range:
@@ -119,11 +126,21 @@ public:
 
 // expression template:
 
-    template<typename Expr>
-    vec (const vec_expr<Expr>& expr);
+    template <class Expr, 
+              class Sfinae
+	          = typename std::enable_if<
+			     details::is_vec_expr_v2_arg<Expr>::value
+			&& ! details::is_vec<Expr>::value
+		    >::type>
+    vec (const Expr& expr);
 
-    template<typename Expr>
-    vec<T,M>& operator= (const vec_expr<Expr>& expr);
+    template <class Expr,
+              class Sfinae 
+	          = typename std::enable_if<
+			     details::is_vec_expr_v2_arg<Expr>::value
+			&& ! details::is_vec<Expr>::value
+		    >::type>
+    vec<T, M>& operator=  (const Expr& expr);
 
 // initializer list (c++ 2011):
 
@@ -139,10 +156,24 @@ public:
 // ----------------------------------------------------------------------------
 template <class T, class M>
 inline
+vec<T,M>::vec (const vec<T,M>& x)
+  : disarray<T,M>(x)
+{
+}
+template <class T, class M>
+inline
+vec<T,M>&
+vec<T,M>::operator= (const vec<T,M>& x)
+{
+  disarray<T,M>::operator= (x);
+  return *this;
+}
+template <class T, class M>
+inline
 vec<T,M>::vec (
     const distributor& ownership,
     const T&  init_val)
-  : array<T,M>(ownership,init_val)
+  : disarray<T,M>(ownership,init_val)
 {
 }
 template <class T, class M>
@@ -150,7 +181,7 @@ inline
 vec<T,M>::vec (
     size_type dis_size,
     const T&  init_val)
-  : array<T,M>(dis_size,init_val)
+  : disarray<T,M>(dis_size,init_val)
 {
 }
 template <class T, class M>
@@ -171,12 +202,13 @@ vec<T,M>::resize (
 {
     base::resize (dis_size, init_val);
 }
+// TODO: group cstors vec(int) & vec(T) via Sfinae
 template <class T, class M>
 inline
 vec<T,M>&
 vec<T,M>::operator= (const int& expr)
 {
-    std::fill (array<T,M>::begin(), array<T,M>::end(), expr);
+    std::fill (disarray<T,M>::begin(), disarray<T,M>::end(), expr);
     return *this;
 }
 template <class T, class M>
@@ -184,7 +216,7 @@ inline
 vec<T,M>&
 vec<T,M>::operator= (const T& expr)
 {
-    std::fill (array<T,M>::begin(), array<T,M>::end(), expr);
+    std::fill (disarray<T,M>::begin(), disarray<T,M>::end(), expr);
     return *this;
 }
 template <class T, class M>
@@ -208,14 +240,14 @@ vec<T,M>::operator= (const vec_range<T,M>& vr)
 template <class T, class M>
 inline
 vec<T,M>::vec(const vec_range<T,M>& vr)
-  : array<T,M>()
+  : disarray<T,M>()
 {
     operator= (vr);
 }
 template <class T, class M>
 inline
 vec<T,M>::vec(const vec_range_const<T,M>& vr)
-  : array<T,M>()
+  : disarray<T,M>()
 {
     operator= (vr);
 }
@@ -248,7 +280,32 @@ vec<T,M>::operator[] (const range_type& r) const
     return vec_range_const<T,M> (*this, r);
 }
 template <class T, class M>
-inline
+T
+vec<T,M>::min () const
+{
+    T val = std::numeric_limits<T>::max();
+    for (const_iterator iter = base::begin(), last = base::end(); iter != last; iter++) {
+      val = std::min(val, *iter);
+    }
+#ifdef _RHEOLEF_HAVE_MPI
+    val = mpi::all_reduce (base::comm(), val, mpi::minimum<T>());
+#endif // _RHEOLEF_HAVE_MPI
+    return val;
+}
+template <class T, class M>
+T
+vec<T,M>::max () const
+{
+    T val = std::numeric_limits<T>::min();
+    for (const_iterator iter = base::begin(), last = base::end(); iter != last; iter++) {
+      val = std::max(val, *iter);
+    }
+#ifdef _RHEOLEF_HAVE_MPI
+    val = mpi::all_reduce (base::comm(), val, mpi::maximum<T>());
+#endif // _RHEOLEF_HAVE_MPI
+    return val;
+}
+template <class T, class M>
 T
 vec<T,M>::max_abs () const
 {
@@ -296,15 +353,30 @@ operator << (odiststream& ods, const vec<T,distributed>& x)
 {
     iorheo::flag_type format = iorheo::flags(ods.os()) & iorheo::format_field;
     if (format [iorheo::matlab] || format [iorheo::sparse_matlab]) {
-      warning_macro ("put_matlab");
       return x.put_matlab (ods);
     }
     // default is raw output
-    warning_macro ("put_default");
     return x.put_values(ods);
 }
 #endif // TO_CLEAN
 #endif // _RHEOLEF_HAVE_MPI
+// -------------------------------------------
+// norm(x) ; dot(x,y)
+// -------------------------------------------
+template<class T, class M>
+inline
+T
+norm2 (const vec<T,M>& x)
+{
+  return dot(x,x);
+}
+template<class T, class M>
+inline
+T
+norm (const vec<T,M>& x)
+{
+  return sqrt(norm2(x));
+}
 
 } // namespace rheolef
 #endif // _RHEO_VEC_H
