@@ -27,7 +27,8 @@
 namespace rheolef {
 
 template <class T, class M>
-struct vec_concat_value {
+class vec_concat_value {
+public:
 // typedef:
  typedef enum { scalar, scalars, vector} variant_type;
 // allocators:
@@ -55,7 +56,8 @@ public:
 };
 
 template <class T, class M>
-struct vec_concat {
+class vec_concat {
+public:
 // typedef:
   typedef typename vec<T,M>::size_type   size_type;
   typedef vec_concat_value<T,M>          value_type;
