@@ -27,5 +27,5 @@ NPROC_MAX=${NPROC_MAX-"7"}
 if test "$MPIRUN" = ""; then
   echo "      (skipped)"
 else 
-  loop_mpirun "./asr_exchange2_tst 2>/dev/null | diff ${SRCDIR}/asr_tst${DD_EXT}.mtx.valid - >/dev/null"
+  loop_mpirun "./asr_exchange2_tst 2>/dev/null | diff ${SRCDIR}/asr_tst${QD_EXT}.mtx.valid - >/dev/null"
 fi
