@@ -22,16 +22,18 @@
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
-    environment rheolef(argc, argv);
-    size_t n = (argc < 2) ? 5 : atoi(argv[1]);
-    asr<Float> a(n,n);
-    size_t first = a.row_first_index();
-    size_t last  = a.row_last_index();
-    for (size_t i = 0; i < n; i++) {
-    	if (i >= first && i < last) {
-	    a.dis_entry (i, i) = 1000+i+0.5;
-        }
+  environment rheolef(argc, argv);
+  size_t dis_n = (argc < 2) ? 5 : atoi(argv[1]);
+  communicator comm;
+  distributor ownership (dis_n, comm, distributor::decide);
+  asr<Float> a(ownership,ownership);
+  size_t first_dis_i = ownership.first_index();
+  size_t  last_dis_i  = ownership.last_index();
+  for (size_t dis_i = 0; dis_i < dis_n; dis_i++) {
+    if (dis_i >= first_dis_i && dis_i < last_dis_i) {
+      a.dis_entry (dis_i, dis_i) += 1000+dis_i+0.5;
     }
-    a.dis_entry_assembly();
-    dout << a;
+  }
+  a.dis_entry_assembly();
+  dout << a;
 }
