@@ -22,12 +22,12 @@
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
-    environment distributed(argc, argv);
+    environment rheolef(argc, argv);
     csr<Float> a;
-    dcin >> a;
+    din >> a;
     vec<Float> x (a.col_ownership(), 1.0);
     vec<Float> y (a.row_ownership(), 1e+38);
     a.mult (x, y);
-    dcout << y.dis_size() << endl
+    dout << y.dis_size() << endl
           << y            << endl;
 }
