@@ -22,6 +22,6 @@
 using namespace std;
 using namespace rheolef;
 int main(int argc, char**argv) {
-    environment distributed(argc, argv);
-    dcout << "io_proc = " << odiststream::io_proc() << endl;
+    environment rheolef(argc, argv);
+    dout << "io_proc = " << odiststream::io_proc() << endl;
 }
