@@ -25,7 +25,7 @@ NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
-loop_mpirun "./solver_ic0_tst < solver_tst.mm 2>/dev/null >/dev/null"
+loop_mpirun "./solver_ic0_tst < $SRCDIR/solver_tst.mtx 2>/dev/null >/dev/null"
 if test $? -ne 0; then status=1; fi
 
 i=5;
