@@ -24,4 +24,6 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"7"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-loop_mpirun "./vec_expr_tst 2>/dev/null | diff -w -B vec_expr_tst.valid - >/dev/null"
+if test "$QD_EXT" = ".float128"; then QD_EXT=""; fi
+
+loop_mpirun "./vec_expr_tst 2>/dev/null | diff -w -B $SRCDIR/vec_expr_tst${QD_EXT}.valid - >/dev/null"
