@@ -96,8 +96,8 @@ extern Real8 Grafh;
 
 Icoor2 inline det(const I2 &a,const I2 & b,const I2 &c)
 {
-  register  Icoor2 bax = b.x - a.x ,bay = b.y - a.y; 
-  register  Icoor2 cax = c.x - a.x ,cay = c.y - a.y; 
+    Icoor2 bax = b.x - a.x ,bay = b.y - a.y; 
+    Icoor2 cax = c.x - a.x ,cay = c.y - a.y; 
   return  bax*cay - bay*cax;}
 
 
@@ -287,15 +287,23 @@ class Edge { public:
 
 /////////////////////////////////////////////////////////////////////////////////////
 class GeometricalVertex :public Vertex {
-  int cas;
-  friend class Geometry;
-  GeometricalVertex * link; //  link all the same GeometricalVertex circular (Crack) 
 public:
+    int cas;
+    friend class Geometry;
+    GeometricalVertex * link; //  link all the same GeometricalVertex circular (Crack)
   int Corner() const {return cas&4;}
   int Required()const {return cas&6;}// a corner is required
   void  SetCorner(){ cas |= 4;}
   void  SetRequired(){ cas |= 2;}
   void  Set(){cas=0;}
+  void  Set(const Vertex & v)
+    { // add for bug in clang++ compile FH very strang and hard  ...
+        i=v.i;
+        r=v.r;
+        m=v.m;
+        t=v.t;
+        vint=v.vint;
+    }
   GeometricalVertex() :cas(0), link(this) {};
   GeometricalVertex * The() { assert(link); return link;}// return a unique vertices
   int IsThe() const { return link == this;}  
@@ -428,9 +436,9 @@ class Triangle {
 
   void SetAdjAdj(Int1 a) 
   { a &= 3;
-   register  Triangle *tt=at[a];
+     Triangle *tt=at[a];
    aa [a] &= 55; // remove MarkUnSwap
-   register Int1 aatt = aa[a] & 3;
+    Int1 aatt = aa[a] & 3;
    if(tt){ 
      tt->at[aatt]=this;
      tt->aa[aatt]=a + (aa[a] & 60 ) ;}// Copy all the mark 
@@ -459,11 +467,11 @@ class Triangle {
   void SetAllFlag(int a,int f){aa[a] = (aa[a] &3) + (1020 & f);}
 
   void SetHidden(int a){
-   register Triangle * t = at[a];
+    Triangle * t = at[a];
     if(t) t->aa[aa[a] & 3] |=16;
     aa[a] |= 16;}
   void SetCracked(int a){
-   register Triangle * t = at[a];
+    Triangle * t = at[a];
     if(t) t->aa[aa[a] & 3] |=32;
     aa[a] |= 32;}
   
@@ -471,18 +479,18 @@ class Triangle {
   Triangle * Quadrangle(Vertex * & v0,Vertex * & v1,Vertex * & v2,Vertex * & v3) const ;
 
   void SetLocked(int a){
-    register Triangle * t = at[a];
+     Triangle * t = at[a];
     t->aa[aa[a] & 3] |=4;
     aa[a] |= 4;}
 
   void SetMarkUnSwap(int a){
-    register Triangle * t = at[a];
+     Triangle * t = at[a];
     t->aa[aa[a] & 3] |=8;
     aa[a] |=8 ;}
 
 
   void SetUnMarkUnSwap(int a){ 
-    register Triangle * t = at[a];
+     Triangle * t = at[a];
     t->aa[aa[a] & 3] &=55; // 23 + 32 
     aa[a] &=55 ;}
   
@@ -580,7 +588,7 @@ class SegInterpolation {
 //  void CopyMetric(const Metric & mm,int j){ lIntTria[j].m=mm;}
 
   void ReShape() { 
-    register int newsize = MaxSize*2;
+     int newsize = MaxSize*2;
     IntersectionTriangles * nw = new IntersectionTriangles[newsize];
     assert(nw);
     for (int i=0;i<MaxSize;i++) // recopy
@@ -786,6 +794,7 @@ public:
   Vertex ** ordre;
   SubDomain * subdomains;
   ListofIntersectionTriangles  lIntTria;
+  int warning ;
 // end of variable
   
   Triangles(Int4 i);//:BTh(*this),Gh(*new Geometry()){PreInit(i);}
@@ -1145,11 +1154,12 @@ inline void VertexOnGeom::Set(const VertexOnGeom & rec,const Triangles & Th ,Tri
   *this = rec;  
   mv = ThNew.vertices + Th.Number(mv);
   if (gv)
+  {
     if (abscisse < 0 )
       gv = ThNew.Gh.vertices + Th.Gh.Number(gv);
     else
       ge = ThNew.Gh.edges + Th.Gh.Number(ge);
-  
+  }
 }
 inline Real8 Edge::MetricLength() const
   { 
@@ -1158,7 +1168,7 @@ inline Real8 Edge::MetricLength() const
 
 inline  void  Triangles::ReMakeTriangleContainingTheVertex()
  {
-  register Int4 i;
+   Int4 i;
   for ( i=0;i<nbv;i++) 
     {
 	vertices[i].vint = 0;
@@ -1170,7 +1180,7 @@ inline  void  Triangles::ReMakeTriangleContainingTheVertex()
 
 inline  void  Triangles::UnMarkUnSwapTriangle()
  {
-  register Int4 i;
+   Int4 i;
   for ( i=0;i<nbt;i++) 
     for(int  j=0;j<3;j++)
       triangles[i].SetUnMarkUnSwap(j);
@@ -1255,7 +1265,7 @@ inline Real4 qualite(const Vertex &va,const Vertex &vb,const Vertex &vc)
        b = sqrt((Real8) (bc,bc)),
        c = sqrt((Real8) (ab,ab)),
        p = a+b+c;
-     Real8 h= Max(Max(a,b),c),ro=deta/p;
+     Real8 h= Max(Max(a,b),c),ro=Real8(deta)/p;
    ret = ro/h;}
   return ret;
 }
@@ -1307,8 +1317,8 @@ Int4 inline  Vertex::Optim(int i,int koption)
 
 Icoor2 inline det(const Vertex & a,const Vertex & b,const Vertex & c)
 {
-  register  Icoor2 bax = b.i.x - a.i.x ,bay = b.i.y - a.i.y; 
-  register  Icoor2 cax = c.i.x - a.i.x ,cay = c.i.y - a.i.y; 
+    Icoor2 bax = b.i.x - a.i.x ,bay = b.i.y - a.i.y; 
+    Icoor2 cax = c.i.x - a.i.x ,cay = c.i.y - a.i.y; 
   return  bax*cay - bay*cax;}
 
 
