@@ -50,7 +50,7 @@ void Triangles::ConsGeometry(Real8 cutoffradian,int *equiedges) // construct a g
   //       
   // --------------------------
   if (verbosity>1) 
-    cout << " -- construction of the geometry from the 2d mesh " << endl;
+    cout << "  -- construction of the geometry from the 2d mesh " << endl;
   if (nbt<=0 || nbv <=0 ) { MeshError(101);}
 
   // construction of the edges 
@@ -196,16 +196,16 @@ void Triangles::ConsGeometry(Real8 cutoffradian,int *equiedges) // construct a g
 	  if (add>=0 && add < nbe)
 	    {
 	      
-		 edges[add].v[0] = &triangles[it][VerticesOfTriangularEdge[j][0]];
-		 edges[add].v[1] = &triangles[it][VerticesOfTriangularEdge[j][1]];
-		  edges[add].on=0; 
-		 if (i<nbeold) // in file edge // Modif FH 06122055 
-		 {
-		    edges[add].ref = edgessave[i].ref; 		      
-		    edges[add].on = edgessave[i].on; //  HACK pour recuperer les aretes requise midf FH avril 2006 ???? 
-		    }
-		 else
-		   edges[add].ref = Min(edges[add].v[0]->ref(),edges[add].v[1]->ref()); // no a good choice
+	      edges[add].v[0] = &triangles[it][VerticesOfTriangularEdge[j][0]];
+	      edges[add].v[1] = &triangles[it][VerticesOfTriangularEdge[j][1]];
+	      edges[add].on=0; 
+	      if (i<nbeold) // in file edge // Modif FH 06122055 
+		{
+		  edges[add].ref = edgessave[i].ref; 		      
+		  edges[add].on = edgessave[i].on; //  HACK pour recuperer les aretes requise midf FH avril 2006 ???? 
+		}
+	      else
+		edges[add].ref = Min(edges[add].v[0]->ref(),edges[add].v[1]->ref()); // no a good choice
 	    }
 	}
       assert(k==nbe);
@@ -298,7 +298,7 @@ void Triangles::ConsGeometry(Real8 cutoffradian,int *equiedges) // construct a g
       for (int j=0;j<3;j++)
 	{
 	  tt=triangles[it].TriangleAdj(j);
-	  if ((!tt || tt->color != triangles[it].color) && !subdomains[isd=colorT[it]].head)
+	  if ((!tt ||  triangles[it].Locked(j) || tt->color != triangles[it].color) && !subdomains[isd=colorT[it]].head)
 	    {
 	      subdomains[isd].head = triangles+it;
 	      subdomains[isd].ref =  triangles[it].color;
@@ -339,25 +339,44 @@ void Triangles::ConsGeometry(Real8 cutoffradian,int *equiedges) // construct a g
   VerticesOnGeomVertex = new VertexOnGeom[NbVerticesOnGeomVertex];
   NbVerticesOnGeomEdge =0;
   VerticesOnGeomEdge =0;
+  for (i=0;i<Gh.nbv;i++)
+      Gh.vertices[i].Set();// bug clang ???? FH 09/2012
+     if(verbosity>6){
+         int nbr=0;
+         for (i=0;i<Gh.nbv;i++)
+             if( Gh.vertices[i].Required()) nbr++;
+         cout << " --00 nb  require  v in Gh " << nbr << " on " << Gh.nbv << endl;
+     }
+     
   {
     Int4 j;
     for (i=0;i<nbv;i++) 
       if((j=colorV[i])>=0)
 	{
-	  
-	  Vertex & v = Gh.vertices[j];
-	  v = vertices[i];
-	  v.color =0;
+            int k=Gh.vertices[j].cas;
+            Gh.vertices[j].Set(vertices[i]);
+	//  Vertex & v = Gh.vertices[j];
+	 // v = vertices[i];
+	   Gh.vertices[j].color =0;
+            assert(k==Gh.vertices[j].cas);
 	  VerticesOnGeomVertex[j] = VertexOnGeom(vertices[i], Gh.vertices[j]);
 	}
     
   }
+     
   edge4= new SetOfEdges4(nbe,nbv);  
   
   Real4 * len = new Real4[Gh.nbv];
   for(i=0;i<Gh.nbv;i++)
     len[i]=0;
-  
+     if(verbosity>6){
+         int nbr=0;
+         for (i=0;i<Gh.nbv;i++)
+             if( Gh.vertices[i].Required()) nbr++;
+         cout << " --bb nb  require  v in Gh " << nbr << " on " << Gh.nbv
+         <<endl;
+     }
+
   Gh.pmin =  Gh.vertices[0].r;
   Gh.pmax =  Gh.vertices[0].r;
   // recherche des extrema des vertices pmin,pmax
@@ -374,9 +393,9 @@ void Triangles::ConsGeometry(Real8 cutoffradian,int *equiedges) // construct a g
   
   Gh.coefIcoor= (MaxICoor)/(Max(Gh.pmax.x-Gh.pmin.x,Gh.pmax.y-Gh.pmin.y));
   assert(Gh.coefIcoor >0);
-  
+ 
   Real8 hmin = HUGE_VAL;
-     int kreq=0;
+     int kreq=0,kkreq=0;
   for (i=0;i<nbe;i++)
     {
       Int4 i0 = Number(edges[i][0]);
@@ -407,13 +426,14 @@ void Triangles::ConsGeometry(Real8 cutoffradian,int *equiedges) // construct a g
         }
 	
        }
-	if(requis)  {  // correction fevr 2009 JYU ...
-	    Gh.edges[i].v[0]->SetRequired();
-	    Gh.edges[i].v[1]->SetRequired();
-	    Gh.edges[i].SetRequired(); // fin modif ... 
-	}
+      if(requis)  {  // correction fevr 2009 JYU ...
+	Gh.edges[i].v[0]->SetRequired();
+	Gh.edges[i].v[1]->SetRequired();
+	Gh.edges[i].SetRequired(); // fin modif ...
+          kkreq++;
+      }
       R2 x12 = Gh.vertices[j0].r-Gh.vertices[j1].r;
-      Real8 l12=Norme2(x12);        
+      Real8 l12=Norme2(x12);
       hmin = Min(hmin,l12);
       
       Gh.vertices[j1].color++;
@@ -430,7 +450,14 @@ void Triangles::ConsGeometry(Real8 cutoffradian,int *equiedges) // construct a g
       assert(k == i);
       
     }
-  
+     if(verbosity>6){
+         int nbr=0;
+         for (i=0;i<Gh.nbv;i++)
+             if( Gh.vertices[i].Required()) nbr++;
+         cout << " --11 nb  require  v in Gh " << nbr << " on " << Gh.nbv
+              << " kreq =" << kreq<<" kkreq=" << kkreq <<endl;
+     }
+ 
   
   for (i=0;i<Gh.nbv;i++) 
     if (Gh.vertices[i].color > 0) 
@@ -463,8 +490,13 @@ void Triangles::ConsGeometry(Real8 cutoffradian,int *equiedges) // construct a g
   for (i=0;i<nbt;i++)
     for ( j=0;j<3;j++)
       triangles[i].SetAdj2(j,0,triangles[i].GetAllflag(j));
-  
-}
+     if(verbosity>6){
+         int nbr=0;
+         for (i=0;i<Gh.nbv;i++)
+             if( Gh.vertices[i].Required()) nbr++;
+         cout << " -- nb  required  v in Gh " << nbr << " on " << Gh.nbv << endl;
+     }
+ }
 
 
 void Geometry::EmptyGeometry()  // empty geometry
@@ -609,7 +641,7 @@ retry:
           // if (NbTry) cout <<"Read (int) to Show Sioux window", cin >> kkk ;
 	       if(NbTry) 
 	          {
-		    cerr << " --Fatal Error: on the class triangles before call Geometry::ProjectOnCurve" << endl; 
+		    cerr << " -- Fatal Error: on the class triangles before call Geometry::ProjectOnCurve" << endl; 
 		    cerr << "   The mesh of the  Geometry is to fine: ";
 		    cerr << "     1)  a mesh edge  contening more than "<< mxe/2 << " geometrical edges." << endl;
 		    cerr << "     2)  code bug : be sure that we call   Triangles::SetVertexFieldOn() before " << endl;
@@ -672,7 +704,7 @@ retry:
     Real8 sg;
     //   cout << "           " << Number(on) << " " <<  Number(eg0) << " " <<  Number(eg1) << " "  ; 
     if (eg0 == eg1) { 
-       register Real8 s0= vg0,s1=vg1;
+        Real8 s0= vg0,s1=vg1;
        sg =  s0 * (1.0-s) +  s * s1;
        //    cout <<"                s0=" << s0 << " s1=" << s1 
        //             << " s = " << s << " sens= " << OppositeSens << "\t\t sg = " << sg << endl ;
@@ -837,14 +869,14 @@ void Geometry::AfterRead()
         exch = 0;
         Int4  *p =  hv + i, *po = p;
 	Int4 n = *p;
-        register float angleold = -1000 ; // angle = - infini 
+         float angleold = -1000 ; // angle = - infini 
         ord = 0;
         while (n >=0) 
         {
           ord++;
-          register Int4 i1= n /2;
-          register Int4  j1 = n % 2;
-          register Int4 *pn = ev + n;
+           Int4 i1= n /2;
+           Int4  j1 = n % 2;
+           Int4 *pn = ev + n;
           float angle = j1 ? OppositeAngle(eangle[i1]):  eangle[i1];
           n = *pn;
           if (angleold > angle) // exch to have : po -> pn -> p 
@@ -953,7 +985,7 @@ void Geometry::AfterRead()
 		     << edges[i].v[1-jj]->r.y -edges[i].Adj[jj]->v[1-edges[i].SensAdj[jj]]->r.y <<  endl;
 		*/
 	       }
-	       else {tg=R2(0,0); if (verbosity>6) cout << "Corner without tangent, edge " <<i << " end " << jj << endl; }
+	       
 	       //else ;// a Corner with no tangent => nothing to do    
              } // a tg 
              else 
@@ -1052,13 +1084,7 @@ void Geometry::AfterRead()
     for(int i=0;i<NbOfCurves ;i++)
      {
         cout << " Curve " << i << " begin e=" << Number(curves[i].be) << " k=" << curves[i].kb 
-		<< " vert=" << Number(edges[Number(curves[i].be)].v[curves[i].kb])
-		<< " Corner?=" << ((edges[Number(curves[i].be)].v[curves[i].kb])->Corner()?"y":"n")
-		<< " tg=" << edges[Number(curves[i].be)].tg[curves[i].kb] 
-             << "  end e= " << Number(curves[i].ee) << " k=" << curves[i].ke 
-		<< " vert=" << Number(edges[Number(curves[i].ee)].v[curves[i].ke])
-		<< " Corner?=" << ((edges[Number(curves[i].ee)].v[curves[i].ke])->Corner()?"y":"n")
-		<< " tg=" << edges[Number(curves[i].ee)].tg[curves[i].ke] << endl;
+             << "  end e= " << Number(curves[i].ee) << " k=" << curves[i].ke << endl;
      }
     delete []ev;
     delete []hv;
