@@ -62,7 +62,7 @@ void Triangles::Write(const char * filename,const TypeFileMesh typein )
     } 
   if (verbosity>1)
     {
-      cout << " -- Writing the file " << filename << " of type " ;
+      cout << "  -- Writing the file " << filename << " of type " ;
      switch (type) 
        {
        case BDMesh     :  cout << " BD Mesh "  ; break;
@@ -104,8 +104,8 @@ void Triangles::Write(const char * filename,const TypeFileMesh typein )
                   f << Gh ;
                   Gh.OnDisk=true;
               }
-            f << *this     ;
-               break;
+	     f << *this     ;
+	     break;
            }
        case NOPOMesh   :  Write_nopo(f)  ; break;
        case amMesh     :  Write_am(f)    ; break;
@@ -767,7 +767,7 @@ ostream& operator <<(ostream& f, const   Triangles & Th)
 	   Triangle * tb = Th.BTh.FindTriangleContening(I,dete);
 	   if (tb->link) // a true triangle
 	     {
-	       Real8 aa= (Real8) dete[1]/ tb->det, bb= (Real8) dete[2] / tb->det;
+	       Real8 aa= Real8(dete[1])/Real8(tb->det), bb= Real8(dete[2])/Real8(tb->det);
 	       f << i+1 << " " << Th.BTh.Number(tb)+1 << " " << aa << " " << bb << endl ;
 	     }
 	   else 
@@ -802,7 +802,7 @@ void Geometry::Write(const char * filename)
   if (f)
     {
       if(verbosity>1)
-	cout << " -- write geometry in file " << filename << endl;
+	cout << "  -- write geometry in file " << filename << endl;
        if (name) delete name;
        name = new char[strlen(filename)+1];
        strcpy(name,filename);
