@@ -782,9 +782,9 @@ int main(int argc, char **argv)
 		     Triangle & tb = *Th.BTh.FindTriangleContening(I,dete);
 		     
 		     if (tb.det>0) { // internal point 
-		       a[0]= (Real8) dete[0]/ tb.det;
-		       a[1]= (Real8) dete[1] / tb.det;
-		       a[2] = (Real8) dete[2] / tb.det;
+		       a[0]= Real8(dete[0])/Real8(tb.det);
+		       a[1]= Real8(dete[1])/Real8(tb.det);
+		       a[2]= Real8(dete[2])/Real8(tb.det);
 		       i0=Th.BTh.Number(tb[0]);
 		       i1=Th.BTh.Number(tb[1]);
 		       i2=Th.BTh.Number(tb[2]);}
