@@ -42,7 +42,7 @@
 //       c) in iorheo constructor initializer
 //
 # include "rheolef/iorheo.h"
-using namespace rheolef;
+namespace rheolef {
 using namespace std;
 
 //
@@ -188,13 +188,13 @@ iorheo::~iorheo()
 // trivial memory handler instanciation
 // ---------------------------------------------------------------------
 
-// class instanciation:
-template class iorheobase_memory_handler<iorheo>;
-
 // static variable initialization in template class:
 template <>
 list<iorheo*> *iorheobase_memory_handler<iorheo>::pointer_list = 0;
 
+// class instanciation:
+template class iorheobase_memory_handler<iorheo>;
+
 iorheo* 
 iorheo::get_pointer (ios& s)
 {
@@ -267,3 +267,4 @@ iorheo::unsetf (ios& s, size_type i_del)
 	return iorheo::get_pointer(s) -> unsetf (i_del);
 }
 
+} // namespace rheolef
