@@ -186,7 +186,7 @@ int
 smart_pointer_base<T,C>::counter::operator-- ()
 { 
     if (--_n != 0) return _n;
-    delete_macro(this);
+    delete(this);
     return 0;
 }
 // -----------------------------------------------------------------------
