@@ -90,7 +90,7 @@ public:
     stack_allocator (unsigned char* stack, size_t stack_size) throw()
       : handler (new handler_type (stack, stack_size))
     {
-	warning_macro ("stack_allocator cstor");
+	trace_macro ("stack_allocator cstor");
     }
     stack_allocator (const stack_allocator& sa) throw()
       : handler (sa.handler)
@@ -105,7 +105,7 @@ public:
     }
     ~stack_allocator() throw()
     {
-	warning_macro ("stack_allocator dstor");
+	trace_macro ("stack_allocator dstor");
         check_macro (handler != NULL, "unexpected null mem_info");
         if (--handler->reference_count == 0) delete handler;
     }
@@ -150,20 +150,20 @@ public:
 
     pointer allocate (size_type n, const void* = NULL)
     {
-	warning_macro ("allocate "<<n<<" type " << typename_macro(T));
+	trace_macro ("allocate "<<n<<" type " << typename_macro(T));
         check_macro (handler->stack != NULL, "unexpected null stack");
         void* p = handler->stack + handler->allocated_size;
         handler->allocated_size += n*sizeof(T);
 
         if (handler->allocated_size + 1 > handler->max_size) {
-	    warning_macro ("stack is full: throwing...");
+	    trace_macro ("stack is full: throwing...");
             throw std::bad_alloc();
 	}
         return pointer (p);
     }
     void deallocate (pointer p, size_type n)
     {
-	warning_macro ("deallocate "<<n<<" type "<<typename_macro(T));
+	trace_macro ("deallocate "<<n<<" type "<<typename_macro(T));
         // No need to free stack memory
     }
     const handler_type* get_handler() const {
@@ -185,7 +185,7 @@ protected:
             max_size (0),
             reference_count (1)
         {
-	  warning_macro ("stack_allocator::mem_info cstor NULL");
+	  trace_macro ("stack_allocator::mem_info cstor NULL");
         }
         handler_type (unsigned char* stack1, size_t size1)
           : stack (stack1),
@@ -193,11 +193,11 @@ protected:
             max_size (size1),
             reference_count (1)
         {
-	  warning_macro ("stack_allocator::mem_info cstori: size="<<max_size);
+	  trace_macro ("stack_allocator::mem_info cstori: size="<<max_size);
         }
         ~handler_type()
         {
-	  warning_macro ("stack_allocator::mem_info dstor: size="<<max_size);
+	  trace_macro ("stack_allocator::mem_info dstor: size="<<max_size);
 	}
     };
     handler_type* handler;
