@@ -32,8 +32,8 @@
 #include <ctime>
 #endif
 
-using namespace std;
 namespace rheolef {
+//using namespace std; // pb with clang++ here
 double the_clock()
 {
 #if defined(_RHEOLEF_HAVE_CLOCK_GETTIME)
