@@ -19,6 +19,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-echo "      echo ${SRCDIR}/ipstream_tst.cc | ${RUN} ./ipstream_tst"
-echo ${SRCDIR}/ipstream_tst.cc | ${RUN} ./ipstream_tst 2> /dev/null | \
-    diff ${SRCDIR}/ipstream_tst.cc -
+TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+. "${TOP_SRCDIR}/config/loop_mpirun.sh"
+
+run "echo ${SRCDIR}/ipstream_tst.cc | ./ipstream_tst 2>/dev/null | diff ${SRCDIR}/ipstream_tst.cc - >/dev/null"
+status=$?
+exit $status
