@@ -19,8 +19,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"../../../rheolef/util/tst"}
-echo "      ${RUN} ./opstream_tst < ${SRCDIR}/opstream_tst.cc"
-${RUN} ./opstream_tst 2>/dev/null < ${SRCDIR}/opstream_tst.cc | \
-	diff ${SRCDIR}/opstream_tst.cc -
+TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+. "${TOP_SRCDIR}/config/loop_mpirun.sh"
+SRCDIR=${SRCDIR-"."}
 
+run "./opstream_tst 2>/dev/null < ${SRCDIR}/opstream_tst.cc | diff ${SRCDIR}/opstream_tst.cc -"
+status=$?
+exit $status
